/*

-----DbHikePersonalInformation---------------------------------------------
  -----DESCRIPTION-----
    Using these scripts to remove any personal information and identification
    associated with the samples so we can use the samples for validation of
    the HL7 project.
    
    Note, we could use TRUNCATE TABLE, but going with Delete to make sure 
    all dependenies have been identified, and to try to avoid having orphand
    records.
    
    The following actions will be taken:
      01. Communications Wipe
      02. Reports Wipe
      03. Wipe External Patient and Sample ID Info
      04. Randomize patient name, dob and sex
      05. Shuffle Patient Street Address
      06. Sync Sample Patient Info to Patient table Info
      07. Shuffle Provider Inforamation
      08. Folder Notes And Comments Update
      09. Chemistry - Delete Dynamicdata (10.2) flat table records
      10. Chemistry - Delete Dynamicdata108 flat table records
      11. Chemistry - Shuffle Client in CentralReceiving and Metadata repository
      12. Chemistry - Randomize patient Date of Death and Case number
      
  ----- -----
  
  -----HISTORY-----
    --2020.01.23: Update script from existing wipe script
    --2020.10.28: Updated script (Chemistry)
  ----- -----


---------------------------------------------------------------------------
*/



-----01. Communications Wipe-----------------------------------------------
  --Wipe all communication logs and associated attachements.
/*  
  ---Review Table Records---
    SELECT * FROM communication_log;
    SELECT * FROM communication_attach;
    SELECT * FROM communication_follow_up;
  ----- -----
  
  -----Wipe all data from tables-----
    DELETE FROM communication_follow_up;
    DELETE FROM communication_attach;
    DELETE FROM communication_log;
  ----- -----
*/  
---------------------------------------------------------------------------




-----02. Reports Wipe------------------------------------------------------
  --Wipe out any existing reports and attachements.
/*  
  -----Review Table Records-----
    SELECT * FROM res_attachments ra;
    SELECT * FROM rr_rdq_history rdh;
    SELECT * FROM rr_report_delivery_queue rdq;
  ----- -----
  
  -----Wipe all data from tables-----
    DELETE FROM res_attachments ra;
    DELETE FROM rr_rdq_history rdh;
    DELETE FROM rr_report_delivery_queue rdq;
    DELETE FROM rr_batchstatus rs;
    DELETE FROM rr_batchstatus rs;
  ----- -----


  
*/
---------------------------------------------------------------------------





-----03. Wipe External Patient and Sample ID Info--------------------------
  --Remove any references to PatientID used by external organizations to 
  --identify the patient
/*
  -----Review Table Records-----
    SELECT 
      p.patient_id, 
      cr.pid,
      cr.client_sample_id,      
      p.external_pid1,
      p.external_pid2,
      p.external_pid3,
      p.external_pid4,
      p.external_pid5,      
      p.external_pid6,
      p.external_patient_id,
      '~' AS eol
    FROM patients p
      left JOIN centralreceiving CR ON (p.patient_id = cr.patient_id) 
    WHERE 1=1
      AND (
        cr.pid || cr.client_sample_id ||
        p.external_pid1   || p.external_pid2 || p.external_pid3  ||
        p.external_pid4   || p.external_pid5 || p.external_pid6  ||
        p.external_patient_id
     ) IS NOT NULL
      --AND p.date_of_birth IS NOT NULL
      --AND p.patient_id IN (&PatientList)
    ORDER BY
      p.patient_id DESC;
  ----- -----

  -----Take Action-----
    UPDATE patients p 
    SET
      p.external_patient_id = NULL,
      p.external_pid1 = NULL,
      p.external_pid2 = NULL,
      p.external_pid3 = NULL,
      p.external_pid4 = NULL,
      p.external_pid5 = NULL,
      p.external_pid6 = NULL;
      
    UPDATE centralreceiving cr
    SET
      cr.pid = NULL,
      cr.client_sample_id = NULL;      
  ----- -----
*/
---------------------------------------------------------------------------




-----04. Randomize patient name, dob and sex-------------------------------
  --This script will update the following Patient fields:
    --first_name: Set to Random string
    --last_name:  Set to Random string
    --middle_name: Set to nothing
    --date_of_birth: Random date between 01/01/1950 - systemdate
    --sex: Random M/F
/*
  -----Review Table Records-----
    SELECT 
      p.patient_id,
      p.first_name,
      p.middle_name,
      p.last_name,
      p.date_of_birth,
      p.age,
      p.sex,
      '~' AS eol
    FROM patients p
    WHERE 1=1
    and last_name not like 'PT%'
    AND p.patient_id IN (&PatientList);
  ----- -----
  
  -----Randomize Patient Fields-----
    MERGE INTO patients t1
    USING (
      ---CORE QUERY---
        SELECT DISTINCT
          p.patient_id,
          ('FN_' || DBMS_RANDOM.string('a', 12)) AS ran_first,
          ('') AS ran_middle,
          ('LN_' || DBMS_RANDOM.string('a', 10)) AS ran_last,
          (TO_DATE(TRUNC(
            DBMS_RANDOM.VALUE(TO_CHAR(DATE '1950-01-01','J')
            ,TO_CHAR(SYSDATE,'J'))),'J')) AS ran_bdate,          
          p.date_of_birth,
          p.age,
          TRANSLATE( trunc(dbms_random.value(1,3)), '12','MF') AS ran_sex,
          '~' AS eol
        FROM patients p      
        WHERE 1=1
        and last_name not like 'PT%'
      --- ---
    ) t2
    ON (t1.patient_id = t2.patient_id)
    WHEN MATCHED THEN
      UPDATE SET
        t1.first_name = t2.ran_first,
        t1.middle_name = t2.ran_middle,
        t1.last_name = t2.ran_last,
        t1.date_of_birth = t2.ran_bdate,
        t1.sex = t2.ran_sex;
  ----- -----
  

  -----Recalulate patent age -----
    UPDATE patients p
    SET
      p.age = COALESCE(trunc(MONTHS_BETWEEN(sysdate, trunc(p.date_of_birth))/12), NULL)
    WHERE 1=1
      AND p.date_of_birth IS NOT NULL;
  ----- -----
  
*/
---------------------------------------------------------------------------




-----05. Shuffle Patient Screet Address------------------------------------
  --Descript Action
/*
  -----Review Table Records-----
    SELECT 
      pa.patient_id, 
      pa.address_type,
      pa.address,
      '~' AS eol
    FROM patient_addresses pa
    WHERE 1=1
      AND pa.address IS NOT NULL
    ORDER BY
      pa.patient_id DESC;
  ----- -----
  
  -----Take Action-----
    MERGE INTO patient_addresses t1
    USING (
      WITH
        MyMapping AS (
          SELECT 
            pa.patient_id,
            pa.address,
            pa.address_type,
            rownum AS org_row,
           row_number() OVER (ORDER BY dbms_random.value) AS rnd_row,
            '~' AS eol
          FROM patient_addresses pa
          WHERE 1=1
            AND pa.address IS NOT NULL
          ORDER BY
            pa.patient_id ASC,
            pa.address_type ASC
        )
        SELECT
          mm.patient_id,
          mm.address_type,
          mm.address,
          mm2.address AS rnd_address,
          '~' AS eol
        FROM MyMapping mm
        INNER JOIN MyMapping mm2 ON (mm.rnd_row = mm2.org_row)
        WHERE 1=1
        ORDER BY 
          mm.patient_id ASC,
          mm.address_type ASC     
    ) t2
    ON (1=1
        AND t1.patient_id = t2.patient_id
        AND t1.address_type = t2.address_type
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.address = t2.rnd_address;
  ----- -----
*/
---------------------------------------------------------------------------




-----06. Sync Sample Patient Info to Patient table Info--------------------
  --Take the updated Patient Information and syncrinize to the sample
  --patient information.
/*  
  -----Review Table Records-----
    SELECT 
      p.patient_id,
      p.first_name AS p_firstname,
      cr.first_name AS cr_firstname,
      p.middle_name AS p_mn,
      cr.middle_initial AS cr_mn,
      p.last_name AS p_lastname,
      cr.last_name AS cr_lastname,
      p.sex AS p_sex,
      cr.sex AS cr_sex,
      p.date_of_birth AS p_dob,
      cr.birth_date AS cr_dob,
      p.age AS p_age,
      mr.field_integer_01 AS cr_age,
      '~' AS eol
    FROM patients p
      INNER JOIN centralreceiving cr ON (p.patient_id = cr.patient_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
    ORDER BY
      p.patient_id DESC;
  ----- -----
  
  -----Sync CentralReceiving information to Patient information-----
    MERGE INTO centralreceiving t1
    USING (
      SELECT DISTINCT
        p.patient_id,
        p.first_name,
        p.middle_name,
        p.last_name,
        p.sex,
        p.date_of_birth,
        p.age,
        '~' AS eol
      FROM patients p
      WHERE 1=1
      ORDER BY
        p.patient_id ASC      
    ) t2
    ON (t1.patient_id = t2.patient_id)
    WHEN MATCHED THEN
      UPDATE SET
        t1.first_name = t2.first_name,
        t1.middle_initial = t2.middle_name,
        t1.last_name = t2.last_name,
        t1.sex = t2.sex,
        t1.birth_date = t2.date_of_birth;      
  ----- -----
  -----Sync CR Patient Age, kept in MetaData_Repository table-----
    MERGE INTO metadata_repository t1
    USING (
      SELECT 
        p.patient_id,
        p.age AS p_age,
        mr.origrec AS mr_origrec,
      --  mr.field_integer_01,
        '~' AS eol
      FROM patients p
        INNER JOIN centralreceiving cr ON (p.patient_id = cr.patient_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      WHERE 1=1
      ORDER BY
        p.patient_id DESC
    ) t2
    ON (t1.origrec = t2.mr_origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.field_integer_01 = t2.p_age;      
  ----- -----
*/
---------------------------------------------------------------------------




-----07. Shuffle Provider Inforamtion---------------------------------------------------------
  --We are going to shuffle the provider infromation in the CentralReceviing table.
  --When provider information is entered (Looking for street address) we will
  --shuffle that with another provider in the CentralReceving table
/*  
  
  -----Review Table Records-----
    SELECT 
      cr.patient_id,
      mr.field_varchar_20 AS provider_name,
      mr.field_varchar_21 AS facility_name,
      mr.field_varchar_22 AS street_address,
      mr.field_varchar_23 AS city,
      mr.field_varchar_24 AS state,
      mr.field_varchar_25 AS zip_code,
      mr.field_varchar_26 AS county,
      mr.field_varchar_27 AS telephone,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND cr.patient_id IS NOT NULL
      AND cr.
      AND mr.field_varchar_22 IS NOT NULL
    ORDER BY
      cr.patient_id DESC;
  ----- -----
  
  -----Perofrm Provider Shuffle-----
    MERGE INTO metadata_repository t1
    USING (
      WITH
        MyMapping AS (
          SELECT 
            cr.external_id,
            cr.patient_id,
            mr.origrec AS mr_origrec,
            mr.field_varchar_20 AS provider_name,
            mr.field_varchar_21 AS facility_name,
            mr.field_varchar_22 AS street_address,
            mr.field_varchar_23 AS city,
            mr.field_varchar_24 AS state,
            mr.field_varchar_25 AS zip_code,
            mr.field_varchar_26 AS county,
            mr.field_varchar_27 AS telephone,
            rownum AS org_row,
            row_number() OVER (ORDER BY dbms_random.value) AS rnd_row,
            '~' AS eol
          FROM centralreceiving cr
          INNER JOIN metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
        WHERE 1=1
          AND cr.patient_id IS NOT NULL
          AND mr.field_varchar_22 IS NOT NULL
        ORDER BY
          cr.external_id DESC,
          cr.patient_id DESC
        )
        SELECT
          mm.mr_origrec,
          mm.external_id,
          mm.provider_name,
          mm.street_address,
          '~' AS sp1,
          mm2.mr_origrec AS rnd_mr_origrec,
          mm2.provider_name AS rnd_provider_name,
          mm2.facility_name AS rnd_facility_name,
          mm2.street_address AS rnd_street_address,
          mm2.city AS rnd_city,
          mm2.state AS rnd_state,
          mm2.zip_code AS rnd_zip_code,
          mm2.county AS rnd_county,
          mm2.telephone AS rnd_telephone,
          '~' AS eol
        FROM MyMapping mm
        INNER JOIN MyMapping mm2 ON (mm.rnd_row = mm2.org_row)
        WHERE 1=1
        ORDER BY 
          mm.patient_id ASC,
          mm.external_id ASC   
    ) t2
    ON (t1.origrec = t2.mr_origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.field_varchar_20 = t2.rnd_provider_name,
        t1.field_varchar_21 = t2.rnd_facility_name,
        t1.field_varchar_22 = t2.rnd_street_address,
        t1.field_varchar_23 = t2.rnd_city,
        t1.field_varchar_24 = t2.rnd_state,
        t1.field_varchar_25 = t2.rnd_zip_code,
        t1.field_varchar_26 = t2.rnd_county,
        t1.field_varchar_27 = t2.rnd_telephone;   
  ----- -----
*/
---------------------------------------------------------------------------




-----08. Folder Notes And Comments Update----------------------------------
  --Descript Action
/*  
  -----Review Table Records-----
    SELECT DISTINCT
      f.folderno AS f_origrec,
      f.origrec,
      f.notes AS f_notes,
      (cr.first_name || ' - ' || cr.last_name) AS new_notes,
      f.comments AS f_comments,
      (cr.first_name || ' - ' || cr.last_name) AS new_comments,
      '~' AS eol
    FROM folders f
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
    WHERE 1=1;
  ----- -----
  
  -----Update Folder Comments and Notes-----
    MERGE INTO folders t1
    USING (
      SELECT DISTINCT
        f.folderno,
        f.origrec AS f_origrec,
        (cr.first_name || ' - ' || cr.last_name) AS new_notes,
        (cr.first_name || ' - ' || cr.last_name) AS new_comments,
        '~' AS eol
      FROM folders f
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
      WHERE 1=1      
    ) t2
    ON (t1.origrec = t2.f_origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.notes = t2.new_notes,
        t1.comments = t2.new_comments;   
  ----- -----
*/
---------------------------------------------------------------------------




-----09. Chemistry ONLY - Delete v10.2 data---------------------------------------------------------
  --V10.8 data is in a flat table and not linked to other tables
/*  
  -----Review Table Records-----
    SELECT * FROM dynamicdata;
  ----- -----
  
  -----Take Action-----
    DELETE FROM dynamicdata;
  ----- -----
*/
---------------------------------------------------------------------------






-----10. Chemistry ONLY - Delete v10.8 data---------------------------------------------------------
  --V10.8 data is in a flat table and not linked to other tables
/*  
  -----Review Table Records-----
    SELECT * FROM dynamicdata108;
  ----- -----
  
  -----Take Action-----
    DELETE FROM dynamicdata108;
  ----- -----
*/
---------------------------------------------------------------------------



-----11.Chemistry - Shuffle Client in CentralReceiving and Metadata repository---------------------------------------------------------
  --For Chemistry Client information the Client ID in Centralreceiving needs and Submitting org (metadata field)to be shuffled. 
/*  
  -----Review Table Records-----
    SELECT cr.external_id, cr.rasclientid,  mr.field_varchar_30 AS Submitting_Org
    FROM centralreceiving cr
    INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec);
  ----- -----
  
  -----Take Action-----
    MERGE INTO centralreceiving t1
    USING (
      WITH
        MyMapping AS (
          SELECT 
            cr.external_id,
            cr.rasclientid,
            rownum AS org_row,
           row_number() OVER (ORDER BY dbms_random.value) AS rnd_row,
            '~' AS eol
          FROM centralreceiving cr
          WHERE 1=1
            AND cr.rasclientid IS NOT NULL
          ORDER BY
            cr.external_id ASC
        )
        SELECT
          mm.external_id,
          mm.rasclientid,          
          mm2.rasclientid AS rnd_rasclientid,
          '~' AS eol
        FROM MyMapping mm
        INNER JOIN MyMapping mm2 ON (mm.rnd_row = mm2.org_row)
        WHERE 1=1
        ORDER BY 
          mm.external_id ASC    
    ) t2
    ON (1=1
        AND t1.external_id = t2.external_id
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.rasclientid = t2.rnd_rasclientid;
  ----- -----
 
-----Review Table Records-----
    SELECT 
      cr.external_id,
      cr.rasclientid,
      mr.field_varchar_30 AS Submitting_Org,      
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
       AND mr.field_varchar_30 IS NOT NULL
    ORDER BY
      cr.external_id DESC;
  ----- -----

  -----Update submitting org to match Client id in central receiving-----
    MERGE INTO metadata_repository t1
    USING (
      WITH
        MyMapping AS (
          SELECT 
            cr.external_id,
            cr.rasclientid,
            rc.compname,
            mr.origrec AS mr_origrec,
            mr.field_varchar_30 AS Submitting_Org,           
            '~' AS eol
          FROM centralreceiving cr
          INNER JOIN rasclients rc
                on cr.rasclientid = rc.rasclientid
          INNER JOIN metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
        WHERE 1=1
          AND cr.external_id IS NOT NULL
          AND mr.field_varchar_30 IS NOT NULL
        ORDER BY
          cr.external_id DESC          
        )
        SELECT
          mm.mr_origrec,
          mm.external_id,
          mm.rasclientid,
          mm.compname,
          mm.Submitting_Org,        
          '~' AS eol
        FROM MyMapping mm        
        WHERE 1=1
        ORDER BY          
          mm.external_id ASC   
    ) t2
    ON (t1.origrec = t2.mr_origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.field_varchar_30 = t2.compname
        ;   
  ----- -----
*/

 

---------------------------------------------------------------------------


-----12. Randomize patient Date of Death and Case number-------------------------------
  --This script will update the following metadata field :
   --date_of_death: Random date between 01/01/2020 - systemdate
   --Case number

/*
  -----Review Table Records-----
    SELECT DISTINCT
           a.origrec, 
           a.original_origrec, 
           a.tablereference,
           a.field_date_03,
           a.field_varchar_12 
    FROM metadata_repository a
    Where (a.field_date_03 is not null or a.field_varchar_12 is not null)
;
  ----- -----
  
  -----Randomize Date of death Field-----
    MERGE INTO metadata_repository t1
    USING (
      ---CORE QUERY---
        SELECT DISTINCT
           mr.origrec,
           (TO_DATE(TRUNC(
            DBMS_RANDOM.VALUE(TO_CHAR(DATE '2020-01-01','J')
            ,TO_CHAR(SYSDATE,'J'))),'J')) AS ran_dateofDeath,          
          mr.field_date_03,
          
          '~' AS eol
        FROM metadata_repository mr
        INNER JOIN centralreceiving cr
              ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)       
        WHERE 1=1
        AND  mr.field_date_03 is not null
     ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.field_date_03 = t2.ran_dateofDeath;
 -----
        
-----Randomize Case number field-----
    MERGE INTO metadata_repository t1
    USING (
      ---CORE QUERY---
        SELECT DISTINCT
           mr.origrec,
           DBMS_RANDOM.string('a', 5) AS ran_casenumber,          
          mr.field_varchar_12,          
          '~' AS eol
        FROM metadata_repository mr
        INNER JOIN centralreceiving cr
              ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)       
        WHERE 1=1
        AND  mr.field_varchar_12 is not null
     ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET
        t1.field_varchar_12 = t2.ran_casenumber;
  
  
  -----XX. ----------------------------
  --Descript Action
/*  
  -----Review Table Records-----
    SELECT * FROM xxx;
  ----- -----
  
  -----Take Action-----
    DELETE FROM xx;
  ----- -----
*/
---------------------------------------------------------------------------

