
WITH
  SamplesIssues AS (
    SELECT DISTINCT
      f.external_id,
      f.dept,
      cr.patient_id,
      ---DateOfBirth---
      DECODE (cr.birth_date, p.date_of_birth, '', 'X') AS issue_dob,
      DECODE (cr.birth_date, p.date_of_birth, '', cr.birth_date) AS cr_dob,
      DECODE (cr.birth_date, p.date_of_birth, '', p.date_of_birth) AS p_dob,
      ---FirstName---
      DECODE (UPPER(cr.first_name), UPPER(p.first_name), '', 'X') AS issue_fname,
      DECODE (UPPER(cr.first_name), UPPER(p.first_name), '', cr.first_name) AS cr_fname,
      DECODE (UPPER(cr.first_name), UPPER(p.first_name), '', p.first_name) AS p_fname,
      ---MiddleName---
      DECODE (UPPER(cr.middle_initial), UPPER(p.middle_name), '', 'X') AS issue_mname,
      DECODE (UPPER(cr.middle_initial), UPPER(p.middle_name), '', cr.middle_initial) AS cr_mname,
      DECODE (UPPER(cr.middle_initial), UPPER(p.middle_name), '', p.middle_name) AS p_mname,      
      ---LastName
      DECODE (UPPER(cr.last_name), UPPER(p.last_name), '', 'X') AS issue_lname,
      DECODE (UPPER(cr.last_name), UPPER(p.last_name), '', cr.last_name) AS cr_lname,
      DECODE (UPPER(cr.last_name), UPPER(p.last_name), '', p.last_name) AS p_lname,
      ---Sex---
      DECODE (cr.sex, p.sex, '', 'X') AS issue_sex,
      DECODE (cr.sex, p.sex, '', cr.sex) AS cr_sex,
      DECODE (cr.sex, p.sex, '', p.sex) AS p_sex,
      '~' AS eol
    FROM  folders f
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
      INNER JOIN patients p ON (cr.patient_id = p.patient_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 IN ('Diagnostic','LRN-B'))
    WHERE 1=1
     AND(
       (cr.birth_date <> p.date_of_birth) OR
       (UPPER(cr.first_name) <> UPPER (p.first_name)) OR
       (UPPER(cr.middle_initial) <> UPPER(p.middle_name)) OR
       (UPPER(cr.last_name) <> UPPER (p.last_name)) OR
       (cr.sex <> p.sex)
     ) 
    ORDER BY
      f.external_id DESC      
  )
  
SELECT DISTINCT
  DECODE ((sai.issue_fname || sai.issue_mname || issue_lname), '', '', 'X' ) AS issue_name,
  sai.*
FROM SamplesIssues sai
WHERE 1=1
  
