

/*-----SamplesWithIssues-----------------------------------------------------*/
  -----DESCRIPTION-----
    --This set of queries will be used to help identify samples that may 
    --have issues in STARLiIMS.  Currently SQL for the following issues have
    -- been developed.
    --
      --005. RDQ Errors
      --010. Suspect Runs
      --015. OrdTaskIssue
      --020. NoReportForPanel
      --025. HL7Messaging
      --030. DuplicatePatient
      --035. FailedFax
      --040. FlippedRuns
      --045. MissingMetaDataFlag
      --050. MissingRunNo
      --055. SampleApprovalIssues
      --060. StarlimsLimbo
--030. Sendout Issues
  ----- -----

  ----- HISTORY-----
    --2019.09.17 JTY Addition of StarlimsLimbo check
    --2019.01.24 JTY: Begin development of scripts
  ----- -----

/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
  WITH
    -----000. FolderInfo-----  
      FolderInfo AS (
        SELECT DISTINCT
          f.external_id,
          (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
          f.folderno,
          f.dept,
          f.testgroupname,
          f.apprdate,
          '~' AS eol
        FROM folders f
          INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
          INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
          INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
--          INNER JOIN metadata_repository mr ON (1=1
--            AND mr.tablereference = 'CENTRALRECEIVING'
--            AND mr.original_origrec = cr.origrec
--            AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B'))
        WHERE 1=1
          AND fc.status NOT IN ('Cancel')
          AND f.external_id IN (&SampleList)
      ),
    ----- -----

    -----005. RDQ Errors-----
      RDQErrors AS (
        SELECT
          '005' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Report Delivery Queue' AS sample_issue,
          ---Properties---
            'Delivery Method' AS property01_name,
            CASE rdq.delivery_method
              WHEN 'E-mail' THEN (rdq.delivery_method || '-> ' || rdq.delivery_address)
              WHEN 'Fax' THEN (rdq.delivery_method || '-> ' || rdq.delivery_address)
              WHEN 'Hard Copy' THEN (rdq.delivery_method)
              ELSE (rdq.delivery_method)
            END AS property01_value,
            'Status' AS property02_name,
            rdq.status AS property02_value,
            'Error Details' AS property03_name,
            CASE rdq.delivery_method
              WHEN 'E-mail' THEN rdq.extra_info
              WHEN 'Fax' THEN (fq.errorname || '-> ' || fq.crtmessage)
              WHEN 'Hard Copy' THEN rdq.extra_info
              ELSE (rdq.extra_info)
            END AS property03_value,
            'BatchID-> ItemNo' AS property04_name,
            (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi        
          INNER JOIN rr_report_delivery_queue rdq ON (fi.folderno = rdq.folderno)
          LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
          INNER JOIN centralreceiving cr ON (cr.external_id = fi.external_id)
          LEFT OUTER JOIN rasclients rc ON (rdq.rasclientid = rc.rasclientid)
          LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
        WHERE 1=1
          AND rdq.STATUS = 'ERROR' 
      ),
    ----- -----
    -----010. SuspectRuns-----
      SuspectRuns AS (
        SELECT DISTINCT
          '010' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Suspect Runs' AS sample_issue,
          ---Properties---
            'Test Name' AS property01_name,
            t.testno AS property01_value,
            'Run Number' AS property02_name,
            TO_CHAR(r.runno) AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
           INNER JOIN runs r ON (r.runno = ot.runno)
        WHERE 1=1
          AND (
                (
                 COALESCE(ot.apprvedby ,'NULL') 
                 <> 
                 COALESCE(r.approvedby ,'NULL')
                )
              OR
                (
                 COALESCE(TO_CHAR(ot.apprdate,'DD-MON-YYYY') ,'NULL')
                 <>
                 COALESCE(TO_CHAR(r.approvedate,'DD-MON-YYYY') ,'NULL')
                )
              )
          AND t.apprneed = 'N'
          AND t.testflag = 'Default'
      ),
    ----- -----
    
    -----015. OrdTaskIssues-----
      --Issue: OrdTask flags seem to conflict with what is expected.
      --Impacts: 1. QBE Master Log may show sample that has already been completed.
      --Fixes:
      OrdTaskIssues AS (
        SELECT DISTINCT
          '015' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'OrtTask Flags Conflict' AS sample_issue,
          ---Properties---
            'Test Name' AS property01_name,
            t.testno AS property01_value,
            'Run Number' AS property02_name,
            TO_CHAR(ot.runno) AS property02_value,
            '' AS property03_name,
            '' AS property03_value,            
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          AND ot.apprdate IS NOT NULL
          AND (
               ot.tsa <> ot.tsadisp
               OR ot.tsa NOT IN ('Released', 'Cancel')
               OR ot.ts NOT IN ('OOS', 'Done', 'Cancel')  
          )
      ),
    ----- -----
    -----020. NoReportForPanel-----
      --Issue: No report associated with a completed panel.
      --Impacts: 
      --Fixes:
      NoReportForPanel AS (
        SELECT DISTINCT
          '020' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Missing Final Report' AS sample_issue,
          ---Properties---
            'Folder Approved Date' AS property01_name,
            TO_CHAR(fi.apprdate, 'YYYY-MM-DD') AS property01_value,
            'Approved By' AS property02_name,
            f.approvedby AS property02_value,
            '' AS property03_name,
            '' AS property03_value,            
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN rr_reportingruleslevels rrl ON (
            rrl.caption LIKE ('%' || fi.testgroupname || '%'))
          INNER JOIN rr_reportingrulereports rrr ON (1=1
            AND rrr.ruleid= rrl.ruleid
            AND rrr.ruleselectionid = rrl.ruleselectionid)
           LEFT OUTER JOIN rr_report_delivery_queue rdq ON (1=1
             AND fi.folderno = rdq.folderno)
         WHERE 1=1
           AND f.prodgroup IN ('Human','LRN-B', 'Environmental Microbiology')
           AND fi.testgroupname IS NOT NULL
           AND fi.apprdate IS NOT NULL
           AND rdq.folderno IS NULL
      ),
    ----- -----
    -----025. HL7Messaging-----
      --Issue: Error encountered when performing HL7 Messaging
      --Impacts: 
      --Fixes:
      HL7Messaging AS (
        SELECT DISTINCT
          '025' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'HL7 Message Issue' AS sample_issue,
          ---Properties---
            'Folder Approved Date' AS property01_name,
            TO_CHAR(fi.apprdate, 'YYYY-MM-DD') AS property01_value,
            'Test Name' AS property02_name,
            t.testno AS property02_value,
            'Error Log Comment' AS property03_name,
            fel.thecomment AS property03_value,            
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN foldercondition fc ON (fi.folderno = fc.folderno)
          INNER JOIN floweventlog fel ON (fi.folderno = fel.folderno)  
          LEFT OUTER JOIN tests t ON (fel.testcode = t.testcode)
         WHERE 1=1
           AND fi.apprdate IS NOT NULL
           AND fel.Eventtype = 'Report to HL7'    
           AND fel.stepcode = 'Not Reported to HL7'
           AND f.apprsts = 'Released' 
           AND f.dispsts <> 'Cancel'
      ),
    ----- -----
    -----030. DuplicatePatient-----
      --Issue: Folder has associated patient that may be duplicated in STARTLiMS
      --Impacts: 
      --Fixes:
      DuplicatePatient AS (
        SELECT DISTINCT
          '030' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Potential Duplicate Patient' AS sample_issue,
          ---Properties---
            'This Patient ID' AS property01_name,
            p.patient_id AS property01_value,
            'Other Patient ID' AS property02_name,
            p2.patient_id AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN centralreceiving cr ON (fi.external_id = cr.external_id)
          INNER JOIN patients p ON (cr.patient_id = p.patient_id)
          INNER JOIN patients p2 ON (1=1
            AND UPPER(p.last_name || ', ' || p.first_name) = UPPER(p2.last_name || ', ' || p2.first_name)
            AND p.date_of_birth = p2.date_of_birth)
        WHERE 1=1
          AND p.status = 'Active'
          AND p2.status = 'Active'
          AND p.patient_id <> p2.patient_id
          AND rownum = 1
      ),
    ----- -----

    -----035. FailedFax-----
      --Issue: Failed fax transmittal
      --Impacts: 
      --Fixes:
      FailedFax AS (
        SELECT       
          '035' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Failed Fax' AS sample_issue,
          ---Properties---
            'To Fax' AS property01_name,
            fq.tofax AS property01_value,
            'Post TimeStamp' AS property02_name,
            TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS property02_value,
            'BatchID-> ItemNo' AS property03_name,
            (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS property03_value,
            'Error Details' AS property04_name,
            (fq.errorname || '-> ' || fq.crtmessage) AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi        
          INNER JOIN rr_report_delivery_queue rdq ON (fi.folderno = rdq.folderno)
          LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
          INNER JOIN centralreceiving cr ON (cr.external_id = fi.external_id)
          LEFT OUTER JOIN rasclients rc ON (rdq.rasclientid = rc.rasclientid)
          LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
        WHERE 1=1
          AND fq.statusname <> 'fsDoneOK'
          AND rdh.origrec = (
              SELECT MAX(rdh2.origrec)
              FROM rr_rdq_history rdh2
              WHERE 1=1
                AND rdh2.queue_item_no = rdh.queue_item_no)
      ),
    ----- -----
    -----040. FlippedRuns-----
      --Issue: Runs have somehow been flipped (ie OrderNo sequence does not match RunNo sequence)
      --Impacts: ELR Reporting when Retest have been performed
      --Fixes: Currently there is no known resolution.
      FlippedRuns AS (
      SELECT DISTINCT      
          '040' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Flipped Runs' AS sample_issue,
          ---Properties---
            'Test Name' AS property01_name,
            t.testno AS property01_value,
            '1st Run Details' AS property02_name,
            ( 'OrdNo: ' || ot.ordno || '  ' || 
              'RunNo:' || TO_CHAR(ot.runno) || '  ' || 
              'ApprDate: ' || TO_CHAR(ot.apprdate, 'DD-MON-YYYY')
            ) AS property02_value,
            '2nd Run Details' AS property03_name,
            ( 'OrdNo: ' || ot2.ordno || '  ' || 
              'RunNo:' || TO_CHAR(ot2.runno) || '  ' || 
              'ApprDate: ' || TO_CHAR(ot2.apprdate, 'DD-MON-YYYY')
            ) AS property03_value,

            '' AS property04_name,
            '' AS property04_value,
          --- ---
          '~' AS eol
      FROM FolderInfo fi
        INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
        INNER JOIN ordtask ot2 ON (1=1
          AND ot.folderno = ot2.folderno
          AND ot.testcode = ot2.testcode
          AND ot.ordno <> ot2.ordno
          AND ot.apprdate IS NOT NULL
          AND ot2.apprdate IS NOT NULL
          AND ot.ordno < ot2.ordno
          )
        INNER JOIN tests t ON (ot.testcode = t.testcode)
      WHERE 1=1
        AND ot.runno > ot2.runno
      ),
    ----- -----
    -----045. MissingMetaDataFlag-----
      --Issue: Missing Metadata flag has been set on sample.
      --Impacts: 
      --Fixes:
      MissingMetaDataFlag AS (
        SELECT       
          '045' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Missing Metadata Flag set' AS sample_issue,
          ---Properties---
            'Error Details' AS property01_name,
            'Sample Missing Metadata flag has been set' AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
            '' AS property04_name,
            '' AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi        
          INNER JOIN centralreceiving cr ON (fi.external_id = cr.external_id)
        WHERE 1=1
          AND cr.missingmetadata = 'Y'
          AND fi.apprdate IS NULL
      ),
    ----- -----
    -----045. MissingRunNo-----
      --Issue: Completed test does not have a run number associated with it.
      --Impacts: Cannot locate in STARLiMS
      --Fixes:  Will need to add run information including approval details to ORDTASK and Results tables
      MissingRunNo AS (
        SELECT       
          '050' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Missing Run Number' AS sample_issue,
          ---Properties---
            'Error Details' AS property01_name,
            'OrdTask and/or Results table does not have run associated with test' AS property01_value,
            'Test Name' AS property02_name,
            (ot.testno || ' (' || ot.testcode || ')') AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
            '' AS property04_name,
            '' AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi        
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
          INNER JOIN results r ON (1=1
            AND ot.ordno = r.ordno
            AND ot.testcode = r.testcode)
        WHERE 1=1
          AND t.testflag = 'Default'
          AND ot.ts <> 'Cancel'
          AND ot.eqid IS NOT NULL
          AND r.final IS NOT NULL
          AND ((ot.runno IS NULL) OR (r.runno IS NULL))
          AND fi.apprdate IS NULL
      ),
    ----- -----
    -----055. SampleApprovalIssues-----
      --Issue: Sample completed, but missing ApprovalDate or ApprovedBy information.
      --Impacts: Cannot locate in STARLiMS
      --Fixes:  Review folders and foldercondition tables for approval information and make appropriate adjustments
      SampleApprovalIssues AS (
        SELECT       
          '055' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Approval Issues' AS sample_issue,
          ---Properties---
            'Error Details' AS property01_name,
            'Sample completed, but missing ApprovalDate or ApprovedBy information.' AS property01_value,
            'FolderNo' AS property02_name,
            (f.folderno) AS property02_value,
            'Folder Info' AS property03_name,
            (
             COALESCE(f.approvedby, '') || ' --> ' || COALESCE(to_char(f.apprdate, 'DD-MON-YYYY'), '')
            ) AS property03_value,
            'FolderCondition Info' AS property04_name,
           (
            COALESCE(fc.approvedby, '') || ' --> ' || COALESCE(to_char(fc.approveddate, 'DD-MON-YYYY'), '') 
            ) AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN foldercondition fc ON (fi.folderno = fc.folderno)
        WHERE 1=1
          AND (
            (COALESCE((to_char(f.apprdate) || f.approvedby || to_char(fc.approveddate) || fc.approvedby), '') IS NOT NULL)
            AND (
              (to_char(f.apprdate) IS NULL) OR (f.approvedby IS NULL)
              OR (to_char(fc.approveddate) IS NULL) OR (to_char(fc.approvedby) IS NULL)
            )    
          )
      ),
    ----- -----
    -----060. StarlimsLimbo-----
      --Issue: Flags associated with the Folders, FolderCondition and OrdTask tables conflict in such a way
      --       that the samples cannot be located within STARLiMS in the normal sample flow
      --Impacts: Cannot locate in STARLiMS
      --Fixes:  Review folders and foldercondition tables for approval information and make appropriate adjustments
      StarlimsLimbo AS (
        SELECT       
          '060' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'StarlimsLimbo' AS sample_issue,
          ---Properties---
            'Error Details' AS property01_name,
            'Flags associated with Folders, FolderCondition and OrdTask tables conflict causing active sample to disapear from the standard workflow in STARLiMS ' AS property01_value,
            'FolderFlag - fldsts' AS property02_name,
            (
             f.fldsts
            ) AS property02_value,

            'FolderConditionFlags - dispsts | status' AS property03_name,
            (
             fc.dispsts || ' | ' || fc.status
            ) AS property03_value,
            'OrdTaskFlag - ts' AS property04_name,
           (
            ot.ts 
           ) AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN foldercondition fc ON (fi.folderno = fc.folderno)
          INNER JOIN ordtask OT ON (f.folderno = ot.folderno)
        WHERE 1=1
          AND f.apprdate IS NULL
          AND fc.approveddate IS NULL
          AND f.fldsts IN ('OOS', 'Done')
          AND fc.dispsts IN ('Logged', 'Draft')
          AND fc.status IN ('Logged', 'Prelogged')  
          AND ot.ts IN ('OOS', 'Done')
      ),
    ----- -----



    -----065. OutsourceOrders-----
/*      --Issue: 
      --Impacts: 
      --Fixes:  
      OutsourceOrders(
        sorter,
        dept,
        external_id,
        client_name,
        testgroupname,
        sample_issue,
        property01_name,
        property01_value,
        property02_name,
        property02_value,
        property03_name,
        property03_value,
        property04_name,
        property04_value,
        eol
      ) AS (
        SELECT       
          '065' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Shipment Issues' AS sample_issue,
          ---Properties---
            'Error Details' AS property01_name,
            'Shipment results approval process issues.' AS property01_value,
            'Shippment' AS property02_name,
            (ot1.outsourceordno) AS property02_value,
            'tsDisp' AS property03_name,
            (ot1.tsdisp) AS property03_value,
            'Ship Date' AS property04_name,
            (oo.shipdate) AS property04_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot1 ON (fi.folderno = ot1.folderno)
          INNER JOIN ordtask ot2 ON (1=1  
            AND ot1.outsourceordno = ot2.outsourceordno
            AND ot1.ts = ot2.ts
            AND ot1.tsa = ot2.tsa
            AND ot1.tsadisp = ot2.tsadisp
          )
          INNER JOIN outsourceorders oo ON ( 1=1
            AND ot1.outsourceordno = oo.outsourceordno
            AND ot2.outsourceordno = oo.outsourceordno)
        WHERE 1=1
          AND ot1.outsourceordno <> 'OUTSOURCE'
          AND COALESCE(ot1.tsdisp, 'NULL') <> COALESCE(ot2.tsdisp, 'NULL')
      ),*/
    ----- -----

   
    -----UnionTables-----
      UnionTables AS (
      (SELECT * FROM OrdTaskIssues)
      UNION  (SELECT * FROM RDQErrors)
      UNION  (SELECT * FROM SuspectRuns)
      UNION  (SELECT * FROM OrdTaskIssues)
      UNION  (SELECT * FROM NoReportForPanel)
      UNION  (SELECT * FROM HL7Messaging)
      UNION  (SELECT * FROM DuplicatePatient)
      UNION  (SELECT * FROM FailedFax)
      UNION  (SELECT * FROM FlippedRuns)
      UNION  (SELECT * FROM MissingMetaDataFlag)
      UNION  (SELECT * FROM MissingRunNo)
      UNION  (SELECT * FROM SampleApprovalIssues)
      UNION  (SELECT * FROM StarlimsLimbo)      
--      UNION (SELECT * FROM OutsourceOrders)
      )
    ----- -----
    -----FinalQuery-----
      SELECT DISTINCT
        ut.external_id,
        ut.sorter,
        ut.client_name,
        ut.dept,
        ut.testgroupname,
        ut.sample_issue,
        ut.property01_name,
        ut.property01_value,
        ut.property02_name,
        ut.property02_value,
        ut.property03_name,
        ut.property03_value,
        ut.property04_name,
        ut.property04_value,
        ut.eol
       FROM UnionTables ut
       ORDER BY
        external_id ASC,
        sorter ASC,
        dept ASC,
        testgroupname ASC,
        property01_value ASC,
        property02_value ASC,
        property03_value ASC;
    ----- -----




/*---------------------------------------------------------------------------*/



/*
--Outsource Samples issue
SELECT DISTINCT
  ot1.outsourceordno,
  f.external_id,
  ot1.tsdisp,
  '~' AS eol
FROM folders f
  INNER JOIN ordtask ot1 ON (f.folderno = ot1.folderno)
  INNER JOIN ordtask ot2 ON (1=1
    AND ot1.outsourceordno = ot2.outsourceordno
    AND ot1.ts = ot2.ts
    AND ot1.tsa = ot2.tsa
    AND ot1.tsadisp = ot2.tsadisp
)
WHERE 1=1
  AND ot1.outsourceordno <> 'OUTSOURCE'
--AND ot1.outsourceordno = '2088'
  AND COALESCE(ot1.tsdisp, 'NULL') <> COALESCE(ot2.tsdisp, 'NULL')
ORDER BY 
  ot1.outsourceordno DESC,
  f.external_id ASC

*/



/*
    -----NextItem-----
      NextItem AS (
        SELECT DISTINCT
          'XXX' AS sorter,
          fi.dept,
          fi.external_id,
          fi.testgroupname,
          'XXXXXXXXXX' AS sample_issue,
          ---Properties---
            '' AS property01_name,
            '' AS property01_value,
            '' AS property02_name,
            TO_CHAR('') AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
            '' AS property04_name,
            '' AS property04_value,            
          --- ---
          '~' AS eol
        FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          XXXXXXX
        ORDER BY
          fi.dept ASC,
          fi.external_id ASC,
          fi.testgroupname ASC,
          property01_value ASC,
          property02_value ASC,
          property03_value ASC
      ),
    ----- -----
    */
       
