

----------------------------------------------------------------------
----------Extract LOINC and SNOMED Codes------------------------------
  ------DESCRIPTION-----
    --Retrieve list of test in STARLiMS along with associated LOINC and SNOMED codes
    --Some key columns include:
      --W_SAMPLES      - Indicates test has samples in the system within the last year.
      --ELR            - Indicates test is configured for ELR reporting.
      --PRINT_ANALYTE  - Indicates analyte result should appear on report.
      --DEFAULT_TST    - Seperates Default Possible Results and associated 
      --               - SNOMED codes from Micro Results
      --MICRO_TST      - Seperates Micro results for Micro Component from Default
      --               - Possible Results.
      --PRINT_MC       - Indicates Micro Component result should appear on report.
      

    --Created Queries:
      --1. PossibleResults Query - PossibleResults associated with ALL test
          --including Micro tests.
      --2. MicroResults Query -Query is configured to either provide 
          -- MicroComponent Results for Micro tests.
      --3. All Test Query - Query for Default and Micro test, but will
          --Only show PossibleResults for Default test and MicroComponentResults
          --for Micro Test, but NOT both for the same test.
      --4. MicroComponents Details - Retrieve information related to MicroComponents
  ----- -----

  -----HISTORY-----
    --2018.06.18 JTY: Addition of SNOMED Codes as defined in STARLiMS (not dependent on PR)
    --2018.02.15 JTY: Add MicroComponents Detsils query
    --2018.02.13 JTY: Created Query
  ----- -----
  
----------------------------------------------------------------------




----------------------------------------------------------------------
-----1. PossibleResults Query-----------------------------------------
    --Query is configured to either only PossibleResults for all test.
    --This excludes the MicroCompoent Results, but includes PR for Micro
    --tests.

  WITH
    --- ---
      AllTests AS (
        SELECT DISTINCT
          sp.progname,
          t.testcatcode,
          (t.testno || ' (' || t.testcode || ')') AS test_name,
          t.teststatus,
          t.testflag,
          t.tmname,
          a.analyte,
          sa.printflag,
          lc.loinccomponenet,
          lc.loincmethod,
          lc.loincnumber,
          lc.version AS loincversion,
          lc.hl7_reportable,
          lc.code_system_oid,
          t.testcode,
          '~' AS eol
        FROM sample_programs sp
          LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
          LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
          LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
          LEFT OUTER JOIN spec_analytes sa ON (1=1
            AND sa.specno = '3'
            AND a.testcode = sa.testcode
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
          LEFT OUTER JOIN testloinccodes lc ON (1=1
            AND a.testcode = lc.testcode
            AND a.analyte = lc.analyte)
        WHERE 1=1
          AND (sp.progname IN ('Human', 'LRN-B', 'Ad Hoc'))
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
        ORDER BY
          sp.progname ASC,
          t.testcatcode ASC,
          t.testflag ASC,
          test_name ASC,
          a.analyte ASC
      ),
    --- ---
    ---DefaultResults---  
      DefaultResults AS (
        SELECT DISTINCT
          al.test_name,
          pr.result,
          pr.conclusion_report,
          pr.localnumber,
          pr.snomedconceptid,
          pr.snomeddescriptionid,
          pr.snomedcode,
          al.testcode
        FROM AllTests al
          LEFT OUTER JOIN possibleresults pr ON (1=1
            AND al.testcode = pr.testcode
            AND al.analyte = pr.analyte)
        WHERE 1=1
          --AND al.testflag = 'Default'
        ORDER BY
          al.test_name ASC,
          pr.result ASC
      ),
    --- ---
    
    ---WithSamples---
      WithSamples AS (
        SELECT DISTINCT
          al.test_name,
          'Y' AS w_samples,
          al.testcode
        FROM AllTests al
          INNER JOIN sundata_prod.results r ON (1=1
            AND al.testcode = r.testcode
            AND al.analyte = r.analyte)
          INNER JOIN sundata_prod.folders f ON (r.folderno = f.folderno)
          INNER JOIN sundata_prod.centralreceiving cr ON (f.external_id = cr.external_id)
          INNER JOIN sundata_prod.metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec
            AND mr.field_varchar_80 = 'Diagnostic')
        WHERE 1=1
          -- 1year lookback
          AND MONTHS_BETWEEN(sysdate, f.apprdate) <= 12
        ),
    --- ---

    ---ElrConfig---
      ElrConfig AS (
        SELECT DISTINCT
          h7.rasclientid,
          h7.testcode,
          h7.analyte,
          '~' AS eol
        FROM hl7_analytes h7
        WHERE 1=1
          AND h7.rasclientid = 'MEDSIS-TEST'  
      ),
    --- ---

    ---Combined---
      Combined AS (
        SELECT DISTINCT
          al.progname,
          al.testcatcode,
          al.test_name,
          al.testflag,
          COALESCE(ws.w_samples, 'N') AS w_samples,
          CASE
            WHEN (elr.analyte IS NOT NULL) THEN 'Y'
            ELSE 'N'
          END AS elr,       
          al.analyte,
          COALESCE (al.printflag, 'N') AS print_analyte,
          al.loinccomponenet,
          al.loincmethod,
          al.loincnumber,
          al.loincversion,
          al.hl7_reportable,
          al.code_system_oid,
          dr.result,
          dr.conclusion_report,
          dr.localnumber,
          dr.snomedconceptid,
          dr.snomeddescriptionid,
          dr.snomedcode,
          al.eol
        FROM AllTests al
          LEFT OUTER JOIN ElrConfig elr ON (elr.testcode = al.testcode)
          LEFT OUTER JOIN WithSamples ws ON (1=1
            AND al.testcode = ws.testcode)
          LEFT OUTER JOIN DefaultResults dr ON (al.testcode = dr.testcode)
        WHERE 1=1
        ORDER BY
          al.progname ASC,
          al.testcatcode ASC,
          al.test_name ASC,
          al.analyte ASC,
          dr.result ASC
      )
    --- ---

    ---Final---
      SELECT DISTINCT
        cb.progname,
        cb.testcatcode,
        cb.test_name,
        cb.testflag,
        cb.w_samples,
        cb.elr,       
        cb.analyte,
        cb.print_analyte,
        cb.loinccomponenet,
        cb.loincmethod,
        cb.loincnumber,
        cb.loincversion,
        cb.hl7_reportable,
        cb.code_system_oid,
        cb.result,
        cb.conclusion_report,
        cb.localnumber,
        cb.snomedconceptid,
        cb.snomeddescriptionid,
        cb.snomedcode,
        cb.eol
      FROM Combined cb
      WHERE 1=1
      ORDER BY
        cb.progname ASC,
        cb.testcatcode ASC,
        cb.test_name ASC,
        cb.analyte ASC,
        cb.result ASC;
    --- ---
----------------------------------------------------------------------





----------------------------------------------------------------------
-----2. MicroResults Query--------------------------------------------
    --Query is configured to either provide MicroComponent Results for
    --Micro tests.

  WITH
    --- ---
      AllTests AS (
        SELECT DISTINCT
          sp.progname,
          t.testcatcode,
          (t.testno || ' (' || t.testcode || ')') AS test_name,
          t.teststatus,
          t.testflag,
          t.tmname,
          a.analyte,
          sa.printflag,
          lc.loinccomponenet,
          lc.loincmethod,
          lc.loincnumber,
          lc.version AS loincversion,
          lc.hl7_reportable,
          lc.code_system_oid,
          t.testcode,
          '~' AS eol
        FROM sample_programs sp
          LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
          LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
          LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
          LEFT OUTER JOIN spec_analytes sa ON (1=1
            AND sa.specno = '3'
            AND a.testcode = sa.testcode
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
          LEFT OUTER JOIN testloinccodes lc ON (1=1
            AND a.testcode = lc.testcode
            AND a.analyte = lc.analyte)
        WHERE 1=1
          AND (sp.progname IN ('Human', 'LRN-B', 'Ad Hoc'))
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
        ORDER BY
          sp.progname ASC,
          t.testcatcode ASC,
          t.testflag ASC,
          test_name ASC,
          a.analyte ASC
      ),
    --- ---
    ---MicroResults---  
      MicroResults AS (
        SELECT DISTINCT
          al.test_name,
          tws.sorter AS stepsorter,
          tws.stepcode,
          tws.prelimreport AS mc_print,
          mc.comptype AS mc_comptype,
          mc.compid AS mc_compid,      
          mc.compname AS mc_compname,
          mcr.response AS mc_response,
          mcr.snomedcode AS mc_snomedcode,
          mcr.code_system_oid AS mc_code_system_oid,
          mcr.loincnumber AS mc_loincnumber,
          al.testcode
        FROM AllTests al
          LEFT OUTER JOIN testwfmethods twm ON (al.tmname = twm.tmname)
          LEFT OUTER JOIN testwfsteps tws ON (twm.tmcode = tws.tmcode)
          LEFT OUTER JOIN microplates mp ON (1=1
            AND tws.tmcode = mp.tmcode
            AND tws.stepcode = mp.stepcode)
          LEFT OUTER JOIN microplatedefcomp mpc ON (1=1
            AND mp.tmcode = mpc.tmcode
            AND mp.stepcode = mpc.stepcode
            AND mp.platecode = mpc.platecode)
          LEFT OUTER JOIN microcomponents mc ON (1=1
            AND mpc.compid = mc.compid)
          LEFT OUTER JOIN microcompresponse mcr ON (1=1
            AND mc.comptype = mcr.comptype
            AND mc.compid = mcr.compid)
        WHERE 1=1
          AND al.testflag = 'Micro'
        ORDER BY
          al.test_name ASC,
          tws.sorter ASC,
          mcr.response ASC
      ),
    --- ---
    
    ---WithSamples---
      WithSamples AS (
        SELECT DISTINCT
          al.test_name,
          'Y' AS w_samples,
          al.testcode
        FROM AllTests al
          INNER JOIN sundata_prod.results r ON (1=1
            AND al.testcode = r.testcode
            AND al.analyte = r.analyte)
          INNER JOIN sundata_prod.folders f ON (r.folderno = f.folderno)
          INNER JOIN sundata_prod.centralreceiving cr ON (f.external_id = cr.external_id)
          INNER JOIN sundata_prod.metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec
            AND mr.field_varchar_80 = 'Diagnostic')
        WHERE 1=1
          -- 1year lookback
          AND MONTHS_BETWEEN(sysdate, f.apprdate) <= 12
        ),
    --- ---

    ---ElrConfig---
      ElrConfig AS (
        SELECT DISTINCT
          h7.rasclientid,
          h7.testcode,
          h7.analyte,
          '~' AS eol
        FROM hl7_analytes h7
        WHERE 1=1
          AND h7.rasclientid = 'MEDSIS-TEST'  
      ),
    --- ---

    ---Combined---
      Combined AS (
        SELECT DISTINCT
          al.progname,
          al.testcatcode,
          al.test_name,
          al.testflag,
          COALESCE(ws.w_samples, 'N') AS w_samples,
          CASE
            WHEN (elr.analyte IS NOT NULL) THEN 'Y'
            ELSE 'N'
          END AS elr,       
          al.analyte,
          COALESCE (al.printflag, 'N') AS print_analyte,
          al.loinccomponenet,
          al.loincmethod,
          al.loincnumber,
          al.loincversion,
          al.hl7_reportable,
          al.code_system_oid,
          '--MICRO--' AS micro_tst,
          mr.stepcode,
          mr.stepsorter,
          mr.mc_print AS print_mc,
          mr.mc_comptype,
          mr.mc_compid,
          mr.mc_compname,
          mr.mc_response,
          mr.mc_snomedcode,
          mr.mc_code_system_oid,
          mr.mc_loincnumber,
          al.eol
        FROM AllTests al
          LEFT OUTER JOIN ElrConfig elr ON (elr.testcode = al.testcode)
          LEFT OUTER JOIN WithSamples ws ON (1=1
            AND al.testcode = ws.testcode)
          LEFT OUTER JOIN MicroResults mr ON (al.testcode = mr.testcode)
        WHERE 1=1
        ORDER BY
          al.progname ASC,
          al.testcatcode ASC,
          al.test_name ASC,
          al.analyte ASC,
          mr.stepsorter ASC,
          mr.mc_compid ASC,
          mr.mc_response ASC
      )
    --- ---

    ---Final---
      SELECT DISTINCT
        cb.progname,
        cb.testcatcode,
        cb.test_name,
        cb.testflag,
        cb.w_samples,
        cb.elr,       
        cb.analyte,
        cb.print_analyte,
        cb.loinccomponenet,
        cb.loincmethod,
        cb.loincnumber,
        cb.loincversion,
        cb.hl7_reportable,
        cb.code_system_oid,
        cb.stepcode,
        cb.stepsorter,
        cb.print_mc,
        cb.mc_comptype,
        cb.mc_compid,
        cb.mc_compname,
        cb.mc_response,
        cb.mc_snomedcode,
        cb.mc_code_system_oid,
        cb.mc_loincnumber,
        cb.eol
      FROM Combined cb
      WHERE 1=1
      ORDER BY
        cb.progname ASC,
        cb.testcatcode ASC,
        cb.test_name ASC,
        cb.analyte ASC,
        cb.stepsorter ASC,
        cb.mc_compid ASC,
        cb.mc_response ASC;
    --- ---
----------------------------------------------------------------------






----------------------------------------------------------------------
-----3. All Test Query------------------------------------------------
    --Query is configured to either provide PossibleResults for Default
    --test, or Micro Component Reults for Micro test, but not both.
    --providing both would generate way to many records since each
    --PossibleResult for Micro test would have Multiple results associated
    --with each of the MicroComponents.
/*
  WITH
    --- ---
      AllTests AS (
        SELECT DISTINCT
          sp.progname,
          t.testcatcode,
          (t.testno || ' (' || t.testcode || ')') AS test_name,
          t.teststatus,
          t.testflag,
          t.tmname,
          a.analyte,
          sa.printflag,
          lc.loinccomponenet,
          lc.loincmethod,
          lc.loincnumber,
          lc.version AS loincversion,
          lc.hl7_reportable,
          lc.code_system_oid,
          t.testcode,
          '~' AS eol
        FROM sample_programs sp
          LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
          LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
          LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
          LEFT OUTER JOIN spec_analytes sa ON (1=1
            AND sa.specno = '3'
            AND a.testcode = sa.testcode
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
          LEFT OUTER JOIN testloinccodes lc ON (1=1
            AND a.testcode = lc.testcode
            AND a.analyte = lc.analyte)
        WHERE 1=1
          AND (sp.progname IN ('Human', 'LRN-B', 'Ad Hoc'))
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
        ORDER BY
          sp.progname ASC,
          t.testcatcode ASC,
          t.testflag ASC,
          test_name ASC,
          a.analyte ASC
      ),
    --- ---
    ---DefaultResults---  
      DefaultResults AS (
        SELECT DISTINCT
          al.test_name,
          pr.result,
          pr.conclusion_report,
          pr.localnumber,
          pr.snomedconceptid,
          pr.snomeddescriptionid,
          pr.snomedcode,
          al.testcode
        FROM AllTests al
          LEFT OUTER JOIN possibleresults pr ON (1=1
            AND al.testcode = pr.testcode
            AND al.analyte = pr.analyte)
        WHERE 1=1
          AND al.testflag = 'Default'
        ORDER BY
          al.test_name ASC,
          pr.result ASC
      ),
    --- ---
    ---MicroResults---  
      MicroResults AS (
        SELECT DISTINCT
          al.test_name,
          tws.sorter AS stepsorter,
          tws.stepcode,
          tws.prelimreport AS mc_print,
          mc.comptype AS mc_comptype,
          mc.compid AS mc_compid,      
          mc.compname AS mc_compname,
          mcr.response AS mc_response,
          mcr.snomedcode AS mc_snomedcode,
          mcr.code_system_oid AS mc_code_system_oid,
          mcr.loincnumber AS mc_loincnumber,
          al.testcode
        FROM AllTests al
          LEFT OUTER JOIN testwfmethods twm ON (al.tmname = twm.tmname)
          LEFT OUTER JOIN testwfsteps tws ON (twm.tmcode = tws.tmcode)
          LEFT OUTER JOIN microplates mp ON (1=1
            AND tws.tmcode = mp.tmcode
            AND tws.stepcode = mp.stepcode)
          LEFT OUTER JOIN microplatedefcomp mpc ON (1=1
            AND mp.tmcode = mpc.tmcode
            AND mp.stepcode = mpc.stepcode
            AND mp.platecode = mpc.platecode)
          LEFT OUTER JOIN microcomponents mc ON (1=1
            AND mpc.compid = mc.compid)
          LEFT OUTER JOIN microcompresponse mcr ON (1=1
            AND mc.comptype = mcr.comptype
            AND mc.compid = mcr.compid)
        WHERE 1=1
          AND al.testflag = 'Micro'
        ORDER BY
          al.test_name ASC,
          tws.sorter ASC,
          mcr.response ASC
      ),
    --- ---
    
    ---WithSamples---
      WithSamples AS (
        SELECT DISTINCT
          al.test_name,
          'Y' AS w_samples,
          al.testcode
        FROM AllTests al
          INNER JOIN sundata_prod.results r ON (1=1
            AND al.testcode = r.testcode
            AND al.analyte = r.analyte)
          INNER JOIN sundata_prod.folders f ON (r.folderno = f.folderno)
          INNER JOIN sundata_prod.centralreceiving cr ON (f.external_id = cr.external_id)
          INNER JOIN sundata_prod.metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec
            AND mr.field_varchar_80 = 'Diagnostic')
        WHERE 1=1
          -- 1year lookback
          AND MONTHS_BETWEEN(sysdate, f.apprdate) <= 12
        ),
    --- ---

    ---ElrConfig---
      ElrConfig AS (
        SELECT DISTINCT
          h7.rasclientid,
          h7.testcode,
          h7.analyte,
          '~' AS eol
        FROM hl7_analytes h7
        WHERE 1=1
          AND h7.rasclientid = 'MEDSIS-TEST'  
      ),
    --- ---

    ---Combined---
      Combined AS (
        SELECT DISTINCT
          al.progname,
          al.testcatcode,
          al.test_name,
          al.testflag,
          COALESCE(ws.w_samples, 'N') AS w_samples,
          CASE
            WHEN (elr.analyte IS NOT NULL) THEN 'Y'
            ELSE 'N'
          END AS elr,       
          al.analyte,
          COALESCE (al.printflag, 'N') AS print_analyte,
          al.loinccomponenet,
          al.loincmethod,
          al.loincnumber,
          al.loincversion,
          al.hl7_reportable,
          al.code_system_oid,
          '--DEFAULT--' AS default_tst,
          dr.result,
          dr.conclusion_report,
          dr.localnumber,
          dr.snomedconceptid,
          dr.snomeddescriptionid,
          dr.snomedcode,
          '--MICRO--' AS micro_tst,
          mr.stepcode,
          mr.stepsorter,
          mr.mc_print AS print_mc,
          mr.mc_comptype,
          mr.mc_compid,
          mr.mc_compname,
          mr.mc_response,
          mr.mc_snomedcode,
          mr.mc_code_system_oid,
          mr.mc_loincnumber,
          al.eol
        FROM AllTests al
          LEFT OUTER JOIN ElrConfig elr ON (elr.testcode = al.testcode)
          LEFT OUTER JOIN WithSamples ws ON (1=1
            AND al.testcode = ws.testcode)
          LEFT OUTER JOIN DefaultResults dr ON (al.testcode = dr.testcode)
          LEFT OUTER JOIN MicroResults mr ON (al.testcode = mr.testcode)
        WHERE 1=1
        ORDER BY
          al.progname ASC,
          al.testcatcode ASC,
          al.test_name ASC,
          al.analyte ASC,
          dr.result ASC,
          mr.stepsorter ASC,
          mr.mc_compid ASC,
          mr.mc_response ASC
      )
    --- ---

    ---Final---
      SELECT DISTINCT
        cb.progname,
        cb.testcatcode,
        cb.test_name,
        cb.testflag,
        cb.w_samples,
        cb.elr,       
        cb.analyte,
        cb.print_analyte,
        cb.loinccomponenet,
        cb.loincmethod,
        cb.loincnumber,
        cb.loincversion,
        cb.hl7_reportable,
        cb.code_system_oid,
        cb.default_tst,
        cb.result,
        cb.conclusion_report,
        cb.localnumber,
        cb.snomedconceptid,
        cb.snomeddescriptionid,
        cb.snomedcode,
        cb.micro_tst,
        cb.stepcode,
        cb.stepsorter,
        cb.print_mc,
        cb.mc_comptype,
        cb.mc_compid,
        cb.mc_compname,
        cb.mc_response,
        cb.mc_snomedcode,
        cb.mc_code_system_oid,
        cb.mc_loincnumber,
        cb.eol
      FROM Combined cb
      WHERE 1=1
      ORDER BY
        cb.progname ASC,
        cb.testcatcode ASC,
        cb.test_name ASC,
        cb.analyte ASC,
        cb.result ASC,
        cb.stepsorter ASC,
        cb.mc_compid ASC,
        cb.mc_response ASC;
    --- ---
*/    
----------------------------------------------------------------------





-----4. MicroComponents Details---------------------------------------
  --Retrieve information related to MicroComponents
  
  SELECT DISTINCT
    mct.comptype,
    mc.compid,
    mc.compname,
    mc.hidefromreport AS mc_hidefromreport,
    mcr.response AS mcr_response,
    mcr.snomedcode AS mcr_snomedcode,
    mcr.code_system_oid AS mcr_loincnumber,
    mcr.loincnumber AS mcr_,
    mcr.localnumber AS mcr_localnumber,
    mcr.hidefromreport AS mcr_hidefromreport,
    mcr.cdc_reportable AS mcr_cdc_reportable,
    mcr.elr_reportable AS mcr_elr_reportable,
    mcl.loinccomponenet,
    mcl.loincmethod,
    mcl.loincnumber,
    mcl.loincproperty,
    mcl.loincscale,
    mcl.loincshortname,
    mcl.loincsystems,
    mcl.loinctime,
    mcl.version AS mcl_version,
    mcl.code_system_oid AS mcl_code_system_oid,
    '~' AS eol
  FROM microcomptype mct
    INNER JOIN microcomponents mc ON (mct.comptype = mc.comptype)
    INNER JOIN microcompresponse mcr ON (1=1
      AND mc.comptype = mcr.comptype
      AND mc.compid = mcr.compid)
    INNER JOIN microcomploinc mcl ON (1=1
      AND mc.comptype = mcl.comptype
      AND mc.compid = mcl.compid)
    
  WHERE 1=1
  ORDER BY
    mct.comptype ASC,
    mc.compid ASC,
    mcr.response ASC;
    
    
----------------------------------------------------------------------







----05. SNOMED Codes--------------------------------------------------
  ---Sample Description---
    --AS defined in the Sample Description application ---
    SELECT DISTINCT
      bsd.bs_name AS specimen_source,
      to_char(bsd.bs_description) AS hl7_spec_source_code,
      bsd.bs_status AS status,
      mr.field_varchar_01 AS specimen_type,
      mr.field_varchar_10 AS snomed_ct,
      mr.field_varchar_11 AS snomed_description,
      '~' eol
    FROM  base_static_data bsd
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'BASE_STATIC_DATA'
        AND mr.original_origrec = bsd.origrec)
    WHERE 1=1
      AND bsd.bs_type = 'Sample Descriptions'
    ORDER BY 
      specimen_source ASC;
  --- ---
  
  ---Specimen Type---
    --As defined in the Specimen Sources application
    SELECT DISTINCT
      trim(SPECIMEN_SOURCE) AS specimen_type,
      ss.snomedct,
      ss.snomed_description
    FROM  SPECIMEN_SOURCES ss
    ORDER BY specimen_type ASC;
  --- ---
----------------------------------------------------------------------

