----------------------------------------------------------------------
-----HL7ProgramsSamples-----------------------------------------------
  -----DESCRIPTION-----
    --This query is designed to show what samples have been processed
    --in STARLiMS for the various reporting programs including:
      --PHLIP-FLU
      --LRN-B
      --MEDSIS
      --MEDSIS-TEST
  ----- -----

  ----- -----
  ----- -----

  -----HISTORY-----
    --2019.10.03 JTY: Created Script
  ----- -----

  
----------------------------------------------------------------------


----------------------------------------------------------------------
WITH
  -----SampleInfo-----
    SampleInfo AS (
      SELECT DISTINCT
        mr.field_varchar_80 AS activity_type,
        f.apprdate,
        f.approvedby,
        cr.external_id,
        (rc.compname || ' (' || rc.rasclientid || ')') AS ras_client,
        (ot.testno || ' (' || ot.testcode || ')') AS test_name,
        r.final,
        ot.testcode,
        rc.rasclientid,
        '~' AS eol
      FROM folders f
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN results r ON (1=1
          AND ot.ordno = r.ordno
          AND ot.testcode = r.testcode)
      WHERE 1=1
        AND f.apprdate IS NOT NULL
        AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
AND to_date(f.apprdate, 'DD-MON-YY') BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
        AND rc.rasclientid NOT IN ('ASL-P')  -- Want to exclude Arizona State Laboratory.
      ORDER BY
        f.apprdate DESC,
        cr.external_id ASC
    ),
  ----- -----
  -----PhlipFlu-----
    PhlipFlu AS (
      SELECT DISTINCT
        'PHLIP-FLU' AS hl7_program,
        si.activity_type,
        si.apprdate,
        si.approvedby,
        si.external_id,
        si.ras_client,
        si.test_name,
        si.final,
        si.testcode,
        si.rasclientid,
        '~' AS eol  
      FROM  SampleInfo si
        INNER JOIN hl7_dist_loincs dl ON (1=1
          AND si.testcode = dl.testcode)
      WHERE 1=1
      ORDER BY
        si.apprdate DESC ,
        si.external_id ASC     
    ),
  ----- -----
  -----LrnB-----
    LrnB AS (
      SELECT DISTINCT
        'LRN-B' AS hl7_program,
        si.activity_type,
        si.apprdate,
        si.approvedby,
        si.external_id,
        si.ras_client,
        si.test_name,
        si.final,
        si.testcode,
        si.rasclientid,
        '~' AS eol  
      FROM  SampleInfo si
        INNER JOIN hl7_analytes ha ON (si.testcode = ha.testcode)        
      WHERE 1=1
        AND si.activity_type = 'LRN-B'
        AND ha.rasclientid = 'CDC'
      ORDER BY
        si.apprdate DESC ,
        si.external_id ASC     
    ),
  ----- -----
  -----Medsis-----
    Medsis AS (
      SELECT DISTINCT
        'MEDSIS' AS hl7_program,
        si.activity_type,
        si.apprdate,
        si.approvedby,
        si.external_id,
        si.ras_client,
        si.test_name,
        si.final,
        si.testcode,
        si.rasclientid,
        '~' AS eol  
      FROM  SampleInfo si
        INNER JOIN hl7_analytes ha ON (si.testcode = ha.testcode)        
      WHERE 1=1
        --AND si.activity_type = 'Diagnostic'
        AND ha.rasclientid = 'MEDSIS'
      ORDER BY
        si.apprdate DESC ,
        si.external_id ASC     
    ),
  ----- -----  
  -----MedsisTest-----
    MedsisTest AS (
      SELECT DISTINCT
        'MEDSIS-TEST' AS hl7_program,
        si.activity_type,
        si.apprdate,
        si.approvedby,
        si.external_id,
        si.ras_client,
        si.test_name,
        si.final,
        si.testcode,
        si.rasclientid,
        '~' AS eol  
      FROM  SampleInfo si
        INNER JOIN hl7_analytes ha ON (si.testcode = ha.testcode)        
      WHERE 1=1
        --AND si.activity_type = 'Diagnostic'
        AND ha.rasclientid = 'MEDSIS-TEST'
      ORDER BY
        si.apprdate DESC ,
        si.external_id ASC     
    ),
  ----- -----
  -----UnionTables-----
    UnionTables AS (
      (SELECT * FROM PhlipFlu)
      UNION  (SELECT * FROM LrnB)
      UNION  (SELECT * FROM Medsis)
      UNION  (SELECT * FROM MedsisTest)
    )
  ----- -----
  -----FinalQuery-----
    SELECT DISTINCT
      ut.hl7_program,
      ut.activity_type,
      ut.apprdate,
      ut.approvedby,
      ut.external_id,
      ut.ras_client,
      ut.test_name,
      ut.final,
      ut.testcode,
      ut.rasclientid,
      '~' AS eol  
     FROM UnionTables ut
     WHERE 1=1
AND ut.hl7_program IN ('LRN-B')
     ORDER BY
      ut.hl7_program ASC,
      ut.activity_type ASC,
      ut.apprdate ASC,
      ut.external_id ASC
    ----- -----
----------------------------------------------------------------------

