--Retrieve list of test in STARLiMS along with associated LOINC codes
--elr column indicates if test has been configured to send results
--to the ELR program.


WITH
  ---AllTests---
    AllTests AS (
      SELECT DISTINCT
        t.testcatcode,
        t.testno,
        t.testcode,
        tlc.analyte,
        sp.printflag,
        NULL AS w_samples,
        tlc.loincnumber,
        tlc.version,
        tlc.loinccomponenet,
        '~' AS eol
      FROM sundata_prod.testloinccodes tlc
        INNER JOIN sundata_prod.tests t ON (tlc.testcode = t.testcode)
        INNER JOIN sundata_prod.spec_analytes sp ON (1=1
          AND tlc.testcode = sp.testcode
          AND tlc.analyte = sp.analyte)
      WHERE 1=1
        AND t.testcatcode NOT IN ('Retired','Clinical')
        --AND tlc.analyte <> 'TESTLOINC'
      ORDER BY
        t.testcatcode ASC,
        t.testcode ASC,
        tlc.analyte ASC,
        tlc.version ASC,
        tlc.loincnumber ASC),
  --- ---
  ---WithSamples---
    WithSamples AS (
      SELECT DISTINCT
        al.testcatcode,
        al.testno,
        al.testcode,
        al.analyte,
        al.printflag,
        'Y' AS w_samples,
        al.loincnumber,
        al.version,
        al.loinccomponenet,
        al.eol
      FROM AllTests al
        INNER JOIN sundata_prod.results r ON (1=1
          AND al.testcode = r.testcode
          AND al.analyte = r.analyte)
        INNER JOIN sundata_prod.folders f ON (r.folderno = f.folderno)
        INNER JOIN sundata_prod.centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN sundata_prod.metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec
          AND mr.field_varchar_80 = 'Diagnostic')
      WHERE 1=1
        -- 1year lookback
        AND MONTHS_BETWEEN(sysdate, f.apprdate) <= 12
      ),
  --- ---
  ---Combined---
    Combined AS (
      SELECT DISTINCT
        al.testcatcode,
        al.testno,
        al.testcode,
        al.analyte,
        al.printflag,
        COALESCE(ws.w_samples, 'N') AS w_samples,
        al.loincnumber,
        al.version,
        al.loinccomponenet,
        (al.testno || ' (' || al.testcode || ')') AS testname_code,
        al.eol
      FROM AllTests al
        LEFT OUTER JOIN WithSamples ws ON (1=1
          AND al.testcode = ws.testcode
          AND al.analyte= ws.analyte)
      WHERE 1=1
    ),
  --- ---

  ---ElrConfig---
    ElrConfig AS (
      SELECT DISTINCT
        h7.rasclientid,
        h7.testcode,
        h7.analyte,
        '~' AS eol
      FROM hl7_analytes h7
      WHERE 1=1
        AND h7.rasclientid = 'MEDSIS-TEST'  
    )  
  --- ---  
  
  ---Final Query---
    SELECT DISTINCT
        cb.testcatcode,
        cb.testname_code,
        cb.analyte,
        CASE
          WHEN (el.analyte IS NOT NULL) THEN 'Y'
          ELSE 'N'
        END AS elr,
        cb.printflag,
        cb.w_samples,
        cb.loincnumber,
        cb.version,
        cb.loinccomponenet,
        cb.testno,
        cb.testcode,
        cb.eol
    FROM Combined cb
      LEFT OUTER JOIN ElrConfig el ON (1=1
        AND cb.testcode = el.testcode
        AND cb.analyte = el.analyte)
    WHERE 1=1
    ORDER BY
        cb.testcatcode ASC,
        cb.testcode ASC,
        cb.analyte ASC,
        cb.version ASC,
        cb.loincnumber ASC
  --- ---          
        
