

--Query PHLIP samples that need to be re-transmitted for date range 
--of 30-SEP-2018 to 06-JAN-2019

WITH
  --mysamples---
    --Base query to pick up samples that need to be re-transmitted.
    mysamples AS (
      SELECT DISTINCT
        f.external_id,
        ot.ordno,
        ot.runno,
        ot.usrnam,
        cr.date_collected,
        f.dept,
        f.testgroupname,
        ot.testno,
        ot.apprdate AS test_approval,
        f.apprdate AS panel_approval,
        r.final,
        '~' AS eol
      FROM folders f
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN ordtask ot2 ON (f.folderno = ot2.folderno)
        INNER JOIN results r ON (1=1
          AND ot.ordno = r.ordno
          AND ot.testcode = r.testcode)
      WHERE 1=1
        AND mr.field_varchar_80 = 'Diagnostic'
        AND ot2.ordno LIKE '%-001A'
        AND to_date(cr.date_collected, 'DD-MON-YY') BETWEEN
          to_date('30-SEP-2018', 'DD-MON-YYYY') AND to_date('06-JAN-2019', 'DD-MON-YYYY')
        AND ot.testno = 'Influenza PCR'
        AND f.apprdate IS NOT NULL

    ),
  -- ---
  --oddRuns---
    --Samples where the retest RunNumber is less than the original RunNumber (Should be impossible)
    oddruns AS (
      SELECT
        'Runs Flipped' AS my_comment,
        ms.external_id,
        '~' AS sp1,      
        ms.ordno AS ordno_1,
        ms2.ordno AS ordno_2,
        ms.runno AS run_1,
        ms2.runno AS run_2,      
        ms.usrnam AS usrnam_1,
        ms2.usrnam AS usrnam_2,
        '~' AS sp2,
        ms.date_collected,
        ms.dept,
        ms.testgroupname,
        ms.testno,
        ms2.test_approval,
        ms2.panel_approval,
        ms2.final,
        ms.eol
      FROM mysamples ms
        INNER JOIN mysamples ms2 ON (ms.external_id = ms2.external_id)
      WHERE 1=1
        AND (ms.ordno<ms2.ordno AND ms.runno>ms2.runno)
    ),
  -- ---
  --okruns---
    --Runs with no issues associated with the sequence of run number
    okruns AS (
      SELECT
        '' AS my_comment,
        ms.external_id,
        '~' AS sp1,      
        ms.ordno AS ordno_1,
        ms2.ordno AS ordno_2,
        ms.runno AS run_1,
        ms2.runno AS run_2,      
        ms.usrnam AS usrnam_1,
        ms2.usrnam AS usrnam_2,
        '~' AS sp2,
        ms.date_collected,
        ms.dept,
        ms.testgroupname,
        ms.testno,
        ms2.test_approval,
        ms2.panel_approval,
        ms2.final,
        ms.eol
      FROM mysamples ms
        INNER JOIN mysamples ms2 ON (ms.external_id = ms2.external_id)
      WHERE 1=1
        AND (ms.ordno<ms2.ordno AND ms.runno<ms2.runno)
    ),
  -- ---
  --uniontables---
    --Combine samples with odd run issues samples with no issues
    uniontables AS (
      SELECT * FROM oddruns
      UNION SELECT * FROM okruns  
    )
  -- ---
  --Final Query---
    SELECT * FROM uniontables ut
        ORDER BY
          ut.external_id ASC,
          ut.ordno_1 ASC,
          ut.run_1
  -- ---
