

/*-----Test Volume and Programs------------------------------------*/
  /*-----DESCRIPTION-----*/
    --This query will list the active test in STARLiMS, and the following
    --informtion:
      --Department
      --Program associated with test (ELR/LRN-B/PHLIP/None)
      --TestCount (over the specified time period)
      --Test Type (Micro/Default)
    --This query may be usefull in determining the priorities of what
    --test to convert to ELR.
  /*----- -----*/
  
  /*-----HISTORY-----*/
    --2018.03.19 JTY - Created Query
  /*----- -----*/

/*-----------------------------------------------------------------*/


/*-----------------------------------------------------------------*/
  WITH
    ---DataSource---
    DataSource AS (
    SELECT DISTINCT
      f.dept,
      cr.external_id,
      ot.testno,
      ot.testcode,
      to_date(cr.date_received, 'DD-MON-YY') AS date_received,
      mr.field_varchar_80 AS activity_type,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
      AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN
         to_date('&Date_Start', 'DD-MON-YY') AND to_date('&Date_End', 'DD-MON-YY')
    ORDER BY
      f.dept ASC,
      cr.external_id ASC
    ),
    --- ---
    ---TestTotals---
      TestTotals AS (
        SELECT DISTINCT
          ds1.dept,
          ds1.testno,
          ds1.testcode,
          COUNT(ds2.testno) AS Test_count
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.dept = ds2.dept
            AND ds1.testno = ds2.testno
            AND ds1.external_id = ds2.external_id)
        WHERE 1=1
--          AND ds1.dept = 'PHX-VIR'
        GROUP BY 
          ds1.dept,
          ds1.testcode,
          ds1.testno
        ORDER BY
          ds1.dept ASC,
          Test_count DESC
      ),
    --- ---   
    ---LRN-B, ELR---
      clients1 AS (
        SELECT DISTINCT
          (rc.compname || ' (' || rc.rasclientid || ')') AS client,
          (t.testno || ' (' || t.testcode || ')' ) AS test_nacode,
          rc.rasclientid,
          t.testcode,
          '~' AS eol
        FROM sundata_prod.hl7_analytes ha
          INNER JOIN sundata_prod.tests t ON (ha.testcode = t.testcode)
          INNER JOIN sundata_prod.rasclients rc ON (ha.rasclientid = rc.rasclientid)
        WHERE 1=1
        ORDER BY
          client ASC,
          test_nacode ASC
      ),
    ---  ---
    ---PHLIP---
      clients2 AS (  
        SELECT DISTINCT
          (rc.compname || ' (' || rc.rasclientid || ')') AS client,
          (t.testno || ' (' || t.testcode || ')' ) AS test_nacode,
          rc.rasclientid,
          t.testcode,
          '~' AS eol  
        FROM sundata_prod.HL7_DIST_SUBMITTERS hs
          INNER JOIN sundata_prod.rasclients rc ON (hs.rasclientid = rc.rasclientid)
          INNER JOIN sundata_prod.hl7_dist_loincs hl ON (hs.rasclientid = hl.rasclientid)
          INNER JOIN sundata_prod.tests t ON (hl.testcode = t.testcode)
        WHERE 1=1
        ORDER BY
          client ASC,
          test_nacode ASC
      ),
    ---  ---
    ---Combined---
      Combined AS (
        SELECT DISTINCT * FROM clients1
        UNION
        SELECT DISTINCT * FROM clients2
      ),
    ---  ---
    ---PRCount---
      PRCount AS (
        SELECT DISTINCT
          pr.testcode,
          COUNT(DISTINCT pr.result) AS result_count
        FROM possibleresults pr
        WHERE 1=1
        GROUP BY 
          pr.testcode
        ORDER BY
          pr.testcode ASC
      ),
    --- ---
    ---AnalyteCount---
      AnalyteCount AS (
        SELECT DISTINCT
          a.testcode,
          COUNT(DISTINCT a.analyte) AS analyte_count
        FROM analytes a
        WHERE 1=1
        GROUP BY 
          a.testcode
        ORDER BY
          a.testcode ASC
      ),
    --- --- 
    --- AllTogether ---
      AllTogether AS (
        SELECT
          tt.dept,
          CASE c.rasclientid
            WHEN 'CDC' THEN 'LRN-B'
            WHEN 'MEDSIS-TEST' THEN 'ELR'
            WHEN 'PHLIP-FLU' THEN 'PHLIP'
            ELSE '-None-'
          END AS program,
          (tt.testno || ' (' || t.testcode || ')') AS testnoco,
          t.testflag,
          tt.test_count,
          ac.analyte_count,
          pc.result_count,
          tt.testcode,
          '~' AS eol
        FROM TestTotals tt
          INNER JOIN tests t ON (tt.testcode = t.testcode)
          INNER JOIN PRCount pc ON (t.testcode = pc.testcode)
          INNER JOIN AnalyteCount ac ON (t.testcode = ac.testcode)
          LEFT OUTER JOIN combined c ON (t.testcode = c.testcode)
        WHERE 1=1
          AND t.testcatcode IN ('Bacteriology', 'BioTerrorism', 'Mycobacteriology', 'Serology', 'Virology' )
          AND tt.dept IN ('PHX-BAC', 'PHX-BT', 'PHX-SER', 'PHX-TB', 'PHX-VIR')
        ORDER BY
          tt.dept ASC,
          t.testflag ASC,
          tt.test_count DESC,
          tt.testno ASC
      )
    ---  ---
  SELECT * FROM AllTogether;
/*-----------------------------------------------------------------*/
