

/*-----BarcodeProjectScripts-------------------------------------------------*/
  -----DESCRIPTION-----
    --These scripts were developed to provide Lookup Values for the Sample
    --submission form for the Barcode project.  The following Scripts are
    --included:
      --Barcode Submittals: Identify samples submitted and what ones were via barcode
      --01. AZ_Cities: List of cities in Arizona
      --02. US States
      --03. Clients
      --04. SpecimenTypes list
      --05. SamplesDescriptions list
      --06. Change Barcode Version Status
      --07. Clean LF and CR from field
  ----- -----
  

  -----HISTORY-----
  ----- -----

/*---------------------------------------------------------------------------*/
/*-----Barcode Submittals----------------------------------------------------*/
  --Identify clients submitting samples via Barcode form
/*
  SELECT DISTINCT
    to_date(cr.date_received, 'DD-MON-YY') AS date_received,
    cr.external_id,
    CASE COALESCE(length(bl.scanned_by), 0)
      WHEN 0 THEN ''
      ELSE 'X'
    END AS barcode,
    (rc.compname || '(' || cr.rasclientid || ')') AS client,
    f.dept,
    f.testgroupname AS panel,
    bl.scanned_by,
--    COALESCE(bl.scanned_by AS barcode_scanned),
    '~' AS eol
  FROM centralreceiving cr
    INNER JOIN folders f ON (cr.external_id = f.external_id)
    LEFT OUTER JOIN barcode_log bl ON (cr.external_id = bl.external_id)
    INNER JOIN rasclients rc ON (f.rasclientid = rc.rasclientid)
  WHERE 1=1
    AND f.prodgroup IN ('Human')
    AND f.dept IN ('PHX-SER', 'PHX-VIR', 'PHX-TB', 'PHX-BAC')
    AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN to_date('&BeginDate', 'DD-MON-YY') AND to_date('&EndDate', 'DD-MON-YY')
  ORDER BY
    date_received DESC,
    cr.external_id DESC
*/

/*---------------------------------------------------------------------------*/




/*  https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_Arizona
/*---------------------------------------------------------------------------*/



/*---03. Clients List---------------------------------------------------------*/

  ---03.1 Get Client List---
    SELECT DISTINCT
      rc.compname,
      rc.rasclientid,
      rc.primaryphone,
      rc.adress,
      rc.city,
      rc.state,
      rc.zip,
      rc.county
    FROM rasclients rc  
    WHERE 1=1
      AND rc.status = 'Active'
      AND rc.rasclientid NOT IN (
      'APHL', 
      'CDC', 'ERA', 'MEDSIS',
      'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
       'CA State Lab-Ca', 'CA State Lab-Fl',
      'CDC NARMS', 'CDC WGS',
      'Regional MLVA', 'Regional WGS', 'CDC Influenza'
      )
    ORDER BY
      rc.compname ASC,
      rc.rasclientid ASC; 
  --- ---

  ---03.2 Identify any Duplicate Client Names---
    SELECT DISTINCT
      rc.compname,
      rc.rasclientid,
      rc.primaryphone,
      rc.adress,
      rc.city,
      rc.state,
      rc.zip,
      rc.county
    FROM rasclients rc  
      INNER JOIN rasclients rc2 ON (rc.compname = rc2.compname)
    WHERE 1=1
      AND rc.status = 'Active'
      AND rc2.status = 'Active'
      AND rc.rasclientid <> rc2.rasclientid
    ORDER BY
      rc.compname ASC,
      rc.rasclientid ASC;
  --- ---

  ---03.3 Get Clients with no phone numbers---
    SELECT DISTINCT
      rc.compname,
      rc.rasclientid,
      rc.primaryphone,
      rc.adress,
      rc.city,
      rc.state,
      rc.zip,
      rc.county
    FROM rasclients rc  
    WHERE 1=1
      AND rc.primaryphone IS NULL
      AND rc.status = 'Active'
      AND rc.rasclientid NOT IN (
      'APHL', 
      'CDC', 'ERA', 'MEDSIS',
      'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
       'CA State Lab-Ca', 'CA State Lab-Fl',
      'CDC NARMS', 'CDC WGS',
      'Regional MLVA', 'Regional WGS', 'CDC Influenza'
      )
    ORDER BY
      rc.compname ASC,
      rc.rasclientid ASC; 
  --- ---
  
  ---03.4 Get Clients with Bad Cities---
    SELECT DISTINCT
      rc.city,
      rc.zip,
      rc.compname,
      rc.rasclientid,
      rc.adress,
      rc.county
    FROM rasclients rc  
    WHERE 1=1
      AND rc.state = 'AZ'
      AND rc.status = 'Active'
      AND rc.rasclientid NOT IN (
      'APHL', 
      'CDC', 'ERA', 'MEDSIS',
      'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
       'CA State Lab-Ca', 'CA State Lab-Fl',
      'CDC NARMS', 'CDC WGS',
      'Regional MLVA', 'Regional WGS', 'CDC Influenza'
      )
      AND rc.city NOT IN (
      'Apache Junction',
      'Avondale',
      'Benson',
      'Bisbee',
      'Buckeye',
      'Bullhead City',
      'Bylas', 
      'Camp Verde',
      'Carefree',
      'Casa Grande',
      'Cave Creek',
      'Chandler',
      'Chinle', 
      'Chino Valley',
      'Cibecue',
      'Clarkdale',
      'Clifton',
      'Cochise',
      'Colorado City',
      'Coolidge',
      'Cottonwood',
      'Dewey', 
      'Dewey-Humboldt',
      'Douglas',
      'Duncan',
      'Eagar',
      'El Mirage',
      'Eloy',
      'Flagstaff',
      'Florence',
      'Forest Lakes',
      'Fort Defiance',
      'Fort Huachuca',
      'Fort Mohave',
      'Fountain Hills',
      'Fredonia',
      'Gila Bend',
      'Gilbert',
      'Glendale',
      'Globe',
      'Goodyear',
      'Guadalupe',
      'Hayden',
      'Hereford', 
      'Holbrook',
      'Huachuca City',
      'Jerome',
      'Kayenta',
      'Kearny',
      'Kingman',
      'Lake Havasu City',
      'Lakeside',
      'Laveen',
      'Litchfield Park',
      'Luke Air Force Base',
      'Mammoth',
      'Many Farms', 
      'Marana',
      'Maricopa',
      'Mesa',
      'Miami',
      'Mohave Valley',
      'Morenci',
      'Nogales',
      'Oracle',
      'Oro Valley',
      'Page',
      'Paradise Valley',
      'Parker',
      'Patagonia',
      'Payson',
      'Peach Springs',
      'Peoria',
      'Phoenix',
      'Pinon',
      'Peridot',
      'Pima',
      'Pinetop-Lakeside',
      'Polacca',
      'Prescott',
      'Prescott Valley',
      'Quartzsite',
      'Queen Creek',
      'Sacaton',
      'Safford',
      'Sahuarita',
      'San Carlos',
      'San Luis',
      'San Manuel',
      'San Tan Valley',
      'Scottsdale',
      'Sedona',
      'Sells',
      'Show Low',
      'Sierra Vista',
      'Snowflake',
      'Somerton',
      'South Tucson',
      'Springerville',
      'St. Johns',
      'Star Valley',
      'Sun City',
      'Sun City West',
      'Superior',
      'Supai',
      'Surprise',
      'Taylor',
      'Teec Nos Pos',
      'Tempe',
      'Thatcher',
      'Tolleson',
      'Tombstone',
      'Tsaile',
      'Tuba City',
      'Tucson',
      'Tusayan',
      'Vail', 
      'Wellton',
      'Whiteriver',
      'Wickenburg',
      'Willcox',
      'Williams',
      'Window Rock',
      'Winkelman',
      'Winslow',
      'Youngtown',
      'Yuma'
      )      
    ORDER BY
      rc.city,
      rc.zip,
      rc.compname ASC,
      rc.rasclientid ASC; 
  --- ---
  
  ---03.5 Get Clients with Bad Counties---
    SELECT DISTINCT
      rc.compname,
      rc.rasclientid,
      rc.primaryphone,
      rc.adress,
      rc.city,
      rc.state,
      rc.zip,
      '~' || rc.county || '~' AS county
    FROM rasclients rc  
    WHERE 1=1
      AND rc.state = 'AZ'
      AND rc.primaryphone IS NULL
      AND rc.status = 'Active'
      AND rc.rasclientid NOT IN (
      'APHL', 
      'CDC', 'ERA', 'MEDSIS',
      'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
       'CA State Lab-Ca', 'CA State Lab-Fl',
      'CDC NARMS', 'CDC WGS',
      'Regional MLVA', 'Regional WGS', 'CDC Influenza'
      )
      AND rc.county NOT IN (
        'Apache',
        'Cochise',
        'Coconino',
        'Gila',
        'Graham',
        'Greenlee',
        'La Paz',
        'Maricopa',
        'Mohave',
        'Navajo',
        'Pima',
        'Pinal',
        'Santa Cruz',
        'Yavapai',
        'Yuma',
        'In-House'
      )      
    ORDER BY
      rc.compname ASC,
      rc.rasclientid ASC; 
  --- ---


/*---------------------------------------------------------------------------*/






/*----04. SpecimenTypes list-------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Get the SpecimenType drop-down list for the Clinical accessioning screen

  SELECT DISTINCT
    TRIM(ss.specimen_source) AS specimen_types
  FROM specimen_sources ss
  WHERE 1=1
  ORDER BY
    ss.specimen_source ASC;
/*---------------------------------------------------------------------------*/




/*----05. SamplesDescriptions list--------------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Get the Sample Description drop-down list for the clinical Accessioning screen
      SELECT 'sample_description' 
      FROM BASE_STATIC_DATA
    UNION
      SELECT TRIM(BS_NAME)
      FROM BASE_STATIC_DATA
        INNER JOIN METADATA_REPOSITORY
         ON  BASE_STATIC_DATA.ORIGREC = METADATA_REPOSITORY.ORIGINAL_ORIGREC
             AND METADATA_REPOSITORY.TABLEREFERENCE = 'BASE_STATIC_DATA'               
      WHERE 1=1
        AND BS_TYPE = 'Sample Descriptions'
        AND BS_STATUS = 'Active'
        AND METADATA_REPOSITORY.FIELD_VARCHAR_01 = 'Clinical'
   ORDER BY 1;
          
/*---------------------------------------------------------------------------*/






/*-----06. Change Barcode Version Status--------------------------------------*/
  --Review and update the identified Barcode Version from Approve to Draft.
  --this will allow you to make changes to the barcode.  Of course you will need
  --to change the status of the barcode back to Approve before being able to 
  --use the barcode again.


  ---Review Barcode Versions---
    SELECT DISTINCT
      bv.*
    FROM barcode_versions bv
    WHERE 1=1
    ORDER BY bv.origrec DESC;
  --- ---

  ---Update Version Status---  
/*  
    UPDATE barcode_versions bv
    SET bv.status = '&Status'  --Draft, Approve, Retire
    WHERE 1=1
      AND bv.origrec = '&Origrec';
*/      
  --- ---  
/*---------------------------------------------------------------------------*/


/*-----07. Clean LF and CR from field----------------------------------------*/
  --Remove any LF/CR from the Phone number field.


  ---Review Barcode Versions---
    UPDATE metadata_repository mr
    SET
      mr.field_varchar_27 = 
      regexp_replace(mr.field_varchar_27, '([' || chr(10) || chr(13) || '])+','')
    WHERE 1=1
      AND mr.tablereference = 'CENTRALRECEIVING'
      AND mr.field_varchar_27 LIKE '%' || chr(10)
  --- ---

  ---Update Version Status---  
/*  
    UPDATE barcode_versions bv
    SET bv.status = '&Status'  --Draft, Approve, Retire
    WHERE 1=1
      AND bv.origrec = '&Origrec';
*/      
  --- ---  
/*---------------------------------------------------------------------------*/



