

/*----CIFOR_Troubleshooting--------------------------------------------------*/
  -----DESCRIPTION-----
    --Use these sets of SQL statements to identify and repair issues with CIFOR
    --extracts.
    --
    --2. CentralReceivingAddress: Identify patients with multiple address
    --                            for the their house.
  ----- -----
  
  ----- -----
  ----- -----


  -----HISTORY-----
    --2018.04.30 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----1. Review Job Log-----------------------------------------------------*/
  SELECT *
  FROM sundata_prod.adhs_batch_log bl
  WHERE 1=1
    AND bl.package_name = 'CIFOR'
  ORDER BY
    bl.last_updated DESC,
    bl.method_name ASC;
    
/*---------------------------------------------------------------------------*/





/*-----1. CentralReceivingAddress--------------------------------------------*/
  --Identify patients that have multiple addresses for their home address.
  --typically this is due to capitalization issue.

/*  SQL error generated on this situation
          SQL*Plus: Release 9.2.0.5.0 - Production on Sun Apr 29 22:00:00 2018

          Copyright (c) 1982, 2002, Oracle Corporation.  All rights reserved.


          Connected to:
          Oracle Database 11g Enterprise Edition Release 11.2.0.4.0 - 64bit Production With the Partitioning, OLAP, Data Mining and Real Application Testing options

          DECLARE
          *
          ERROR at line 1:
          ORA-30926: unable to get a stable set of rows in the source tables
          ORA-06512: at "SUNDATA_PROD.CIFOR_PKG", line 408
          ORA-06512: at "SUNDATA_PROD.CIFOR_PKG", line 468
          ORA-06512: at "SUNDATA_PROD.CIFOR_PKG", line 95
          ORA-06512: at "SUNDATA_PROD.CIFOR_PKG", line 124
          ORA-06512: at line 11


          Disconnected from Oracle Database 11g Enterprise Edition Release 11.2.0.4.0 - 64bit Production With the Partitioning, OLAP, Data Mining and Real Application Testing options
*/



-----Identify patient(s) of interest-----
  WITH
    ---myRecords---
      myRecords AS (
        SELECT DISTINCT
          'Home' AS address_type,
          cr.origrec AS cr_origrec,
          cr.owner_address,
          cr.owner_city,
          cr.owner_zip,
          cr.owner_county,
          cr.owner_state,
          cr.owner_country,
          cr.patient_id,
          SUBSTR('MEDSIS ' || (TO_CHAR(TRUNC(sysdate))),1,25) AS description,
          pa.origrec AS pa_origrec,      
          '~' AS EOL
        FROM centralreceiving cr
          INNER JOIN patient_addresses pa ON (cr.patient_id = pa.patient_id)
        WHERE 1=1
          AND cr.external_pid2 LIKE '%MEDSIS%'
          AND pa.address_type = 'Home'
          AND (
            COALESCE(cr.owner_address,'-') <> COALESCE(pa.address,'-')
            OR COALESCE(cr.owner_city,'-') <> COALESCE(pa.city,'-')
            OR COALESCE(cr.owner_zip,'-') <> COALESCE(pa.zip,'-')
            OR COALESCE(cr.owner_county,'-') <> COALESCE(pa.county,'-')
            OR COALESCE(cr.owner_state,'-') <> COALESCE(pa.state,'-')
            OR COALESCE(cr.owner_country,'-') <> COALESCE(pa.country,'-')
          )
        ORDER BY
          cr.patient_id ASC,
          cr.owner_address ASC
      ),
    --- ---
    ---myDuplicates---
      myDuplicates AS (
        SELECT DISTINCT
        mr1.patient_id,
        mr1.cr_origrec AS mr1_cr_origrec,
        mr1.owner_address AS mr1_owner_address,
        mr2.cr_origrec AS mr2_cr_origrec,
        mr2.owner_address AS mr2_owner_address,
        mr1.address_type,   
        mr1.owner_city,
        mr1.owner_zip,
        mr1.owner_county,
        mr1.owner_state,
        mr1.owner_country,
        mr1.description,
        '~' AS eol
        FROM myRecords mr1
          INNER JOIN myRecords mr2 ON (1=1
            AND mr1.patient_id = mr2.patient_id
            AND mr1.address_type = mr2.address_type
            AND mr1.owner_address <> mr2.owner_address)
        WHERE 1=1  
      )
    --- ---
    ---Final Query---
      SELECT *
      FROM myDuplicates md;
    --- ---
----- -----

-----Record Fix-----
  --Use the identified cr.origrec's to make the records match.  
  --we will use the latest cr.origrec as the template value.
  UPDATE centralreceiving cr
  SET
    cr.owner_address = '6419 W PIMA ST' --6419 W Pima St
  WHERE 1=1
    AND cr.origrec = '172472'
----- -----

-----After Fix-----
--  1. Load and execut the Execute_BatchJob scipt located in the 
--     \\hsphxmstarlims2\STARLIMS_Share\SQL Repository\Version10\98_CIFOR
--     directory.
-- 2. Log onto the CIFOR server(LAB-090621D.hs.azdhs.gov) and execute the 
--    CIFOR_ExtractJob in the Task Scheduler.  It will update the extract
--    located in the \\Lab-090621D.hs.azdhs.gov\CIFOR\Datafiles Shared directory.
----- -----
 
/*---------------------------------------------------------------------------*/
