CREATE OR REPLACE VIEW V_CIFOR_MERGE AS
WITH  /*-----------------------------------------------------------------*/
                                                      /*-----Desription-----*/
                 --This query is the core query used to merge data between the
                 --BioNumeric databases and the STARLiMS database.  Results of
                  --this view are the basis of the text file imported into the
                                                          --CIFOR application.
                                                               /*----- -----*/

                                                         /*-----History-----*/
                                                --2015.07.31 JTY: Created View
                  --2015.08.07 JTY: Updated patient ID column to use MEDSIS ID
                                          --                (cr.external_pid1)
                        --2015.08.20 JTY: Updated STARLiMS query to return "."
                  --                instead of " " if no value was present for
                         --                RasClient.county --> Region.  since
              --                records without this value were crashing CIFOR
                 --                import since text file generated for import
                      --                trimmed blanks spaces for final column
                              --                (SourceCounty) in each record.
                   --2015.08.21 JTY  Updated Query to pull SeroType infor from
                --                BioNumerics database for other_result column
             --2015.11.11 JTY  Updated to allow for NULL pattern values in the
              --                BioNumeric Databases.  Apparently, it's ok for
                            --                the CDC not to assign a pattern.
                --2015.12.22 JTY: Addition of date_uploaded field.  This value
               --                is obtained from the BioNumerics database and
               --                represents the date the results were uploaded
                                    --                to the PulseNet program.
                  --2016.07.15 JTY: BioNumerics program now stores patient age
               --                differntly if over 1 years old.  Update Query
                                  --                to accomicate this change.
              --2016.08.25 JTY: Again, issues with patient_age value stored in
                --                database field.  I have updated the query to
                 --                try to make it more dynamic for the various
               --                forms they store the age in.  We will see how
                  --                long this last until the figure out how to
                                                 --                break this!
               --2017.10.17 JTY: Hijacking Submitter_Specimen_ID for EPI group
                --                They want to use the ENTRYTABLE.WGS_id field
                                                       --                here.
                                                               /*----- -----*/

         /*-----------------------------------------------------------------*/
                                                             /*---no_data---*/
   no_data AS (SELECT   DISTINCT                        --' ' AS primary_test,
                                                        --' ' AS other_result,
                         ' ' AS multiple_unit, --Now Using UploadedDate from BioNumerics for this field 2015.12.23
                         ' ' AS postal_code_plus_4,
                         ' ' AS local_primary_enzyme_pattern,
                         ' ' AS local_secondary_enzyme_pattern,
                         '~' AS eol
                 FROM   DUAL),
   /*--- ---*/
   /*---sl_data---*/
   sl_data
      AS (SELECT   DISTINCT
                   SUBSTR (TRIM (cr.external_id), 1, 10)
                      AS lab_specimen_id,
                   TO_CHAR (f.apprdate, 'MMDDYYYY') AS date_reported,
                   SUBSTR (COALESCE (TRIM (r.analyte), ' '), 1, 60)
                      AS primary_test,
                   SUBSTR (COALESCE (TRIM (r.final), ' '), 1, 80)
                      AS organism,
                   SUBSTR (COALESCE (TRIM (rc.rasclientid), ' '), 1, 20)
                      AS submitter_id,
                   SUBSTR (COALESCE (TRIM (rc.compname), ' '), 1, 50)
                      AS submitter_name,
                   SUBSTR (COALESCE (TRIM (rc.state), ' '), 1, 2)
                      AS submitter_state,
                   SUBSTR (COALESCE (TRIM (cr.external_pid1), ' '),
                           1,
                           20)
                      AS patient_id,
                   SUBSTR (COALESCE (TRIM (cr.first_name), ' '), 1, 20)
                      AS first_name,
                   SUBSTR (COALESCE (TRIM (cr.middle_initial), ' '),
                           1,
                           20)
                      AS middle_name,
                   SUBSTR (COALESCE (TRIM (cr.last_name), ' '), 1, 20)
                      AS last_name,
                   SUBSTR (COALESCE (TRIM (cr.owner_address), ' '),
                           1,
                           30)
                      AS street_address,
                   SUBSTR (COALESCE (TRIM (cr.owner_city), ' '), 1, 30)
                      AS source_city,
                   SUBSTR (COALESCE (TRIM (cr.owner_zip), ' '), 1, 5)
                      AS postal_code_5,
                   COALESCE (TO_CHAR (cr.birth_date, 'MMDDYYYY'), ' ')
                      AS date_of_birth,
                   SUBSTR (COALESCE (rc.county, '.'), 1, 20) AS region,
                   '~' AS eol
            FROM                     sundata_prod.centralreceiving cr
                                  INNER JOIN
                                     sundata_prod.rasclients rc
                                  ON (cr.rasclientid = rc.rasclientid)
                               INNER JOIN
                                  sundata_prod.patients p
                               ON (cr.patient_id = p.patient_id)
                            INNER JOIN
                               sundata_prod.folders f
                            ON (cr.external_id = f.external_id)
                         INNER JOIN
                            sundata_prod.ordtask ot
                         ON (f.folderno = ot.folderno)
                      INNER JOIN
                         sundata_prod.tests t
                      ON (ot.testcode = t.testcode)
                   INNER JOIN
                      sundata_prod.results r
                   ON (    1 = 1
                       AND ot.testcode = r.testcode
                       AND ot.ordno = r.ordno)
           WHERE   1 = 1 AND f.apprdate IS NOT NULL
                   AND t.testno IN
                            ('PFGE - E. coli O157',
                             'PFGE - Salmonella',
                             'PFGE - Listeria',
                             'PFGE - Non-O157 E. coli')),
   /*--- ---*/

   /*---list_data---*/
   list_data
      AS (SELECT   DISTINCT
                   'bn_list' AS db_source,
                   et."KEY" AS lab_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."WGS_id"), ' '), 1, 20)
                      AS submitter_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."SourceSite"), ' '), 1, 20)
                      AS specimen_source,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."IsolatDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_collected,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."ReceivedDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_received,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."UploadDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_uploaded,
                   COALESCE (TRIM (et."PFGE-AscI-pattern"), ' ')
                      AS cdc_primary_enzyme_pattern,
                   COALESCE (TRIM (et."PFGE-ApaI-pattern"), 'None')
                      AS cdc_secondary_enzyme_pattern,
                   SUBSTR (COALESCE (TRIM (et."Serotype"), ' '), 0, 80)
                      AS other_result,
                   SUBSTR (COALESCE (TRIM (et."SourceState"), ' '), 1, 2)
                      AS source_state,
                   SUBSTR (COALESCE (TRIM (et."SourceCounty"), ' '),
                           1,
                           30)
                      AS source_county,
                   CASE
                      WHEN (UPPER (et."PatientSex") = 'MALE') THEN 'M'
                      WHEN (UPPER (et."PatientSex") = 'FEMALE') THEN 'F'
                      ELSE 'U'                                       --Unknown
                   END
                      AS patient_sex,
                   --patient_age--
                   --Age as supplied by BioNumerics, we will need to replace this
                   --further down the query, right now we keep it as-is for
                   --troubleshooting.
                   et."PatientAge" AS patient_age,
                   -- --
                   --age_years--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '-') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '.') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      ELSE
                         CAST (
                            COALESCE ( (TRIM (et."PatientAge")), '0') AS INTEGER
                         )
                   END
                      AS age_years,
                   -- --
                   --age_months--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       (INSTR (et."PatientAge", '-') + 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            TO_NUMBER(COALESCE (
                                         TRIM(SUBSTR (
                                                 et."PatientAge",
                                                 (INSTR (et."PatientAge",
                                                         '.')
                                                  + 1)
                                              )),
                                         '0'
                                      ))
                            * 12 AS INTEGER
                         )
                      ELSE
                         CAST (0 AS INTEGER)
                   END
                      AS age_months,
                   -- --
                   SUBSTR (COALESCE (TRIM (et."Outbreak"), ' '), 1, 20)
                      AS cdc_cluster_code,
                   '~' AS eol
            FROM   bn_list.entrytable@biop et
           WHERE   1 = 1
                   --AND TRIM(et."PFGE-AscI-pattern") IS NOT NULL  --2015.11.11 JTY
                   --Filter out non-conforming data--
                   AND REGEXP_LIKE (
                         SUBSTR (et."IsolatDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         SUBSTR (et."ReceivedDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         et."PatientAge",
                         '((^((( )|[0-9]){3}){1}(-)((( )|[0-9]){3}){1}$)|(^(1|\s)?[0-9]?[0-9]?))'
                      )),
   /*--- ---*/

   /*---sal_data---*/
   sal_data
      AS (SELECT   DISTINCT
                   'bn_sal' AS db_source,
                   et."KEY" AS lab_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."WGS_id"), ' '), 1, 20)
                      AS submitter_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."SourceSite"), ' '), 1, 20)
                      AS specimen_source,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."IsolatDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_collected,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."ReceivedDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_received,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."UploadDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_uploaded,
                   SUBSTR (COALESCE (TRIM (et."PFGE-XbaI-pattern"), ' '),
                           1,
                           30)
                      AS cdc_primary_enzyme_pattern,
                   SUBSTR (
                      COALESCE (TRIM (et."PFGE-BlnI-pattern"), 'None'),
                      1,
                      60
                   )
                      AS cdc_secondary_enzyme_pattern,
                   SUBSTR (COALESCE (TRIM (et."SEROTYPE"), ' '), 0, 80)
                      AS other_result,
                   SUBSTR (COALESCE (TRIM (et."SourceState"), ' '), 1, 2)
                      AS source_state,
                   SUBSTR (COALESCE (TRIM (et."SourceCounty"), ' '),
                           1,
                           30)
                      AS source_county,
                   CASE
                      WHEN (UPPER (et."PatientSex") = 'MALE') THEN 'M'
                      WHEN (UPPER (et."PatientSex") = 'FEMALE') THEN 'F'
                      ELSE 'U'                                       --Unknown
                   END
                      AS patient_sex,
                   --patient_age--
                   --Age as supplied by BioNumerics, we will need to replace this
                   --further down the query, right now we keep it as-is for
                   --troubleshooting.
                   et."PatientAge" AS patient_age,
                   -- --
                   --age_years--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '-') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '.') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      ELSE
                         CAST (
                            COALESCE ( (TRIM (et."PatientAge")), '0') AS INTEGER
                         )
                   END
                      AS age_years,
                   -- --
                   --age_months--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       (INSTR (et."PatientAge", '-') + 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            TO_NUMBER(COALESCE (
                                         TRIM(SUBSTR (
                                                 et."PatientAge",
                                                 (INSTR (et."PatientAge",
                                                         '.')
                                                  + 1)
                                              )),
                                         '0'
                                      ))
                            * 12 AS INTEGER
                         )
                      ELSE
                         CAST (0 AS INTEGER)
                   END
                      AS age_months,
                   -- --
                   SUBSTR (COALESCE (TRIM (et."Outbreak"), ' '), 1, 20)
                      AS cdc_cluster_code,
                   '~' AS eol
            FROM   bn_sal.entrytable@biop et
           WHERE   1 = 1
                   --AND TRIM(et."PFGE-XbaI-pattern") IS NOT NULL  --2015.11.11 JTY
                   --Filter out non-conforming data--
                   AND REGEXP_LIKE (
                         SUBSTR (et."IsolatDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         SUBSTR (et."ReceivedDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         et."PatientAge",
                         '((^((( )|[0-9]){3}){1}(-)((( )|[0-9]){3}){1}$)|(^(1|\s)?[0-9]?[0-9]?))'
                      )),
   /*--- ---*/

   /*---ecoli_data---*/
   ecoli_data
      AS (SELECT   DISTINCT
                   'bn_ecoli' AS db_source,
                   et."KEY" AS lab_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."WGS_id"), ' '), 1, 20)
                      AS submitter_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."SourceSite"), ' '), 1, 20)
                      AS specimen_source,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."IsolatDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_collected,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."ReceivedDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_received,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."UploadDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_uploaded,
                   SUBSTR (COALESCE (TRIM (et."PFGE-XbaI-pattern"), ' '),
                           1,
                           30)
                      AS cdc_primary_enzyme_pattern,
                   SUBSTR (
                      COALESCE (TRIM (et."PFGE-BlnI-pattern"), 'None'),
                      1,
                      60
                   )
                      AS cdc_secondary_enzyme_pattern,
                   SUBSTR (COALESCE (TRIM (et."Serotype"), ' '), 0, 80)
                      AS other_result,
                   SUBSTR (COALESCE (TRIM (et."SourceState"), ' '), 1, 2)
                      AS source_state,
                   SUBSTR (COALESCE (TRIM (et."SourceCounty"), ' '),
                           1,
                           30)
                      AS source_county,
                   CASE
                      WHEN (UPPER (et."PatientSex") = 'MALE') THEN 'M'
                      WHEN (UPPER (et."PatientSex") = 'FEMALE') THEN 'F'
                      ELSE 'U'                                       --Unknown
                   END
                      AS patient_sex,
                   --patient_age--
                   --Age as supplied by BioNumerics, we will need to replace this
                   --further down the query, right now we keep it as-is for
                   --troubleshooting.
                   et."PatientAge" AS patient_age,
                   -- --
                   --age_years--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '-') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '.') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      ELSE
                         CAST (
                            COALESCE ( (TRIM (et."PatientAge")), '0') AS INTEGER
                         )
                   END
                      AS age_years,
                   -- --
                   --age_months--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       (INSTR (et."PatientAge", '-') + 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            TO_NUMBER(COALESCE (
                                         TRIM(SUBSTR (
                                                 et."PatientAge",
                                                 (INSTR (et."PatientAge",
                                                         '.')
                                                  + 1)
                                              )),
                                         '0'
                                      ))
                            * 12 AS INTEGER
                         )
                      ELSE
                         CAST (0 AS INTEGER)
                   END
                      AS age_months,
                   -- --
                   SUBSTR (COALESCE (TRIM (et."Outbreak"), ' '), 1, 20)
                      AS cdc_cluster_code,
                   '~' AS eol
            FROM   bn_ecoli.entrytable@biop et
           WHERE   1 = 1
                   --AND TRIM(et."PFGE-XbaI-pattern") IS NOT NULL  --2015.11.11 JTY
                   --Filter out non-conforming data--
                   AND REGEXP_LIKE (
                         SUBSTR (et."IsolatDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         SUBSTR (et."ReceivedDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         et."PatientAge",
                         '((^((( )|[0-9]){3}){1}(-)((( )|[0-9]){3}){1}$)|(^(1|\s)?[0-9]?[0-9]?))'
                      )),
   /*--- ---*/

   /*---no157_data---*/
   no157_data
      AS (SELECT   DISTINCT
                   'bn_no157' AS db_source,
                   et."KEY" AS lab_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."WGS_id"), ' '), 1, 20)
                      AS submitter_specimen_id,
                   SUBSTR (COALESCE (TRIM (et."SourceSite"), ' '), 1, 20)
                      AS specimen_source,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."IsolatDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_collected,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."ReceivedDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_received,
                   COALESCE (
                      TO_CHAR (
                         TO_DATE (SUBSTR (et."UploadDate", 1, 10),
                                  'YYYY-MM-DD'),
                         'MMDDYYYY'
                      ),
                      ' '
                   )
                      AS date_uploaded,
                   SUBSTR (COALESCE (TRIM (et."PFGE-XbaI-pattern"), ' '),
                           1,
                           30)
                      AS cdc_primary_enzyme_pattern,
                   SUBSTR (
                      COALESCE (TRIM (et."PFGE-BlnI-pattern"), 'None'),
                      1,
                      60
                   )
                      AS cdc_secondary_enzyme_pattern,
                   SUBSTR (COALESCE (TRIM (et."Serotype"), ' '), 0, 80)
                      AS other_result,
                   SUBSTR (COALESCE (TRIM (et."SourceState"), ' '), 1, 2)
                      AS source_state,
                   SUBSTR (COALESCE (TRIM (et."SourceCounty"), ' '),
                           1,
                           30)
                      AS source_county,
                   CASE
                      WHEN (UPPER (et."PatientSex") = 'MALE') THEN 'M'
                      WHEN (UPPER (et."PatientSex") = 'FEMALE') THEN 'F'
                      ELSE 'U'                                       --Unknown
                   END
                      AS patient_sex,
                   --patient_age--
                   --Age as supplied by BioNumerics, we will need to replace this
                   --further down the query, right now we keep it as-is for
                   --troubleshooting.
                   et."PatientAge" AS patient_age,
                   -- --
                   --age_years--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '-') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       0,
                                       (INSTR (et."PatientAge", '.') - 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      ELSE
                         CAST (
                            COALESCE ( (TRIM (et."PatientAge")), '0') AS INTEGER
                         )
                   END
                      AS age_years,
                   -- --
                   --age_months--
                   CASE
                      WHEN INSTR (et."PatientAge", '-') > 0
                      THEN
                         CAST (
                            COALESCE (
                               TRIM(SUBSTR (
                                       et."PatientAge",
                                       (INSTR (et."PatientAge", '-') + 1)
                                    )),
                               '0'
                            ) AS INTEGER
                         )
                      WHEN INSTR (et."PatientAge", '.') > 0
                      THEN
                         CAST (
                            TO_NUMBER(COALESCE (
                                         TRIM(SUBSTR (
                                                 et."PatientAge",
                                                 (INSTR (et."PatientAge",
                                                         '.')
                                                  + 1)
                                              )),
                                         '0'
                                      ))
                            * 12 AS INTEGER
                         )
                      ELSE
                         CAST (0 AS INTEGER)
                   END
                      AS age_months,
                   -- --
                   SUBSTR (COALESCE (TRIM (et."Outbreak"), ' '), 1, 20)
                      AS cdc_cluster_code,
                   '~' AS eol
            FROM   bn_no157.entrytable@biop et
           WHERE   1 = 1
                   --AND TRIM(et."PFGE-XbaI-pattern") IS NOT NULL  --2015.11.11 JTY
                   --Filter out non-conforming data--
                   AND REGEXP_LIKE (
                         SUBSTR (et."IsolatDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         SUBSTR (et."ReceivedDate", 1, 10),
                         '^[1-2][0-9]{3}-[0-1][0-9]-[0-3][0-9]'
                      )
                   AND REGEXP_LIKE (
                         et."PatientAge",
                         '((^((( )|[0-9]){3}){1}(-)((( )|[0-9]){3}){1}$)|(^(1|\s)?[0-9]?[0-9]?))'
                      )),
   /*--- ---*/

   /*---bn_union---*/
   bn_union AS (SELECT   * FROM ecoli_data
                UNION
                SELECT   * FROM list_data
                UNION
                SELECT   * FROM no157_data
                UNION
                SELECT   * FROM sal_data),
   /*--- ---*/
   /*---all_together---*/
   all_together
      AS (  SELECT   DISTINCT
                     sl.lab_specimen_id,
                     bn.submitter_specimen_id,
                     bn.specimen_source,
                     bn.date_collected,
                     bn.date_received,
                     bn.date_uploaded,
                     sl.date_reported,
                     sl.primary_test,
                     ' ',
                     sl.organism,
                     bn.cdc_primary_enzyme_pattern,
                     bn.cdc_secondary_enzyme_pattern,
                     bn.other_result,
                     sl.submitter_id,
                     sl.submitter_name,
                     sl.submitter_state,
                     sl.patient_id,
                     sl.first_name,
                     sl.middle_name,
                     sl.last_name,
                     --2015.12.23 JTY: Changed for EPI
                     bn.date_uploaded AS multiple_unit,
                     --COALESCE(nd.multiple_unit, ' ') AS multiple_unit,
                     sl.street_address,
                     sl.source_city,
                     bn.source_state,
                     bn.source_county,
                     sl.postal_code_5,
                     COALESCE (nd.postal_code_plus_4, ' ')
                        AS postal_code_plus_4,
                     bn.patient_sex AS gender,
                     sl.date_of_birth,
                     bn.age_years AS patient_age,   --Only interested in years
                     bn.cdc_cluster_code,
                     COALESCE (nd.local_primary_enzyme_pattern, ' ')
                        AS local_primary_enzyme_pattern,
                     COALESCE (nd.local_secondary_enzyme_pattern, ' ')
                        AS local_secondary_enzyme_pattern,
                     sl.region,
                     --Not Required Fields--
                     bn.db_source,
                     bn.age_years,
                     bn.age_months,
                     '~' AS eol
              FROM         sl_data sl
                        INNER JOIN
                           bn_union bn
                        ON (sl.lab_specimen_id = bn.lab_specimen_id)
                     LEFT OUTER JOIN
                        no_data nd
                     ON (sl.primary_test = bn.lab_specimen_id)
             WHERE   1 = 1
          ORDER BY   sl.date_reported DESC, sl.lab_specimen_id ASC)
     /*--- ---*/

     /*---Final Query---*/
     SELECT   DISTINCT al.lab_specimen_id,
                       al.submitter_specimen_id,
                       al.specimen_source,
                       al.date_collected,
                       al.date_received,
                       al.date_uploaded,
                       al.date_reported,
                       al.primary_test,
                       al.organism,
                       al.cdc_primary_enzyme_pattern,
                       al.cdc_secondary_enzyme_pattern,
                       al.other_result,
                       al.submitter_id,
                       al.submitter_name,
                       al.submitter_state,
                       al.patient_id,
                       al.first_name,
                       al.middle_name,
                       al.last_name,
                       al.multiple_unit,
                       al.street_address,
                       al.source_city,
                       al.source_state,
                       al.source_county,
                       al.postal_code_5,
                       al.postal_code_plus_4,
                       al.gender,
                       al.date_of_birth,
                       al.patient_age,
                       al.cdc_cluster_code,
                       al.local_primary_enzyme_pattern,
                       al.local_secondary_enzyme_pattern,
                       al.region
       FROM   all_together al
      WHERE   1 = 1
   ORDER BY   al.date_reported DESC, al.lab_specimen_id ASC
;
