/*-----CleanupNon-ActiveUsersRecords-----------------------------------------*/
  -----DESCRIPTION-----
    --Use this set of scripts to clean-up tables that are associated with
    --users who may have been retired.
    --
    --1. ResponsibleSync - Update Responsible persons for panels
    --2. StorageLocations - Update storage locations access.
    --3. SiteMembers - Update members list ssscoiated with sites.
    --4. DepartmentList - Remove all departments user is associated with
    --5. InternalContacts - Ensure retired users are not associated with
    --    any clients as Internal Contacts
  ----- -----


  -----HISTORY-----
    --20180430 JTY: Begin creation of scripts.
  ----- -----

/*---------------------------------------------------------------------------*/





/*-----1. ResponsibleSync----------------------------------------------------*/
  --Update the Responsible list for the panels to ensure anyone not active
  --is NOT responsible for the panel.
  
  ---Identify records to be removed.---  
    SELECT DISTINCT
      u.usrnam,
      u.fullname,
      u.status,
      tgu.*
    FROM  testgroup_users tgu
      INNER JOIN users u ON (tgu.usrnam = u.usrnam)    
    WHERE 1=1
      AND u.status <> 'Active'
    ORDER BY
      u.usrnam ASC,
      tgu.testgroupname ASC;
  --- ---

  ---Remove Responsible records for retired persons---
/*  
    DELETE
    FROM testgroup_users tgu
    WHERE 1=1
      AND tgu.origrec IN (
        SELECT DISTINCT
          tgu.origrec
        FROM  testgroup_users tgu
          INNER JOIN users u ON (tgu.usrnam = u.usrnam)    
        WHERE 1=1
          AND u.status <> 'Active'
      )
*/
  --- ---
/*---------------------------------------------------------------------------*/




  




/*-----2. StorageLocations--------------------------------------------------*/
  --Update the StorageLocations list so if the user is not active, they cannot
  --have access to the storage locations.
  
  ---Identify records to be removed.---  
    SELECT DISTINCT
      u.usrnam,
      u.fullname,
      u.status,
      bl.*
    FROM benchlocations bl
      INNER JOIN users u ON (bl.usrnam = u.usrnam)    
    WHERE 1=1
      AND u.status <> 'Active'
    ORDER BY
      u.usrnam ASC,
      bl.locationcode ASC;
  --- ---

  ---Remove access to StorageLocations for retired persons---
/*  
    DELETE
    FROM benchlocations bl
    WHERE 1=1
      AND bl.origrec IN (
        SELECT DISTINCT
          bl.origrec
        FROM benchlocations bl
          INNER JOIN users u ON (bl.usrnam = u.usrnam)    
        WHERE 1=1
          AND u.status <> 'Active'
      )
*/
  --- ---
/*---------------------------------------------------------------------------*/



  


/*-----3. SiteMembers-------------------------------------------------------*/
  --Update the Site Members for departments to ensure anyone not active
  --does not have access to the Site.
  
  ---Identify records to be removed.---  
    SELECT DISTINCT
      u.usrnam,
      u.fullname,
      u.status,
      sa.*
    FROM servganalyst sa
      INNER JOIN users u ON (sa.usrnam = u.usrnam)    
    WHERE 1=1
      AND u.status <> 'Active'
    ORDER BY
      u.usrnam ASC,
      sa.dept ASC;
  --- ---

  ---Remove retired persons from Sites---
/*  
    DELETE
    FROM servganalyst sa
    WHERE 1=1
      AND sa.origrec IN (
        SELECT DISTINCT
          sa.origrec
        FROM servganalyst sa
          INNER JOIN users u ON (sa.usrnam = u.usrnam)    
        WHERE 1=1
          AND u.status <> 'Active'
      )
*/
  --- ---
/*---------------------------------------------------------------------------*/



  


/*-----4. DepartmentList----------------------------------------------------*/
  --Remove all departments user is associated with.

  ---Identify records to be removed.---  
    SELECT DISTINCT
      u.usrnam,
      u.fullname,
      u.status,
      u.deptlist,
      '~' AS eol
    FROM users u
    WHERE 1=1
      AND u.status <> 'Active'
    ORDER BY
      u.usrnam ASC;
  --- ---

  ---Remove DepartmentList associated with retired persons---
/*  
    UPDATE users u
    SET u.deptlist = ''
    WHERE 1=1
      AND u.origrec IN (
        SELECT DISTINCT
          u.origrec
        FROM users u
        WHERE 1=1
          AND u.status <> 'Active'
      )
*/
  --- ---
/*---------------------------------------------------------------------------*/



  


/*-----5. InternalContacts--------------------------------------------------*/
  --Ensure retired users are not associated with any clients as Internal Contacts

  ---Identify records to be removed.---  
    SELECT DISTINCT
      u.usrnam,
      u.fullname,
      u.status,
      rc.rasclientid,
      rc.compname,
      rcc.*
    FROM rasclientcontacts rcc
      INNER JOIN users u ON (rcc.usrnam = u.usrnam)
      LEFT OUTER JOIN rasclients rc ON (rcc.rasclientid = rc.rasclientid)
    WHERE 1=1
      AND u.status <> 'Active'
    ORDER BY
      u.usrnam ASC,
      rcc.rasclientid ASC;
  --- ---

  ---Remove InternalContacts records for retired persons---
/*  
    DELETE
    FROM rasclientcontacts rcc
    WHERE 1=1
      AND rcc.origrec IN (
        SELECT DISTINCT
          rcc.origrec
        FROM rasclientcontacts rcc
          INNER JOIN users u ON (rcc.usrnam = u.usrnam)    
        WHERE 1=1
          AND u.status <> 'Active'
      )
*/
  --- ---
/*---------------------------------------------------------------------------*/
