

/*-----Cross Environments Check: CannedComments--------------------*/
  /*----------DESCRIPTION----------*/
    --Use this script to compare CannedComments across environements.
    --the query will identify what CC are in Environment1 but not
    --Environment2
  /*---------- ----------*/

  /*----------HISTORY----------*/
    --2013.05.08 JTY: Created Script
  /*---------- ----------*/


  /*---------- ----------*/
  /*---------- ----------*/

  /*----------ENVIRONMENTS----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod  
  /*---------- ----------*/
  
  /*----------Reference Tables----------*/
    --SELECT * FROM &Environment.canned_comments
    --SELECT * FROM &Environment.tests
  /*---------- ----------*/
  
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
  /*---------- ----------*/
    WITH
    ---Environment1---
      MyEnv01 AS (
        SELECT DISTINCT
          CASE 
            WHEN ('&Environment_01' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_01' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_01' = 'sundata_prod') THEN 'PROD'                            
          END AS env,
          cc.testgroupname,
          t.testno,  
          cc.analyte,
          (cc.conditionfield || ' ' || cc.qualifier || ' ' || cc.conditionvalue) as cc_trigger,
          cc.status,
          cc.canned_comment,
          cc.testcode,
          (
            COALESCE(cc.testgroupname, 'testgroupname') || '~' || CHR(13) ||
            COALESCE(t.testno, 'testno') || '~' || CHR(13) ||
            COALESCE(cc.analyte, 'analyte') || '~' || CHR(13) ||
            COALESCE(
              (TRIM(cc.conditionfield || ' ' || cc.qualifier)), 'cc_trigger') || '~' || CHR(13) ||
            COALESCE(cc.status, 'status') || '~' || CHR(13) ||
            COALESCE(cc.canned_comment, 'canned_comment')
          ) AS MyJoin,
          '~' AS eol
        FROM &Environment_01.canned_comments cc        
          LEFT OUTER JOIN &Environment_01.tests t ON (cc.testcode = t.testcode)
        WHERE 1=1
          AND NOT (cc.status IN ('Retired'))
        ORDER BY
          cc.testgroupname ASC,
          t.testno ASC,  
          cc.analyte ASC,
          cc.canned_comment ASC
      ),
    ---
    ---Environment2--
      MyEnv02 AS (
        SELECT DISTINCT
          CASE 
            WHEN ('&Environment_02' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_02' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_02' = 'sundata_prod') THEN 'PROD'                            
          END AS env,
          cc.testgroupname,
          t.testno,  
          cc.analyte,
          (cc.conditionfield || ' ' || cc.qualifier || ' ' || cc.conditionvalue) as cc_trigger,
          cc.status,
          cc.canned_comment,
          cc.testcode,
          (
            COALESCE(cc.testgroupname, 'testgroupname') || '~' || CHR(13) ||
            COALESCE(t.testno, 'testno') || '~' || CHR(13) ||
            COALESCE(cc.analyte, 'analyte') || '~' || CHR(13) ||
            COALESCE(
              (TRIM(cc.conditionfield || ' ' || cc.qualifier )), 'cc_trigger') || '~' || CHR(13) ||
            COALESCE(cc.status, 'status') || '~' || CHR(13) ||
            COALESCE(cc.canned_comment, 'canned_comment')
          ) AS MyJoin,
          '~' AS eol
        FROM &Environment_02.canned_comments cc        
          LEFT OUTER JOIN &Environment_02.tests t ON (cc.testcode = t.testcode)
        WHERE 1=1
          AND NOT (cc.status IN ('Retired'))
        ORDER BY
          cc.testgroupname ASC,
          t.testno ASC,  
          cc.analyte ASC,
          cc.canned_comment ASC
        ),
    ---    
    ---Difference---
      MyDiff AS (
        SELECT DISTINCT
          E01.env AS env_01,
          CASE 
            WHEN ('&Environment_02' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_02' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_02' = 'sundata_prod') THEN 'PROD'                            
          END AS env_02,
          E01.testgroupname,
          E01.testno,  
          E01.analyte,
          E01.cc_trigger,
          E01.status,
          E01.canned_comment,
          E01.testcode,
          '~' AS eol
        FROM MyEnv01 E01
          LEFT OUTER JOIN MyEnv02 E02 ON (
            E01.MyJoin = E02.MyJoin
          )
        WHERE 1=1
          AND E02.MyJoin IS NULL
        ORDER BY
          E01.testgroupname ASC,
          E01.testno ASC,  
          E01.analyte ASC,
          E01.canned_comment ASC
        )
    ---
    ---Final Query---
      --What's in Environment01 that is missing in Environment02
      SELECT DISTINCT 
          md.env_01,
          md.env_02,
          md.testgroupname,
          md.testno,  
          md.analyte,
          md.cc_trigger,
          md.status,
          md.canned_comment,
          md.testcode,
          '~' AS eol      
      FROM MyDiff md
      ORDER BY 
          md.testgroupname ASC,
          md.testno ASC,  
          md.analyte ASC,
          md.canned_comment ASC;
    ---    
  /*---------- ----------*/
/*-----------------------------------------------------------------*/
