

/*-----Cross Environments Check: Materials-------------------------*/
  /*----------DESCRIPTION----------*/
    --Use this script to compare Material across environements.
    --the query will identify what Materials in in Environment1
    --but NOT in Environment2
  /*---------- ----------*/

  /*----------HISTORY----------*/
  /*---------- ----------*/


  /*---------- ----------*/
  /*---------- ----------*/

  /*----------ENVIRONMENTS----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod  
  /*---------- ----------*/
  
  /*----------Reference Tables----------*/
    --SELECT * FROM &Environment.materials
    --SELECT * FROM sunrise_data.Prod_Suppliers
  /*---------- ----------*/
  
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
  /*---------- ----------*/
    WITH
    ---Environment1---
      MyEnv01 AS (
        SELECT DISTINCT
          CASE 
            WHEN ('&Environment_01' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_01' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_01' = 'sundata_prod') THEN 'PROD'                            
          END AS env_01,
          m.mattype,
          m.matcode,
          m.matname,
          m.unit_code,
          ps.suppcode,          
          --Optional--
          m.needqcprep,
          m.dept,
          --
          '~' AS eol
        FROM &Environment_01.Materials m        
          LEFT OUTER JOIN &Environment_01.Prod_Suppliers ps ON (m.matcode = ps.matcode)
        WHERE 1=1
          AND NOT (m.mattype IN ('Delete'))
        ORDER BY
          m.mattype ASC,
          m.matcode ASC,
          m.matname ASC,
          m.unit_code ASC,
          ps.suppcode ASC
      ),
    ---
    ---Environment2--
      MyEnv02 AS (
        SELECT DISTINCT
          CASE 
            WHEN ('&Environment_02' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_02' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_02' = 'sundata_prod') THEN 'PROD'                            
          END AS env_02,
          m.mattype,
          m.matcode,
          m.matname,
          m.unit_code,
          ps.suppcode,          
          --Optional--
          m.needqcprep,
          m.dept
          --
        FROM &Environment_02.Materials m
          LEFT OUTER JOIN &Environment_02.Prod_Suppliers ps ON (m.matcode = ps.matcode)        
        WHERE 1=1
          AND NOT (m.mattype IN ('Delete'))
        ORDER BY
          m.mattype ASC,
          m.matcode ASC,
          m.matname ASC,
          m.unit_code ASC,
          ps.suppcode ASC
        ),
    ---    
    ---Difference---
      MyDiff AS (
        SELECT DISTINCT
          E01.env_01,
          CASE 
            WHEN ('&Environment_02' = 'sunrise_data') THEN 'DEV'
            WHEN ('&Environment_02' = 'sundata_sat') THEN 'TEST'
            WHEN ('&Environment_02' = 'sundata_prod') THEN 'PROD'                            
          END AS env_02,
          E01.mattype,
          E01.matcode,
          E01.matname,
          E01.unit_code,
          E01.suppcode,
          --Optional--
          E01.needqcprep,
          E01.dept          
        FROM MyEnv01 E01
          LEFT OUTER JOIN MyEnv02 E02 ON (
              E01.matcode = E02.matcode)
        WHERE 1=1
          AND E02.matcode IS NULL
        ORDER BY
          E01.mattype ASC,
          E01.matcode ASC,
          E01.matname ASC,
          E01.unit_code ASC,
          E01.suppcode ASC
        )
    ---
    ---Final Query---
      --What's in Environment01 that is missing in Environment02
      SELECT DISTINCT 
          md.dept,          
          md.env_01,
          md.env_02,
          md.mattype,
          md.matcode,
          md.matname,
          md.unit_code,
          md.suppcode,
          --Optional--
          md.needqcprep,
          '~' AS eol      
      FROM MyDiff md
      ORDER BY 
          md.dept ASC,
          md.mattype ASC,
          md.matcode ASC,
          md.matname ASC,
          md.unit_code ASC,
          md.suppcode ASC;
    ---    
  /*---------- ----------*/

  /*---------- ----------*/
  /*---------- ----------*/


/*-----------------------------------------------------------------*/
