/*-----------------------------------------------------------------*/     
/*-----DefaultTest HL7 Config Information--------------------------*/
  /*----------Summary----------*/
    --Queries to retreive information from STARLiMS related to the
    --test HL7 configuration.  Queries Include:
      --01. General Information
      --02. HL7 Clients Manager
      --03. Client List
      --04. LOINC Codes
      --05. HL7 Mappings
      --06. PHVS Value Set
      --07. Sample Conclusions
      --08. SNOMED Codes
      --09. Test Group Agents
      --10. Test Manager
      --11. Test Manager: Possible Results
      --12. Test Manager: Analyte LOINC Codes
      --13. Test Manager: Test LOINC Codes
      --14. Panels for Clinical Login
  /*---------- ----------*/  

  /*----------History----------*/
    --2018.04.09 JTY: Begin script creation
    --2018.04.10 JTY: Tune Script
  /*---------- ----------*/  

/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/
/*-----01. General Information-------------------------------------*/
  --Section 01.General Information

  SELECT DISTINCT
      ctt.dept,
      t.testno,
      ListAgg(cta.analyte, ', ')WITHIN GROUP (ORDER BY cta.analyte) AS analytes,
    '~' AS eol
  FROM conditiontesttriggers ctt 
    INNER JOIN conditiontestanalytes cta ON ( 1=1
      AND ctt.dept = cta.dept
      AND ctt.testcode = cta.testcode
      AND ctt.testgroupname = cta.testgroupname
      AND ctt.method = cta.method)
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
---    
  WHERE 1=1
    --AND ctt.dept = '&Dept'
    --AND cta.testgroupname = '&PanelName'
    AND t.testno = '&TestName'
    --AND t.testcode = '&TestCode'
  GROUP BY
    ctt.dept,
    cta.testgroupname,
    t.testno
  ORDER BY 
    ctt.dept ASC,
    t.testno ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----02. HL7 Clients Manager-------------------------------------*/
  --Section 02 Identify what analytes are to be reported
  SELECT DISTINCT
    ha.rasclientid,
    t.testno,
    ha.analyte,
    ha.reportable,
    ha.result_fld AS reported_field,
    ha.value_type,
    ha.lrn_param AS is_parameter,
    '~' AS sp1,
--    a.sorter,
    '~' AS eol
  FROM hl7_analytes ha
    INNER JOIN tests t ON (ha.testcode = t.testcode)
    INNER JOIN analytes a ON (t.testcode = a.testcode)
  WHERE 1=1
   AND t.testno = '&TestName'
  ORDER BY
    ha.rasclientid ASC,
    t.testno ASC,
--    a.sorter ASC,
    ha.analyte ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----03. Client List---------------------------------------------*/
  --Section 03 Identify where generated XML file is stored
  SELECT DISTINCT
    rt.rasclientid,
    rt.ior_xml_path,
    '~' AS eol
  FROM hl7_analytes ha
    INNER JOIN tests t ON (ha.testcode = t.testcode)
    LEFT OUTER JOIN rasclientmessagetypes rt ON (ha.rasclientid = rt.rasclientid)
  WHERE 1=1
   AND t.testno = '&TestName'
  ORDER BY
    rt.rasclientid ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----04. LOINC Codes---------------------------------------------*/
  --Section 04 Identify LOINC codes associated with test 
  SELECT DISTINCT
    lc.version,
    lc.classcode,
    cl.classname,
    lc.loincnumber,
    lc.loinccomponenet AS component,
    lc.loincshortname AS short_name,
    '~' AS sp1,
    '~' AS eol
  FROM tests t
    LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
    INNER JOIN testloinccodes tc ON (t.testcode = tc.testcode)
    INNER JOIN loinccodes lc ON (1=1
      AND tc.loinccomponenet = lc.loinccomponenet
      AND tc.version = lc.version
      AND tc.loincnumber = lc.loincnumber)
    INNER JOIN loincclasses cl ON (1=1
      AND lc.classcode = cl.classcode
      AND lc.version = cl.version)
--      tc.analyte
  WHERE 1=1
   AND t.testno = '&TestName'
  ORDER BY
    lc.classcode ASC,
    lc.loinccomponenet ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----05. HL7 Mappings--------------------------------------------*/
  --Section 05 Dictate message layout format for the client 
  SELECT DISTINCT
    ha.rasclientid,
    fb.header_name AS mapping_name,
    fb.message_type AS mapping_type,
    fb.hl7_version,
    fb.description,
    '~' AS eol
  FROM tests t
    INNER JOIN hl7_analytes ha ON (t.testcode = ha.testcode)
    INNER JOIN rasclientmessagetypes rmt ON (ha.rasclientid = rmt.rasclientid)
    INNER JOIN hl7_fieldmap_binder fb ON (1=1
      AND rmt.ior_message_type = fb.message_type
      AND rmt.ior_header_name = fb.header_name)
    INNER JOIN hl7_fieldmap fm ON (1=1
      AND fb.hl7_version = fm.hl7_version)
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    fb.header_name ASC,
    ha.rasclientid ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----06. PHVS Value Set------------------------------------------*/
  --Represents the Possible responses for Sample Conclusions
  
  --NOTE: Not sure on the join of the phvs_value_sets_details table
  SELECT DISTINCT
    pvd.concept_code,
    pvd.concept_name,
    pvd.code_system_oid,
    pvd.display_name,
    pvd.code_system_version,
    pvd.code_system_code,
    '~' AS eol
  FROM conditiontesttriggers ctt
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
    INNER JOIN base_static_data bsd ON (bsd.bs_type = 'Sample Conclusions')
    INNER JOIN metadata_repository mr ON ( 1=1
      AND mr.tablereference = 'BASE_STATIC_DATA'
      AND mr.original_origrec = bsd.origrec
      AND UPPER(mr.field_varchar_01) LIKE (UPPER(ctt.testgroupname || ',%'))
     )
    INNER JOIN phvs_value_sets_details pvd ON (1=1
      AND pvd.value_set_code = 'PHVS_SAMPLE_CONCLUSIONS_LRN-B'
      AND pvd.concept_name = bsd.bs_name
    )
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    pvd.concept_code ASC,
    pvd.concept_name;   
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----07. Sample Conclusions--------------------------------------*/
  --identify the set of valid conclusions that can be associated
  --the panel associated with a sample.
  
  --NOTE: Not sure on the join of the phvs_value_sets_details table
  SELECT DISTINCT
    ctt.testgroupname AS panel,
    bsd.bs_status AS status,
    pvd.concept_code,
    pvd.concept_name,
    pvd.code_system_oid,
    pvd.display_name,
    '~' AS eol
  FROM conditiontesttriggers ctt
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
    INNER JOIN base_static_data bsd ON (bsd.bs_type = 'Sample Conclusions')
    INNER JOIN metadata_repository mr ON ( 1=1
      AND mr.tablereference = 'BASE_STATIC_DATA'
      AND mr.original_origrec = bsd.origrec
      AND UPPER(mr.field_varchar_01) LIKE (UPPER(ctt.testgroupname || ',%'))
    )
    INNER JOIN phvs_value_sets_details pvd ON (1=1
      AND pvd.value_set_code = 'PHVS_SAMPLE_CONCLUSIONS_LRN-B'
      AND pvd.concept_name = bsd.bs_name
    )
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    ctt.testgroupname ASC;    
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----08. SNOMED Codes--------------------------------------------*/
  --SNOMED codes are the codes associated with results of the test.
  
  SELECT DISTINCT
    --pr.analyte,
    pr.result,
    sc.snomedcode,
    sc.snomed_group,
    sc.snomedelement,
    sc.snomedconceptid,
    sc.snomeddescriptionid,
    '~' AS eol
  FROM tests t
    INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
    INNER JOIN snomedcodes sc ON (pr.snomedcode = sc.snomedcode)
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    --pr.analyte ASC,
    pr.result ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----09. Test Group Agents---------------------------------------*/
  --SNOMED codes are the codes associated with results of the test.
  
  SELECT DISTINCT
    ctt.testgroupname AS panel,
    mr.field_varchar_01 AS agent_description,
    mr.field_varchar_02 AS agent_code,
    mr.field_varchar_03 AS agent_oid,
    '~' AS eol
  FROM conditiontesttriggers ctt
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
    INNER JOIN base_static_data bsd ON (1=1
      AND bsd.bs_type = 'TestGroupAgents'
      AND bsd.bs_name = ctt.testgroupname)
    INNER JOIN metadata_repository mr ON ( 1=1
      AND mr.tablereference = 'BASE_STATIC_DATA'
      AND mr.original_origrec = bsd.origrec
    )
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    ctt.testgroupname ASC;    
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----10. Test Manager--------------------------------------------*/
  --Code asociated with the test.
  
  SELECT DISTINCT
    t.testno,
    t.phvs_code_system_code,
    t.phvs_code_system_oid,
    t.phvs_concept_code,
    t.phvs_concept_name,
    '~' AS eol
  FROM tests t
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    t.testno ASC;    
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----11. Test Manager: Possible Results--------------------------*/
  --Codes associated with test results.
  
  SELECT DISTINCT
    t.testno,
    pr.analyte,
    '~' AS sp1,
    pr.result,
    pr.snomedcode AS code,
    pr.result_status AS status,
    pr.conclusion_report AS reported_conclusion,
    '~' AS sp1,
    pr.sorter,
    '~' AS eol
  FROM tests t
    INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
  WHERE 1=1
    AND t.testno = '&TestName'
  ORDER BY
    t.testno ASC,
    pr.analyte ASC,
    pr.sorter ASC,
    pr.result ASC
    ;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----12. Test Manager: Analyte LOINC Codes-----------------------*/
  --Association of LOINC and SNOMED codes with the test
  SELECT DISTINCT
    --For Documentation--
    lc.classcode,
    a.analyte,
    '~' AS sp1,
    lc.loincnumber AS loinc_number,
    lc.loinccomponenet AS loinc_component,
    lc.version AS loinc_version,
    tc.loincdefault,
    tc.hl7_reportable,
    tc.code_system_oid,
    pr.result,
    pr.cdc_reportable,
    pr.elr_reportable,
    pr.localnumber,
    pr.code_system_oid,
    '~~~' AS sp2,
    -- -- 
  
    lc.classcode,
    '~' AS sp1,
    a.analyte,
    a.analtype,
    '~'AS sp2,
    lc.loincnumber AS loinc_number,
    lc.loinccomponenet AS loinc_component,
    lc.version AS loinc_version,
    tc.loincdefault,
    lc.loincmethod,
    lc.loincproperty,
    lc.loincscale,
    lc.loincsystems AS sample_type,
    lc.loinctime,
    tc.hl7_reportable,
    tc.code_system_oid,
    '~' AS sp3,
    pr.result,
    pr.snomedcode,
    pr.snomeddescriptionid,
    pr.snomedconceptid,
    pr.conclusion_report,
    pr.result_status,
    pr.cdc_reportable,
    pr.elr_reportable,
    pr.localnumber,
    pr.code_system_oid,
    '~' AS sp3,
    a.sorter,
    pr.sorter,
    '~' AS eol
  FROM tests t
    INNER JOIN analytes a ON (t.testcode = a.testcode)
    INNER JOIN testloinccodes tc ON (1=1
      AND a.testcode = tc.testcode
      AND a.analyte = tc.analyte)
    INNER JOIN loinccodes lc ON (1=1
      AND tc.loinccomponenet = lc.loinccomponenet
      AND tc.version = lc.version
      AND tc.loincnumber = lc.loincnumber)
    INNER JOIN loincclasses cl ON (1=1
      AND lc.classcode = cl.classcode
      AND lc.version = cl.version)
    INNER JOIN possibleresults pr ON (1=1
      AND a.testcode = pr.testcode
      AND a.analyte = pr.analyte)
  WHERE 1=1
   AND t.testno = '&TestName'
  ORDER BY
    a.sorter ASC,
    a.analyte ASC,
    lc.loinccomponenet ASC,
    pr.sorter ASC,
    pr.result ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----13. Test Manager: Test LOINC Codes--------------------------*/
  --LOINC code associated with test
  SELECT DISTINCT
    tc.loincnumber,
    tc.loinccomponenet,
    tc.version,
    tc.loincdefault,
    tc.loincmethod,
    tc.loincproperty,
    tc.loincscale,
    tc.loincsystems AS sample_type,
    tc.loinctime,
    '~' AS eol
  FROM tests t
    INNER JOIN testloinccodes tc ON (t.testcode = tc.testcode)
  WHERE 1=1
   AND tc.analyte = 'TESTLOINC'
   AND t.testno = '&TestName'
  ORDER BY
    tc.loinccomponenet ASC,
    tc.loincnumber ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----14. Panels for Clinical Login------------------------------*/
  --LOINC codes associated with test
  SELECT DISTINCT
    ctt.testgroupname AS panel,
    hdm.header_name,
    hfb.message_type,
    hfb.description,
    '~' AS sp1,
    hds.rasclientid,
    rc.compname,
    '~' AS sp2,
    t.testno AS test_name,    
    hdl.analyte,
    hdl.loincnumber,
    hdl.value_type,
    hdl.reportable_condition,
    hdl.reportsection,
    hdl.dept,
    hdl.header_name,
    '~' AS eol
  FROM tests t
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN hl7_dist_messages hdm ON (ctt.testgroupname = hdm.testgroupname)
    INNER JOIN hl7_fieldmap_binder hfb ON (hdm.header_name = hfb.header_name)
    INNER JOIN hl7_dist_submitters hds ON (ctt.testgroupname = hds.testgroupname)
    INNER JOIN rasclients rc ON (hds.rasclientid = rc.rasclientid)
    INNER JOIN hl7_dist_loincs hdl ON (1=1
      AND ctt.testgroupname = hdl.testgroupname
      AND ctt.testcode = hdl.testcode)
  WHERE 1=1
   AND t.testno = '&TestName'
  ORDER BY
    ctt.testgroupname ASC,
    hds.rasclientid ASC,
    t.testno ASC,
    hdl.analyte ASC,
    hdl.loincnumber ASC;
/*-----------------------------------------------------------------*/



/*-----------------------------------------------------------------*/
--Check to see what samples may have been approved recently that are
--associated with test we have configured.


  SELECT DISTINCT
    TO_DATE('10-APR-2018', 'DD-MON-YYYY') AS first_date,
    f.dept,
    (t.testno || ' (' || t.testcode || ')') AS test_name,
    f.folderno,
    f.testgroupname,
    f.apprdate,
    f.apprtime,
    f.approvedby,
    mr.field_varchar_80 AS activity_type,
    '~' AS eol
  FROM centralreceiving cr
    INNER JOIN folders f ON (cr.external_id = f.external_id)
    INNER JOIN metadata_repository mr ON (1=1
      AND mr.tablereference = 'CENTRALRECEIVING'
      AND mr.original_origrec = cr.origrec)
    INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
    INNER JOIN tests t ON (ot.testcode = t.testcode)
  WHERE 1=1
    AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
    AND f.apprdate IS NOT NULL
    AND f.folderno IS NOT NULL
    AND t.testno IN (
--      'CHIKV IgM MAC-ELISA', 
--      'Geenius HIV1/2 Assay',
--      'Zika IgM MAC-ELISA',
--4/10      'Plaque Reduction Neutralization Test (PRNT)',
--4/10      'Dengue IgM EIA',
--      'Dengue PCR',
--4/10      'Zika IgM Capture ELISA',
--      'Molecular Salmonella Serotyping',
      ''
      )
    AND f.apprdate >= TO_DATE('&CheckDate', 'DD-MON-YYYY')
--    AND f.external_id = '&AccessionID'
  ORDER BY
    test_name ASC,
    f.apprdate DESC,
    f.apprtime DESC,
    f.testgroupname ASC
    ;

/*-----------------------------------------------------------------*/
