/*-----AgeFix-----------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Use these scripts to identify and fix calculated age problems.
    --Age value is stored in the tables following tables:
      --[MetaData_Reposistory].field_integer_01
      --[Patients].age
  /*----- -----*/  

  /*----- -----*/
  /*----- -----*/  
/*---------------------------------------------------------------------------*/

--SELECT * FROM SUNDATA_PROD.PATIENTS P WHERE P.PATIENT_ID = 'PID00036428'
--
/*---------------------------------------------------------------------------*/
  /*-----Identify Issues-----*/
    SELECT 
      cr.external_id,
      cr.patient_id,
      (cr.last_name || ', ' || cr.first_name) AS patient_name,
      TRUNC(months_between(cr.date_collected, cr.birth_date)/12) AS calc_age,
      mr.field_integer_01 AS cr_age,
      p.age AS p_age,
      cr.birth_date,
      cr.date_collected,  
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN sundata_prod.metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      INNER JOIN sundata_prod.patients p ON (cr.patient_id = p.patient_id)      
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND cr.patient_id IS NOT NULL
      AND cr.birth_date IS NOT NULL           
      AND mr.field_integer_01 <> TRUNC(months_between(cr.date_collected, cr.birth_date)/12)
    ORDER BY
      cr.external_id ASC;  
  /*----- -----*/  

  /*----- -----*/
  /*----- -----*/  

/*---------------------------------------------------------------------------*/

  
  
/*---------------------------------------------------------------------------*/
  /*-----Perform Update On MetaData_Repository Table-----*/
    MERGE INTO sundata_prod.metadata_repository t1
    USING (
      SELECT
        cr.external_id,
        cr.patient_id,
        (cr.last_name || ', ' || cr.first_name) AS patient_name,
        TRUNC(months_between(cr.date_collected, cr.birth_date)/12) AS calc_age,
        mr.field_integer_01 AS cr_age,
        p.age AS p_age,
        cr.birth_date,
        cr.date_collected,
        mr.origrec AS mr_origrec,
        p.origrec AS p_origrec,
        '~' AS eol
      FROM sundata_prod.centralreceiving cr
        INNER JOIN sundata_prod.metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
        INNER JOIN sundata_prod.patients p ON (cr.patient_id = p.patient_id)
      WHERE 1=1
       AND cr.external_id IN (
         'AZ00041708','AZ00041709','AZ00041710',
         'AZ00041711','AZ00041712','AZ00041713', 
         'AZ00041714','AZ00041715','AZ00041716', 
         'AZ00041717','AZ00041718','AZ00041719', 
         'AZ00041720','AZ00041721','AZ00041722', 
         'AZ00041723','AZ00041724','AZ00041725', 
         'AZ00041726','AZ00041727', 'AZ00041763'
       )
      ORDER BY
        cr.external_id ASC
    ) t2
    ON  (t1.origrec = t2.mr_origrec)   
    WHEN MATCHED THEN
      UPDATE SET t1.field_integer_01 = t2.calc_age
  /*----- -----*/  

  /*-----Perform Update On Patients Table-----*/
    MERGE INTO sundata_prod.patients t1
    USING (

      SELECT DISTINCT
        cr.patient_id,
        (cr.last_name || ', ' || cr.first_name) AS patient_name,
        mr.field_integer_01 AS cr_age,
        p.age AS p_age,
        --p.origrec AS p_origrec,
        '~' AS eol
      FROM sundata_prod.centralreceiving cr
        INNER JOIN sundata_prod.metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
        INNER JOIN sundata_prod.patients p ON (cr.patient_id = p.patient_id)

      WHERE 1=1
       AND cr.external_id IN (
         'AZ00041708','AZ00041709','AZ00041710',
         'AZ00041711','AZ00041712','AZ00041713', 
         'AZ00041714','AZ00041715','AZ00041716', 
         'AZ00041717','AZ00041718','AZ00041719', 
         'AZ00041720','AZ00041721','AZ00041722', 
         'AZ00041723','AZ00041724','AZ00041725', 
         'AZ00041726','AZ00041727', 'AZ00041763'
       )
      ORDER BY
        cr.patient_id ASC

    ) t2
    ON  ( 1=1
          AND t1.patient_id = t2.patient_id
          --AND (t1.age IS NULL OR t1.age = 77)
        )   
    WHEN MATCHED THEN
      UPDATE SET t1.age = t2.cr_age
  /*----- -----*/  


/*---------------------------------------------------------------------------*/  
