/*-----------------------------------------------------------------*/
/*-----CommunicationsLogConflictFix--------------------------------*/
  ---Description---
    --These scripts will identify and fix conflicts between the
    --department the sample(folder) is associated with, and the
    --department the communication is associated with.
    --It is assumed the department associated with the communication
    --will be the same department the sample is associated with.

    --We have three conditions we need to cover:
      --1. External Users Communication Fix: Need to associate the 
          --Lab EXTERNAL with any communications created by external
          --lab personel.
      --2. Receving Dept Communication Fix: Need to associate the 
          --Lab RECEIVING with any communications created by peronel
          --in the Receiving Department.  (They cannot be associated
          --with any other departments).
      --3. Lab Communication Fix: Need to identify communications that
          --were created in a lab, and ensure that it matches the 
          --lab that the sample has been assigned to.
    
    --We are not currently aware of what may be causing this behavior.
    

  ---
  
  --History---
    --2014.05.06 JTY: Created Script
    --Path: \\hsphxvstrlms03\starlims online help\SQL Repository\Version10\FixScripts\CommunicationsLogConflictFix.sql
  ---

/*-----------------------------------------------------------------*/

/*-----Identify Conflicts------------------------------------------*/
  --This script will identify samples with conflicting communications.
  /*
      SELECT DISTINCT
        cl.origrec,
        cl.rasclientid,
        cl.folder_number,
        f.dept AS proposed,
        cl.dept AS curr_dept,
        cl.communication_id,
        cl.logged_by,
        cl.logged_date,
        cl.category,
        cl.comm_comment,
        '~' AS eol
      FROM &Environment.communication_log cl
        INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
      WHERE 1=1 
--        AND cl.dept NOT IN ('Receiving','External')
   
        AND cl.dept <> f.dept
      ORDER BY
        cl.folder_number DESC,
        cl.rasclientid ASC,
        cl.communication_id ASC;    
*/        
/*-----------------------------------------------------------------*/






/*-----Perform Repairs---------------------------------------------*/
  --This script will take update all conflicting communication departments
  --and sync them with the department assoicated with the sample.
  

/*----------1. External Users Communication Fix---------*/
  -----Identify any issues-----
      WITH
        ---RoleCount---
          RoleCount AS (
            SELECT DISTINCT
              ur.usrnam,
              count(distinct ur.treeauth) AS role_count,
              u.status,          
              '~' AS eol
            FROM &Environment.userroles ur
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND u.status = 'Active'
            GROUP BY
              ur.usrnam,
              u.status
            ORDER BY 
              ur.usrnam
          ),
        ---
        ---ExternalUsers--
          ExternalUsers AS (
            SELECT DISTINCT
              rc.usrnam,
              u.fullname,
              r.role,
              rc.eol
            FROM RoleCount rc
              INNER JOIN &Environment.userroles ur ON (rc.usrnam = ur.usrnam)
              INNER JOIN &Environment.roles r ON (ur.treeauth = r.treeauth)
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND rc.role_count = 1
              AND r.role IN ('External')
            ORDER BY
              rc.usrnam ASC,
              r.role ASC      
          ),
        ---    
        ---TroubledCommunications---
          TroubledCommunications AS (
            SELECT DISTINCT
              cl.origrec,
              cl.communication_id,
              eu.fullname,
              'External' AS dept,
              cl.dept AS bad_dept,
              cl.comm_comment,              
              eu.eol
            FROM ExternalUsers eu
              INNER JOIN &Environment.communication_log cl ON (cl.logged_by = eu.usrnam)
              INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
            WHERE 1=1
              AND cl.dept <> 'External'         
            ORDER BY
              cl.communication_id ASC
          )
        ---        
        SELECT * FROM TroubledCommunications;
  ----- -----
  
  -----Repair Conflicts-----
/*  
  MERGE INTO &Environment.communication_log t1
    USING (
      WITH
        ---RoleCount---
          RoleCount AS (
            SELECT DISTINCT
              ur.usrnam,
              count(distinct ur.treeauth) AS role_count,
              u.status,          
              '~' AS eol
            FROM &Environment.userroles ur
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND u.status = 'Active'
            GROUP BY
              ur.usrnam,
              u.status
            ORDER BY 
              ur.usrnam
          ),
        ---
        ---ExternalUsers--
          ExternalUsers AS (
            SELECT DISTINCT
              rc.usrnam,
              u.fullname,
              r.role,
              rc.eol
            FROM RoleCount rc
              INNER JOIN &Environment.userroles ur ON (rc.usrnam = ur.usrnam)
              INNER JOIN &Environment.roles r ON (ur.treeauth = r.treeauth)
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND rc.role_count = 1
              AND r.role IN ('External')
            ORDER BY
              rc.usrnam ASC,
              r.role ASC      
          ),
        ---    
        ---TroubledCommunications---
          ExtCommunications AS (
            SELECT DISTINCT
              cl.origrec,
              cl.communication_id,
              eu.fullname,              
              'External' AS dept,
              cl.dept AS bad_dept,
              cl.comm_comment,              
              eu.eol
            FROM ExternalUsers eu
              INNER JOIN &Environment.communication_log cl ON (cl.logged_by = eu.usrnam)
              INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
            WHERE 1=1
              AND cl.dept <> 'External'         
            ORDER BY
              cl.communication_id ASC
          )
        ---        
        SELECT * FROM ExtCommunications
    ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET t1.dept = t2.dept;
  ----- -----      
*/  
/*----------  ----------*/




/*----------2. Receving Dept Communication Fix---------*/ 
  -----Identify RECEIVING Conflicts-----  
      WITH
        ---RoleCount---
          RoleCount AS (
            SELECT DISTINCT
              ur.usrnam,
              count(distinct ur.treeauth) AS role_count,
              u.status,          
              '~' AS eol
            FROM &Environment.userroles ur
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND u.status = 'Active'
            GROUP BY
              ur.usrnam,
              u.status
            ORDER BY 
              ur.usrnam
          ),
        ---
        ---ReceivingUsers--
          ReceivingUsers AS (
            SELECT DISTINCT
              rc.usrnam,
              u.fullname,
              r.role,
              rc.eol
            FROM RoleCount rc
              INNER JOIN &Environment.userroles ur ON (rc.usrnam = ur.usrnam)
              INNER JOIN &Environment.roles r ON (ur.treeauth = r.treeauth)
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND rc.role_count = 1
              AND r.role IN ('Receiving','ReceivingSuper')
            ORDER BY
              rc.usrnam ASC,
              r.role ASC      
          ),
        ---
        ---TroubledCommunications---
          ExtCommunications AS (
            SELECT DISTINCT
              cl.origrec,
              cl.communication_id,
              ru.fullname,
              'Receiving' AS dept,
              cl.dept AS bad_dept,
              cl.comm_comment,                            
              ru.eol
            FROM ReceivingUsers ru
              INNER JOIN &Environment.communication_log cl ON (cl.logged_by = ru.usrnam)
              INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
            WHERE 1=1
              AND cl.dept <> 'Receiving' --'Receiving'         
            ORDER BY
              cl.communication_id ASC
          )
        ---        
        SELECT * FROM ExtCommunications;
  
  ----- -----
  
  -----Repair RECEIVING Conflicts-----
  /*
    MERGE INTO &Environment.communication_log t1
    USING (
      WITH
        ---RoleCount---
          RoleCount AS (
            SELECT DISTINCT
              ur.usrnam,
              count(distinct ur.treeauth) AS role_count,
              u.status,          
              '~' AS eol
            FROM &Environment.userroles ur
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND u.status = 'Active'
            GROUP BY
              ur.usrnam,
              u.status
            ORDER BY 
              ur.usrnam
          ),
        ---
        ---ReceivingUsers--
          ReceivingUsers AS (
            SELECT DISTINCT
              rc.usrnam,
              u.fullname,
              r.role,
              rc.eol
            FROM RoleCount rc
              INNER JOIN &Environment.userroles ur ON (rc.usrnam = ur.usrnam)
              INNER JOIN &Environment.roles r ON (ur.treeauth = r.treeauth)
              INNER JOIN &Environment.users u ON (ur.usrnam = u.usrnam)
            WHERE 1=1
              AND rc.role_count = 1
              AND r.role IN ('Receiving','ReceivingSuper')
            ORDER BY
              rc.usrnam ASC,
              r.role ASC      
          ),
        ---
        ---TroubledCommunications---
          ExtCommunications AS (
            SELECT DISTINCT
              cl.origrec,
              cl.communication_id,
              ru.fullname,              
              'Receiving' AS dept,
              cl.dept AS bad_dept,
              cl.comm_comment,                            
              ru.eol
            FROM ReceivingUsers ru
              INNER JOIN &Environment.communication_log cl ON (cl.logged_by = ru.usrnam)
              INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
            WHERE 1=1
              AND cl.dept <> 'Receiving' --'Receiving'         
            ORDER BY
              cl.communication_id ASC
          )
        ---        
        SELECT * FROM ExtCommunications
    ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET t1.dept = t2.dept  
*/          
  ----- -----      




/*----------3. Lab Communication Fix---------*/ 
  -----Identify Lab Conflicts-----  
        SELECT DISTINCT
        cl.origrec,
        cl.rasclientid,
        cl.folder_number,
        f.dept AS proposed,
        cl.dept AS curr_dept,
        cl.communication_id,
        cl.logged_by,
        cl.logged_date,
        cl.category,
        cl.comm_comment,
        '~' AS eol
      FROM &Environment.communication_log cl
        INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
      WHERE 1=1 
        AND cl.dept NOT IN ('Receiving','External')   
        AND cl.dept <> f.dept
      ORDER BY
        cl.folder_number DESC,
        cl.rasclientid ASC,
        cl.communication_id ASC;   
        
  ----- -----
  
  -----Repair Lab Conflicts-----
  /*
    MERGE INTO &Environment.communication_log t1
    USING (
        SELECT DISTINCT
        cl.origrec,
        cl.rasclientid,
        cl.folder_number,
        f.dept AS proposed,
        cl.dept AS curr_dept,
        cl.communication_id,
        cl.logged_by,
        cl.logged_date,
        cl.category,
        cl.comm_comment,
        '~' AS eol
      FROM &Environment.communication_log cl
        INNER JOIN &Environment.folders f ON (cl.folder_number = f.folderno) 
      WHERE 1=1 
        AND cl.dept NOT IN ('Receiving','External')   
        AND cl.dept <> f.dept
      ORDER BY
        cl.folder_number DESC,
        cl.rasclientid ASC,
        cl.communication_id ASC 
    ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET t1.dept = t2.proposed  
*/          
  ----- -----      




/*-----------------------------------------------------------------*/
    
