

/*-----RunApprovedFix----------------------------------------------*/
  /*----------Description----------*
    --There seems to be a bug in SL in that sometimes when a run
    --is approved that some of the QC and samples get the apprdate
    --and apprvedby columns updated, while other samles in the run
    --do not.  This is a problem in that for these samples the final
    --report may show the result as Pending even though the sample
    --appears to be completed since the panel has been approved.
    
    --These set of queries will identify what runs appear to have 
    --this issue and repair the problem.
    --
    --The three SQL statements provided here are:
      --Review Suspect Runs - Displays what runs are seeem to have issues.
      --Fix Single Run - Fix provided run number.
      --Fix Set Of Runs - Fix class of runs.
   
  /*---------- ----------*  

  /*----------Environments----------*
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod   
  /*---------- ----------*  


  /*----------History----------*
    --2013.08.22 JTY: Created Script
  /*---------- ----------*  

  /*---------- ----------*
  /*---------- ----------*  

/*-----------------------------------------------------------------*/





/*----Review Suspect Runs------------------------------------------*/
  --Want to review what runs seem to be having problems.
  
  WITH
    ---AllApprovedRuns---
    AllApprovedRuns AS (
      SELECT DISTINCT
        ot.runno,
        ot.apprdate,
        ot.apprvedby
      FROM &Environment.ordtask ot 
        INNER JOIN &Environment.tests t ON (ot.testcode = t.testcode)
      WHERE 1=1
        AND t.testflag = 'Default'
        AND t.testtype = 'Single'    
        AND ot.apprdate IS NOT NULL
      ORDER BY 
        ot.runno ASC),
    ---    
    ---RunsInQuestion---            
    RunsInQuestion AS (
      SELECT DISTINCT
        ot.runno     
      FROM  AllApprovedRuns aar
        INNER JOIN sundata_prod.ordtask ot ON (aar.runno = ot.runno)
      WHERE 1=1
        AND (ot.apprvedby IS NULL
        OR ot.apprdate IS NULL)),
    ---    
    ---RunsForReview---                    
    RunsForReview AS (
      SELECT DISTINCT
        ot.dept,
        r.analyte,
        ot.apprdate,
        ot.apprvedby,
        ot.runno,      
        f.external_id,
        r.final,
        '~' AS eol      
      FROM RunsInQuestion riq
         INNER JOIN &Environment.ordtask ot ON (riq.runno = ot.runno)
         INNER JOIN &Environment.results r ON (ot.ordno = r.ordno 
             AND ot.testcode = r.testcode)
         INNER JOIN &Environment.folders f ON (ot.folderno = f.folderno)
         INNER JOIN &Environment.tests t ON (ot.testcode = t.testcode)
      WHERE 1=1 
        AND t.testflag = 'Default'
        AND t.testtype = 'Single'
---Optional filters to narrow search---        
        --AND ot.dept = '&Dept'
        --AND ot.runno = '&RunNo'
        --AND r.analyte = '&Analyte' --'Syphilis RPR', 'Hepatitis C EIA'
        --AND f.external_id = '&SampleID'    
---        
      ORDER BY
        ot.dept ASC,
        r.analyte ASC,      
        ot.runno ASC,
        f.external_id ASC)
    ---    
    ---Final Query---                        
      SELECT * FROM  RunsForReview  
    ---    
/*-----------------------------------------------------------------*/





/*-----Fix Single Run----------------------------------------------*/
  --Use this SQL to fix an identified run.
/*
  MERGE INTO &Environment.ordtask ot
  USING (
    SELECT DISTINCT
      tot.runno,
      tot.apprdate,
      tot.apprvedby
    FROM &Environment.ordtask tot
    WHERE 1=1
      AND tot.apprdate IS NOT NULL
      AND tot.runno = '&RunNumber'--'2139'
    ) nv
  ON (ot.runno = nv.runno)
  WHEN MATCHED THEN
    UPDATE SET 
      ot.apprdate = nv.apprdate,
      ot.apprvedby = nv.apprvedby
*/   
/*-----------------------------------------------------------------*/





/*-----Fix run with NO approved samples----------------------------*/
  --Fix identified run when NO samples have approved date.
  --we will use the Run approval information to repair OrdTask table
/*  
  MERGE INTO &Environment.ordtask ot
  USING (
    SELECT DISTINCT
      r.runno,
      r.approvedate AS analyzeddate,
      r.approvedby,
      r.approvedate
    FROM &Environment.runs r
    WHERE 1=1
      AND r.runno = '&RunNumber'--'2139'
    ) nv
  ON (ot.runno = nv.runno)
  WHEN MATCHED THEN
    UPDATE SET 
      ot.analyzeddate = nv.analyzeddate,
      ot.apprdate = nv.approvedate,
      ot.apprvedby = nv.approvedby
*/      
/*-----------------------------------------------------------------*/





/*-----Fix Set Of Runs---------------------------------------------*/
  --Use this SQL to repair a class of runs
/*
  MERGE INTO sundata_prod.ordtask ot
  USING (
    --Identify Runs And Values--
    WITH
      AllApprovedRuns AS (
        SELECT DISTINCT
          ot.runno,
          ot.apprdate,
          ot.apprvedby
        FROM sundata_prod.ordtask ot 
          INNER JOIN sundata_prod.tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          AND t.testflag = 'Default'
          AND t.testtype = 'Single'    
          AND ot.apprdate IS NOT NULL
        ORDER BY 
          ot.runno ASC),
          
      RunsInQuestion AS (
        SELECT DISTINCT
          ot.runno     
        FROM  AllApprovedRuns aar
          INNER JOIN sundata_prod.ordtask ot ON (aar.runno = ot.runno)
        WHERE 1=1
          AND (ot.apprvedby IS NULL
          OR ot.apprdate IS NULL)),
      RunsForReview AS (
        SELECT DISTINCT
          ot.dept,
          r.analyte,
          ot.apprdate,
          ot.apprvedby,
          ot.runno,      
          f.external_id,
          r.final,
          '~' AS eol      
        FROM RunsInQuestion riq
           INNER JOIN sundata_prod.ordtask ot ON (riq.runno = ot.runno)
           INNER JOIN sundata_prod.results r ON (ot.ordno = r.ordno AND ot.testcode = r.testcode)
           INNER JOIN sundata_prod.folders f ON (ot.folderno = f.folderno)
           INNER JOIN sundata_prod.tests t ON (ot.testcode = t.testcode)
        WHERE 1=1 
          AND t.testflag = 'Default'
          AND t.testtype = 'Single'
---Optional filters to narrow fix set---                
          --AND ot.dept = '&Dept'
          --AND ot.runno = '&RunNo'
          --AND r.analyte = '&Analyte' --'Syphilis RPR', 'Hepatitis C EIA'
          --AND f.external_id = '&SampleID'
---
        ORDER BY
          ot.dept ASC,
          r.analyte ASC,      
          ot.runno ASC,
          f.external_id ASC)      
    SELECT DISTINCT
      rfr.runno,
      rfr.apprdate,
      rfr.apprvedby
    FROM  RunsForReview rfr
    WHERE 1=1
      AND rfr.apprdate IS NOT NULL
      AND rfr.apprvedby IS NOT NULL
    ORDER BY
      rfr.runno ASC,
      rfr.apprdate ASC,
      rfr.apprvedby ASC      
    --
    ) nv
  ON (ot.runno = nv.runno)
  WHEN MATCHED THEN
    UPDATE SET 
      ot.apprdate = nv.apprdate,
      ot.apprvedby = nv.apprvedby
*/
/*-----------------------------------------------------------------*/
