/*-----OutsourceSamplesFi------------------------------------------*/
  ---DESCRIPTION---
    --Some samples that have Send-Out test assigned to them seem to be
    --disapearing from the shipment they have been assigned to.
    --A typical sample lifecycle with a sendout is as follows:
      --{Samples for Shipment}: Sample is selected and assigned for 
      --shipment
      --{Enter Outsource Sample Results}: When results are received
      --from send-out lab the result are entered here.
          
    --The problem we are observing here is that after the samples have
    --been assigned to a shipement in the {Samples for Shipment}
    --application, they are not visible in the 
    --{Enter Outsource Samples Results} application, and also do not 
    --appear in the {Generl EPI} query in the {QBE Query} application.
    --
    --Root cause of this issue is not known, but we have determined
    --the that an row is not added to the [results] table, and
    --an entry in this table is required for a sample to appear in
    --a the {Enter Outsource Sample Results} application.
  ---
  ---Work-Around---
    --Until STARLIMS is able to address the root cause of this problem
    --we have created two scripts provided below.  The first is to
    --identify samples that may have this prolbem, and the second
    --script is used to fix the problem.
  ---
  ---History---
    --2014.05.06 JTY: Created Scripts
  ---

  /*----------SL10 Environments----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod
  /*----------  ----------*/


/*-----------------------------------------------------------------*/





/*-----Identify Outsource Samples with Issues----------------------*/
  --These samples have been identified as outsource, but do not
  --have enetries in the [Results] table.

    SELECT DISTINCT
      r.origrec,
      ot.ordno,
      os.outsourceordno,
      ot.folderno,
      ot.testcode,
      ot.testno,
      os.createdept,
      os.dispsts,
      os.shipdate,
      os.status,
      os.trackingnumber,
      os.usrnam,
      '~' AS eol
    FROM &Environment.Outsourceorders os
      INNER JOIN &Environment.ordtask ot ON (os.outsourceordno = ot.outsourceordno)
      LEFT OUTER JOIN &Environment.results r ON (ot.folderno = r.folderno AND ot.testcode = r.testcode)
    WHERE 1=1
      AND r.origrec IS NULL
      AND os.outsourceordno <>'OUTSOURCE'
  --AND ot.outsourceordno = '216'    
    ORDER BY
      ot.folderno ASC;   
/*-----------------------------------------------------------------*/  




/*-----Repair Identified Samples----------------------------------*/
  --Utilize this script to take the identified
  --records and add new rows in the [Results] table
/*  
  MERGE INTO sundata_prod.results t1
  USING (
    WITH
      --Identify Problem Samples---
      ProblemSamples AS (
        SELECT DISTINCT    
          r.origrec,
          ot.ordno,
          os.outsourceordno,
          ot.folderno,
          ot.testcode,
          ot.testno,
          os.createdept,
          os.dispsts,
          os.shipdate,
          os.status,
          os.trackingnumber,
          os.usrnam,
          '~' AS eol
        FROM &Environment.Outsourceorders os
          INNER JOIN &Environment.ordtask ot ON (os.outsourceordno = ot.outsourceordno)
          LEFT OUTER JOIN &Environment.results r ON ( 1=1
              AND ot.folderno = r.folderno 
              AND ot.testcode = r.testcode)
        WHERE 1=1
          AND r.origrec IS NULL  
        ORDER BY
          ot.folderno ASC
        ),
      --
      --Determine Row Inserts in Results Table--
      ProposedInserts AS (
        SELECT DISTINCT
          ps.outsourceordno,
          r.analtype, r.analyte, r.cupno,
          ps.folderno, --r.folderno: Query
          r.norep, 
          ps.ordno, --r..ordno: Query
          'N' AS origsts, --r.origsts: HardCode 'A'
          r.picture, r.rep, 
          r.retestno, 
          'Logged' AS s, --r.s: HardCode
          r.sorter,
          r.sp_code, r.specno, r.testcode,
          r.testno, r.sinonym, 
          '' AS sptestsorter, --HardCode: r.sptestsorter, 
          r.namingconvention, r.snomedcode, r.printflag, 
          r.report_flag,
          '~' AS eol
        FROM ProblemSamples ps
          INNER JOIN &Environment.ordtask ot ON (1=1
              AND ps.testcode = ot.testcode)
          INNER JOIN &Environment.Outsourceorders os ON (1=1
              AND ot.outsourceordno = os.outsourceordno)
          INNER JOIN sundata_prod.results r ON ( 1=1
              AND ot.folderno = r.folderno 
              AND ot.testcode = r.testcode)
        WHERE 1=1
          AND ps.outsourceordno <> 'OUTSOURCE'
        ORDER BY
          ps.folderno ASC,
          r.testno ASC,
          r.analyte ASC      
       )
       SELECT * FROM ProposedInserts       
  ) t2
  ON (1=1
          AND t1.folderno = t2.folderno 
          AND t1.testcode = t2.testcode
     )
  WHEN NOT MATCHED THEN
    INSERT (
    t1.analtype, t1.analyte, t1.cupno,
    t1.folderno, t1.norep, t1.ordno,
    t1.origsts, t1.picture, t1.rep, 
    t1.retestno, t1.s, t1.sorter,
    t1.sp_code, t1.specno, t1.testcode,
    t1.testno, t1.sinonym, t1.sptestsorter, 
    t1.namingconvention, t1.snomedcode, t1.printflag, 
    t1.report_flag          
    )
    VALUES (
      t2.analtype, t2.analyte, t2.cupno,
      t2.folderno, t2.norep, t2.ordno,
      t2.origsts, t2.picture, t2.rep, 
      t2.retestno, t2.s, t2.sorter,
      t2.sp_code, t2.specno, t2.testcode,
      t2.testno, t2.sinonym, t2.sptestsorter, 
      t2.namingconvention, t2.snomedcode, t2.printflag, 
      t2.report_flag
    );
*/    
/*-----------------------------------------------------------------*/  


  
  
  



