/*-----PanelPrinters_Reassign------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Created this set of scripts to recover if printers that have been assigned
    --to panels has somehow been undone.  We seem to be having issues on this
    --lately.
    --Recovery process is as follows:
      --In Reporting Rules Application
        --1. Select the appropriate "Rule Type" (Clinical Default) in the
        --   "Reporting Rules" area.
        --2. Ensure all Active panels have been added to the "Selection Levels"
        --   section.
        --3. Review scripts below, and execute each script for the report
        --   that you wish to update for the panels.
        
        --Remember, Newly added Panels will default to the default printer.
        --currently this is the "Default Printer Config".
        --So we are assuming before you run this set of scripts, you have
        --already identified the panels, and they have defaulted to the 
        --default printer, all that is needed now is to update these printers.
  /*----- -----*/

  /*----- -----*/
  /*----- -----*/

  /*-----History-----*/
    --2016.06.06 JTY: Created Script
  /*----- -----*/
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
  --Identify panels that are Inactive...
/*  
  SELECT DISTINCT
    tgn.testgroupname,
    tgn.status,
    '~' AS eol
  FROM &Environment.testgroupnames tgn
  WHERE 1=1 
    AND tgn.status <> 'Active'
  ORDER BY
    tgn.testgroupname ASC;
*/    
/*---------------------------------------------------------------------------*/



/*----REVIEW PANEL/PRINTERS--------------------------------------------------*/
/*
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ci.itemname,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_categoryitems ci ON rm.itemid = ci.itemid
      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
      ORDER BY
        ci.itemname ASC,
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
*/        
/*---------------------------------------------------------------------------*/




/*------PHX-BAC--------------------------------------------------------------*/
  --Repair printers associated with PHX-BAC panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'BioterrorismPrinter') AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-BAC'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
 */
/*---------------------------------------------------------------------------*/  


/*------PHX-BT---------------------------------------------------------------*/
  --Repair printers associated with PHX-BT panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'BioterrorismPrinter' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-BT'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
    -- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  


/*------PHX-EM---------------------------------------------------------------*/
  --Repair printers associated with PHX-EM panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'BioterrorismPrinter' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-EM'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  


/*------PHX-SER--------------------------------------------------------------*/
  --Repair printers associated with PHX-SER panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'VirologyPrinter' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-SER'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  




/*------PHX-VIR--------------------------------------------------------------*/
  --Repair printers associated with PHX-VIR panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'VirologyPrinter' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-VIR'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  


/*------PHX-TB--------------------------------------------------------------*/
  --Repair printers associated with PHX-TB panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'TB Printer' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-TB'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  


/*------xxxNextDeptment------------------------------------------------------*/
  --Repair printers associated with xxxNextItemxxx panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'xxxPreferedPrinterxxx' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'xxxDepartmentxxx'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  


/*------xxxNextDeptment------------------------------------------------------*/
  --Repair printers associated with xxxNextItemxxx panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulemethods t1
    USING (
--Run this query to review records--
      SELECT DISTINCT
        rm.itemid AS current_itemid,
        ( SELECT DISTINCT ci1.itemid 
          FROM &Environment.rr_categoryitems ci1 
          WHERE ci1.itemname = 'xxxPreferedPrinterxxx' ) AS new_itemid,
        '~' AS SP1,
        rr.rulename,
        ctt.dept,
        tgn.testgroupname,
        rl.caption,
        rp.reportname,
        rm.submit_method,
        '~' AS SP2,
        rm.ruleid,
        rm.entitytypeid,
        rm.ruleselectionid,
        '~' AS eol
      FROM &Environment.rr_reportingrulemethods rm
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid)
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.rr_reportingrules rr ON (rr.ruleid = rl.ruleid)

      WHERE 1=1
        AND rm.submit_method = 'Hard Copy'
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'xxxDepartmentxxx'
        --AND tgn.testgroupname IN ('xxxPanelNamexxx')
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC,
        rl.caption ASC,
        rp.reportname ASC,
        rm.submit_method ASC
-- --
      ) t2
      ON ( 1=1
        AND t1.entitytypeid = t2.entitytypeid
        AND t1.ruleid = t2.ruleid
        AND t1.ruleselectionid = t2.ruleselectionid
        AND t1.submit_method = t2.submit_method
      )
      WHEN MATCHED THEN
        UPDATE SET t1.itemid = t2.new_itemid;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  

