/*-----PanelReports_Reassign-------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Created this set of scripts to recover if reports that have been assigned
    --to panels has somehow been undone.  We seem to be having issues on this
    --lately.
    --Recovery process is as follows:
      --In Reporting Rules Application
        --1. Select the appropriate "Rule Type" (Clinical Default) in the
        --   "Reporting Rules" area.
        --2. Ensure all Active panels have been added to the "Selection Levels"
        --   section.
        --3. Review scripts below, and execute each script for the report
        --   that you wish to update for the panels.
        
        --Remember, Newly added Panels will default to the default report.
        --currently this is the ADHS_FINALREPORTS.ADHS_HUMAN_FINALREPORT.
        --So we are assuming before you run this set of scripts, you have
        --already identified the panels, and they have defaulted to the 
        --default report, all that is needed now is to update these reports.
  /*----- -----*/

  /*----- -----*/
  /*----- -----*/

  /*-----History-----*/
    --2016.06.02 JTY: Created Script
    --2016.06.21 JTY: Added PFGE to panel Exclude List query
  /*----- -----*/
/*---------------------------------------------------------------------------*/


/*-----Panel Exclude List----------------------------------------------------*/
  --Identify panels that are Inactive...Easiest ways to get all panels is to 
  --select all panels and remove inactive ones.
  --2016.06.21 JTY: We also want to make sure PFGE panels are not included.
/*  
  SELECT DISTINCT
    tgn.testgroupname,
    tgn.status,
    '~' AS eol
  FROM &Environment.testgroupnames tgn
  WHERE 1=1 
    AND (tgn.status <> 'Active'
      OR tgn.testgroupname LIKE 'PFGE%')
  ORDER BY
    tgn.testgroupname ASC;
*/    
/*---------------------------------------------------------------------------*/




/*------PFGE Reports Review----------------------------------------------------*/
  --PFGE panels should NOT have any reports asscoated with them.
/*  
  ----- -----
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_HUMANTB_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND ctt.dept = 'PHX-BAC'
        AND rr.rulename = 'Clinical Default'
        AND tgn.testgroupname IN (
          'PFGE - E. coli O157',
          'PFGE - Listeria',
          'PFGE - Miscellaneous',
          'PFGE - Non-O157 E. coli',
          'PFGE - Salmonella'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  ----- -----
*/
/*---------------------------------------------------------------------------*/  




/*------BAC Reports-----------------------------------------------------------*/
  --Repair reports associated with BAC panels.
/*  
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_HUMANTB_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-BAC'
        AND tgn.testgroupname IN (
          'Bacteriology Culture Archive Only',
          'Carbapenemase Screen',
          'Diphtheria Culture',
          'E. coli STEC Broth Culture',
          'E. coli STEC Reference Culture',
          'Enteric Culture',
          'Giardia/Cryptosporidium',
          'Haemophilus Culture',
          'Listeria Culture',
          'Meningococcus Culture',
          'Miscellaneous Bacteriology Culture',
          'Pertussis Culture',
          'Pneumococcus Culture',
          'Reference Bacteriology Culture',
          'Salmonella Culture',
          'Send out Misc Bacteriology',
          'Sendout Bacteriology',
          'Sendout Botulism',
          'Sendout Legionella Culture',
          'Sendout Listeria Culture',
          'Sendout Mycology',
          'Sendout Parasitology',
          'Sendout Salmonella Culture',
          'Sendout Shiga Toxin',
          'Sendout Shigella Culture',
          'Shiga Toxin Production',
          'VISA - VRSA Culture',
          'Vibrio Culture'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  





/*------TB Reports-----------------------------------------------------------*/
  --Repair reports associated with TB panels.
/*  
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_HUMANTB_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-TB'
        AND tgn.testgroupname IN (
        'AFB Archive Only', 'AFB Clinical', 
        'AFB Reference', 'Acid-fast Bacillus (AFB) Smear', 
        'Agar Proportion Drug Susceptibility', 'MGIT Drug Susceptibility', 
        'Nucleic Acid Amplification'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  


/*------Rabies Report--------------------------------------------------------*/
  --Repair reports associated with Rabies panel.
/*  
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_ANIMAL_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-VIR'
        AND tgn.testgroupname IN (
        'Rabies FRA'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  



/*------Multiple Agents Report-----------------------------------------------*/
  --Repair reports associated with Multiple Agents panel.
  /*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.MULTIPLEAGENTS_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-BT'
        AND tgn.testgroupname IN (
        'Multiple Agents'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  


/*------HIV Report-----------------------------------------------------------*/
  --Repair reports associated with HIV panel. - Note, not sure if 
  --we want to change these from the default report......
  /*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_FINALREPORT_SER' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-SER'
        AND tgn.testgroupname IN (
        'HIV'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  


/*------Environmental Non-Drinking Water-------------------------------------*/
  --Repair reports associated with Environmental non-Drinking Water panels.
  ----- -----
/*  
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_ENVNONDW_COA' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-EM'
        AND tgn.testgroupname IN (
        'Water-Bacillus anthracis',
        'Water-Campylobacter',
        'Water-E. coli',
        'Water-E. coli O157',
        'Water-Fecal Coliform',
        'Water-Francisella tularensis',
        'Water-Heterotrophic Plate Count',
        'Water-Legionella',
        'Water-Listeria',
        'Water-STEC E. coli',
        'Water-Salmonella',
        'Water-Shigella',
        'Water-Staphylococcus aureus',
        'Water-Total Coliform',
        'Water-Vibrio',
        'Water-Yeast and Molds',
        'Water-Yersinia pestis'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  


/*------Environmental Drinking Water-----------------------------------------*/
  --Repair reports associated with Drinking Water panel.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ADHS_ENVNONDW_COA' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-EM'
        AND tgn.testgroupname IN (
        'Drinking Water SM9223B'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
  */
/*---------------------------------------------------------------------------*/  


/*------Environmental Food---------------------------------------------------*/
  --Repair reports associated with Food related panels.
/*  
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'ADHS_FINALREPORTS.ENVFOOD_FINALREPORT' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'PHX-EM'
        AND tgn.testgroupname IN (
        'Environmental',
        'Food - Aerobic Plate Count',
        'Food - Bacillus cereus',
        'Food - Campylobacter',
        'Food - Clostridium perfringens',
        'Food - E. coli',
        'Food - E. coli O157',
        'Food - Listeria',
        'Food - STEC E. coli',
        'Food - Shigella',
        'Food - Staphylococcus aureus',
        'Food - Vibrio',
        'Food - Salmonella',  --NOTE: this appears as Food ? Salmonella in extract, so we probably need to repair this panel name.
        'Food-Bacillus Anthracis',
        'Food-Brucella',
        'Food-Clostridium Botulinum toxin',
        'Food-Container Analysis',
        'Food-Environmental Miscellaneous',
        'Food-Fecal Coliform',
        'Food-Filth and Foreign Objects',
        'Food-Francisella tularensis',
        'Food-Ricin',
        'Food-Total Coliform',
        'Food-Yeast and Molds',
        'Food-Yersinia pestis'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/
/*---------------------------------------------------------------------------*/  


/*------xxxNextItemxxx-------------------------------------------------------*/
  --Repair reports associated with xxxNextItemxxx panels.
/*
  ----- -----
    MERGE INTO &Environment.rr_reportingrulereports t1
    USING (
  --Run this to review records--   
      SELECT DISTINCT
       rr.rulename,
       ctt.dept,
       tgn.testgroupname,
       'xxxReportNamexxx' AS reportname,
        '~~' AS sp1,
       rp.ruleid,
       rp.ruleselectionid,
       --rm.submit_method,
       rp.reportname AS rp_reportname,
       '~' AS eol
      FROM &Environment.rr_reportingrules rr
        INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
        INNER JOIN &Environment.rr_reportingrulemethods rm ON ( 1=1
          AND rl.ruleid = rm.ruleid
          AND rl.ruleselectionid = rm.ruleselectionid
        )
        INNER JOIN &Environment.rr_reportingrulereports rp ON ( 1=1
          AND rl.ruleid = rp.ruleid
          AND rl.ruleselectionid = rp.ruleselectionid
        )
        INNER JOIN &Environment.testgroupnames tgn ON (1=1
          AND tgn.status = 'Active'
          AND tgn.testgroupname = substr(rl.caption, 10)
        )
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      WHERE 1=1
        AND rr.rulename = 'Clinical Default'
        AND ctt.dept = 'xxxDEPTIDxxx'
        AND tgn.testgroupname IN (
        'xxxPanelNamexxx',
        'xxxPanelNamexxx'
        )
      ORDER BY
        rr.rulename ASC,
        ctt.dept ASC,
        tgn.testgroupname ASC
  -- --
    ) t2
    ON ( 1=1
      AND t1.ruleid = t2.ruleid
      AND t1.ruleselectionid = t2.ruleselectionid
    )
    WHEN MATCHED THEN
      UPDATE SET t1.reportname = t2.reportname;
  ----- -----
*/  
/*---------------------------------------------------------------------------*/  
