
/*-----ReportDeliveryQueue_Fix-----------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Use this set of SQL statements to identify issues in the Report Delivery
    --Queue (RDQ) and address the identified issues.
    --
    --01. Clean Table Enteries - Clean out table enteries by ORIGRIC number.
    --02. Identify RDQ Record With Issues
    --03. Bacth Progress - Check batch job progress and update if needed.
    --04. Update Fax Number For Item In RDQ
    
  /*----- -----*/
  
  
  /*----- -----*/
  /*----- -----*/

  /*-----HISTORY-----*/
    --2016.12.08 JTY: Created Script File
  /*----- -----*/

/*---------------------------------------------------------------------------*/





/*-----01. Clean Table Enteries----------------------------------------------*/
  --Use this set of SQL statements to clean out the table enteries for identified
  --samples/reports
  
  --DELETE FROM faxqueue fq WHERE 1=1 AND fq.origrec = '&fq_Origrec';
  --DELETE FROM rr_rdq_history rdh WHERE 1=1 AND rdh.origrec = '&rdh_origrec';
  --DELETE FROM rr_report_delivery_queue rdq WHERE 1=1 AND rdq.origrec = '&rdq_origrec';  
/*---------------------------------------------------------------------------*/




/*-----02. Identify RDQ Record With Issues----------------------------------*/
  SELECT DISTINCT
    rdq.status,
    rbs.progress,
    '~' AS SP_1,
    f.dept,
    rdq.batch_id,
    rdq.itemid,
    f.folderno,  
    f.testgroupname,
    to_char(rdh.sent_date, 'YYYY.MM.DD')  || '  ' || rdh.sent_time AS approved_dt,
    rdq.delivery_method,
    rdq.delivery_address, 
    u.fullname,
    f.rasclientid,
    rdq.extra_info,
    fq.crtmessage AS fax_message,
    rdq.reporttype,  
    '~' AS SP_2,
    fq.origrec AS fq_origrec,
    rdh.origrec AS rdh_origrec,
    rdq.origrec AS rdq_origrec,
    rb.origrec AS rb_origrec,
    rbs.origrec AS rbs_origrec,
    '~' AS eol
  FROM rr_report_delivery_queue rdq
    INNER JOIN folders f on (rdq.folderno = f.folderno)
    INNER JOIN users u ON (rdq.usrnam = u.usrnam)
    LEFT OUTER JOIN rr_rdq_history rdh ON (1=1
      AND rdh.stardoc_id= rdq.stardoc_id
      AND rdh.queue_item_no = rdq.queue_item_no
      )
    LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    LEFT OUTER JOIN rr_batches rb ON (rdq.batch_id = rb.batchid)
    LEFT OUTER JOIN rr_batchstatus rbs ON (rdq.batch_id = rbs.batchid)
    
  WHERE 1=1
    --Identified Possible Problems--  
      AND (
        rdq.status IN ('RUNNING', 'ERROR')
        OR rdq.extra_info IS NOT NULL
        OR rbs.progress <> '100'
        OR upper(fq.crtmessage) LIKE '%ERROR%'
        OR (fq.origrec IS NOT NULL AND fq.senddate IS NULL)
      )
    --
    --AND rdq.batch_id = '&BatchID'
    --AND rdq.queue_item_no = '&QueueItemNumber'
    --AND rdq.folderno = '&FolderNo'
  ORDER BY 
    rdq.status ASC,
    f.dept ASC,
    rdq.batch_id ASC,
    f.folderno ASC,
    approved_dt ASC
/*---------------------------------------------------------------------------*/



/*-----03. Bacth Progress----------------------------------------------------*/
  --Check the status of the batch job, and update it if it appears to be hung
/*
  SELECT DISTINCT
    bs.batchid,
    bs.progress,
    bs.noerrors,
    bs.totalitems,
    bs.processed,
    f.folderno,
    f.dept,
    f.testgroupname,
    '~' AS eol
  FROM rr_batchstatus bs
    INNER JOIN rr_report_delivery_queue rdq ON (rdq.batch_id = bs.batchid)
    INNER JOIN folders f ON (rdq.folderno = f.folderno)
  WHERE 1=1
    AND bs.progress <> 100
--AND bs.batchid = '5972'
  ORDER BY  
    bs.batchid DESC,
    f.folderno ASC;
    
--    update rr_batchstatus bs SET bs.progress = 100 WHERE bs.batchid = '5972'
*/
/*---------------------------------------------------------------------------*/


/*-----04. Update Fax Number For Item In RDQ---------------------------------*/
/*
  SELECT DISTINCT
    f.dept,
    f.rasclientid,    
    f.folderno,
    rdq.delivery_method,
    rdq.delivery_address,
    rdq.contactid,
    fcx.contactid,
  
--    rcx.contactid,
--    rcx.fax AS rcx_fax,
--    rcx.fullname,
    rdq.origrec AS rdq_origrec,
    rdq.delivery_address,
    rdq.delivery_address,
    '~' AS eol
  FROM rr_report_delivery_queue rdq
    INNER JOIN folders f ON (rdq.folderno = f.folderno)
    INNER JOIN sundata_prod.folderscontactsext fcx ON (f.folderno = fcx.folderno)
    INNER JOIN sundata_prod.rasclientcontactsext rcx ON (1=1
      AND rcx.rasclientid = f.rasclientid 
      AND f.folderno = fcx.folderno)
  WHERE 1=1
    AND rdq.delivery_method = 'Fax'
    AND rdq.delivery_address IS NULL
  ORDER BY
    f.dept ASC,
    f.rasclientid ASC,
    f.folderno ASC
--    AND rdq.origrec = '156092'
*/

/*
  UPDATE sundata_prod.rr_report_delivery_queue rdq
  SET rdq.delivery_address = '(520) 469-8722'
  WHERE rdq.origrec = '156092'
*/
/*---------------------------------------------------------------------------*/



/*-----05. Report Not Generated-----------------------------------------------*/
  --Sometimes the sample is approved, in the Release by Panel application, but
  --no report is generated.  Not sure of the root cause of this, but there appears
  --to be two situations 
    --1. Flags and approval information does not match between folders and 
    --   FolderCondition tables
    --2. Folder and FolderCondition tabels match, and seem ok, but no report 
    --   was generated 
    --
    -- Resolution is to :
      --1. Adjust flags if needed so Folders and FolderCondition tables match
      --  (Merge Statement).
      --2. Manually create report with the ADHS Utilities tool.

    SELECT DISTINCT
      f.dept,
      f.external_id AS f_external_id,
      f.apprdate AS f_apprdate,
      f.approvedby AS f_approvedby,
      f.apprdisp AS f_apprdisp,
      f.apprsts AS f_apprsts,
      f.dispsts AS f_dispsts,
      fc.approveddate AS fc_approveddate,
      fc.approvedby AS fc_approvedby,
      fc.approvalstatus AS fc_approvalstatus,
      fc.dispsts AS fc_dispsts,
      fc.status AS fc_status,
      '~'
    FROM folders f
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
    WHERE 1=1
      AND f.external_id IN (
        'AZ00070760',
    --    'AZ00070830',
        'AZ00070749',
        'AZ00070922',
        'AZ00070932',
        'AZ00070933',
        'AZ00070890',
    --    'AZ00070667',
    --'AZ00068788', 'AZ00069904',
    --'AZ00070117',
      ''
      )
    ORDER BY f.external_id ASC




/*  --Update flags in the folders table to match the
    --values in the FolderCondition table.
      MERGE INTO folders t1
      USING (
          SELECT DISTINCT
            fc.folderno,
            fc.approveddate,
            fc.approvedtime,
            fc.approvedby
          FROM foldercondition fc
          WHERE fc.folderno = '&SampleID-01') t2
      ON (t1.folderno = t2.folderno)
      WHEN MATCHED THEN
        UPDATE SET
        t1.apprdate = t2.approveddate,
        t1.apprtime = t2.approvedtime,
        t1.approvedby = t2.approvedby,
        t1.apprdisp = 'Released',
        t1.apprsts = 'Released'
*/

/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
