

/*-----RunApprovedFix----------------------------------------------*/
  /*----------Description----------*
    --There seems to be a bug in SL in that sometimes when a run
    --is approved that some of the QC and samples get the apprdate
    --and apprvedby columns updated, while other samles in the run
    --do not.  This is a problem in that for these samples the final
    --report may show the result as Pending even though the sample
    --appears to be completed since the panel has been approved.
    
    --These set of queries will identify what runs appear to have 
    --this issue and repair the problem.
    --
    --The three SQL statements provided here are:
      --Review Suspect Runs - Displays what runs are seeem to have issues.
      --Fix Single Run - Fix provided run number.
      --Fix Set Of Runs - Fix class of runs.
   
  /*---------- ----------*  

  /*----------Environments----------*
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod   
  /*---------- ----------*  


  /*----------History----------*
    --2013.08.22 JTY: Created Script
    --2013.11.18 JTY: Updated to include runs with no samples approved
        --but run is approved.
  /*---------- ----------*  

  /*---------- ----------*
  /*---------- ----------*  

/*-----------------------------------------------------------------*/





/*----Review Suspect Samples----------------------------------------*/
  --Show samples that are associated with released runs but the
  --samles have not been approved.
  
  SELECT DISTINCT 
    r.dept,
    r.runno,
    f.external_id,
    f.folderno,
    ot.testgroupname AS panel,
    (ot.testno || ': ' || ot.testcode) AS test_name,
    re.analyte,
    r.approvalstatus AS r_approvalstatus,
    r.approvedate AS r_approvedate,
    ot.apprdate AS ot_apprdate,
    r.approvedby AS r_approvedby,
    ot.apprvedby AS ot_apprvedby,
    r.origrec AS run_origrec,
    ot.origrec AS ot_origrec,
    f.origrec AS f_origrec,
    fc.origrec AS fc_origrec,
    '~' AS eol
  FROM &Environment.runs r
    INNER JOIN &Environment.results re ON (r.runno = re.runno)
    INNER JOIN &Environment.ordtask ot ON (ot.runno = r.runno)
    INNER JOIN &Environment.folders f ON (ot.folderno = f.folderno)
    INNER JOIN &Environment.foldercondition fc ON (f.folderno = fc.folderno)
  WHERE 1=1
    AND r.approvalstatus = 'Released'
    AND (r.approvedby IS NOT NULL)
    AND (r.approvedate IS NOT NULL)
    AND (ot.apprvedby IS NULL
        OR ot.apprdate IS NULL)
--    AND r.dept IN ('PHX-VIR','PHX-SER')
    ORDER BY
      r.dept ASC,
      r.runno ASC,
      f.external_id ASC,
      ot.testgroupname ASC,
      test_name ASC,
      re.analyte ASC;
/*-----------------------------------------------------------------*/


/*-----Show troubled runs------------------------------------------*/
/*
  SELECT DISTINCT 
    r.dept,
    ot.testno,
    r.runno,
    r.approvalstatus,
    r.approvedate AS apprdate,
    r.approvedby AS apprvedby
  FROM &Environment.runs r
    INNER JOIN &Environment.ordtask ot ON (ot.runno = r.runno)
  WHERE 1=1
    AND r.approvalstatus = 'Released'
    AND (r.approvedby IS NOT NULL)
    AND (r.approvedate IS NOT NULL)
    AND (ot.apprvedby IS NULL
        OR ot.apprdate IS NULL)
    ORDER BY
      r.dept ASC,
      ot.testno ASC,
      r.runno ASC;
*/      
/*-----------------------------------------------------------------*/





/*-----Fix  Runs---------------------------------------------------*/
  --Use this SQL to repair a class of runs
/*
  MERGE INTO sundata_prod.ordtask ot
  USING (
  SELECT DISTINCT 
    r.runno,
    r.approvalstatus,
    r.approvedate AS apprdate,
    r.approvedby AS apprvedby
  FROM &Environment.runs r
    INNER JOIN &Environment.ordtask ot ON (ot.runno = r.runno)
  WHERE 1=1
    AND r.approvalstatus = 'Released'
    AND (r.approvedby IS NOT NULL)
    AND (r.approvedate IS NOT NULL)
    AND (ot.apprvedby IS NULL
        OR ot.apprdate IS NULL)
    --AND r.runno = '2860'        
    ORDER BY
      r.runno ASC
    ) nv
  ON (ot.runno = nv.runno)
  WHEN MATCHED THEN
    UPDATE SET 
      ot.apprdate = nv.apprdate,
      ot.apprvedby = nv.apprvedby
*/
/*-----------------------------------------------------------------*/

