/*-----TB NewCase Fix----------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Scripts used to add New Case to identified sample.  This script
    --is to be used when the analysts has not added the new case
    --information to a sample and this is discovered much later.
    --These scripts will add the new case without impacting the 
    --TAT calcualtions for the sample.
    
    --Note that the QA/QC officer needs to be notified of this.
    --Also included is the TB Grant Query Extact.
    
    --Task that need to be accomplished include:
      --1. Review and update MicroSteps Tree to include 
      --   New Case with date.
      --2. Update Communication Log to log change made
      --3. Update FlowEventLog to reflect changes.
  /*----- -----*/

  /*-----HISTORY-----*/
    --2015.08.03 JTY: Created script
    --2015.08.06 JTY: Correction required for microtasksteps.dateentered
  /*----- -----*/


/*-----------------------------------------------------------------*/






/*-----01. Reveiw And Update MicroSteps----------------------------*/
  /*-----Sample Review-----*/
    SELECT DISTINCT
      f.external_id,
      mts.origrec,
      mts.ordno,
      mts.stepcode,
      mts.rep,
      mts.usrnam,
      mts.res01,
      '~' AS SP1,
      mts.colony,
      mts.dispmicstatus,
      mts.execdate,
      mts.micstatus,
      mts.ordno,
      mts.origsts,
      mts.rep,
      mts.runno,
      mts.sorter,
      mts.stepcode,
      mts.testcode,
      mts.workdueby,
      mts.parentsteporigrec,
      mts.compid,
      mts.comptype,
      mts.res01,
      mts.readno,
      mts.initialreporigrec,
      mts.panelsorter,
      mts.dateentered,
      mts.timeentered,
      mts.usrnam,
      mts.resultstatus,
      mts.reported,      
      '~' AS eol      
    FROM sundata_prod.folders f
      INNER JOIN sundata_prod.ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN sundata_prod.microtasksteps mts ON (1=1
        AND ot.ordno = mts.ordno
        AND ot.testcode = mts.testcode)
    WHERE 1=1
      AND f.external_id = '&SampleID'
      AND ot.testcode = '301'
    ORDER BY
      f.external_id ASC,
      mts.ordno ASC,
      mts.sorter ASC;
  /*----- -----*/
  
  /*-----Insert NewCase into MicroTaskTree-----*/
  --NOTE:  Make sure to double check to see if the 
      --microtasksteps.dateentered value has the
      --full year amount (ie 2015, not 0015)  This
      --has caused issues in the past. because I
      --uses sysdate instead of an input date.
/*  
    INSERT INTO sundata_prod.microtasksteps mts(
      mts.colony,
      mts.dispmicstatus,
      mts.execdate,
      mts.micstatus,
      mts.ordno,
      mts.origsts,
      mts.rep,
      mts.runno,
      mts.sorter,
      mts.stepcode,
      mts.testcode,
      mts.workdueby,
      mts.parentsteporigrec,
      mts.compid,
      mts.comptype,
      mts.res01,
      mts.readno,
      mts.initialreporigrec,
      mts.panelsorter,
      mts.dateentered,
      mts.timeentered,
      mts.usrnam,
      mts.resultstatus,
      mts.reported
    )

    VALUES(
      '0',
      'Done',
      TO_DATE('&DateEntered','DD-MON-YYYY'),
      'Done',
      '&OrdNo',  --Format AZ########-01-001
      'N',
      '&REP',
      '0',
      '37',
      'New Case',
      '301',  --TestCode 301 = 
      TO_DATE('&DateEntered','DD-MON-YYYY'),
      '-1',
      'New Case',
      'Miscellanoeus',
      TO_CHAR(TO_DATE('&NewCaseDate','DD-MON-YYYY'),'YYYY-MM-DD'),  --Format DD-MON-YYYY
      '1',
      '-1',
      '0',
      TO_DATE('&DateEntered','DD-MON-YYYY'),
      TO_CHAR(sysdate,'hh:MM'),
      '&Usernam',
      'Done',
      'N'
    )
*/
/* Update step Date instead of insert step.
    UPDATE sundata_prod.microtasksteps mts
    SET mts.res01 = TO_CHAR(TO_DATE('&NewCaseDate','DD-MON-YYYY'),'YYYY-MM-DD')
    WHERE mts.origrec = '&origrec'
*/    
/*-----------------------------------------------------------------*/



/*---03. Update Communications Log---------------------------------*/
  /*-----Review Communications Log-----*/
    SELECT DISTINCT
      f.external_id,
      cl.*,
      '~' AS eol
    FROM sundata_prod.folders f
      INNER JOIN sundata_prod.communication_log cl ON (f.folderno = cl.folder_number)
    WHERE 1=1
      AND f.external_id = '&SampleID'
    ORDER BY
      cl.folder_number ASC,
      cl.origrec ASC;
  /*----- -----*/

  /*-----Update Communications Log-----*/
    --No script needed for this, Addition of entry can be done
    --through the [View Released Clinical Samples] application in the
    --[Comm Log] link.
    --
    --Example Text
    --2015.08.03 JTY: Addition of New Case to TB Test per instructions from Stacy White
  /*----- -----*/


/*-----------------------------------------------------------------*/



/*-----------------------------------------------------------------*/
/*-----03. Update FlowEventLog-------------------------------------*/

  /*-----Review FlowEventLog for samples-----*/
  
    SELECT DISTINCT
      f.external_id,
      fel.dept,
      fel.eventdate,
      fel.eventtime,
      fel.eventtype,
      fel.folderno,
      fel.ordno,
      fel.origsts,
      fel.rep,
      fel.runno,
      fel.servgrp,
      fel.sorter,
      fel.stepcode,
      fel.testcode,
      fel.testgroupname,
      fel.thecomment,
      fel.usrnam,
      fel.external_id,
      fel.table_origrec,
      fel.appr_level,
      '~' AS SP1,
      fel.*,
      '~' AS eol
    FROM sundata_prod.folders f
      INNER JOIN sundata_prod.floweventlog fel ON (f.folderno = fel.folderno)
    
    WHERE 1=1
      AND f.external_id = '&SampleID'
    ORDER BY
      f.external_id ASC,
      fel.origrec DESC;
  /*----- -----*/

  /*-----Insert Entry in FlowEventLog-----*/
/*  
    INSERT INTO sundata_prod.floweventlog fel(
      fel.dept,
      fel.eventdate,
      fel.eventtime,
      fel.eventtype,
      fel.folderno,
      fel.ordno,
      fel.origsts,
      fel.rep,
      fel.runno,
      fel.servgrp,
      fel.stepcode,
      fel.testcode,
      fel.testgroupname,
      fel.thecomment,
      fel.usrnam,
      fel.external_id
    )
    VALUES (
      'PHX-TB',
      sysdate,
      TO_CHAR(sysdate,'hh:MM'),
      'Database Change',
      '&FolderNo',
      '&OrderNo',
      'N',
      '', --'&Rep',
      '', --'&RunNo',
      'TB Team',
      'New Case',
      '301',
      'AFB Clinical',
      'Manual insert of New Case in MicroTree via Database update to microtasksteps table per request.  See Communications Log.',
      'YODERJ',
      '&SampleID'
    );
*/    
  /*----- -----*/

/*-----------------------------------------------------------------*/





/*-----TB Extract Query--------------------------------------------*/

  /*----- -----*/
    --Script to run for TB Grant Query
    WITH
    ---HaveBothTests---
      --All samples with both MGIT & AFB Culture test
      HaveBothTests AS (
        SELECT DISTINCT
          F.external_id,
          F.folderno,
          OT1.Ordno,
          T1.testno AS mgit_testno,
          T1.Testcode AS mgit_testcode,
          T2.testno AS afbcul_testno,
          T2.Testcode AS afbcul_testcode,
          '~' AS eol
        FROM Folders F
          INNER JOIN OrdTask OT1 ON (f.folderno = OT1.Folderno)
          INNER JOIN Tests T1 ON (OT1.Testcode = T1.testcode)
          INNER JOIN OrdTask OT2 ON (f.folderno = OT2.Folderno)
          INNER JOIN Tests T2 ON (OT2.Testcode = T2.testcode)
        WHERE 1=1
          AND T1.Testno = 'MGIT Drug Susceptibility'
          AND T2.Testno = 'AFB Culture'
        ORDER BY
          F.External_Id ASC),
    --- ---
    ---NewCaseSamples---
      NewCaseSamples AS (
        SELECT DISTINCT
          (P.Last_Name || ', ' || P.First_Name) AS patient_name,
          P.patient_id,
          HBT.external_id,
          TO_DATE(
              COALESCE(TO_CHAR(CR.date_collected,'DD-MON-YYYY'),'1-JAN-1900')
              || ' ' ||
              COALESCE(CR.time_collected,'00:00:01')
              ,'DD-MON-YYYY HH24:MI:SS')
              AS date_collected,
          TO_DATE(
              COALESCE(TO_CHAR(CR.date_received,'DD-MON-YYYY'),'1-JAN-1900')
              || ' ' ||
              COALESCE(CR.time_received,'00:00:01')
              ,'DD-MON-YYYY HH24:MI:SS')
              AS date_received,
          TRUNC(P.date_of_birth) AS date_of_birth,
          TRUNC(TO_DATE(MTS2.res01,'YYYY-MM-DD'))AS new_case_date,
          '~' AS eol
        FROM HaveBothTests HBT
          INNER JOIN CentralReceiving CR ON (HBT.external_id = CR.external_id)
          INNER JOIN Metadata_Repository MR ON ( 1=1
            AND MR.TABLEREFERENCE = 'CENTRALRECEIVING'
            AND MR.Original_Origrec = CR.ORIGREC)
          INNER JOIN Patients P ON (CR.Patient_Id = P.Patient_Id)
          LEFT OUTER JOIN MicroTaskSteps MTS2 ON ( 1=1
            AND HBT.Ordno = MTS2.Ordno
            AND HBT.afbcul_testcode = MTS2.Testcode
            AND MTS2.Stepcode = 'New Case')
        WHERE 1=1
          AND mr.field_varchar_80 = 'Diagnostic'
          AND P.Status = 'Active'
        ORDER BY
          patient_name ASC,
          P.patient_id ASC,
          new_case_date ASC
      ),
    --- ---
    ---FirstCaseDate---
      --149 samples, 18 No New Case
      FirstCaseDate AS (
        SELECT DISTINCT
          NCS.patient_name,
          MIN(NCS.new_case_date) AS first_case_date
        FROM NewCaseSamples NCS
        WHERE 1=1
        GROUP BY
          NCS.patient_name
        ORDER BY
          patient_name,
          first_case_date NULLS FIRST,
          NCS.patient_name
      ),
    --- ---
    ---TBList---
      --149 samples, 18 No New Case
      TBList AS (
        SELECT DISTINCT
          NCS.patient_name,
          NCS.patient_id,
          NCS.external_id,
          NCS.date_of_birth,
          NCS.date_collected,
          NCS.date_received,
          FCL.first_case_date,
          '~' AS eol
        FROM NewCaseSamples NCS
          LEFT OUTER JOIN FirstCaseDate FCL ON (
          COALESCE(NCS.new_case_date,TRUNC(SYSDATE))
           =
          COALESCE(FCL.first_case_date, TRUNC(SYSDATE))
          )
        WHERE 1=1
              AND NCS.patient_name = FCL.patient_name
        ORDER BY
          NCS.patient_name ASC,
          NCS.patient_id ASC,
          NCS.external_id ASC
      ),
    --- ---
    ---CaseDetails---
      --150 samples, 18 No New Case
      CaseDetails AS (
        SELECT DISTINCT
          HBT.Ordno,
          (TB.patient_name || ' ' || TO_CHAR(TB.date_of_birth, 'MM/DD/YYYY')) AS name,

          HBT.mgit_testcode,
          HBT.afbcul_testcode,
          O.Logdate,
          TB.date_collected,
          TB.date_received,
          --new_case_date--
          TO_DATE(
            COALESCE(TO_CHAR(TB.first_case_date,'DD-MON-YYYY'),'1-JAN-1900')
            || ' ' ||
            COALESCE(MRD2.SectionTime,'00:00:01')
            ,'DD-MON-YYYY HH24:MI:SS')
            AS new_case_date,
          --mgit_completed--
          TO_DATE(
            COALESCE(TO_CHAR(MTS2.Dateentered,'DD-MON-YYYY'),'1-JAN-1900')
            || ' ' ||
            COALESCE(MTS2.TimeEntered,'00:00:01')
            ,'DD-MON-YYYY HH24:MI:SS')
            AS mgit_completed,
        --cal_tat--
        (TO_NUMBER(
            TO_DATE(
              COALESCE(TO_CHAR(MTS2.Dateentered,'DD-MON-YYYY'),'1-JAN-1900')
              || ' ' ||
              COALESCE(MTS2.TimeEntered,'00:00:01')
              ,'DD-MON-YYYY HH24:MI:SS')
            -
            TO_DATE(
              COALESCE(TO_CHAR(TB.first_case_date,'DD-MON-YYYY'),'1-JAN-1900')
              || ' ' ||
              COALESCE(MRD2.SectionTime,'00:00:01')
              ,'DD-MON-YYYY HH24:MI:SS')
        )) AS cal_tat,
        --Supplemental---
          TB.patient_name,
          TB.patient_id,
          TB.external_id,
          F.Folderno,
          TB.date_of_birth,
          TB.first_case_date,
          HBT.mgit_testno,
          HBT.afbcul_testno,
        --
          '~' AS eol
        FROM TBList TB
          INNER JOIN HaveBothTests HBT ON (TB.external_id = HBT.external_id)
          INNER JOIN Folders F ON TB.external_id = F.external_id
          INNER JOIN Orders O ON (F.Folderno = O.Folderno)
          --Get MGIT DST Info--
          LEFT OUTER JOIN MicroTaskSteps MTS2 ON (1=1
            AND HBT.Ordno = MTS2.Ordno
            AND HBT.mgit_testcode = MTS2.testcode
            AND MTS2.Stepcode = 'DST'
            AND MTS2.Comptype = 'MGIT DST'
            AND MTS2.Compid = 'Rifampin 1.0 ug/mL')
          --Get TB Info--
          LEFT OUTER JOIN MicroRepDetails MRD2 ON (1=1
            AND HBT.Ordno = MRD2.Ordno
            AND HBT.afbcul_testcode = MRD2.testcode
            AND MRD2.Reportsection = 'Conclusion'
            AND MRD2.Col1 = 'Conclusion')
        WHERE 1=1
        ORDER BY
          TB.patient_name,
          TB.patient_id,
          TB.external_id
      )
    --- ---
    ---Final Query---
      SELECT DISTINCT
        CD.name,
        CD.patient_id,
        CD.external_id,
        CD.Folderno,
        CD.cal_tat,
        CD.new_case_date,
        CD.mgit_completed,
        CD.date_collected,
        CD.date_received,
        CD.Ordno,
        CD.first_case_date,
        --CD.patient_name,
        --CD.mgit_testcode,
        --CD.afbcul_testcode,
        --CD.Logdate,
        --CD.date_of_birth,
        --CD.mgit_testno,
        --CD.afbcul_testno,
        '~' AS eol
      FROM CaseDetails CD
      WHERE 1=1
AND CD.date_received  between to_date('01-JAN-2015', 'DD-MON-YYYY') AND to_date('01-JUL-2015', 'DD-MON-YYYY')
      ORDER BY
        CD.name ASC,
        CD.date_collected ASC,
        CD.date_received ASC,
        CD.patient_id ASC,
        CD.external_id ASC
/*-----------------------------------------------------------------*/



