
/*-----AFBCulture_AutoPreliminaryResults_Identified.sql----------------------
  -----Description-----
    This script can be used to identify the samples that will be processed by
    the ADHS_AFBCultureAutoPreliminary server script located in at:
      |Server Scripts | BATCHJOBS | ADHS_AFBCultureAutoPreliminary |
    In this script it is assumed the ElapsedDays calculation is based on the
    sysdate of the server.  The following parameters will also need to be
    specified:
      &Environment: Database schema to run query against.
      &LowerLimit:  ElapsedDays lower limit window for samples (Typically 28days).
      &UpperLimit:  ElapsedDays upper limit window for samples 
                    (Arbitrarily set at 35days).
  ----- -----

  -----History-----
    2016.10.03 JTY: Created Script
  ----- -----
---------------------------------------------------------------------------*/

---------------------------------------------------------------------------
  WITH
    SamplesOfInterest AS (
      SELECT DISTINCT
        f.external_id,
        f.folderno,
        fc.status,
        f.need_preliminary,
        ot1.testcode AS smear_testcode,
        ot1.apprdate AS smear_apprdate,
        ot1.ordno AS smear_ordno,
        ot2.testcode AS culture_testcode,
        ot2.ordno AS culture_ordno,
        r2.numres AS culture_numres,
        (TRUNC(sysdate) - TRUNC(ot1.apprdate)) AS elapsed_days,
        '~' AS eol
      FROM &Environment.folders f
        INNER JOIN &Environment.foldercondition fc ON (fc.folderno = f.folderno)
        INNER JOIN &Environment.ordtask ot1 ON (1=1
          AND ot1.folderno = f.folderno
          AND ot1.testno = 'AFB Smear'
          AND ot1.apprdate IS NOT NULL)
        INNER JOIN &Environment.ordtask ot2 ON (1=1
          AND ot2.folderno = f.folderno
          AND ot2.testno = 'AFB Culture'        
          AND ot2.apprdate IS NULL)
        INNER JOIN &Environment.results r2 ON ( 1=1
          AND ot2.folderno = r2.folderno
          AND ot2.ordno = r2.ordno
          AND ot2.testcode = r2.testcode
          AND r2.numres IS NULL)
      WHERE 1=1
        AND f.folderno IS NOT NULL
        AND fc.status IN ('Active', 'Logged') 
      ORDER BY
       f.external_id DESC
    ),
      AfbMicroResults AS (
        SELECT
        soi.external_id,     
        soi.culture_ordno,
        ListAgg(mts.res01,',')WITHIN GROUP(ORDER BY mts.sorter) AS step_results,
        '~' AS EOL
        FROM SamplesOfInterest soi
          INNER JOIN &Environment.microtasksteps mts ON ( 1=1
            AND soi.culture_ordno = mts.ordno
            AND soi.culture_testcode = mts.testcode)
        WHERE 1=1
        GROUP BY
          soi.external_id,
          soi.culture_ordno
        ORDER BY
        soi.external_id ASC    
      ),
      IdentifiedSamples AS (
        SELECT  
          soi.external_id,
          soi.folderno,
          soi.elapsed_days,
          soi.status,
          soi.need_preliminary,
          soi.smear_testcode,
          soi.smear_apprdate,
          soi.smear_ordno,
          soi.culture_testcode,
          soi.culture_ordno,
          soi.culture_numres,
          amr.step_results,
          soi.eol        
        FROM SamplesOfInterest soi
          INNER JOIN AfbMicroResults amr ON (1=1
            AND soi.external_id = amr.external_id
            AND soi.culture_ordno = amr.culture_ordno
            AND amr.step_results IS NULL)
        WHERE 1=1
          AND soi.elapsed_days BETWEEN &LowerLimit AND &UpperLimit
        ORDER BY
          soi.external_id ASC
      )
   SELECT * FROM IdentifiedSamples a  
---------------------------------------------------------------------------
