

/*-----RightFax--------------------------------------------------------------*/
  ---DESCRIPTION---
    --Use this script for review and identification of isssues related to
    --faxing within the STARLiMS application
  --- ---

  ---HISTORY---
    --2016.09.19 JTY: Created Script
  --- ---

/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
  /*-----PROD Fax Status Check-----*/
  
    --This query will show what Faxes have been processed from STARLiMS
    --and may have issues
    SELECT DISTINCT
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      rdq.dept,
      rdq.folderno,
      --cr.first_name,
      rdq.testgroupname AS panel,
      rdh.sent_by AS appr_by,
      to_char(rdh.sent_date, 'YYYY.MM.DD')  || '  ' || rdh.sent_time AS approved_dt,
      to_char(fq.senddate, 'YYYY.MM.DD')  || '  ' || fq.sendtime AS faxed_dt,
      rdq.status,
      fq.tofax,
      rdh.message,
      fq.crtmessage,
      rdq.stardoc_id,
      fq.receipt,

      '~' AS eol
    FROM &Environment.rr_report_delivery_queue rdq
      LEFT OUTER JOIN &Environment.rr_rdq_history rdh ON (1=1
        AND rdq.receipt_number = rdh.receipt_number
        AND rdq.queue_item_no = rdh.queue_item_no)
      INNER JOIN &Environment.rasclients rc ON (rdq.rasclientid = rc.rasclientid)
      INNER JOIN &Environment.folderscontactsext fcx ON (1=1
        AND rdq.rasclientid = fcx.rasclientid
        AND rdq.contactid = fcx.contactid)
      LEFT OUTER JOIN &Environment.faxqueue fq ON (rdq.receipt_number = fq.receipt)
      INNER JOIN &Environment.folders f ON (rdq.folderno = f.folderno)
      INNER JOIN &Environment.centralreceiving cr ON (f.external_id = cr.external_id)
    WHERE 1=1
      AND rdq.delivery_method = 'Fax'
      AND fq.senddate IS NULL
      --AND rc.rasclientid IN ('MCHD-TB', 'PCPH')
      AND TRUNC(rdh.sent_date) BETWEEN TRUNC(SYSDATE-1) AND TRUNC(SYSDATE)
--      AND fq.receipt = '80DB955A-3DBF-42C1-A134-8759AA9A23C4'
    ORDER BY
      rdq.dept ASC,
      client ASC,
      approved_dt ASC,
      faxed_dt ASC;
      
  /*----- -----*/


  /*----- -----*/
  /*----- -----*/
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
  /*-----01. Tables Review-----*/
    --Tables related to RightFax functionality
/*    
    SELECT * FROM &Environment.faxqueue ORDER BY origrec DESC;
--    SELECT * FROM &Environment.faxattachments ORDER BY origrec DESC;
    SELECT * FROM &Environment.rr_report_delivery_queue rdq ORDER BY origrec DESC;
    SELECT * FROM &Environment.rr_batchstatus ORDER BY origrec DESC;
    SELECT * FROM &Environment.rr_rdq_history ORDER BY origrec DESC;
*/  
  /*----- -----*/

  /*-----02. Clean Tables-----*/
    --Note Truncate will wipe all records from the table.  May want to use
    --more targeted process of removing enteries in PROD.
    --truncate table &Environment.faxqueue
    --truncate table &Environment.faxattachments

  /*----- -----*/

  /*-----03 Find canidates for validation-----*/
    --Use this script to identify Performance Samples that would be
    --good for verifying RightFax works.  Remember  the client needs
    --to be ASL-P in PROD, ADHS in DEV/TEST and the external contact
    --needs to be James Yoder for RightFax delivery.
/*    
    SELECT DISTINCT
      f.external_id,
      ot.testgroupname,
      ot.testno,
      mr.field_varchar_80,
      f.apprdate,
      f.dept,
      cr.rasclientid,
      '~' AS eol
    FROM &Environment.centralreceiving cr
      INNER JOIN &Environment.metadata_repository mr ON (1=1
        AND mr.original_origrec = cr.origrec
        AND mr.tablereference = 'CENTRALRECEIVING')
      INNER JOIN  &Environment.folders f ON (cr.external_id = f.external_id)
      INNER JOIN &Environment.ordtask ot ON (f.folderno = ot.folderno)
        
    WHERE 1=1
      AND mr.field_varchar_80 = 'PT'
      AND cr.rasclientid = 'ASL-P'
      AND f.dept = 'PHX-VIR'
    ORDER BY 
      f.apprdate DESC;
*/      
  /*----- -----*/
  
/*---------------------------------------------------------------------------*/





/*---------------------------------------------------------------------------*/
  /*-----General Fax Information-----*/
/*  
    SELECT DISTINCT
      fq.crtmessage,
      fq.crttry,
      fq.fromfax,
      fq.fromname,
      fq.postdate,
      fq.toname,
      fq.toname,
      fq.statusname,
      fq.errorname,
      fq.receipt,
      fq.origrec as fq_origrec,
      '~' AS eol
    FROM sundata_prod.faxqueue fq
    WHERE 1=1

    ORDER BY
      fq.origrec DESC;
*/
  /*----- -----*/


  /*----- -----*/
  /*----- -----*/
/*---------------------------------------------------------------------------*/


--Determine what samples are in-house for client that we may need to update
--delivery method.
/*
SELECT DISTINCT
  f.apprsts,
  f.rasclientid,
  rc.compname,
  f.folderno,
  f.dept,
  f.testgroupname,
  '~' AS eol
FROM sundata_prod.folders f
  INNER JOIN sundata_prod.rasclients rc ON (f.rasclientid = rc.rasclientid)
WHERE 1=1
  AND f.rasclientid IN ('&ClientID')
  AND f.apprdate IS NULL
      AND f.dept IN ('PHX-VIR')
ORDER BY 
 f.dept ASC,
 f.folderno ASC
*/ 
 

  --Identify active samples in system for specific External Contact
  /*
 SELECT DISTINCT
   f.rasclientid,
   f.dept,
   f.folderno,  
   rcx.fullname,
   rcx.submit_method
 FROM sundata_prod.folderscontactsext fcx
   INNER JOIN sundata_prod.folders f ON (fcx.folderno = f.folderno)
   INNER JOIN sundata_prod.rasclientcontactsext rcx ON (1=1
     AND fcx.rasclientid = rcx.rasclientid
     AND fcx.contactid = rcx.contactid)
 WHERE 1=1
   AND f.apprdate IS NULL
   AND f.rasclientid IN ('&RasClientID))
   AND f.dept IN 'PHX-BAC'
--   AND rcx.fullname = 'Laboratory Results-PHL'
 ORDER BY
   f.rasclientid ASC,
   f.dept ASC,
   f.folderno ASC
*/



/*
    SELECT DISTINCT
      rdq.rasclientid,
      rdq.dept,
      (TRUNC(sysdate) - TRUNC(rdh.sent_date)) AS elapsed_days,
      rdq.folderno,
      rdh.reporttype,
      rdq.status,
      rdh.delivery_method,
      rdh.delivery_address,
      rdq.testgroupname AS panel,
      rdq.queue_item_no,
      rdh.sent_by AS appr_by,
      to_char(rdh.sent_date, 'YYYY.MM.DD')  || '  ' || rdh.sent_time AS approved_dt,

      --FaxInfo--
      to_char(fq.senddate, 'YYYY.MM.DD')  || '  ' || fq.sendtime AS faxed_dt,
      fq.receipt,
      --EmailInfo
      rdh.message,
      rdh.stardoc_id,
      fq.crtmessage,
      rc.compname,
      rdq.stardoc_id,
      '~' AS eol
    FROM rr_report_delivery_queue rdq
      INNER JOIN rr_rdq_history rdh ON (1=1
        AND rdq.queue_item_no = rdh.queue_item_no)
      INNER JOIN rasclients rc ON (rdq.rasclientid = rc.rasclientid)
      INNER JOIN folderscontactsext fcx ON (1=1
        AND rdq.rasclientid = fcx.rasclientid
        AND rdq.contactid = fcx.contactid)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
      INNER JOIN folders f ON (rdq.folderno = f.folderno)
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
    WHERE 1=1
      AND rdh.delivery_method IN ('Fax', 'E-mail')
      AND rc.rasclientid IN ('MCHD-TB', 'PCPH', 'ADHS')
      AND TRUNC(rdh.sent_date) BETWEEN TRUNC(SYSDATE-50) AND TRUNC(SYSDATE)
    ORDER BY
      rdq.rasclientid ASC,
      rdq.dept ASC,
      elapsed_days ASC,
      rdq.folderno ASC;
 */
