/*---------------------------------------------------------------------------*/
/*-----HL7_Queries-----------------------------------------------------------*/
  -----DESCRIPTION-----
    --Use this set of qeries to investigate information related to
    --HL7 Messaging includind messaging for the following programs:
      --PHLIP
      --MEDSIS
      --LRN-B
  ----- -----
  
  -----HISTORY-----
    --2015.01.06 JTY: Created file
    --2015.02.09 JTY: Addition of Processed Query
  ----- -----
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
  -----Reference Tables-----
/*  
    select * from sundata_prod.orion_queue;
    select * from sundata_prod.orion_details;    
    select * from sundata_prod.hl7_analytes;
    select * from sundata_prod.hl7_dist_loincs;
    select * from sundata_prod.hl7_dist_messages;
    select * from sundata_prod.hl7_dist_submitters;
    select * from sundata_prod.hl7_error_log;
    select * from sundata_prod.hl7_fieldmap;
    select * from sundata_prod.hl7_fieldmap_binder;
    select * from sundata_prod.hl7_fieldnames;
    select * from sundata_prod.hl7_message_types;
    select * from sundata_prod.hl7_microcomponents;
    select * from sundata_prod.hl7_oor_log;
    select * from sundata_prod.hl7_orders_review;
    select * from sundata_prod.hl7_orders_review_detail;
    select * from sundata_prod.hl7_organisms;
    select * from sundata_prod.hl7_rhapsody_msg_log;
    select * from sundata_prod.hl7_rhapsody_nack;
    select * from sundata_prod.hl7_segments;
    select * from sundata_prod.hl7_versions;  
    select * from sundata_prod.cr_hl7_request;
    select * from sundata_prod.testloinccodes;    
*/
  ----- -----
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*-----01. Processed Query---------------------------------------------------*/
  --Idendify samples that have been processed withing the specified time period.

    SELECT DISTINCT
      f.external_id,
      f.dept,
      (t.testcode || ' : ' ||t.testno) AS test_id,  
      f.dispsts,
      f.apprdate,
      f.approvedby,
      f.apprsts,
      r.final,
      t.testcode,
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN sundata_prod.metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      INNER JOIN sundata_prod.folders f ON (cr.external_id = f.external_id)
      INNER JOIN sundata_prod.results r ON (1=1
        AND f.folderno = r.folderno)
      INNER JOIN sundata_prod.tests t ON (r.testcode = t.testcode)
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND f.external_id IS NOT NULL
      AND f.dispsts IN ('Done', 'OOS')
      AND f.dept IN ('PHX-VIR')
      AND f.apprdate BETWEEN to_date('01-JAN-2015', 'DD-MON-YYYY') and to_date('05-JAN-2015', 'DD-MON-YYYY')
      AND t.testcode IN ('1','2','6','41','444')
    --  AND cr.external_id IN ('AZ00022758')
    ORDER BY 
      f.dept ASC,
      f.external_id DESC,
      t.testcode ASC;

/*---------------------------------------------------------------------------*/

  -----Client HL7MappingNames and Paths-----
/*
    SELECT DISTINCT
      CASE
        WHEN ('&Environment' = 'sunrise_data') THEN 'DEV'
        WHEN ('&Environment' = 'sundata_sat') THEN 'TEST'
        WHEN ('&Environment' = 'sundata_prod') THEN 'PROD'
      END AS env,
      rc.compname,
      rc.rasclientid,
      lower(rc.dev_outbound_results) AS phlip_path,
      mt.ior_message_type,
      mt.ior_header_name,
      lower(mt.ior_xml_path) AS elr_lrnb_Path,
      '~' AS eol
    FROM &Environment.rasclients rc
      INNER JOIN &Environment.rasclientmessagetypes mt ON ( 1=1
        AND rc.rasclientid = mt.rasclientid)
    WHERE 1=1
      AND mt.ior_xml_path IS NOT NULL
    ORDER BY
      rc.compname ASC;
*/      
  ----- -----


  -----HL7 Message Queue-----
/*  
    SELECT DISTINCT
      f.external_id,
      fc.status,
      oq.folderno,
      oq.status,
      oq.type,
      oq.rasclientid,
      oq.expversion,
      oq.header_name,
      (to_char(fel.eventdate,'MM-DD-YYYY') || '  ' || fel.eventtime) AS HL7_TimeStamp,
      fel.thecomment,
      --oq.upload_flag,
      --od.segment,
      --od.component,
      --od.fieldno,
      --od.content,
      --od.setid,
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN sundata_prod.folders f ON (cr.external_id = f.external_id)
      INNER JOIN sundata_prod.foldercondition fc ON (f.folderno = fc.folderno)
      LEFT OUTER JOIN sundata_prod.orion_queue oq ON (f.folderno = oq.folderno)
      LEFT OUTER JOIN sundata_prod.floweventlog fel ON (1=1
        AND (fel.folderno = f.folderno OR fel.external_id = cr.external_id)
        AND fel.eventtype = 'Report to HL7')
      LEFT OUTER JOIN sundata_prod.orion_details od ON (oq.guid = od.guid)      
    WHERE 1=1
--      AND cr.external_id IN ('&SampleID')
      AND oq.rasclientid = '&RasClientID'  ---CDC, PHLIP-FLU, MEDSIS-TEST
    ORDER BY
      hl7_timeStamp DESC,
      oq.folderno ASC,
      oq.header_name ASC;
      --od.segment ASC;
*/      
  ----- -----
  


  -----HL7 Message Queue-----
/*  
    SELECT DISTINCT
      f.external_id,
      fc.status,
      oq.folderno,
      oq.status,
      oq.type,
      oq.rasclientid,
      oq.expversion,
      oq.header_name,
      (to_char(fel.eventdate,'MM-DD-YYYY') || '  ' || fel.eventtime) AS HL7_TimeStamp,
      fel.thecomment,
      --oq.upload_flag,
      --od.segment,
      --od.component,
      --od.fieldno,
      --od.content,
      --od.setid,
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN sundata_prod.folders f ON (cr.external_id = f.external_id)
      INNER JOIN sundata_prod.foldercondition fc ON (f.folderno = fc.folderno)
      LEFT OUTER JOIN sundata_prod.orion_queue oq ON (f.folderno = oq.folderno)
      LEFT OUTER JOIN sundata_prod.floweventlog fel ON (1=1
        AND (fel.folderno = f.folderno OR fel.external_id = cr.external_id)
        AND fel.eventtype = 'Report to HL7')
      LEFT OUTER JOIN sundata_prod.orion_details od ON (oq.guid = od.guid)      
    WHERE 1=1
      AND cr.external_id IN ('&SampleID')
    ORDER BY
      oq.folderno ASC,
      oq.header_name ASC;
      --od.segment ASC;
*/      
  ----- -----
  
  -----HL7 Message Config Query-----
/*  
    SELECT DISTINCT
      fb.header_name,
      fb.message_type,
      ver.version,
      fb.description AS fb_description,
      seg.segment,
      seg.description AS seg_description,
      fn.fieldname,
      fn.description AS fn_description,
      fm.starlims_table,
      fm.starlims_column,
      '~' AS eol
    FROM  sundata_prod.hl7_versions ver
      INNER JOIN sundata_prod.hl7_fieldmap_binder fb ON (ver.version = fb.hl7_version)
      INNER JOIN sundata_prod.hl7_segments seg ON (ver.version = seg.version)
      INNER JOIN sundata_prod.hl7_fieldnames fn ON (1=1
        AND seg.version = fn.version 
        AND seg.segment = fn.segment)
     INNER JOIN sundata_prod.hl7_fieldmap fm ON (1=1
       AND fn.version = fm.hl7_version
       AND fb.header_name = fm.header_name
       AND fn.segment = fm.hl7_segment)
    WHERE 1=1
    ORDER BY
      fb.header_name ASC,
      fb.message_type ASC,
      ver.version ASC,
      seg.segment ASC,
      fn.fieldname ASC,
      fm.starlims_table ASC,
      fm.starlims_column ASC;
*/      
  ----- -----
/*---------------------------------------------------------------------------*/

