/*-----SL10: MicroCoponents and Materials---------------------------*/

  /*---------- ----------*/
    --Identify Materials related to a Micro Test.
    --2012.12.21: JTY  
  /*---------- ----------*/  

  /*----------Enviroments----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod
  /*---------- ----------*/

  /*----------Departments----------*/
    --PHX-BT
    --PHX-TB
    --PHX-VIR
    --BAC
    --PHX-SER
  /*---------- ----------*/  


  /*---------- Core Query ----------*/
    WITH
      ---MySteps---
        --Get the Steps related to the Micro Test
        MySteps AS (
          SELECT DISTINCT
            tc.dept,
            tc.testcatcode,
            t.testno,
            t.testcode,
            t.testflag,
            t.tmname,
            tws.Stepcode,
            '~' AS sp1,
            tws.Sorter AS step_order,
            twm.tmcode,
            '~' AS eol
          FROM &Environment.testcategory tc
            INNER JOIN &Environment.tests t ON (tc.testcatcode = t.testcatcode)
            INNER JOIN &Environment.testwfmethods twm ON (t.tmname = twm.tmname)
            INNER JOIN &Environment.testwfsteps tws ON (twm.tmcode = tws.tmcode)
          WHERE 1=1
            AND t.testflag = 'Micro'  --Only interested in Micro Tests
  ---Optional Parameters here---
  --          AND t.testno = 'E. coli STEC Broth Culture'
            AND tc.dept = '&Department'
  ---          
          ORDER BY
            tc.dept ASC,
            t.testno ASC,
            tws.sorter ASC),
      ---
      ---StepComponents1---
        --Get the Components related to each step via ComponentType
        StepComponents1 AS (
          SELECT DISTINCT
            MS.dept,
            MS.testcatcode,
            MS.testno,
            MS.testcode,
            MS.testflag,
            MS.tmname,
            MS.Stepcode,
            mc.comptype,
            mc.compname,          
            mpcm.compid,
            '~' AS sp1,
            MS.step_order,
            --MS.tmcode,
            '~' AS eol
          FROM MySteps MS
            INNER JOIN &Environment.microplates mp ON (
                ms.stepcode = mp.stepcode AND ms.tmcode = mp.tmcode)
            INNER JOIN &Environment.micropanelconditions mpc ON (mp.fromcomptype = mpc.comptype)
            INNER JOIN &Environment.micropanelcomp mpcm ON (
              mpc.comptype = mpcm.comptype AND mpc.panelid = mpcm.panelid)
            INNER JOIN &Environment.microcomponents mc ON (mpcm.compid = mc.compid)
          WHERE 1=1
          ORDER BY
            MS.dept ASC,
            MS.testno ASC,
            MS.step_order ASC,
            mc.comptype ASC,
            mc.compname ASC),
      ---            
      ---StepComponents2---
        --Get the Default Components related to each step
        StepComponents2 AS (
          SELECT DISTINCT
            MS.dept,
            MS.testcatcode,
            MS.testno,
            MS.testcode,
            MS.testflag,
            MS.tmname,
            MS.Stepcode,
            mc.comptype,
            mc.compname,
            mpdc.compid,
            '~' AS sp1,
            MS.step_order,
            --MS.tmcode,
            '~' AS eol
          FROM MySteps MS
            INNER JOIN &Environment.microplatedefcomp mpdc ON (
                ms.stepcode = mpdc.stepcode AND ms.tmcode = mpdc.tmcode)
            INNER JOIN &Environment.microcomponents mc ON (mpdc.compid = mc.compid)              
          WHERE 1=1
          ORDER BY
            MS.dept ASC,
            MS.testno ASC,
            MS.step_order ASC,
            mc.comptype ASC,
            mc.compname ASC),
      ---          
      ---MyComponents---
        --Combine StepComponents1 & StepComponents2 to get all micro components
        --related to the Micro Test.
        MyComponents AS (
          (SELECT DISTINCT
            sc1.dept,
            sc1.testcatcode,
            sc1.testno,
            sc1.testcode,
            sc1.testflag,
            sc1.tmname,
            sc1.stepcode,
            sc1.comptype,
            sc1.compname,
            sc1.compid,
            '~' AS sp1,
            sc1.step_order,
            '~' AS eol
          FROM StepComponents1 sc1)
          UNION
          (SELECT DISTINCT
            sc2.dept,
            sc2.testcatcode,
            sc2.testno,
            sc2.testcode,
            sc2.testflag,
            sc2.tmname,
            sc2.stepcode,
            sc2.comptype,
            sc2.compname,          
            sc2.compid,
            '~' AS sp1,
            sc2.step_order,
            '~' AS eol
          FROM StepComponents2 sc2)
          ORDER BY
          dept ASC,
          testno ASC,
          step_order ASC,
          comptype ASC,
          compname ASC),
      ---     
      ---MyMaterials---
        --Get materials for all identified components
        MyMicroTestMaterials AS (
          SELECT DISTINCT
            MC.dept,
            MC.testcatcode,
            MC.testno,
            MC.testcode,
            MC.testflag,
            MC.tmname,
            MC.stepcode,
            MC.comptype,
            MC.compname,
            MC.compid, 
            m.mattype,
            m.matname,
            m.matcode,
            m.unit_code,                                 
            '~' AS sp1,
            MC.step_order,
            '~' AS eol
          FROM MyComponents MC
            INNER JOIN &Environment.microcompreagents mcr ON (
                MC.Comptype = mcr.comptype AND MC.Compid = mcr.compid)
            INNER JOIN &Environment.materials m ON (mcr.matcode = m.matcode)
          WHERE 1=1
          ORDER BY
          dept ASC,
          testno ASC,
          step_order ASC,
          comptype ASC,
          compname ASC,
          m.mattype,
          m.matcode ASC)     
      ---  
      ---Final Query---
        --Bring it all together and identify what materials are required for
        --a given Micro test
        SELECT * FROM MyMicroTestMaterials
      ---
  /*---------- ----------*/
  

  /*---------- Component Related Tables ----------*/  
  --Test--
    --select * from sunrise_data.testcategory;
    --select * from sunrise_data.tests; 
  --
  --MicroTests with workflows--

    --select * from sunrise_data.microtestgroups;
    --select * from sunrise_data.testwfmethods;
  --
  --Workflow to Steps--
    --select * from sunrise_data.testwfmethods;
    --select * from sunrise_data.testwfsteps;
    --select * from sunrise_data.testwfchildsteps;
    --select * from sunrise_data.microplates;
    --select * from sunrise_data.microplatedefcomp;
    --select * from sunrise_data.microplateactions;
  --
  --MicroPanels and Components--
    --select * from sunrise_data.micropanels;
    --select * from sunrise_data.micropanelconditions;
    --select * from sunrise_data.micropanelcomp;

    --select * from sunrise_data.microcomponents;
    --select * from sunrise_data.microcompresponse;
    --select * from sunrise_data.micropanelcomp;
  --
  --Materials--
    --select * from sunrise_data.microcompreagents

    --select * from sunrise_data.materials
    --select * from sunrise_data.mattypes
  --
  /*---------- ----------*/
/*------------------------------------------------------------------*/
