

/*-----Reports-----------------------------------------------------*/

  -----Desription-----
    --Contains scripts related to reports including:
      --01. ReportDeliveryQueue
      --02. Panel Reports
      --03. Reports As Attachements
  -----
  -----History-----
    --2015.07.10 Created Script File
  -----
/*-----------------------------------------------------------------*/


/*-----01. ReportDeliveryQueue-------------------------------------*/

  /*-----Description-----*/
    --Queries used to review Report Delivery Queue jobs.
  /*----- -----*/

  /*-----Core Tables-----*/  
    --SELECT * FROM sundata_prod.rr_report_delivery_queue;
    --SELECT * FROM sundata_prod.rr_batchstatus;
  /*----- -----*/  

  /*----- -----*/
    SELECT DISTINCT 
      bs.batchid,
      bs.progress,
      bs.totalitems,
      bs.progress,
      bs.noerrors,
      bs.error,
      bs.process,
      bs.origrec AS bs_origrec,
      dq.dept,
      dq.folderno,
      dq.testgroupname,
      dq.printed,
      dq.queue_item_no,
      dq.reptemplate,
      dq.stardoc_id,
      dq.status,
      dq.usrnam,
      dq.reporttype,
      dq.schedstatus,
      '~' AS eol
    FROM  sundata_prod.rr_batchstatus bs
      INNER JOIN sundata_prod.rr_report_delivery_queue dq ON (bs.batchid = dq.batch_id)
    WHERE 1=1
    ORDER BY
      bs.batchid DESC,
      dq.folderno ASC;    
  /*----- -----*/  
  

/*-----------------------------------------------------------------*/



/*-----02. Panel Reports--------------------------------------------*/
  --Identify what reports are associated with panels
  SELECT DISTINCT
    rr.rulename,
    rl.caption,
    rp.reportname,
    rr.ruleid,
    rr.entitytypeid,
    rl.ruleselectionid,
    '~' AS EOL
  FROM &Environment.rr_reportingrules rr
    INNER JOIN &Environment.rr_reportingruleslevels rl ON (rr.ruleid = rl.ruleid)
    INNER JOIN &Environment.rr_reportingrulereports rp ON (1=1
      AND rr.entitytypeid = rp.entitytypeid 
      AND rr.ruleid = rp.ruleid
      AND rl.ruleselectionid = rp.ruleselectionid)
  WHERE 1=1
    AND rr.rulename = 'Clinical Default'
    AND rp.reportname IN (
      'ADHS_FINALREPORTS.ADHS_HUMAN_FINALREPORT',
      'ADHS_FINALREPORTS.ADHS_FINALREPORT_SER',
      'ADHS_FINALREPORTS.ADHS_FINALREPORT')
  ORDER BY
    rp.reportname ASC,
    rl.caption ASC;
/*-----------------------------------------------------------------*/



/*-----03. Reports As Attachements---------------------------------*/
  --Get a list of reports in relation to attachemenets.
  
  SELECT DISTINCT
    ra.folderno,
    ra.stardoc_id,
    ra.reporttype,
    ra.attdate,
    ra.atttime,
    ra.attby,
    rq.batch_id,
    rq.dept,
    rq.delivery_method,
    rq.status,
    ra.attachmenttype,
    ra.mycomment,
    '~' AS eol
  FROM sundata_prod.res_attachments ra
    INNER JOIN sundata_prod.rr_report_delivery_queue rq ON (ra.folderno = rq.folderno)
  WHERE 1=1
    AND ra.attachmenttype = 'RRARCH'
  --  AND ra.folderno = 'AZ00039694-01'
  --  AND to_date(ra.attdate, 'DD-MON-YY') 
  --      BETWEEN to_date('29-JAN-2016', 'DD-MON-YY') AND to_date('29-JAN-2016', 'DD-MON-YY')
  --AND rq.status <> 'PROCESSED'
  ORDER BY
    ra.attdate ASC,
    ra.atttime ASC,
    ra.folderno ASC

/*-----------------------------------------------------------------*/
