
/*-----ReportsPanelsAndTest--------------------------------------------------*/
  -----DESCRIPTION-----
    --Identify Report templates, and what panels and tests are associated with
    --the templates.
  ----- -----


  -----HISTORY-----
    --2017.01.05 JTY: Created Query
  ----- -----

/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
  --Report Template, Panel and Test
  SELECT DISTINCT
  -- rr.rulename,
   rrr.reportname AS report_template_name,
   LTRIM(rrl.caption,'Panel(s):') AS panel,
   t.testno AS test_name,
    '~' AS EOL
  FROM rr_reportingrules rr
    INNER JOIN rr_reportingrulereports rrr ON (1=1
      AND rr.entitytypeid = rrr.entitytypeid
      AND rr.ruleid = rrr.ruleid)
    INNER JOIN rr_reportingruleslevels rrl ON (1=1
      AND rr.ruleid = rrl.ruleid
      AND rrr.ruleselectionid = rrl.ruleselectionid)
    INNER JOIN testgroupnames tgn ON (
      LTRIM(rrl.caption,'Panel(s):') = tgn.testgroupname)
    INNER JOIN conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
  WHERE 1=1
    AND rr.rulename IN ('Clinical Default', 'Env Default')
    AND tgn.status <> 'Retired'

  ORDER BY
    rrr.reportname ASC,
    panel ASC,
    t.testno ASC  
    ;
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
  --Department, Panel, ReportTemplate, PanelTest, DeliveryMethod
  --DeliveryDetail, PrinterName
    SELECT DISTINCT
      ctt.dept,
      LTRIM(rrl.caption,'Panel(s):') AS panel,
--      rrr.reportname AS report_template_name,
--      (t.testno || ' (' || t.testcode || ')' ) AS panel_test,
      rrm.submit_method AS delivery_method,
      ci.itemname AS delivery_detail,
      ci.printername,
      '~' AS eol
    FROM rr_reportingrules rr
      INNER JOIN rr_reportingrulereports rrr ON (1=1
        AND rr.entitytypeid = rrr.entitytypeid
        AND rr.ruleid = rrr.ruleid)
      INNER JOIN rr_reportingrulemethods rrm ON (1=1
        AND rrm.ruleid = rrr.ruleid
        AND rrm.ruleselectionid = rrr.ruleselectionid
        AND rrm.entitytypeid = rrr.entitytypeid
        )
      INNER JOIN rr_categoryitems ci ON (rrm.itemid = ci.itemid)        
      INNER JOIN rr_reportingruleslevels rrl ON (1=1
        AND rr.ruleid = rrl.ruleid
        AND rrr.ruleselectionid = rrl.ruleselectionid)
      INNER JOIN testgroupnames tgn ON (
        LTRIM(rrl.caption,'Panel(s):') = tgn.testgroupname)
      INNER JOIN conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      INNER JOIN tests t ON (ctt.testcode = t.testcode)
    WHERE 1=1
      AND tgn.status = 'Active'
AND (rrm.submit_method IN ('Hard Copy'))      
    ORDER BY
      ctt.dept ASC,
      panel ASC,
      delivery_method ASC;
/*---------------------------------------------------------------------------*/
