
/*-----WhereIsItAt-----------------------------------------------------------*/
  -----DESCRIPTION-----
    --This set of queries will be used to help determine where in the sample
    --lifecycle the sample is located.  We will uses this as a foundation
    --for the WhreIsItAt application in STARLiMS
      --01. Sample Pre Login
      --02. Receive Prelogged
      --03. Clinical Data Entry
      --04. My Teams Pending Test
      --05. Run Approval
      --06. Micro Results Entry
      --07. Samples for Shipment
      --08. Outsource Samples Results Entry        
      --09. Preliminary Release By Panel
      --10. Release By Panel
      --11. Report Delivery Queue
  ----- -----

  ----- HISTORY-----
    --2019.01.14 JTY: Begin development of scripts
  ----- -----

/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
/*
  SELECT DISTINCT
  FROM centralreceiving cr
    INNER JOIN folders f ON (cr.external_id = f.external_id)
    INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
    INNER JOIN ordtask ot on (f.folderno = ot.folderno)
  WHERE 1=1
*/  
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*----Sample Pre Login-------------------------------------------------------*/
  SELECT DISTINCT
    cr.dept,
    cr.external_id,
    'Sample Pre Login' AS sample_location,
    cr.status,
    '~' AS eol
  FROM centralreceiving cr
  WHERE 1=1
    AND (cr.status IN ('Draft', 'Requested', 'HL7 Pending')
         AND cr.prelogged = 'Y'
         AND cr.status <> 'DBDE')
    OR (cr.status IN ('Prelogged')
        AND EXISTS (SELECT mr.ORIGREC 
                    FROM metadata_repository mr
                    WHERE 1=1
                      AND mr.ORIGINAL_ORIGREC = cr.ORIGREC
                      AND mr.TABLEREFERENCE = 'CENTRALRECEIVING'
                      AND mr.FIELD_VARCHAR_89 = 'Y' 
                      AND mr.FIELD_VARCHAR_90 = 'Receiving')
       )
  ORDER BY
    cr.dept ASC,
    cr.external_id ASC
       ;
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*----Receive Prelogged------------------------------------------------------*/

  SELECT DISTINCT
    cr.dept,
    cr.external_id,
    'Received Prelogged' AS sample_location,
    '~' AS eol
  FROM centralreceiving cr
  WHERE 1=1
    AND cr.status IN('Prelogged', 'Requested', 'HL7 Pending')  
    AND cr.status <> 'DBDE'  
    AND (EXISTS(SELECT ot.origrec
                FROM folders f
                  LEFT OUTER JOIN ordtask ot ON (f.folderno = ot.folderno)
                WHERE 1=1
                  AND f.external_id = cr.external_id
                  AND ot.dept = '&Dept')
         OR cr.dept IS NULL
         OR cr.dept = '')  
    AND NOT EXISTS(SELECT mr.origrec
                   FROM metadata_repository mr
                   WHERE 1=1
                     AND mr.original_origrec = cr.origrec
                     AND mr.tablereference = 'CENTRALRECEIVING'
                     AND mr.field_varchar_89 = 'Y'
                      )
   ORDER BY
     cr.dept ASC,
     cr.external_id ASC;
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*-----Clinical Data Entry---------------------------------------------------*/
  SELECT DISTINCT
    cr.dept,
    cr.external_id,
    'Clinical Data Entry' AS sample_location,
    cr.origrec,
    '~' AS eol
  FROM centralreceiving cr
  WHERE 1=1
    AND cr.dataentrystatus IN ('ReceiveDone', 'LoginDone', 'Pending')
    AND (cr.dept IS NULL OR DEPT IN ('', 'PHX-BAC'))
    AND cr.status  <> 'DBDE' 
    AND cr.user_dbde IS NULL OR cr.user_dbde <> 'YODERJ' 
  ORDER BY
    cr.dept ASC,
    cr.external_id ASC;
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*------My Teams Pending Test------------------------------------------------*/
  SELECT DISTINCT
    f.dept,
    f.external_id,
    'My Teams Pending Test' AS sample_location,
    f.testgroupname,
    (t.testno || ' (' || t.testcode || ')') AS test_name,
    '~' AS eol  
  FROM ordtask ot
    INNER JOIN folders f ON (ot.folderno = f.folderno)
    INNER JOIN tests t ON (ot.testcode = t.testcode)    
  WHERE 1=1
    AND ot.dept = 'PHX-BAC'
    AND ot.ts IN ('Logged','Active')
    AND t.testtype IN ('Multi','Single')
    AND t.testflag <> 'Micro'
    AND ot.qctype = 'N/A'
    AND ot.servgrp IN ('Bacteriology Team')
    AND (ot.outsourceordno IS NULL
         OR EXISTS (SELECT oo.origrec
                    FROM outsourceorders oo
                    WHERE 1=1
                      AND oo.outsourceordno = ot.outsourceordno
                      AND oo.status = 'Received')
        ) 
  ORDER BY
    f.dept ASC,    
    f.external_id ASC,
    f.testgroupname ASC,
    test_name ASC;
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*-----Run Approval----------------------------------------------------------*/
  SELECT DISTINCT
    ot.runno,
    'Run Approval' AS sample_location,
    '~' AS eol
  FROM ordtask ot
    INNER JOIN tests t ON (ot.testcode = t.testcode)
  WHERE 1=1
    AND t.testtype IN ('Multi','Single')
    AND ot.tsa IN ('RTR','RTROOS')
    AND ((EXISTS(SELECT r.origrec
                FROM runs r
                WHERE 1=1
                  AND r.runno = ot.runno
                  AND r.runindicator='Manual' 
                  AND r.runstatus='Done' 
                  AND r.approvalstatus IS NULL
                  AND r.servgrp IN ('Serology')
                  AND r.dept = 'PHX-SER'
                  AND r.usrnam<>'YODERJ'                  
                  AND r.usrnam IN ('BAKERBA','BEYERAM','BILLENM','BREAULC','CARTERN',
                                   'DESTEPR','ELSTONJ','ERHARTL','ESCOBAJ','FARABAS',
                                   'FINKM','FITZPAK','FRANCID','GERARDF','GETSINL',
                                   'GOODYKS','HADZIHM','HUYNHTP','IMHOLTS','KORBINJ',
                                   'LAYTONS','LEVYC','MEHTARU','MULLIGJ','NEWSUMM',
                                   'PATTERJO','PIERCEN','POUJLVK','PRICEEL','RIGLERJ',
                                   'RODRIGA','ROYALCA','SYSADM','VILLARL','WAMPLEC',
                                   'WANGSNK','WASHINN','WEISSJ','WHITESD')
               )
        )
         OR (
             ot.usrnam IN ('BAKERBA','BEYERAM','BILLENM','BREAULC','CARTERN','DESTEPR',
                           'ELSTONJ','ERHARTL','ESCOBAJ','FARABAS','FINKM','FITZPAK',
                           'FRANCID','GERARDF','GETSINL','GOODYKS','HADZIHM','HUYNHTP',
                           'IMHOLTS','KORBINJ','LAYTONS','LEVYC','MEHTARU','MULLIGJ',
                           'NEWSUMM','PATTERJO','PIERCEN','POUJLVK','PRICEEL','RIGLERJ',
                           'RODRIGA','ROYALCA','SYSADM','VILLARL','WAMPLEC','WANGSNK',
                           'WASHINN','WEISSJ','WHITESD')
             AND  ot.dept='PHX-SER'
             AND ot.servgrp IN ('Serology')
             AND EXISTS (SELECT r.origrec
                         FROM runs r
                         WHERE 1=1
                           AND r.runno = ot.runno
                           AND r.runindicator <> 'Manual'))  
       )
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*-----Micro Results Entry---------------------------------------------------*/
  SELECT DISTINCT
    f.dept,
    f.external_id,
    'Micro Results Entry' AS sample_location,
    f.testgroupname,
    (t.testno || ' (' || t.testcode || ')') AS test_name,
    '~' AS eol
  FROM folders f
    INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
    INNER JOIN tests t ON (ot.testcode = t.testcode)
    INNER JOIN orders o ON (ot.ordno = o.ordno)
    INNER JOIN microtasksteps mts ON (1=1
      AND ot.testcode = mts.testcode
      AND ot.ordno = mts.ordno)
    WHERE 1=1
      AND ot.dept = 'PHX-BAC'
      AND ot.servgrp IN ('Bacteriology Team')
      AND ot.ts NOT IN ('Prelogged','Draft')
      AND mts.micstatus = 'Logged'                                    
  ORDER BY
    f.dept ASC,    
    f.external_id ASC,
    f.testgroupname ASC,
    test_name ASC;
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*-----Samples for Shipment--------------------------------------------------*/
  (SELECT DISTINCT
     f.dept,
     f.external_id,
     'Samples for Shipment' AS sample_location,
     f.testgroupname,
     (t.testno || ' (' || t.testcode || ')') AS test_name,
     '~' AS eol
   FROM folders f
     INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
     INNER JOIN tests t ON (ot.testcode = t.testcode)
     INNER JOIN samplecontainers sc ON (ot.ordno = sc.ordno)
     INNER JOIN samplecontainertests sct ON (sc.containerid = sct.containerid)  
   WHERE 1=1
     AND ot.outsourceordno = 'OUTSOURCE'
     AND (f.dept = 'PHX-BAC' OR f.dept = ot.dept)
     AND ot.ts = 'Logged'
     AND ot.dept <> 'PHX-BAC' 
     AND sc.status = 'For Shipment' 
     AND sct.testcode = ot.testcode)
    
  UNION
    
  (SELECT DISTINCT    
     f.dept,
     f.external_id,
     'Samples for Shipment' AS sample_location,
     f.testgroupname,
     (t.testno || ' (' || t.testcode || ')') AS test_name,
     '~' AS eol
   FROM folders f
     INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
     INNER JOIN tests t ON (ot.testcode = t.testcode)
     INNER JOIN outsourceorders oso ON (ot.outsourceordno = oso.outsourceordno)
   WHERE 1=1
     AND (oso.status NOT IN ('Shipped', 'Received', 'Done') 
          OR oso.status IS NULL)
     AND oso.createdept = 'PHX-BAC'
     AND ot.ts = 'Logged' 
     AND ot.outsourceordno <> 'OUTSOURCE')

  ORDER BY
    dept ASC,    
    external_id ASC,
    testgroupname ASC,
    test_name ASC;
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*-----Outsource Samples Results Entry---------------------------------------*/

  SELECT DISTINCT
    f.dept,    
    oso.outsourceordno,
    f.external_id,
    'Outsource Samples Results Entry' AS sample_location,
    '~' AS eol
  FROM outsourceorders oso
    INNER JOIN ordtask ot ON (oso.outsourceordno = ot.outsourceordno)
    INNER JOIN folders f ON (ot.folderno = f.folderno)
  WHERE 1=1
    AND oso.status IN ('Shipped','Received') 
    AND (CREATEDEPT = 'PHX-BAC' 
         OR EXISTS (SELECT 1
                    FROM ordtask ot2
                    WHERE 1=1
                      AND ot2.outsourceordno = oso.outsourceordno
                      AND ot2.dispdept = 'PHX-BAC')
        )
  ORDER BY
    f.dept ASC,
    oso.outsourceordno ASC,
    f.external_id ASC;   
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*-----Preliminary Release By Panel------------------------------------------*/
  SELECT DISTINCT
     f.dept,
     f.external_id,
     'Preliminary Release By Panel' AS sample_location,
     f.testgroupname,
     '~' AS eol
  FROM folders f
    INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
    INNER JOIN testgroup_users tgu ON (f.testgroupname = tgu.testgroupname)
  WHERE 1=1
    AND fc.status NOT IN ('Done','OOS','Cancel')
    AND fc.approvalstatus IS NULL
    AND f.need_preliminary = 'Y'
    AND tgu.usrnam = 'YODERJ'
    AND f.dept = 'PHX-BAC'
    AND NOT EXISTS(
        SELECT cr.origrec
        FROM centralreceiving cr
        WHERE 1=1
          AND cr.external_id LIKE (f.external_id || '%')
          AND (cr.dataentrystatus <> 'ReleaseDone' OR cr.dbdestatus = 'Conflict'))
   AND NOT EXISTS(
       SELECT 1
       FROM ordtask ot2
         INNER JOIN runs r ON (ot2.runno = r.runno)
       WHERE 1=1
         AND r.approvalstatus IS NULL
         AND ot2.folderno = f.folderno
         AND r.microtestgroup IS NULL)
  ORDER BY
    f.dept ASC,    
    f.external_id ASC,
    f.testgroupname ASC;
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*-----Release By Panel------------------------------------------------------*/
  SELECT DISTINCT
    f.dept,
    f.external_id,
    'Release By Panel' AS sample_location,
    f.testgroupname,
    '~' AS eol
  FROM foldercondition fc
    INNER JOIN folders f ON (fc.folderno = f.folderno)
    INNER JOIN testgroup_users tgu ON (f.testgroupname = tgu.testgroupname)
  WHERE 1=1
    AND fc.status IN ('Done','OOS','Cancel') 
    AND fc.approvalstatus IS NULL 
    AND tgu.usrnam NOT IN (
        SELECT fel.USRNAM 
        FROM floweventlog fel
        WHERE 1=1
          AND fel.folderno = f.folderno
          AND UPPER(fel.eventtype) = 'RELEASE BY PANEL' 
          AND fel.sorter IS NULL
          AND fel.appr_level <> -1) 
    AND f.appr_level = tgu.appr_level
    AND f.dept = 'PHX-SER' 
    AND NOT EXISTS(
        SELECT cr.origrec
        FROM centralreceiving cr
        WHERE 1=1
          AND cr.external_id LIKE (f.External_Id || '%') 
          AND (cr.dataentrystatus <> 'ReleaseDone' 
               OR cr.dbdestatus = 'Conflict'))
    AND NOT EXISTS(
         SELECT ot.origrec
         FROM ordtask ot 
         WHERE 1=1
           AND (ot.tsa <> 'Released' OR ot.tsa IS NULL) 
           AND f.folderno = ot.folderno)
  ORDER BY
    f.dept ASC,
    f.external_id ASC
    f.testgroupname ASC;  
/*---------------------------------------------------------------------------*/





/*---------------------------------------------------------------------------*/
/*-----Report Delivery Queue-------------------------------------------------*/
  SELECT DISTINCT
     f.dept,
     f.external_id,
     'Report Delivery Queue' AS sample_location,
     f.testgroupname,
     '~' AS eol  
  FROM rr_report_delivery_queue rdq
    INNER JOIN folders f ON (rdq.folderno = f.folderno)
  WHERE 1=1
    AND rdq.status = 'QUEUED'
    AND rdq.dept = 'PHX-BAC'
  ORDER BY
    f.dept ASC,    
    f.external_id ASC,
    f.testgroupname ASC;
/*---------------------------------------------------------------------------*/






