

/*-----------------------------------------------------------------*/
  -----DESCRIPTION-----
    --Scripts used for investigation on HL7 messaging problems.
  -----
  -----SCRIPTS LIST-----
    --01. Check FlowEventLog
    --02. Processed Query
    --03. PHLIP Approvals    
  -----
  -----HISTORY-----
    --2015.07.08 JTY: Created script file
    --2017.05.18 JTY: Addition of PHILP Approvals query
  -----
/*-----------------------------------------------------------------*/



/*-----01. Check FlowEventLog---------------------------------------*/
  --See how HL7 messaging was handled in the FlowEventLog
/*
  SELECT DISTINCT
    f.external_id,
    fl.folderno,
    fl.eventdate,
    fl.eventtime,
    fl.eventtype,
    fl.stepcode,
    fl.thecomment,
    fl.origrec,
    '~' AS eol
  FROM &Environment.Floweventlog fl
    INNER JOIN &Environment.Folders f ON (fl.folderno = f.folderno)
  WHERE 1=1
    AND f.external_id = '&SampleID'
    AND fl.eventtype = 'Report to HL7'
  ORDER BY
    f.external_id ASC,
    fl.folderno ASC,
    fl.origrec DESC;
*/    
/*-----------------------------------------------------------------*/





/*-----02. Processed Query---------------------------------------------------*/
  --Idendify samples that have been processed withing the specified time period.
/*
    SELECT DISTINCT
      f.external_id,
      f.dispsts,
      f.dept,
      (t.testcode || ' : ' ||t.testno) AS test_id,  
      f.dispsts,
      f.apprdate,
      f.approvedby,
      f.apprsts,
      r.final,
      t.testcode,
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN sundata_prod.metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      INNER JOIN sundata_prod.folders f ON (cr.external_id = f.external_id)
      INNER JOIN sundata_prod.results r ON (1=1
        AND f.folderno = r.folderno)
      INNER JOIN sundata_prod.tests t ON (r.testcode = t.testcode)
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND f.external_id IS NOT NULL
--AND f.external_id = 'AZ00038846'      
--      AND f.dispsts IN ('Done', 'OOS')
      AND f.dept IN ('PHX-VIR')
--      AND f.apprdate BETWEEN to_date('21-JAN-2016', 'DD-MON-YYYY') and to_date('21-JAN-2016', 'DD-MON-YYYY')
      AND t.testcode IN ('1','2','6','41','444')
  --  AND cr.external_id IN ('AZ00022758')
    ORDER BY 
      f.dept ASC,
      f.external_id DESC,
      t.testcode ASC;
*/
/*---------------------------------------------------------------------------*/


/*------03 PHLIP Approvals---------------------------------------------------*/
  --Show most recent samples with Influenza panel (PHLIP program) that have
  --been approved.

    SELECT DISTINCT
      f.dept,
      f.testgroupname AS panel,
      f.external_id,
      (SUBSTR(cr.last_name, 1, 3) || '----, ' || SUBSTR(cr.first_name, 1, 3) || '----') AS patient_name,
      cr.patient_id,
      f.apprdate,
      f.approvedby,
      '~' AS eol
    FROM &Environment.folders f
      INNER JOIN &Environment.centralreceiving cr ON (cr.external_id = f.external_id)
      INNER JOIN &Environment.metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND f.testgroupname = 'Influenza'
      AND f.apprdate IS NOT NULL
      AND mr.field_varchar_80 = 'Diagnostic'
      AND f.apprdate > (sysdate - &LookbackDays)
    ORDER BY f.apprdate DESC

/*---------------------------------------------------------------------------*/
