
/*-----RightFaxTroubleshooting------------------------------------------------
  -----DESCRIPTION-----
    Use this ste of queries to investigate issues with RightFax.  Queries Include:
      1. GetFaxDetails - Get detail information on faxes for samples.
      2. DaysFaxReview - Review faxes for the day
      3. ClientFailedFaxes - Display list of failed faxes associated with client     
  ----- -----



  -----HISTORY-----
    2019.02.15 JTY: Created scripts.
  ----- -----

-----------------------------------------------------------------------------*/







/*-----01. GetFaxDetails-----------------------------------------------------*/
  --Get details on faxes for identified samples
  /*
    SELECT DISTINCT
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
      fq.tofax AS to_fax,
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      fq.statusname,
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,

      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
      AND cr.external_id IN (&ExternalIDList)
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      client_name ASC, 
      cr.external_id ASC;
  */
  /*---------------------------------------------------------------------------*/


/*-----02. DaysFaxReview-------------------------------------------------------*/
  --Get Review faxes for the specified day.
    SELECT DISTINCT
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      rdh.sent_date,
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
      fq.tofax AS to_fax,
      fq.statusname,
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,
      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      fq.postdate,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
      AND TO_DATE(rdh.sent_date, 'DD-MON-YY') =  TO_DATE('&CheckDate', 'DD-MON-YY') 
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      fq.postdate ASC;
  
  /*---------------------------------------------------------------------------*/
  
  /*-----03. ClientFailedFaxes-------------------------------------------------*/
  /*
  --Display list of failed faxes associated with client
    SELECT DISTINCT
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      rdh.sent_date,
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
      fq.tofax AS to_fax,
      fq.statusname,
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,
      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      fq.postdate,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
--      AND TO_DATE(rdh.sent_date, 'DD-MON-YY') =  TO_DATE('&CheckDate', 'DD-MON-YY') 
      AND rc.rasclientid = '&RasClientID'
      AND  fq.statusname <> 'fsDoneOK'
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      fq.postdate ASC;
  */
  /*---------------------------------------------------------------------------*/  
  
