/*-----Communications_Stats--------------------------------------------------*/
  ---DESCRIPTION---
    --These sets of queries provide information related to the Communications 
    --log
  --- ---
  
  ---SCRIPTS LIST---
    --1. ReceivingCommunications - How many samples and communications for
    --       each month of the year for clients that the Receiving dept has.
  --- ---
  
  ---HISTORY---
    --2018.05.18 Created Script
  --- ---
/*---------------------------------------------------------------------------*/




/*-----1. ReceivingCommunications--------------------------------------------*/
  --How many samples and communications for each month of the year for clients
  -- that the Receiving dept has.
  
    WITH
      --year_months--
        year_months AS (
          SELECT DISTINCT
            '&TheYear' AS the_year,
            (TO_CHAR(cr.date_received, 'MM') || ' - ' || TO_CHAR(cr.date_received, 'MON')) AS year_months,
            TO_CHAR(cr.date_received, 'MM') AS month_no,
            '~' AS eol
          FROM centralreceiving cr
          WHERE 1=1
            AND cr.date_received IS NOT NULL
          ORDER BY month_no ASC
        ),
      -- --
      --client_months--
        client_months AS (
          SELECT DISTINCT
            ym.the_year,
            ym.month_no,
            cr.rasclientid,
            ym.eol
          FROM year_months ym
            FULL OUTER JOIN centralreceiving cr ON (1=1)      
          WHERE 1=1
          ORDER BY
            cr.rasclientid ASC,
            ym.month_no
        ),
      -- --
      --client_samples--
        client_samples AS (
          SELECT
            cm.rasclientid,
            cm.month_no,
            COUNT(f.folderno) AS sample_count
          FROM client_months cm
            LEFT OUTER JOIN centralreceiving cr ON (1=1
              AND cm.rasclientid = cr.rasclientid
              AND cm.the_year = EXTRACT(YEAR FROM cr.date_received)
              AND cm.month_no = TO_CHAR(cr.date_received, 'MM')
            )
            LEFT OUTER JOIN folders f ON (cr.external_id = f.external_id)
          WHERE 1=1
          GROUP BY
            cm.rasclientid,
            cm.month_no
          ORDER BY
            cm.rasclientid ASC,
            cm.month_no ASC
        ),
      -- --  
      --client_communications--
        client_communications AS (
          SELECT
            cm.rasclientid,
            cm.month_no,
            COUNT(cl.folder_number) AS comm_count
          FROM client_months cm
            LEFT OUTER JOIN communication_log cl ON (1=1
              AND cm.rasclientid = cl.rasclientid
              AND cm.the_year = EXTRACT(YEAR FROM cl.logged_date)
              AND cm.month_no = TO_CHAR(cl.logged_date, 'MM')
            )
          WHERE 1=1
            AND cl.dept = '&Dept'--'Receiving'
          GROUP BY

            cm.rasclientid,
            cm.month_no
          ORDER BY
            cm.rasclientid ASC,
            cm.month_no ASC
        )
      -- --
      --all_together--
        SELECT 
          '&Dept' AS comm_department,
          ym.the_year,
          cs.rasclientid,
          ym.year_months AS month,
          cs.sample_count,
          cc.comm_count,
          '~' AS eol
        FROM client_samples cs
          INNER JOIN client_communications cc ON  (1=1
            AND cs.rasclientid = cc.rasclientid
            AND cs.month_no = cc.month_no)
          INNER JOIN year_months ym ON (cs.month_no = ym.month_no)
        WHERE 1=1
          AND (cs.sample_count > 0 OR cc.comm_count > 0)
  --AND cs.rasclientID IN ('ACC','MCHD-TB')
        ORDER BY
          ym.the_year ASC,
          cs.rasclientid ASC,
          cs.month_no ASC;



  -----Check Script for one client-----
/*  
    SELECT DISTINCT --1
      cl.rasclientid,
      cl.folder_number,
      cl.origrec
    FROM communication_log cl
    WHERE 1=1
      AND cl.rasclientid = '&ClientID'
      AND EXTRACT(YEAR FROM cl.logged_date) = '&Year'
      AND TO_CHAR(cl.logged_date, 'MM') = '&MonthNo';

    SELECT DISTINCT --0
      cr.rasclientid,
      f.folderno,
      cr.origrec
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
    WHERE 1=1
      AND cr.rasclientid = '&ClientID'
      AND EXTRACT(YEAR FROM cr.date_received) = '&Year'
      AND TO_CHAR(cr.date_received, 'MM') = '&MonthNo'
*/      
  ----- -----
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/


