

/*-----Report Deivery Statistics----------------------------------------*/
--Script to provide Report Delivery Statistics
/*----------------------------------------------------------------------*/


/*----------------------------------------------------------------------*/
/*-----01. By Delivery Method-------------------------------------------*/
  --Show number of reports by delivery method of Hard-Copy, Fax, Email
  WITH
    ---DataSource---
    DataSource AS (
      SELECT DISTINCT
        rdq.delivery_method,
        rdq.rasclientid,
        f.folderno,
        '~' AS eol 
      FROM rr_report_delivery_queue rdq
        INNER JOIN folders f ON (rdq.folderno = f.folderno)
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      WHERE 1=1
        AND mr.field_varchar_80 IN ('Diagnostic','LRN-B')
        AND TO_DATE(f.apprdate, 'DD-MON-YYYY') 
            BETWEEN TO_DATE((sysdate-&LookBackDays), 'DD-MON-YYYY') AND TO_DATE(sysdate, 'DD-MON-YYYY')
        AND rdq.delivery_method IN ('E-mail', 'Fax', 'Hard Copy')            
      ORDER BY
        rdq.delivery_method ASC,
        rdq.rasclientid ASC,
        f.folderno ASC
    ),
    --- ---
    ---Totals---
      Totals AS (
        SELECT DISTINCT
          ds1.delivery_method,
          COUNT(ds2.delivery_method) AS delivery_count          
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.delivery_method = ds2.delivery_method
            AND ds1.folderno = ds2.folderno)
        WHERE 1=1
        GROUP BY 
          ds1.delivery_method
        ORDER BY
          ds1.delivery_method ASC      
      )
    --- ---
  SELECT * FROM Totals;

/*----------------------------------------------------------------------*/



/*-----02. By Method and Type-------------------------------------------*/  
  --In addition to delivery method, break down by method and Type.  Where
  --type is the type of report (Amended, Corrected, Preliminary, Final).
/*  
  WITH
    ---DataSource---
    DataSource AS (
      SELECT DISTINCT
        rdq.delivery_method || ' | ' || rdq.reporttype AS method_and_type,
        rdq.rasclientid,
        f.folderno,
        '~' AS eol 
      FROM rr_report_delivery_queue rdq
        INNER JOIN folders f ON (rdq.folderno = f.folderno)
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      WHERE 1=1
        AND mr.field_varchar_80 IN ('Diagnostic','LRN-B')
        AND TO_DATE(f.apprdate, 'DD-MON-YYYY') 
            BETWEEN TO_DATE((sysdate-&LookBackDays), 'DD-MON-YYYY') AND TO_DATE(sysdate, 'DD-MON-YYYY')
        AND rdq.delivery_method IN ('E-mail', 'Fax', 'Hard Copy')            
      ORDER BY
        method_and_type ASC,
        rdq.rasclientid ASC,
        f.folderno ASC
    ),
    --- ---
    ---Totals---
      Totals AS (
        SELECT DISTINCT
          ds1.method_and_type,
          COUNT(ds2.method_and_type) AS delivery_count          
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.method_and_type = ds2.method_and_type
            AND ds1.folderno = ds2.folderno)
        WHERE 1=1
        GROUP BY 
          ds1.method_and_type
        ORDER BY
          ds1.method_and_type ASC      
      )
    --- ---
SELECT * FROM Totals
*/
/*----------------------------------------------------------------------*/



/*-----03. Report Types-------------------------------------------------*/  
  --Of the reports completed, what types of reports are these.
  
  WITH
    ---DataSource---
    DataSource AS (
      SELECT DISTINCT
        rdq.reporttype,
        rdq.rasclientid,
        f.folderno,
        '~' AS eol 
      FROM rr_report_delivery_queue rdq
        INNER JOIN folders f ON (rdq.folderno = f.folderno)
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
      WHERE 1=1
        AND mr.field_varchar_80 IN ('Diagnostic','LRN-B')
        AND TO_DATE(f.apprdate, 'DD-MON-YYYY') 
            BETWEEN TO_DATE((sysdate-&LookBackDays), 'DD-MON-YYYY') AND TO_DATE(sysdate, 'DD-MON-YYYY')
        AND rdq.delivery_method IN ('E-mail', 'Fax', 'Hard Copy')
      ORDER BY
        rdq.reporttype ASC,
        rdq.rasclientid ASC,
        f.folderno ASC
    ),
    --- ---
    ---Totals---
      Totals AS (
        SELECT DISTINCT
          ds1.reporttype,
          COUNT(ds2.reporttype) AS reporttype_count
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.reporttype = ds2.reporttype
            AND ds1.folderno = ds2.folderno)
        WHERE 1=1
        GROUP BY 
          ds1.reporttype
        ORDER BY
          ds1.reporttype ASC      
      )
    --- ---
SELECT * FROM Totals

/*----------------------------------------------------------------------*/
