

/*-----Samples Count---------------------------------------------------------*/
  
  -----Description-----
    --Scripts used to give you basic Samples processed information
    --01. Overall Sample Count
    --02. By Department
    --03. By Test
    --04. By Submitters
    --05. Weekly Received Sample Count
    
  ----- -----
    
  -----History-----
    --2017.08.14 JTY: Created Script
  ----- -----

/*---------------------------------------------------------------------------*/


--select distinct mr.tablereference  from sundata_prod.metadata_repository mr

/*-----01. Overall Sample Count---------------------------------------------*/
  ----- -----
    SELECT DISTINCT
      CR.External_Id,
      to_date(cr.date_received, 'DD-MON-YY') AS date_received,
      mr.field_varchar_80  AS activity_type,
      '~' AS eol
    FROM centralreceiving CR
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
      AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN
         to_date('&Date_Start', 'DD-MON-YY') AND to_date('&Date_End', 'DD-MON-YY');
  ----- -----

/*---------------------------------------------------------------------------*/



/*-----02. By Department----------------------------------------------------*/

  WITH
    ---DataSource---
    DataSource AS (
    SELECT DISTINCT
      f.dept,
      cr.external_id,
      to_date(cr.date_received, 'DD-MON-YY') AS date_received,
      mr.field_varchar_80 AS activity_type,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
      AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN
         to_date('&Date_Start', 'DD-MON-YY') AND to_date('&Date_End', 'DD-MON-YY')
    ORDER BY
      f.dept ASC,
      cr.external_id ASC
    ),
    --- ---
    ---Totals---
      Totals AS (
        SELECT DISTINCT
          ds1.dept,
          COUNT(ds2.dept) AS dept_count
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.dept = ds2.dept
            AND ds1.external_id = ds2.external_id)
        WHERE 1=1
        GROUP BY 
          ds1.dept
        ORDER BY
          ds1.dept ASC      
      )
    --- ---
  SELECT * FROM Totals;
  --- ---

/*---------------------------------------------------------------------------*/




/*-----03. By Test-----------------------------------------------------------*/

  WITH
    ---DataSource---
    DataSource AS (
    SELECT DISTINCT
      f.dept,
      cr.external_id,
      ot.testno,
      to_date(cr.date_received, 'DD-MON-YY') AS date_received,
      mr.field_varchar_80 AS activity_type,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
      AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN
         to_date('&Date_Start', 'DD-MON-YY') AND to_date('&Date_End', 'DD-MON-YY')
    ORDER BY
      f.dept ASC,
      cr.external_id ASC
    ),
    --- ---
    ---Totals---
      TestTotals AS (
        SELECT DISTINCT
          ds1.dept,
          ds1.testno,
          COUNT(ds2.testno) AS Test_count
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.dept = ds2.dept
            AND ds1.testno = ds2.testno
            AND ds1.external_id = ds2.external_id)
        WHERE 1=1
          AND ds1.dept = 'PHX-VIR'
        GROUP BY 
          ds1.dept,
          ds1.testno
        ORDER BY
          ds1.dept ASC,
          Test_count DESC
      )
    --- ---
  SELECT * FROM TestTotals;

  --- ---

/*---------------------------------------------------------------------------*/





/*-----04. By Submitters----------------------------------------------------*/

  WITH
    ---DataSource---
    DataSource AS (
    SELECT DISTINCT
      f.dept,
      cr.external_id,
      cr.rasclientid,
      to_date(cr.date_received, 'DD-MON-YY') AS date_received,
      mr.field_varchar_80 AS activity_type,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
      AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN
         to_date('&Date_Start', 'DD-MON-YY') AND to_date('&Date_End', 'DD-MON-YY')
    ORDER BY
      f.dept ASC,
      cr.external_id ASC
    ),
    --- ---
    ---TotalSamples---
      TotalSamples AS (
        SELECT DISTINCT
          ds1.rasclientid,
          COUNT(ds2.rasclientid) AS samples_count
        FROM DataSource ds1
          INNER JOIN DataSource ds2 ON (1=1
            AND ds1.dept = ds2.dept
            AND ds1.external_id = ds2.external_id)
        WHERE 1=1
        GROUP BY 
          ds1.rasclientid
        ORDER BY
          samples_count DESC      
      ),
    --- ---
    ---CleintDetails---
      CleintDetails AS (
        SELECT DISTINCT
          ts.samples_count,
          rc.compname,
          rc.rasclientid,
          rc.adress,
          rc.city,
          rc.state,
          rc.zip,
          rc.county,
          '~' AS eol
        FROM TotalSamples ts
          INNER JOIN rasclients rc ON (ts.rasclientid = rc.rasclientid)
        WHERE 1=1
          AND ts.samples_count > '&CutOff'        
        ORDER BY
          rc.compname ASC,
          rc.rasclientid ASC
      )
    --- ---
  SELECT * FROM CleintDetails;
  --- ---

/*---------------------------------------------------------------------------*/



/*-----05. Weekly Received Sample Count--------------------------------------*/
  --Get weekly sample count of samples received for a given year.
    SELECT DISTINCT
     TO_CHAR(cr.date_received, 'WW') AS week_no,
     MAX(cr.date_received) AS last_day,
     COUNT (DISTINCT cr.external_id) AS sample_count,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
      AND EXTRACT(YEAR FROM cr.date_received) = '&TheYear'
    GROUP BY
      TO_CHAR(cr.date_received, 'WW')
    ORDER BY
       week_no ASC;


  --Get weekly sample count of samples received for a given year by Deptment
    SELECT DISTINCT
     f.dept,
     TO_CHAR(cr.date_received, 'WW') AS week_no,
     MAX(cr.date_received) AS last_day,
     COUNT (DISTINCT cr.external_id) AS sample_count,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
      AND EXTRACT(YEAR FROM cr.date_received) = '&TheYear'
      AND f.dept = '&Department'
    GROUP BY
      f.dept,
      TO_CHAR(cr.date_received, 'WW')
    ORDER BY       
       f.dept ASC,
       week_no ASC;      
/*---------------------------------------------------------------------------*/



/*-----06. Monthly Received Sample Count per Department----------------------*/
  --Get Monthly sample count of samples received for a given year by Deptment
    SELECT DISTINCT
     TO_CHAR(cr.date_received, 'YYYY') AS the_year,
     TO_CHAR(cr.date_received, 'MM') AS month_no,
     f.dept,
     MAX(cr.date_received) AS last_day,
     COUNT (DISTINCT cr.external_id) AS sample_count,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
      AND EXTRACT(YEAR FROM cr.date_received) IN (&TheYears)
      --AND f.dept = '&Department'
    GROUP BY
      f.dept,
      TO_CHAR(cr.date_received, 'YYYY'),
      TO_CHAR(cr.date_received, 'MM')
    ORDER BY
       the_year ASC,
       month_no ASC,
       f.dept ASC;
/*---------------------------------------------------------------------------*/
