/*---------------------------------------------------------------------------*/
  ---Description---
    --Run this set of SQL statements to identify parts of MicroComponents that
    --are in one environment, but not in the other.
    
    --NOTE: DEV/TEST can be accessed from PROD by adding suffix "@exastart"
    --      to table name in JOIN.  IE: 
    --         SELECT * FROM sundata_sat.tests@exastart t 
    
    
      --&DBLink = @exastart for accessing DEV/TEST from PROD
      
      
   --Scripts included on this page are:
   --01. Identify Micro Components Mis-Match between envvironments      
  --- ---
  


/*---------------------------------------------------------------------------*/



/*---Grant Read permissions to TargetSchema----------------------------------*/
  -- You may need to be logged onto the SourceSchema to do this.
/*
    GRANT SELECT ON microcomponents TO &TargetSchema;
    GRANT SELECT ON microcompresponse TO &TargetSchema;
    GRANT SELECT ON micropanels TO &TargetSchema;
    GRANT SELECT ON micropanelcomp TO &TargetSchema;
    GRANT SELECT ON microconditions TO &TargetSchema;
    GRANT SELECT ON micropanelconditions TO &TargetSchema;
    GRANT SELECT ON microqccontrols TO &TargetSchema;
    GRANT SELECT ON materials TO &TargetSchema;  
    GRANT SELECT ON microcompreagents TO &TargetSchema;
    GRANT SELECT ON microcomploinc TO &TargetSchema;
    GRANT SELECT ON microcompequipments TO &TargetSchema;
*/  
/*---------------------------------------------------------------------------*/




  ---01. Identify Micro Components Mis-Match between envvironments---
      --&DBLink = @exastart for accessing DEV/TEST from PROD
    SELECT DISTINCT
      CASE 
        WHEN s_mc.compid IS NULL THEN '&TargetSchema'
        WHEN t_mc.compid IS NULL THEN '&SourceSchema'
      END AS ref_schema,
      COALESCE(s_mc.comptype, t_mc.comptype) AS comptype,
      s_mc.compid AS src_compid,
      t_mc.compid AS tar_compid,
--      COALESCE(s_mcr.compid, t_mcr.compid) AS compid,
      '~' AS eol
    FROM &SourceSchema.microcomponents&DBLink s_mc
      FULL JOIN &TargetSchema.microcomponents t_mc ON (1=1
        AND t_mc.compid = s_mc.compid)
    WHERE 1=1
      AND (t_mc.comptype = '&ComponentType' OR s_mc.comptype = '&ComponentType')
      AND (t_mc.compid IS NULL OR s_mc.compid IS NULL)
    ORDER BY
      ref_schema ASC,
      comptype ASC,
      src_compid ASC,
      tar_compid ASC;
  --- ---  

  ---Identify MC Response mis-match between envrionments---
    SELECT DISTINCT
      CASE 
        WHEN s_mcr.response IS NULL THEN '&TargetSchema'
        WHEN t_mcr.response IS NULL THEN '&SourceSchema'
      END AS ref_schema,
      COALESCE(s_mcr.comptype, t_mcr.comptype) AS comptype,
      COALESCE(s_mcr.compid, t_mcr.compid) AS compid,
      s_mcr.response AS src_response,
      t_mcr.response AS tar_response,
      '~' AS eol
    FROM &SourceSchema.microcompresponse&DBLink s_mcr
      FULL JOIN &TargetSchema.microcompresponse t_mcr ON (1=1
        AND t_mcr.compid = s_mcr.compid 
        AND s_mcr.response = t_mcr.response)
    WHERE 1=1
      AND (t_mcr.comptype = '&ComponentType' OR s_mcr.comptype = '&ComponentType'  )
      AND (t_mcr.response IS NULL OR s_mcr.response IS NULL)
    ORDER BY
      ref_schema ASC,
      comptype ASC,
      compid ASC,
      src_response ASC,
      tar_response ASC;
  --- ---

  ---Identify MC Reagents mis-match between envrionments---
    SELECT DISTINCT
      CASE 
        WHEN s_mcr.matcode IS NULL THEN '&TargetSchema'
        WHEN t_mcr.matcode IS NULL THEN '&SourceSchema'
      END AS ref_schema,
      COALESCE(s_mcr.comptype, t_mcr.comptype) AS comptype,
      COALESCE(s_mcr.compid, t_mcr.compid) AS compid,
      s_mcr.matcode AS src_matcode,
      t_mcr.matcode AS tar_matcode,
      '~' AS eol
    FROM &SourceSchema.microcompreagents&DBLink s_mcr
      FULL JOIN &TargetSchema.microcompreagents t_mcr ON (1=1
        AND t_mcr.compid = s_mcr.compid 
        AND s_mcr.matcode = t_mcr.matcode)
    WHERE 1=1
      AND (t_mcr.comptype = '&ComponentType' OR s_mcr.comptype = '&ComponentType'  )
      AND (t_mcr.matcode IS NULL OR s_mcr.matcode IS NULL)
    ORDER BY
      ref_schema ASC,
      comptype ASC,
      compid ASC,
      src_matcode ASC,
      tar_matcode ASC;
  --- ---


  ---Identify MC Quality Control mis-match between envrionments---
    SELECT DISTINCT
      CASE 
        WHEN s_mqc.matcode IS NULL THEN '&TargetSchema'
        WHEN t_mqc.matcode IS NULL THEN '&SourceSchema'
      END AS ref_schema,
      COALESCE(s_mqc.comptype, t_mqc.comptype) AS comptype,
      COALESCE(s_mqc.compid, t_mqc.compid) AS compid,
      s_mqc.qctype AS src_qctype,
      t_mqc.qctype AS tar_qctype,
      s_mqc.expectedresponse AS src_expectedresponse,
      t_mqc.expectedresponse AS tar_expectedresponse,
      s_mqc.matcode AS src_matcode,
      t_mqc.matcode AS tar_matcode,
      '~' AS eol
    FROM &SourceSchema.microqccontrols&DBLink s_mqc
      FULL JOIN &TargetSchema.microqccontrols t_mqc ON (1=1
        AND t_mqc.compid = s_mqc.compid 
        AND s_mqc.qctype = t_mqc.qctype
        )
    WHERE 1=1
      AND (t_mqc.comptype = '&ComponentType' OR s_mqc.comptype = '&ComponentType'  )
      AND (
           (COALESCE(t_mqc.qctype, '1') || COALESCE(t_mqc.expectedresponse, '1') || COALESCE(t_mqc.matcode, '1') = '111')
           OR
           (COALESCE(s_mqc.qctype, '1') || COALESCE(s_mqc.expectedresponse, '1') || COALESCE(s_mqc.matcode, '1') = '111')
       )
    ORDER BY
      ref_schema ASC,
      comptype ASC,
      compid ASC,
      src_qctype ASC,
      tar_qctype ASC,
      src_expectedresponse ASC,
      tar_expectedresponse ASC,
      src_matcode ASC,
      tar_matcode ASC;
  --- ---

