
/*------------------------------------------------------------*/
/*-----Migrate_CannedComments---------------------------------*/

  /*-----DESCRIPTION-----*/
    --These scripts in development to migrate Canned Comments
    --between envionments.  We will develop these on a as-needed
    --basis.
  /*----- -----*/  

  /*----------SL10 Environments----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod
  /*----------  ----------*/

  /*-----HISTORY-----*/  
    --2014.06.12 JTY: Created Script.
    --2017.09.08 JTY: Updated for broader use.
    --2017.09.11 JTY: Updated for ExaData (DEV & TEST) Access from PROD.
  /*----- -----*/      


  /*-----Tables of Interest-----*/   
    --SELECT cd.* FROM sunrise_data.canned_comments_defaults cd;
    --SELECT cc.* FROM sunrise_data.canned_comments cc;
    --SELECT ca.* FROM sunrise_data.calcs_actions ca;
  /*----- -----*/
  
/*------------------------------------------------------------*/





/*------------------------------------------------------------*/
/*-----Migrate Canned Comments--------------------*/
--JTY 2017.09.08 - This is an updated version that should work for any CC.
  /*-----Notes-----*/
    --Here we will be comparing the SourceSchema Canned_Comments
    --to the TargetSchema Canned_Comments table for the specified
    --TestName.  A number of limitations/requirments to keep in 
    --mind:
      --1. User performing this SQL must have Read-Access to 
      --   SourceSchema Canned_Comment table.
      --2. User performing this SQL must have Insert-Access to 
      --   TargetSchema Canned_Comment table.
      --3. IMPORTANT! This script will NOT transfer Calculations
      --   you will need to manually do that.
      --4. You should use the schema owner of the TargetSchema
      --   to execute this SQL. 
      --5. You will need to grant SELECT access to account performing 
      --   this query to the following SourceSchema tables:
           --[tests]
           --[canned_comments]
  /*----- -----*/  

  /*-----Grand Select to Target Schema Account-----*/  
/*
    GRANT SELECT ON canned_comments TO sundata_prod;
    GRANT SELECT ON tests TO sundata_prod;
    GRANT SELECT ON calcs_actions TO sundata_prod;
*/    
  /*----- -----*/    
  /*-----Review Source Environment C.C.-----*/
    SELECT DISTINCT
      t.testno,
      t.testcode, 
      cc.origsts,
      cc.testgroupname,
      cc.sp_code,
      cc.testcode,
      cc.analyte,
      cc.sorter,
      cc.canned_comment,
      cc.conditionfield,
      cc.qualifier,
      cc.conditionvalue,
      cc.rep,
      cc.attachment_scope,
      cc.printonreport,
      cc.calculation,
      cc.runflag,
      cc.status,
      cc.start_date,
      cc.expiration_date,
      cc.code,
      cc.stepcode,
      cc.compid,
      '~' AS eol
    FROM &SourceSchema.tests&Exadata t
      INNER JOIN &SourceSchema.Canned_Comments&Exadata cc ON (cc.testcode = t.testcode)
      LEFT OUTER JOIN &SourceSchema.calcs_actions&Exadata ca ON (cc.calculation = ca.calcname)
    WHERE 1=1
--AND cc.calculation IS NOT NULL    
      AND t.testno = '&TestName'
    ORDER BY
      cc.Testgroupname ASC,
      cc.Sp_Code ASC,
      cc.testcode ASC,
      cc.analyte ASC;  
  /*----- -----*/      
 

  /*-----Migrate C.C.-----*/
/*  
    MERGE INTO canned_comments t1
    USING (
      SELECT DISTINCT
        t.testno,
        t.testcode AS src_testcode,
        tar_t.testcode AS tar_testcode,
        cc.origsts,
        cc.testgroupname,
        cc.sp_code,
        cc.testcode,
        cc.analyte,
        cc.sorter,
        cc.canned_comment,
        cc.conditionfield,
        cc.qualifier,
        cc.conditionvalue,
        cc.rep,
        cc.attachment_scope,
        cc.printonreport,
--        cc.calculation,
        cc.runflag,
        cc.status,
        cc.start_date,
        cc.expiration_date,
        cc.code,
        cc.stepcode,
        cc.compid,
        '~' AS EOL
      FROM &SourceSchema.tests&Exadata t
        INNER JOIN &SourceSchema.canned_comments&Exadata cc ON (t.testcode = cc.testcode)
        INNER JOIN &TargetSchema.tests tar_t ON (t.testno = tar_t.testno)
      WHERE 1=1
        AND t.testno = '&TestName'    
    ) t2
    ON (1=1
      AND t1.testcode = t2.tar_testcode
      AND t1.analyte = t2.analyte
      AND t1.canned_comment = t2.canned_comment
      AND t1.conditionfield = t2.conditionfield
      AND t1.qualifier = t2.qualifier
      AND t1.conditionvalue = t2.conditionvalue
      AND t1.rep = t2.rep
      AND t1.attachment_scope = t2.attachment_scope
      AND t1.code = t2.code
      AND t1.stepcode = t2.stepcode
      AND t1.compid = t2.compid
      )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.sp_code,
        t1.testgroupname,
        t1.testcode,
        t1.analyte,
        t1.sorter,
        t1.origsts,
        t1.canned_comment,
        t1.conditionfield,
        t1.qualifier,
        t1.conditionvalue,
        t1.rep,
        t1.attachment_scope,
        t1.printonreport,
        --cc.calculation,
        t1.runflag,
        t1.status,
        t1.start_date,
        t1.expiration_date,
        t1.code,
        t1.stepcode,
        t1.compid      
      )
      VALUES (
        t2.sp_code,
        t2.testgroupname,
        t2.tar_testcode,
        t2.analyte,
        t2.sorter,
        t2.origsts,
        t2.canned_comment,
        t2.conditionfield,
        t2.qualifier,
        t2.conditionvalue,
        t2.rep,
        t2.attachment_scope,
        t2.printonreport,
        --cc.calculation,
        t2.runflag,
        t2.status,
        TO_DATE(sysdate,'DD-MON-YYYY'),
        t2.expiration_date,
        t2.code,
        t2.stepcode,
        t2.compid      
      )
*/      
  /*----- -----*/      
/*------------------------------------------------------------*/









/*-----Migrate Test Level Canned Comments--------------------*/
  /*-----Notes-----*/
    --Here we will be comparing the SourceSchema Canned_Comments
    --to the TargetSchema Canned_Comments table for the specified
    --TestName.  A number of limitations/requirments to keep in 
    --mind:
      --1. User performing this SQL must have Read-Access to 
      --   SourceSchema Canned_Comment table.
      --2. User performing this SQL must have Insert-Access to 
      --   TargetSchema Canned_Comment table.
      --3. IMPORTANT! This script will NOT transfer Calculations
      --   you will need to manually do that.
      --4. You should use the schema owner of the TargetSchema
      --   to execute this SQL. 
      --5. You will need to grant SELECT access to account performing 
      --   this query to the following SourceSchema tables:
           --[tests]
           --[canned_comments]
  /*----- -----*/  

  /*-----Grand Select to Target Schema Account-----*/  
/*
    GRANT SELECT ON canned_comments TO sundata_prod;
    GRANT SELECT ON tests TO sundata_prod;
    GRANT SELECT ON calcs_actions TO sundata_prod;
*/    
  /*----- -----*/    
  /*-----Review Source Environment C.C.-----*/
/*  
    SELECT DISTINCT
      t.testno,
      t.testcode,      
      ca.calcname,
      cc.*,
      '~' AS eol
    FROM &Environment.tests t
      INNER JOIN &Environment.Canned_Comments cc ON (cc.testcode = t.testcode)
      LEFT OUTER JOIN &Environment.calcs_actions ca ON (cc.calculation = ca.calcname)
    WHERE 1=1
--AND cc.calculation IS NOT NULL    
      AND t.testno = '&TestName'
    ORDER BY
      cc.Testgroupname ASC,
      cc.Sp_Code ASC,
      cc.testcode ASC,
      cc.analyte ASC;  
*/
  /*----- -----*/      
  

  /*-----Migrate C.C.-----*/
/*  
    MERGE INTO canned_comments t1
    USING (
      SELECT DISTINCT
        cc.sp_code,
        cc.testgroupname,
        t.testno,
        t.testcode AS src_testcode,
        tar_t.testcode AS tar_testcode,
        cc.analyte,
        cc.sorter,
        cc.origsts,
        cc.canned_comment,
        --cc.testcode,
        cc.conditionfield,
        cc.qualifier,
        cc.conditionvalue,
        cc.rep,
        cc.attachment_scope,
        cc.printonreport,
        --cc.calculation,
        cc.runflag,
        cc.status,
        cc.start_date,
        cc.expiration_date,
        cc.code,
        cc.stepcode,
        cc.compid
      FROM &SourceSchema.tests t
        INNER JOIN &SourceSchema.canned_comments&Exadata cc ON (t.testcode = cc.testcode)
        INNER JOIN &TargetSchema.tests tar_t ON (t.testno = tar_t.testno)
      WHERE 1=1
        AND t.testno = '&TestName'    
    ) t2
    ON (1=1
      AND t1.testcode = t2.tar_testcode
      AND t1.analyte = t2.analyte
      AND t1.canned_comment = t2.canned_comment
      AND t1.conditionfield = t2.conditionfield
      AND t1.qualifier = t2.qualifier
      AND t1.conditionvalue = t2.conditionvalue
      AND t1.rep = t2.rep
      AND t1.attachment_scope = t2.attachment_scope
      AND t1.code = t2.code
      AND t1.stepcode = t2.stepcode
      AND t1.compid = t2.compid
      )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.sp_code,
        t1.testgroupname,
        t1.testcode,
        t1.analyte,
        t1.sorter,
        t1.origsts,
        t1.canned_comment,
        t1.conditionfield,
        t1.qualifier,
        t1.conditionvalue,
        t1.rep,
        t1.attachment_scope,
        t1.printonreport,
        --cc.calculation,
        t1.runflag,
        t1.status,
        t1.start_date,
        t1.expiration_date,
        t1.code,
        t1.stepcode,
        t1.compid      
      )
      VALUES (
        t2.sp_code,
        t2.testgroupname,
        t2.tar_testcode,
        t2.analyte,
        t2.sorter,
        t2.origsts,
        t2.canned_comment,
        t2.conditionfield,
        t2.qualifier,
        t2.conditionvalue,
        t2.rep,
        t2.attachment_scope,
        t2.printonreport,
        --cc.calculation,
        t2.runflag,
        t2.status,
        TO_DATE(sysdate,'DD-MON-YYYY'),
        t2.expiration_date,
        t2.code,
        t2.stepcode,
        t2.compid      
      )
*/      
  /*----- -----*/      
    
    
/*------------------------------------------------------------*/





