

/*=================================================================*/
/*=====Migrate_HL7Configuration====================================*/
  /*----------Description----------*/
    --This collection of queries are for migration of HL7 related
    --configuration settings for a single test between environments.
    --These scripts are devided by the Application being updated.
    --Currently the following Applications are included:
      --1. HL7 Clients Manager
      --2. LOINC Codes
      --3. SNOMED Codes
      --4. Test Manager: Test LOINC code
      --5. Test Manager: Possible Results
      --6. Test Manager: Test Plan      
      --7. Test Manager: Analyte LOINC Codes
      --8. Sample Conclusions

      
    --Assumptions:
      --1. This is a Default test.
      --2. Test has already been configured in the target environment
      --   and matches exactly with the source environment.
      --3. Panel(s) containing target test have already been setup
      --   in target environment and is identical to source environment
      --   panel(s).
      
--2018.05.15--
  --Updating script to handl the different domains the databases are in now.  We
  --will need to use links.  Currenly Shandy created a link (@EXASTART.HS.AZDHS.GOV)
  --for us to utilize.  Here we are assuming we are logged into the PROD environment
  --and going to update the TEST and DEV envrionments.
--      
  /*----------  ----------*/

  /*----------SL10.7 Environments----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod
  /*----------  ----------*/
  
  /*----------History----------*/
    --2018.05.15 JTY: Begin update for Link
    --2014.07.08 JTY: Created file.

  /*----------  ----------*/  
  
/*=================================================================*/
--STARP.HS.AZDHS.GOV


  /*----------MIGRATING FROM TEST TO PROD----------*/
    --1. log into my account in TEST (YODER@START.WORLD)
    --2. Source Schema: sundata_sat
    --3. Target Schema: sundata_prod
    --4. Link: @STARP.HS.AZDHS.GOV
  /*----------  ----------*/
  /*----------MIGRATING FROM PROD TO TEST----------*/
    --1. log into my account in PROD (sundata_prod@STARP.WORLD)  -not positive on this one.
    --2. Source Schema: sundata_prod
    --3. Target Schema: sundata_sat
    --4. Link: @EXASTART.HS.AZDHS.GOV
  /*----------  ----------*/




/*-----1. HL7 Clients Manager--------------------------------------*/
  --Migrate new test analytes to the Reportable Analytes tab.  
    --Application: HL7 Clients Manager
    --Change Location:[Reportable Analytes] tab, [Reporatable Analytes] grid
    --Primary Table: [HL7_Analytes]
  /*----------1.1 Review Source data----------*/
/*  
    SELECT DISTINCT
      t1.testcode,
      t1.testno,
      hla.analyte,
      hla.logic,
      hla.rasclientid,
      hla.reportable,
      hla.result_fld,
      hla.testcode,
      hla.value_type,
      hla.upload_flag,
      hla.origsts,
      hla.lrn_param,
      '~' AS eol
    FROM &SourceSchema.Hl7_Analytes hla
      INNER JOIN &SourceSchema.Tests t1 ON (hla.testcode = t1.testcode)
    WHERE 1=1
      AND t1.testno IN (&TestList)  --'Real-Time PCR for NCV-2012'
    ORDER BY
      t1.testno ASC,
      hla.analyte ASC;
*/      
  /*----------  ----------*/

  /*----------1.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.hl7_analytes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
*/    
  /*----------  ----------*/  


  
  
  /*----------1.3  Add new enteries if they don't exits----------*/

    MERGE INTO &TargetSchema.hl7_analytes&Link tar
    USING (
      SELECT DISTINCT
        t_t.testcode AS t_testcode,
        t_t.testno,
        hla.analyte,
        hla.logic,
        hla.rasclientid,
        hla.reportable,
        hla.result_fld,
        --hla.testcode,
        hla.value_type,
        hla.upload_flag,
        hla.origsts,
        hla.lrn_param,
        '~' AS eol
      FROM &SourceSchema.Hl7_Analytes hla
        INNER JOIN &SourceSchema.Tests t1 ON (hla.testcode = t1.testcode)
        INNER JOIN &TargetSchema.tests&Link t_t ON (t1.testno = t_t.testno)
      WHERE 1=1
        AND t1.testno IN (&TestList)  --'Real-Time PCR for NCV-2012'
      ORDER BY
        t_t.testno ASC,
        hla.analyte ASC
    ) src
    ON (1=1
      AND tar.testcode = src.t_testcode
      AND tar.analyte = src.analyte)
    WHEN NOT MATCHED THEN
      INSERT (
        tar.testcode,
        tar.analyte,
        tar.logic,
        tar.rasclientid,
        tar.reportable,
        tar.result_fld,
        tar.value_type,
        tar.upload_flag,
        tar.origsts,
        tar.lrn_param
      )
      VALUES (
        src.t_testcode,
        src.analyte,
        src.logic,
        src.rasclientid,
        src.reportable,
        src.result_fld,
        src.value_type,
        src.upload_flag,
        src.origsts,
        src.lrn_param
      );
  /*----------  ----------*/
  
  /*----------1.4  Compare Environments----------*/
    --This will any differences between environments
    --for the identified Test Name.  Ideally we should
    --get no records back from this query
/*
    WITH 
      ---TheSource---
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,        
          t.testno,
          a.analyte,
          a.logic,
          a.rasclientid,
          a.reportable,
          a.result_fld,
          a.value_type,
          a.upload_flag,
          a.origsts,
          a.lrn_param,
          (
              t.testno || '|' ||
              a.analyte || '|' ||
              a.logic || '|' ||
              a.rasclientid || '|' ||
              a.reportable || '|' ||
              a.result_fld || '|' ||
              a.value_type || '|' ||
              a.upload_flag || '|' ||
              a.origsts || '|' ||
              a.lrn_param           
          ) AS Key
        FROM  &SourceSchema.Hl7_Analytes a
          INNER JOIN &SourceSchema.tests t ON (a.testcode = t.testcode)
        WHERE 1=1
          AND t.testno IN (&TestList)
      ),
     ---
     ---TheTarget---
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
         t.testno,
         a.analyte,
         a.logic,
         a.rasclientid,
         a.reportable,
         a.result_fld,
         a.value_type,
         a.upload_flag,
         a.origsts,
         a.lrn_param,
         (
             t.testno || '|' ||
             a.analyte || '|' ||
             a.logic || '|' ||
             a.rasclientid || '|' ||
             a.reportable || '|' ||
             a.result_fld || '|' ||
             a.value_type || '|' ||
             a.upload_flag || '|' ||
             a.origsts || '|' ||
             a.lrn_param           
         ) AS Key
       FROM &TargetSchema.Hl7_Analytes&Link a
         INNER JOIN &TargetSchema.tests&Link t ON (a.testcode = t.testcode)
       WHERE 1=1
         AND t.testno IN (&TestList)
      )      
     ---
     ---TheDifference---
       SELECT DISTINCT
         COALESCE(ts.env,tt.env) AS env,
         COALESCE(ts.testno,tt.testno) AS testno,
         COALESCE(ts.analyte,tt.analyte) AS analyte,
         COALESCE(ts.logic,tt.logic) AS logic,
         COALESCE(ts.rasclientid,tt.rasclientid) AS rasclientid,
         COALESCE(ts.reportable,tt.reportable) AS reportable,
         COALESCE(ts.result_fld,tt.result_fld) AS result_fld,
         COALESCE(ts.value_type,tt.value_type) AS value_type,
         COALESCE(ts.upload_flag,tt.upload_flag) AS upload_flag,
         COALESCE(ts.origsts,tt.origsts) AS origsts,
         COALESCE(ts.lrn_param,tt.lrn_param) AS lrn_param,         
         '~' AS eol
       FROM TheSource ts
         FULL OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND (tt.key IS NULL OR ts.key IS NULL)
       ORDER BY 
         env ASC,
         rasclientid ASC,
         testno ASC,
         analyte ASC;
     ---                
  /*----------  ----------*/    
  
  
  
/*-----------------------------------------------------------------*/





/*-----2. LOINC Codes----------------------------------------------*/
  --Add new LOINC code for test
    --Application: LOINC Codes application
    --Change Location:[LOINC Codes] grid
    --Primary Table(s): [TestLoincCodes],[LoincCodes],[LoincVersion], [LoincClasses]
    
  /*----------2.1 Review Source data----------*/
/*  
    SELECT DISTINCT
      t.testno,
      lco.classcode,
      lco.codestatus,
      lco.loinccomponenet,
      lco.loincmethod,
      lco.loincnumber,
      lco.loincproperty,
      lco.loincscale,
      lco.loincshortname,
      lco.loincsystems,
      lco.loinctime,
      lco.loinctime,
      lco.mapto,
      lco.origsts,
      lco.version,
      '~' eol
    FROM &SourceSchema.Tests t
      INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
      INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
        AND tlc.loinccomponenet = lco.loinccomponenet
        AND tlc.loincnumber = lco.loincnumber
        AND tlc.version = lco.version)      
      INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
      INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
        AND lco.classcode = lcl.classcode
        AND lco.version = lcl.version)
    WHERE 1=1
      AND t.testno IN (&TestList);
*/      
  /*----------  ----------*/

  /*----------2.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.TestLoincCodes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.LoincCodes TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincVersion TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincClasses TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------2.3  Add new enteries if they don't exits----------*/
    MERGE INTO &TargetSchema.LoincCodes&Link tar
    USING (
      SELECT DISTINCT
        t.testno,
        t_lv.version,
        t_lcl.classcode,
        lco.loinccomponenet,
        lco.loincnumber,
        lco.origsts,      
        lco.loincshortname,
        lco.codestatus,
        lco.loincmethod,
        lco.loincproperty,
        lco.loincscale,
        lco.loincsystems,
        lco.loinctime,
        lco.mapto,
        '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
        INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
          AND tlc.loinccomponenet = lco.loinccomponenet
          AND tlc.loincnumber = lco.loincnumber
          AND tlc.version = lco.version)      
        INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
        INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
          AND lco.classcode = lcl.classcode
          AND lco.version = lcl.version)
        --Join to Target to get target version & classcode
        INNER JOIN &TargetSchema.LoincClasses&Link t_lcl ON ( 1 = 1
          AND lcl.classcode = t_lcl.classcode
          AND lcl.classname = t_lcl.classname)
        INNER JOIN &TargetSchema.LoincVersion&Link t_lv ON (t_lcl.version = t_lv.version)
        --        
      WHERE 1=1
        AND t.testno IN (&TestList)
        AND t_lv.status = 'Active'    
    ) src
    ON (1=1
      AND src.version = tar.version
      AND src.classcode = tar.classcode
      AND src.loinccomponenet = tar.loinccomponenet
      AND src.loincnumber = tar.loincnumber
      )
    WHEN NOT MATCHED THEN
      INSERT (
        tar.version,
        tar.classcode,
        tar.loinccomponenet,
        tar.loincnumber,
        tar.origsts,      
        tar.loincshortname,
        tar.codestatus,
        tar.loincmethod,
        tar.loincproperty,
        tar.loincscale,
        tar.loincsystems,
        tar.loinctime,
        tar.mapto
      )
      VALUES (
        src.version,
        src.classcode,
        src.loinccomponenet,
        src.loincnumber,
        src.origsts,      
        src.loincshortname,
        src.codestatus,
        src.loincmethod,
        src.loincproperty,
        src.loincscale,
        src.loincsystems,
        src.loinctime,
        src.mapto
      );
  /*----------  ----------*/
  /*----------2.4  Check against Target Environment----------*/
    --This will verify the target environment has been updated.
    --If it has, no records should be returned.
/*
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          --t.testno,
          lco.classcode,
          lco.codestatus,
          lco.loinccomponenet,
          lco.loincmethod,
          lco.loincnumber,
          lco.loincproperty,
          lco.loincscale,
          lco.loincshortname,
          lco.loincsystems,
          lco.loinctime,
          lco.mapto,
          lco.origsts,
          lco.version,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
              lco.classcode || '|' ||
              lco.codestatus || '|' ||
              lco.loinccomponenet || '|' ||
              lco.loincmethod || '|' ||
              lco.loincnumber || '|' ||
              lco.loincproperty || '|' ||
              lco.loincscale || '|' ||
              lco.loincshortname || '|' ||
              lco.loincsystems || '|' ||
              lco.loinctime || '|' ||
              lco.loinctime || '|' ||
              lco.mapto || '|' ||
              lco.origsts
          ) AS Key
          --
        FROM &SourceSchema.Tests t
          INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
          INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
            AND tlc.loinccomponenet = lco.loinccomponenet
            AND tlc.loincnumber = lco.loincnumber
            AND tlc.version = lco.version)      
          INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
          INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
            AND lco.classcode = lcl.classcode
            AND lco.version = lcl.version)
        WHERE 1=1
          AND t.testno IN (&TestList)
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          --t.testno,
          lco.classcode,
          lco.codestatus,
          lco.loinccomponenet,
          lco.loincmethod,
          lco.loincnumber,
          lco.loincproperty,
          lco.loincscale,
          lco.loincshortname,
          lco.loincsystems,
          lco.loinctime,
          lco.mapto,
          lco.origsts,
          lco.version,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
              lco.classcode || '|' ||
              lco.codestatus || '|' ||
              lco.loinccomponenet || '|' ||
              lco.loincmethod || '|' ||
              lco.loincnumber || '|' ||
              lco.loincproperty || '|' ||
              lco.loincscale || '|' ||
              lco.loincshortname || '|' ||
              lco.loincsystems || '|' ||
              lco.loinctime || '|' ||
              lco.loinctime || '|' ||
              lco.mapto || '|' ||
              lco.origsts
          ) AS Key
          --
        FROM &TargetSchema.LoincCodes&Link lco
        WHERE 1=1
          --AND t.testno IN (&TestList)
      )      
     ---
     ---TheDifference---
       SELECT DISTINCT
         ts.*
       FROM TheSource ts
         LEFT OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND tt.key IS NULL
     ---     
*/                   
  /*----------  ----------*/  




/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----3. SNOMED CODES---------------------------------------------*/
  --Add new SNOMED CODES if any are missing related to Possible Results
  --NOTE:
  --We seem to have issues where there are multipple enteries for a given
  --SNOMED code.  We will use the review script to identify these.
  --These need to be cleaned-up before promotion to the new envirnment.

    --Application: SNOMED Codes
    --Change Location:[SNOMED Library] section
    --Primary Table(s): [SnomedCodes]

  /*----------3.1 Review Source data----------*/
/*  
    SELECT DISTINCT
      t.testno,
      t.testcode,
      pr.analyte,
      pr.result,
      sc.snomedcode,
      sc.snomedelement,
      sc.snomedconceptid,
      sc.loinccondname,
      sc.origsts,
      sc.snomeddescriptionid,
      sc.snomed_group,      
      '~' eol
    FROM &SourceSchema.Tests t
      INNER JOIN &SourceSchema.analytes a ON (t.testcode = a.testcode)
      INNER JOIN &SourceSchema.possibleresults pr ON (1=1
        AND a.testcode = pr.testcode
        AND a.analyte = pr.analyte)
      INNER JOIN &SourceSchema.SnomedCodes sc ON (1=1
        AND pr.snomedcode = sc.snomedcode)
    WHERE 1=1
      AND t.testno IN (&TestList)
      AND sc.snomedconceptid IS NOT NULL
      AND sc.snomeddescriptionid IS NOT NULL
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      sc.snomedcode ASC;
*/
  /*----------  ----------*/

  /*----------3.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.analytes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.possibleresults TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.SnomedCodes TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------3.3  Add new enteries if they don't exits----------*/
    MERGE INTO &TargetSchema.SnomedCodes&Link tar
    USING (
      SELECT DISTINCT
        t.testno,
        t.testcode,
        pr.analyte,
        pr.result,
        --SNOMED table enteries
        sc.snomedcode,
        sc.snomedelement,
        sc.snomedconceptid,
        sc.loinccondname,
        sc.origsts,
        sc.snomeddescriptionid,
        sc.snomed_group,      
        '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.analytes a ON (t.testcode = a.testcode)
        INNER JOIN &SourceSchema.possibleresults pr ON (1=1
          AND a.testcode = pr.testcode
          AND a.analyte = pr.analyte)
        INNER JOIN &SourceSchema.SnomedCodes sc ON (1=1
          AND pr.snomedcode = sc.snomedcode)
      WHERE 1=1
        AND t.testno IN (&TestList)
        AND sc.snomedconceptid IS NOT NULL
        AND sc.snomeddescriptionid IS NOT NULL
      ORDER BY
        t.testno ASC,
        pr.analyte ASC,
        sc.snomedcode ASC     
    ) src
    ON (1=1
      AND tar.snomedcode = src.snomedcode
      AND tar.snomedelement = src.snomedelement
      AND tar.snomedconceptid = src.snomedconceptid
      AND tar.loinccondname = src.loinccondname
      AND tar.origsts = src.origsts
      AND tar.snomeddescriptionid = src.snomeddescriptionid
      AND tar.snomed_group = src.snomed_group
      )
    WHEN NOT MATCHED THEN
      INSERT (
        tar.snomedcode,
        tar.snomedelement,
        tar.snomedconceptid,
        tar.loinccondname,
        tar.origsts,
        tar.snomeddescriptionid,
        tar.snomed_group
      )
      VALUES (
        src.snomedcode,
        src.snomedelement,
        src.snomedconceptid,
        src.loinccondname,
        src.origsts,
        src.snomeddescriptionid,
        src.snomed_group
      );      
  /*----------  ----------*/
  
  
  /*----------3.4  Check against Target Environment----------*/
    --This will verify the target environment has been updated.
    --If it has, no records should be returned.
/*    
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          sc.snomedcode,
          sc.snomedelement,
          sc.snomedconceptid,
          sc.loinccondname,
          sc.origsts,
          sc.snomeddescriptionid,
          sc.snomed_group,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
            sc.snomedcode || '|' ||
            sc.snomedelement || '|' ||
            sc.snomedconceptid || '|' ||
            sc.loinccondname || '|' ||
            sc.origsts || '|' ||
            sc.snomeddescriptionid || '|' ||
            sc.snomed_group          
          ) AS Key
          --
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.analytes a ON (t.testcode = a.testcode)
        INNER JOIN &SourceSchema.possibleresults pr ON (1=1
          AND a.testcode = pr.testcode
          AND a.analyte = pr.analyte)
        INNER JOIN &SourceSchema.SnomedCodes sc ON (1=1
          AND pr.snomedcode = sc.snomedcode)
      WHERE 1=1
        AND t.testno IN (&TestList)
        AND sc.snomedconceptid IS NOT NULL
        AND sc.snomeddescriptionid IS NOT NULL
      ORDER BY
        sc.snomedcode ASC,
        sc.snomedelement ASC,
        sc.snomedconceptid ASC   
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          sc.snomedcode,
          sc.snomedelement,
          sc.snomedconceptid,
          sc.loinccondname,
          sc.origsts,
          sc.snomeddescriptionid,
          sc.snomed_group,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
            sc.snomedcode || '|' ||
            sc.snomedelement || '|' ||
            sc.snomedconceptid || '|' ||
            sc.loinccondname || '|' ||
            sc.origsts || '|' ||
            sc.snomeddescriptionid || '|' ||
            sc.snomed_group          
          ) AS Key
          --
        FROM &TargetSchema.SnomedCodes&Link sc
        WHERE 1=1
      )      
     ---
     ---TheDifference---
       SELECT DISTINCT
         ts.*
       FROM TheSource ts
         LEFT OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND tt.key IS NULL
      ORDER BY
        ts.snomedcode ASC,
        ts.snomedelement ASC,
        ts.snomedconceptid ASC            
     ---     
*/                   
  /*----------  ----------*/  
  

/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
--*****2018.05.17 JTY: Not sure if this one is doing what we want it to.  Need to revisit after checkin out the rest of the scripts.
/*-----4. Test Manager: Test LOINC code-----------------------------*/
  --Update LOINC information in the Test Manager application for the
  --test as it appears in the test datagrid.

    --Application: Test Manager
    --Change Location:[Tests] grid
    --Primary Table(s): [Tests]
  
  
  /*----------4.1 Review Source data----------*/
/*  
    SELECT DISTINCT
      t.testno,
      t.testcode,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name,      
      '~' eol
    FROM &SourceSchema.Tests t
    WHERE 1=1
      AND t.testno IN (&TestList)
    ORDER BY
      t.testno ASC;
*/
  /*----------  ----------*/

  /*----------4.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------4.3  Update test values if they don't match----------*/
    MERGE INTO &TargetSchema.Tests&Link tar
    USING (
      SELECT DISTINCT
        t_t.testno,
        t_t.testcode,
        t.phvs_code_system_code,
        t.phvs_code_system_oid,
        t.phvs_concept_code,
        t.phvs_concept_name,      
        '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &TargetSchema.Tests&Link t_t ON (t.testno = t_t.testno)
      WHERE 1=1
        AND t.testno IN (&TestList)
    ) src
    ON (1=1
      AND tar.testcode = src.testcode
      AND tar.testno = src.testno
      )
    WHEN MATCHED THEN
      UPDATE SET
        tar.phvs_code_system_code = src.phvs_code_system_code,
        tar.phvs_code_system_oid = src.phvs_code_system_oid,
        tar.phvs_concept_code = src.phvs_concept_code,
        tar.phvs_concept_name = src.phvs_concept_name;
  /*----------  ----------*/


  /*----------4.4 Verify Environments Match----------*/
  --Verify tests values match across environments.
  --Ideally, no records should be returned.
/*  
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          t.testno,
          t.phvs_code_system_code,
          t.phvs_code_system_oid,
          t.phvs_concept_code,
          t.phvs_concept_name,  
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
              t.testno || '|' ||
              t.phvs_code_system_code || '|' ||
              t.phvs_code_system_oid || '|' ||
              t.phvs_concept_code || '|' ||
              t.phvs_concept_name                       
          ) AS Key
          --
        FROM  &SourceSchema.Tests t
          --Any required joins--
        WHERE 1=1
          AND t.testno IN (&TestList)
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          t.testno,
          t.phvs_code_system_code,
          t.phvs_code_system_oid,
          t.phvs_concept_code,
          t.phvs_concept_name,  
          --
          --This join key needs to be built exactly the
          --sam as TheSource join key--
          (
              t.testno || '|' ||
              t.phvs_code_system_code || '|' ||
              t.phvs_code_system_oid || '|' ||
              t.phvs_concept_code || '|' ||
              t.phvs_concept_name                       
          ) AS Key
          --
        FROM  &SourceSchema.Tests t
        WHERE 1=1
          AND t.testno IN (&TestList)
      )      
     ---
     ---TheDifference---
       --Identify rows in Source or Target that don't match.
       SELECT DISTINCT
         COALESCE(ts.env,tt.env) AS env,
         COALESCE(ts.testno,tt.testno) AS testno,
         COALESCE(ts.phvs_code_system_code,tt.phvs_code_system_code) AS phvs_code_system_code,
         COALESCE(ts.phvs_code_system_oid,tt.phvs_code_system_oid) AS phvs_code_system_oid,
         COALESCE(ts.phvs_concept_code,tt.phvs_concept_code) AS phvs_concept_code,
         COALESCE(ts.phvs_concept_name,tt.phvs_concept_name) AS phvs_concept_name,                           
         '~' AS eol
       FROM TheSource ts
         FULL OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND (tt.key IS NULL OR ts.key IS NULL)
       ORDER BY 
         env ASC,
         testno ASC,
         phvs_code_system_code ASC;
     ---
*/     
  /*----------  ----------*/


/*-----------------------------------------------------------------*/





/*-----5. Test Manager: Possible Results--------------------------*/
  --Update Possible results to match source possible results.  Add
  --Possible results if not in target.

    --Application: Test Manager
    --Change Location:[Analytes] tab | [Possible Results] link
    --Primary Table(s): [PossibleResults]
      
  /*----------5.1 Review Source data----------*/
/*
    SELECT DISTINCT
      t.testno,
      t.testcode,
      pr.analyte,
      pr.sorter,
      pr.result,
      pr.result_status,
      pr.conclusion_report,
      pr.snomedcode,    
      pr.code_system_oid,
      pr.origsts,
      pr.calcname,
      pr.localnumber,
      pr.loincnumber,
      pr.snomedconceptid,
      pr.snomeddescriptionid,
      pr.cdc_reportable,
      pr.elr_reportable,
      '~' eol
    FROM &SourceSchema.Tests t
      INNER JOIN &SourceSchema.PossibleResults pr ON (t.testcode = pr.testcode)
    WHERE 1=1
      AND t.testno IN (&TestList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.sorter ASC,
      pr.result;
*/
  /*----------  ----------*/

  /*----------5.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.PossibleResults TO &TargetAccount;
*/    
  /*----------  ----------*/  

  /*----------5.3  Add new enteries if they don't exits----------*/
    MERGE INTO &TargetSchema.PossibleResults&Link tar
    USING (
      SELECT DISTINCT
        t_t.testno,
        t_t.testcode,
        pr.analyte,
        pr.sorter,
        pr.result,
        pr.result_status,
        pr.conclusion_report,
        pr.snomedcode,    
        pr.code_system_oid,
        pr.origsts,
        pr.calcname,
        pr.localnumber,
        pr.loincnumber,
        pr.snomedconceptid,
        pr.snomeddescriptionid,
        pr.cdc_reportable,
        pr.elr_reportable,
        '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.PossibleResults pr ON (t.testcode = pr.testcode)
        ---Link to Target Table---
        INNER JOIN &TargetSchema.Tests&Link t_t ON (t.testno = t_t.testno)
      WHERE 1=1
        AND t.testno IN (&TestList)
      ORDER BY
        t_t.testno ASC,
        pr.analyte ASC,
        pr.sorter ASC,
        pr.result ASC
    ) src
    ON (1=1
      AND tar.testcode = src.testcode
      AND tar.analyte = src.analyte
      AND tar.result = src.result
      )
    WHEN MATCHED THEN
      UPDATE SET
        tar.sorter = src.sorter,
        tar.result_status = src.result_status,
        tar.conclusion_report = src.conclusion_report,
        tar.snomedcode = src.snomedcode,
        tar.code_system_oid = src.code_system_oid,
        tar.origsts = src.origsts,
        tar.calcname = src.calcname,
        tar.localnumber = src.localnumber,
        tar.loincnumber = src.loincnumber,
        tar.snomedconceptid = src.snomedconceptid,
        tar.snomeddescriptionid = src.snomeddescriptionid,
        tar.cdc_reportable = src.cdc_reportable,
        tar.elr_reportable = src.elr_reportable
    WHEN NOT MATCHED THEN
      INSERT (
        tar.testcode,
        tar.analyte,
        tar.sorter,
        tar.result,
        tar.result_status,
        tar.conclusion_report,
        tar.snomedcode,    
        tar.code_system_oid,
        tar.origsts,
        tar.calcname,
        tar.localnumber,
        tar.loincnumber,
        tar.snomedconceptid,
        tar.snomeddescriptionid,
        tar.cdc_reportable,
        tar.elr_reportable      
      )
      VALUES (
        src.testcode,
        src.analyte,
        src.sorter,
        src.result,
        src.result_status,
        src.conclusion_report,
        src.snomedcode,    
        src.code_system_oid,
        src.origsts,
        src.calcname,
        src.localnumber,
        src.loincnumber,
        src.snomedconceptid,
        src.snomeddescriptionid,
        src.cdc_reportable,
        src.elr_reportable     
      );       
  /*----------  ----------*/

  /*----------5.4 Verify Environments Match----------*/
  --Verify values match across environments.  Ideally, no 
  --records should be returned. 
/*  
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          pr.analyte,
          pr.sorter,
          pr.result,
          pr.result_status,
          pr.conclusion_report,
          pr.snomedcode,    
          pr.code_system_oid,
          pr.origsts,
          pr.calcname,
          pr.localnumber,
          pr.loincnumber,
          pr.snomedconceptid,
          pr.snomeddescriptionid,
          pr.cdc_reportable,
          pr.elr_reportable,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
              pr.analyte || '|' ||
              pr.sorter || '|' ||
              pr.result || '|' ||
              pr.result_status || '|' ||
              pr.conclusion_report || '|' ||
              pr.snomedcode || '|' ||    
              pr.code_system_oid || '|' ||
              pr.origsts || '|' ||
              pr.calcname || '|' ||
              pr.localnumber || '|' ||
              pr.loincnumber || '|' ||
              pr.snomedconceptid || '|' ||
              pr.snomeddescriptionid || '|' ||
              pr.cdc_reportable || '|' ||
              pr.elr_reportable
          ) AS Key
          --
        FROM &SourceSchema.Tests t
          INNER JOIN &SourceSchema.PossibleResults pr ON (t.testcode = pr.testcode)
        WHERE 1=1
          AND t.testno IN (&TestList)
        ORDER BY
          pr.analyte ASC,
          pr.sorter ASC,
          pr.result ASC
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          pr.analyte,
          pr.sorter,
          pr.result,
          pr.result_status,
          pr.conclusion_report,
          pr.snomedcode,    
          pr.code_system_oid,
          pr.origsts,
          pr.calcname,
          pr.localnumber,
          pr.loincnumber,
          pr.snomedconceptid,
          pr.snomeddescriptionid,
          pr.cdc_reportable,
          pr.elr_reportable,
          --
          --This join key needs to be built exactly the
          --sam as TheSource join key--
          (
              pr.analyte || '|' ||
              pr.sorter || '|' ||
              pr.result || '|' ||
              pr.result_status || '|' ||
              pr.conclusion_report || '|' ||
              pr.snomedcode || '|' ||    
              pr.code_system_oid || '|' ||
              pr.origsts || '|' ||
              pr.calcname || '|' ||
              pr.localnumber || '|' ||
              pr.loincnumber || '|' ||
              pr.snomedconceptid || '|' ||
              pr.snomeddescriptionid || '|' ||
              pr.cdc_reportable || '|' ||
              pr.elr_reportable
          ) AS Key
          --
        FROM &TargetSchema.Tests&Link t
          INNER JOIN &TargetSchema.PossibleResults&Link pr ON (t.testcode = pr.testcode)
        WHERE 1=1
          AND t.testno IN (&TestList)
        ORDER BY
          pr.analyte ASC,
          pr.sorter ASC,
          pr.result ASC
      )      
     ---
     ---TheDifference---
       --Identify rows in Source or Target that don't match.
       SELECT DISTINCT
         COALESCE(ts.env,tt.env) AS env,
         COALESCE(ts.analyte,tt.analyte) AS analyte,
         COALESCE(ts.sorter,tt.sorter) AS sorter,
         COALESCE(ts.result,tt.result) AS result,
         COALESCE(ts.result_status,tt.result_status) AS result_status,
         COALESCE(ts.conclusion_report,tt.conclusion_report) AS conclusion_report,
         COALESCE(ts.snomedcode,tt.snomedcode) AS snomedcode,
         COALESCE(ts.code_system_oid,tt.code_system_oid) AS code_system_oid,
         COALESCE(ts.calcname,tt.calcname) AS calcname,
         COALESCE(ts.localnumber,tt.localnumber) AS localnumber,
         COALESCE(ts.loincnumber,tt.loincnumber) AS loincnumber,
         COALESCE(ts.snomedconceptid,tt.snomedconceptid) AS snomedconceptid,
         COALESCE(ts.snomeddescriptionid,tt.snomeddescriptionid) AS snomeddescriptionid,
         COALESCE(ts.cdc_reportable,tt.cdc_reportable) AS cdc_reportable,
         COALESCE(ts.elr_reportable,tt.elr_reportable) AS elr_reportable,
         '~' AS eol
       FROM TheSource ts
         FULL OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND (tt.key IS NULL OR ts.key IS NULL)
       ORDER BY 
         env ASC,
         analyte ASC,
         sorter ASC,
         result ASC;
     ---  
*/     
  /*----------  ----------*/
/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/
/*-----6. Test Manager: Test Plan----------------------------------*/
  --This script will enter a Test Plan for the test if it does not 
  --have the same one as in the source environment.
  --NOTE: We probably should NOT need to use this script since
  --      it is asssumed that the test has already been configured.

    --Application: Test Manager
    --Change Location:[Associated Matrices] tab | [Test Plans] grid
    --Primary Table(s): [sp_Tests]


  ---WARNING:  NOT SURE IF WE SHOULD USE THIS SCRIPT.   BEST TO MANUALL
  ---CONFIGURE THIS SETTING.
      
  /*----------6.1 Review Source data----------*/
  /*
    SELECT DISTINCT
      t.testno,
      sp.progname,
      spt.sp_code,
      spt.testcode,
      spt.active,
      spt.byhour,
      spt.contcode,
      spt.drawno,
      spt.firsttestinprofile,
      spt.holdtime,
      spt.mergecontainers,
      spt.origsts,
      spt.prepholdtime,
      spt.preptmname,
      spt.profile,
      spt.qty,
      spt.specimenrequired,
      spt.sptestsorter,
      spt.sp_testno,
      spt.dept,
      spt.eqid,
      spt.servgrp,
      spt.printlabel,
      spt.amount,
      spt.units,
      '~' eol
    FROM &SourceSchema.Tests t
      INNER JOIN &SourceSchema.sp_Tests spt ON (t.testcode = spt.testcode)
      INNER JOIN &SourceSchema.sample_programs sp ON (spt.sp_code = sp.sp_code)
    WHERE 1=1
      AND t.testno IN (&TestList)
      AND spt.active = 'A'
    ORDER BY
      t.testno ASC,
      sp.progname ASC;
*/
  /*----------  ----------*/

  /*----------6.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.sp_Tests TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.sample_programs TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------6.3  Add new enteries if they don't exits----------*/
    MERGE INTO &TargetSchema.sp_Tests&Link tar
    USING (
     SELECT DISTINCT
       t.testno,
        t_t.testcode,
       sp.progname,
        t_sp.sp_code,
        spt.active,
        spt.byhour,
        spt.contcode,
        spt.drawno,
        spt.firsttestinprofile,
        spt.holdtime,
        spt.mergecontainers,
        spt.origsts,
        spt.prepholdtime,
        spt.preptmname,
        spt.profile,
        spt.qty,
        spt.specimenrequired,
        spt.sptestsorter,
        spt.sp_testno,
        spt.dept,
        spt.eqid,
        spt.servgrp,
        spt.printlabel,
        spt.amount,
        spt.units,
        '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.sp_Tests spt ON (t.testcode = spt.testcode)
        INNER JOIN &SourceSchema.sample_programs sp ON (spt.sp_code = sp.sp_code)
        ---Join to Target table(s)---
        INNER JOIN &TargetSchema.Tests&Link t_t ON (t.testno = t_t.testno)
        INNER JOIN &TargetSchema.sample_programs&Link t_sp ON (sp.progname = t_sp.progname)
      WHERE 1=1
        AND t.testno IN (&TestList)
        AND spt.active = 'A'        
    ) src
    ON (1=1
      AND tar.sp_code = src.sp_code
      AND tar.testcode = src.testcode
      AND tar.active = src.active
      )
    WHEN NOT MATCHED THEN
      INSERT (
        tar.testcode,
        tar.sp_code,
        tar.active,
        tar.byhour,
        tar.contcode,
        tar.drawno,
        tar.firsttestinprofile,
        tar.holdtime,
        tar.mergecontainers,
        tar.origsts,
        tar.prepholdtime,
        tar.preptmname,
        tar.profile,
        tar.qty,
        tar.specimenrequired,
        tar.sptestsorter,
        tar.sp_testno,
        tar.dept,
        tar.eqid,
        tar.servgrp,
        tar.printlabel,
        tar.amount,
        tar.units      
      )
      VALUES (
        src.testcode,
        src.sp_code,
        src.active,
        src.byhour,
        src.contcode,
        src.drawno,
        src.firsttestinprofile,
        src.holdtime,
        src.mergecontainers,
        src.origsts,
        src.prepholdtime,
        src.preptmname,
        src.profile,
        src.qty,
        src.specimenrequired,
        src.sptestsorter,
        src.sp_testno,
        src.dept,
        src.eqid,
        src.servgrp,
        src.printlabel,
        src.amount,
        src.units        
      );
  /*----------  ----------*/
  
  /*----------6.4 Verify Environments Match----------*/
  --Verify values match across environments.  Ideally, no 
  --records should be returned. 
/*  
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          t.testno,
          sp.progname,
          spt.active,
          spt.byhour,
          spt.contcode,
          spt.drawno,
          spt.firsttestinprofile,
          spt.holdtime,
          spt.mergecontainers,
          spt.origsts,
          spt.prepholdtime,
          spt.preptmname,
          spt.profile,
          spt.qty,
          spt.specimenrequired,
          spt.sptestsorter,
          spt.dept,
          spt.eqid,
          spt.servgrp,
          spt.printlabel,
          spt.amount,
          spt.units,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
              t.testno || '|' ||
              sp.progname || '|' ||
              spt.active || '|' ||
              spt.byhour || '|' ||
              spt.contcode || '|' ||
              spt.drawno || '|' ||
              spt.firsttestinprofile || '|' ||
              spt.holdtime || '|' ||
              spt.mergecontainers || '|' ||
              spt.origsts || '|' ||
              spt.prepholdtime || '|' ||
              spt.preptmname || '|' ||
              spt.profile || '|' ||
              spt.qty || '|' ||
              spt.specimenrequired || '|' ||
              spt.sptestsorter || '|' ||
              spt.dept || '|' ||
              spt.eqid || '|' ||
              spt.servgrp || '|' ||
              spt.printlabel || '|' ||
              spt.amount || '|' ||
              spt.units                 
          ) AS Key
          --
        FROM &SourceSchema.Tests t
          INNER JOIN &SourceSchema.sp_Tests spt ON (t.testcode = spt.testcode)
          INNER JOIN &SourceSchema.sample_programs sp ON (spt.sp_code = sp.sp_code)
        WHERE 1=1
          AND t.testno IN (&TestList)
          AND spt.active = 'A'
        ORDER BY
          t.testno ASC,
          sp.progname ASC          
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          t.testno,
          sp.progname,
          spt.active,
          spt.byhour,
          spt.contcode,
          spt.drawno,
          spt.firsttestinprofile,
          spt.holdtime,
          spt.mergecontainers,
          spt.origsts,
          spt.prepholdtime,
          spt.preptmname,
          spt.profile,
          spt.qty,
          spt.specimenrequired,
          spt.sptestsorter,
          spt.dept,
          spt.eqid,
          spt.servgrp,
          spt.printlabel,
          spt.amount,
          spt.units,
          --
          --This join key needs to be built exactly the
          --sam as TheSource join key--
          (
              t.testno || '|' ||
              sp.progname || '|' ||
              spt.active || '|' ||
              spt.byhour || '|' ||
              spt.contcode || '|' ||
              spt.drawno || '|' ||
              spt.firsttestinprofile || '|' ||
              spt.holdtime || '|' ||
              spt.mergecontainers || '|' ||
              spt.origsts || '|' ||
              spt.prepholdtime || '|' ||
              spt.preptmname || '|' ||
              spt.profile || '|' ||
              spt.qty || '|' ||
              spt.specimenrequired || '|' ||
              spt.sptestsorter || '|' ||
              spt.dept || '|' ||
              spt.eqid || '|' ||
              spt.servgrp || '|' ||
              spt.printlabel || '|' ||
              spt.amount || '|' ||
              spt.units                 
          ) AS Key
          --
        FROM &TargetSchema.Tests&Link t
          INNER JOIN &TargetSchema.sp_Tests&Link spt ON (t.testcode = spt.testcode)
          INNER JOIN &TargetSchema.sample_programs&Link sp ON (spt.sp_code = sp.sp_code)
        WHERE 1=1
          AND t.testno IN (&TestList)
          AND spt.active = 'A'
        ORDER BY
          t.testno ASC,
          sp.progname ASC          
          
      )      
     ---
     ---TheDifference---
       --Identify rows in Source or Target that don't match.
       SELECT DISTINCT
         COALESCE(ts.env,tt.env) AS env,
         COALESCE(ts.testno,tt.testno) AS testno,
         COALESCE(ts.progname,tt.progname) AS progname,
         COALESCE(ts.active,tt.active) AS active,
         COALESCE(ts.byhour,tt.byhour) AS byhour,
         COALESCE(ts.contcode,tt.contcode) AS contcode,
         COALESCE(ts.drawno,tt.drawno) AS drawno,
         COALESCE(ts.firsttestinprofile,tt.firsttestinprofile) AS firsttestinprofile,
         COALESCE(ts.holdtime,tt.holdtime) AS holdtime,
         COALESCE(ts.mergecontainers,tt.mergecontainers) AS mergecontainers,
         COALESCE(ts.origsts,tt.origsts) AS origsts,
         COALESCE(ts.prepholdtime,tt.prepholdtime) AS prepholdtime,
         COALESCE(ts.preptmname,tt.preptmname) AS preptmname,
         COALESCE(ts.profile,tt.profile) AS profile,
         COALESCE(ts.qty,tt.qty) AS qty,
         COALESCE(ts.specimenrequired,tt.specimenrequired) AS specimenrequired,
         COALESCE(ts.sptestsorter,tt.sptestsorter) AS sptestsorter,
         COALESCE(ts.dept,tt.dept) AS dept,
         COALESCE(ts.eqid,tt.eqid) AS eqid,
         COALESCE(ts.servgrp,tt.servgrp) AS servgrp,
         COALESCE(ts.printlabel,tt.printlabel) AS printlabel,
         COALESCE(ts.amount,tt.amount) AS amount,
         COALESCE(ts.units,tt.units) AS units,
         '~' AS eol
       FROM TheSource ts
         FULL OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND (tt.key IS NULL OR ts.key IS NULL)
       ORDER BY 
         env ASC,
         testno ASC,
         progname ASC;
     ---
*/
  /*----------  ----------*/
  
/*-----------------------------------------------------------------*/





/*-----7. Test Manager: Analyte LOINC Codes-----------------------*/
  --Creat new LOINC codes for Analytes if needed.

    --Application: Test Manager
    --Change Location:[Analyte LOINC Codes] tab | [Analytes LOINC Codes] grid
    --Primary Table(s): [TestLoincCodes]
        
  /*----------7.1 Review Source data----------*/
/*
    SELECT DISTINCT
      t.testno,
      tlc.testcode,
      tlc.analyte,
      tlc.loinccomponenet,
      tlc.loincdefault,
      tlc.loincnumber,
      tlc.version,
      tlc.hl7_reportable,                  
      tlc.code_system_oid,
      tlc.loincmethod,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems,
      tlc.loinctime,
      tlc.origsts,
      '~' eol
    FROM &SourceSchema.Tests t
      INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
      INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
        AND tlc.loinccomponenet = lco.loinccomponenet
        AND tlc.loincnumber = lco.loincnumber
        AND tlc.version = lco.version)      
      INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
      INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
        AND lco.classcode = lcl.classcode
        AND lco.version = lcl.version)
    WHERE 1=1
      AND t.testno IN (&TestList)
    ORDER BY
      tlc.analyte ASC;
*/
  /*----------  ----------*/

  /*----------7.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.TestLoincCodes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.LoincCodes TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincVersion TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincClasses TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------7.3  Add new enteries if they don't exits----------*/ 
    MERGE INTO &TargetSchema.TestLoincCodes&Link tar
    USING (
      SELECT DISTINCT
      t_t.testcode,
      --tlc.testcode,
      tlc.analyte,
      tlc.loinccomponenet,
      tlc.loincdefault,
      tlc.loincnumber,
      t_lv.version,
      --tlc.version,
      tlc.hl7_reportable,                  
      tlc.code_system_oid,
      tlc.loincmethod,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems,
      tlc.loinctime,
      tlc.origsts,
      '~' eol
      FROM &SourceSchema.Tests t
        INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
        INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
          AND tlc.loinccomponenet = lco.loinccomponenet
          AND tlc.loincnumber = lco.loincnumber
          AND tlc.version = lco.version)      
        INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
        INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
          AND lco.classcode = lcl.classcode
          AND lco.version = lcl.version)
        --Join to Target to get target version & classcode
        INNER JOIN &TargetSchema.Tests&Link t_t ON (t.testno = t_t.testno)
        INNER JOIN &TargetSchema.LoincClasses&Link t_lcl ON ( 1 = 1
          AND lcl.classcode = t_lcl.classcode
          AND lcl.classname = t_lcl.classname)
        INNER JOIN &TargetSchema.LoincVersion&Link t_lv ON (t_lcl.version = t_lv.version)
        --        
      WHERE 1=1
        AND t.testno IN (&TestList)
        AND t_lv.status = 'Active'    
    ) src
    ON (1=1
      AND tar.testcode = src.testcode
      AND tar.analyte = src.analyte
      AND tar.loinccomponenet = src.loinccomponenet
      )
    WHEN NOT MATCHED THEN
      INSERT (
      tar.testcode,
      tar.analyte,
      tar.loinccomponenet,
      tar.loincdefault,
      tar.loincnumber,
      tar.version,
      tar.hl7_reportable,                  
      tar.code_system_oid,
      tar.loincmethod,
      tar.loincproperty,
      tar.loincscale,
      tar.loincsystems,
      tar.loinctime,
      tar.origsts
      )
      VALUES (
      src.testcode,
      src.analyte,
      src.loinccomponenet,
      src.loincdefault,
      src.loincnumber,
      src.version,
      src.hl7_reportable,                  
      src.code_system_oid,
      src.loincmethod,
      src.loincproperty,
      src.loincscale,
      src.loincsystems,
      src.loinctime,
      src.origsts
      ); 
  /*----------  ----------*/
  
  /*----------7.4 Verify Environments Match----------*/
  --Verify values match across environments.  Ideally, no 
  --records should be returned. 
/*  
    WITH 
      ---TheSource---
        --Build list to compare
      TheSource AS (
        SELECT DISTINCT
          CASE 
             WHEN ('&SourceSchema' = 'sunrise_data') THEN 'DEV'
             WHEN ('&SourceSchema' = 'sundata_sat') THEN 'TEST'
             WHEN ('&SourceSchema' = 'sundata_prod') THEN 'PROD'                            
           END AS env,   
          --List columns of interest--     
          t.testno,
          tlc.analyte,
          tlc.loinccomponenet,
          tlc.loincdefault,
          tlc.loincnumber,
          tlc.version,
          tlc.hl7_reportable,                  
          tlc.code_system_oid,
          tlc.loincmethod,
          tlc.loincproperty,
          tlc.loincscale,
          tlc.loincsystems,
          tlc.loinctime,
          tlc.origsts,
          --
          --Build join key with relavant columns.  This will
          --join against the TheTarget key--
          (
            t.testno || '|' ||
            tlc.analyte || '|' ||
            tlc.loinccomponenet || '|' ||
            tlc.loincdefault || '|' ||
            tlc.loincnumber || '|' ||
            tlc.version || '|' ||
            tlc.hl7_reportable || '|' ||
            tlc.code_system_oid || '|' ||
            tlc.loincmethod || '|' ||
            tlc.loincproperty || '|' ||
            tlc.loincscale || '|' ||
            tlc.loincsystems || '|' ||
            tlc.loinctime || '|' ||
            tlc.origsts
          ) AS Key
          --
        FROM &SourceSchema.Tests t
          INNER JOIN &SourceSchema.TestLoincCodes tlc ON (t.testcode = tlc.testcode)      
          INNER JOIN &SourceSchema.LoincCodes lco ON (1=1
            AND tlc.loinccomponenet = lco.loinccomponenet
            AND tlc.loincnumber = lco.loincnumber
            AND tlc.version = lco.version)      
          INNER JOIN &SourceSchema.LoincVersion lv ON (lco.version = lv.version)
          INNER JOIN &SourceSchema.LoincClasses lcl ON (1=1
            AND lco.classcode = lcl.classcode
            AND lco.version = lcl.version)
        WHERE 1=1
          AND t.testno IN (&TestList)
        ORDER BY
          tlc.analyte ASC          
      ),
     ---
     ---TheTarget---
       --TheTarget needs to have exact same columns as TheSource.
     TheTarget AS (
       SELECT DISTINCT
         CASE 
            WHEN ('&TargetSchema' = 'sunrise_data') THEN 'DEV'
            WHEN ('&TargetSchema' = 'sundata_sat') THEN 'TEST'
            WHEN ('&TargetSchema' = 'sundata_prod') THEN 'PROD'                            
          END AS env,        
          --List columns of interest--     
          t.testno,
          tlc.analyte,
          tlc.loinccomponenet,
          tlc.loincdefault,
          tlc.loincnumber,
          tlc.version,
          tlc.hl7_reportable,                  
          tlc.code_system_oid,
          tlc.loincmethod,
          tlc.loincproperty,
          tlc.loincscale,
          tlc.loincsystems,
          tlc.loinctime,
          tlc.origsts,
          --
          --This join key needs to be built exactly the
          --sam as TheSource join key--
          (
            t.testno || '|' ||
            tlc.analyte || '|' ||
            tlc.loinccomponenet || '|' ||
            tlc.loincdefault || '|' ||
            tlc.loincnumber || '|' ||
            tlc.version || '|' ||
            tlc.hl7_reportable || '|' ||
            tlc.code_system_oid || '|' ||
            tlc.loincmethod || '|' ||
            tlc.loincproperty || '|' ||
            tlc.loincscale || '|' ||
            tlc.loincsystems || '|' ||
            tlc.loinctime || '|' ||
            tlc.origsts
          ) AS Key
          --
        FROM &TargetSchema.Tests&Link t
          INNER JOIN &TargetSchema.TestLoincCodes&Link tlc ON (t.testcode = tlc.testcode)      
          INNER JOIN &TargetSchema.LoincCodes&Link lco ON (1=1
            AND tlc.loinccomponenet = lco.loinccomponenet
            AND tlc.loincnumber = lco.loincnumber
            AND tlc.version = lco.version)      
          INNER JOIN &TargetSchema.LoincVersion&Link lv ON (lco.version = lv.version)
          INNER JOIN &TargetSchema.LoincClasses&Link lcl ON (1=1
            AND lco.classcode = lcl.classcode
            AND lco.version = lcl.version)
        WHERE 1=1
          AND t.testno IN (&TestList)
        ORDER BY
          tlc.analyte ASC          
      )      
     ---
     ---TheDifference---
       --Identify rows in Source or Target that don't match.
       SELECT DISTINCT
         COALESCE(ts.env,tt.env) AS env,
         COALESCE(ts.testno,tt.testno) AS testno,
         COALESCE(ts.analyte,tt.analyte) AS analyte,
         COALESCE(ts.loinccomponenet,tt.loinccomponenet) AS loinccomponenet,
         COALESCE(ts.loincdefault,tt.loincdefault) AS loincdefault,
         COALESCE(ts.loincnumber,tt.loincnumber) AS loincnumber,
         COALESCE(ts.version,tt.version) AS version,
         COALESCE(ts.hl7_reportable,tt.hl7_reportable) AS hl7_reportable,
         COALESCE(ts.code_system_oid,tt.code_system_oid) AS code_system_oid,
         COALESCE(ts.loincmethod,tt.loincmethod) AS loincmethod,
         COALESCE(ts.loincproperty,tt.loincproperty) AS loincproperty,
         COALESCE(ts.loincscale,tt.loincscale) AS loincscale,
         COALESCE(ts.loincsystems,tt.loincsystems) AS loincsystems,
         COALESCE(ts.loinctime,tt.loinctime) AS loinctime,
         COALESCE(ts.origsts,tt.origsts) AS origsts,
         '~' AS eol
       FROM TheSource ts
         FULL OUTER JOIN TheTarget tt ON (ts.key = tt.key)
       WHERE 1=1
         AND (tt.key IS NULL OR ts.key IS NULL)
       ORDER BY 
         env ASC,
         analyte ASC;
     ---
*/  
  /*----------  ----------*/  

/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/
/*-----8. Sample Conclusions---------------------------------------*/
  --Add new enteries for Sample Conclusion.

    --Application: Sample Conclusions
    --Change Location:[Sample Conclusion] section
    --Primary Table(s): [TestLoincCodes]

---NOTE: UNABLE TO COMPLETE THIS SCRIPT.  NOT SURE HOW bs_ID FIELD
---IS TO BE MIGRATED TO OTHER ENVIORNMENT. 
/*
 SELECT * FROM SUNRISE_DATA.Base_Static_Data bsd WHERE bsd.bs_type = 'Sample Conclusions' ORDER BY BSD.ORIGREC DESC;
 SELECT * FROM SUNRISE_DATA.Metadata_Repository mr WHERE mr.tablereference = 'BASE_STATIC_DATA';
 
  SELECT * FROM SUNRISE_DATA.Base_Static_Data bsd WHERE bsd.bs_id = '713'
 SELECT * FROM SUNRISE_DATA.Metadata_Repository mr WHERE 1=1
   AND mr.tablereference = 'BASE_STATIC_DATA'
   AND mr.field_varchar_01 = 'Novel Coronavirus 2012';
  SELECT * FROM SUNRISE_DATA.Base_Static_Data bsd WHERE bsd.origrec = '7186';
*/   
  
  
-- SELECT * FROM SUNRISE_DATA.Base_Static_Data bsd WHERE bsd.bs_type = 'Sample Conclusions' order by bsd.bs_id desc  
  /*----------.1 Review Source data----------*/
/*  
    SELECT DISTINCT
      t.testno,
      t.testcode,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name,      
      '~' eol
    FROM &SourceSchema.Tests t
    WHERE 1=1
      AND t.testno IN (&TestList)
    ORDER BY
      t.testno ASC;
*/
  /*----------  ----------*/

  /*----------#.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.TestLoincCodes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.LoincCodes TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincVersion TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincClasses TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------#.3  Add new enteries if they don't exits----------*/
/*  
    MERGE INTO sundata_sat.TestLoincCodes tar
    USING (
    ) src
    ON (1=1
      )
    WHEN NOT MATCHED THEN
      INSERT (
      )
      VALUES (
      )            
*/      
  /*----------  ----------*/

/*-----------------------------------------------------------------*/



















/*-----------------------------------------------------------------*/
/*-----#. Next Item------------------------------------------------*/

  /*----------#.1 Review Source data----------*/
    SELECT DISTINCT
      t.testno,
      t.testcode,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name,      
      '~' eol
    FROM &SourceSchema.Tests t
    WHERE 1=1
      AND t.testno IN (&TestList)
    ORDER BY
      t.testno ASC;
  /*----------  ----------*/

  /*----------#.2 May need to grant read access to Source table(s)----------*/ 
/*  
    GRANT SELECT ON &SourceSchema.Tests TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.TestLoincCodes TO &TargetAccount;
    GRANT SELECT ON &SourceSchema.LoincCodes TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincVersion TO &TargetAccount;    
    GRANT SELECT ON &SourceSchema.LoincClasses TO &TargetAccount;    
*/    
  /*----------  ----------*/  

  /*----------#.3  Add new enteries if they don't exits----------*/
  
    MERGE INTO sundata_sat.TestLoincCodes tar
    USING (
    ) src
    ON (1=1
      )
    WHEN NOT MATCHED THEN
      INSERT (
      )
      VALUES (
      )            
  /*----------  ----------*/

/*-----------------------------------------------------------------*/
