

/*-----Migrate_Materials-----------------------------------------------------*/
  /*-----Description-----*/
    --Utilize scripts here to migrate Materials between envrionments (One at at time).
    --the following Tables are updated:
      --Materials
      --prod_suppliers
      --metadata_references


      --Assumptions
        --Target Database must have READ access to Source database
        --Supplier is already in Target System
      
      
      --Scripts:
        --01. Single Material Migration
        --02. Materials by TestName
  /*----- -----*/
  
  /*-----History-----*/
    --2016.03.31 Created Script file
    --2017.09.11 Addition of variable for ExeData schema's (DEV & TEST)
  /*----- -----*/
/*---------------------------------------------------------------------------*/





/*-----00. Single Material Migration-----------------------------------------*/
  /*-----00.1: Grant READ access to Target Schema-----*/
    --Note, you must be logged onto the Source Database to run these scripts.
    --GRANT SELECT ON materials TO &TargetSchema;
    --GRANT SELECT ON prod_suppliers TO &TargetSchema;
  /*----- -----*/

  /*-----00.2 Single Material Migration: Review Source and Target-----*/
/*  
      SELECT DISTINCT
        m.dept,
        m.mattype,
        m.matcode,
        m.matname,
        m.needqcprep,
        m.identifyindunits,
        m.needinvmng,
        m.origsts,
        m.orig_srvgrp,
        m.unit_code,
        m.shareflag,
        m.cocflag,
        m.orderflag,
        m.reducecomponents,
        m.containerflag,
        m.analyte_flag,
        m.std_type,
        m.autorelease_inventory,
        m.exptimeframe_interval,
        m.exptimeframe_unit,
        '~' AS eol
      FROM &SourceSchema.materials&Exadata  m
      WHERE 1=1
        AND m.matcode = '&MatCode'
      ORDER BY
        m.dept ASC,
        m.mattype ASC,
        m.matcode ASC;
        
      SELECT DISTINCT
        ps.suppcode,
        ps.matcode,
        ps.low_level,
        ps.catno,
        ps.high_level,
        ps.origsts,
        ps.requalification_interval,
        '~' AS eol
      FROM &SourceSchema.prod_suppliers&Exadata ps
      WHERE 1=1
      AND ps.matcode = '&MatCode'
      ORDER BY
        ps.suppcode ASC,
        ps.matcode ASC;
*/       
  /*----- -----*/
  
/*---------------------------------------------------------------------------*/




/*-----01. Single Material Migration-----------------------------------------*/
  --Use these scripts (3) to migrate a single material 
  --(Identified by Material Code) to the target database(Schema).

  -----01.01 Materials Migration-----
    MERGE INTO &TargetSchema.materials t1
    USING (
      SELECT DISTINCT
        m.dept,
        m.mattype,
        m.matcode,
        m.matname,
        m.needqcprep,
        m.identifyindunits,
        m.needinvmng,
        m.origsts,
        m.orig_srvgrp,
        m.unit_code,
        m.shareflag,
        m.cocflag,
        m.orderflag,
        m.reducecomponents,
        m.containerflag,
        m.analyte_flag,
        m.std_type,
        m.autorelease_inventory,
        m.exptimeframe_interval,
        m.exptimeframe_unit,
        '~' AS eol
      FROM &SourceSchema.materials&Exadata  m
      WHERE 1=1
        AND m.matcode = '&MatCode'
      ORDER BY
        m.dept ASC,
        m.mattype ASC,
        m.matcode ASC
    ) t2
    ON ( 1=1
      AND (t1.dept = t2.dept)
      AND (t1.mattype = t2.mattype)
      AND (t1.matcode = t2.matcode)
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.dept,
        t1.mattype,
        t1.matcode,
        t1.matname,
        t1.needqcprep,
        t1.identifyindunits,
        t1.needinvmng,
        t1.origsts,
        t1.orig_srvgrp,
        t1.unit_code,
        t1.shareflag,
        t1.cocflag,
        t1.orderflag,
        t1.reducecomponents,
        t1.containerflag,
        t1.analyte_flag,
        t1.std_type,
        t1.autorelease_inventory,
        t1.exptimeframe_interval,
        t1.exptimeframe_unit
      )
      VALUES (
        t2.dept,
        t2.mattype,
        t2.matcode,
        t2.matname,
        t2.needqcprep,
        t2.identifyindunits,
        t2.needinvmng,
        t2.origsts,
        t2.orig_srvgrp,
        t2.unit_code,
        t2.shareflag,
        t2.cocflag,
        t2.orderflag,
        t2.reducecomponents,
        t2.containerflag,
        t2.analyte_flag,
        t2.std_type,
        t2.autorelease_inventory,
        t2.exptimeframe_interval,
        t2.exptimeframe_unit
      );

    ----- -----
    -----01.02 Labels Migration-----
    MERGE INTO &TargetSchema.prod_suppliers t1
    USING (
      SELECT DISTINCT
        ps.suppcode,
        ps.matcode,
        ps.low_level,
        ps.catno,
        ps.high_level,
        ps.origsts,
        ps.requalification_interval,
        '~' AS eol
      FROM &SourceSchema.prod_suppliers&Exadata ps
      WHERE 1=1
      AND ps.matcode = '&MatCode'
      ORDER BY
        ps.suppcode ASC,
        ps.matcode ASC
    ) t2
    ON (1=1
      AND (t1.suppcode = t2.suppcode)
      AND (t1.matcode = t2.matcode)
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.suppcode,
        t1.matcode,
        t1.low_level,
        t1.catno,
        t1.high_level,
        t1.origsts,
        t1.requalification_interval
      )
      VALUES (
        t2.suppcode,
        t2.matcode,
        t2.low_level,
        t2.catno,
        t2.high_level,
        t2.origsts,
        t2.requalification_interval
      );
      
  -----01.03 MetaData Template for Material Migration-----
    MERGE INTO &TargetSchema.metadata_references t1
    USING (
      SELECT DISTINCT
        'N' AS origsts,
        'MaterialsGeneral' AS metadatamethodcode,    
        m.origrec AS original_origrec,
        'MATERIALS' AS tablereference,
        '199' AS metadata_type_id
      FROM  &TargetSchema.materials m
      WHERE 1=1
        AND m.matcode = '&MatCode'
    ) t2
    ON ( 1=1
      AND t1.metadatamethodcode = t2.metadatamethodcode
      AND t1.original_origrec = t2.original_origrec
      AND t1.tablereference = t2.tablereference
      AND t1.metadata_type_id = t2.metadata_type_id 
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.origsts,
        t1.metadatamethodcode,
        t1.original_origrec,
        t1.tablereference,
        t1.metadata_type_id
      )
      VALUES (
        t2.origsts,
        t2.metadatamethodcode,
        t2.original_origrec,
        t2.tablereference,
        t2.metadata_type_id
      );
  ----- -----

/*---------------------------------------------------------------------------*/





/*-----02. Materials by TestName---------------------------------------------*/
  --Use these scripts (3) to migrate a all materials associated with the
  --identified Test (Identified by Test Name) to the target database(Schema).

--NOTE: Have not had a chance to validate this script, but confident it should work fine...  
  
/*
  -----02.01 Materials Migration-----
    MERGE INTO &TargetSchema.materials t1
    USING (
      SELECT DISTINCT
        m.dept,
        m.mattype,
        m.matcode,
        m.matname,
        m.needqcprep,
        m.identifyindunits,
        m.needinvmng,
        m.origsts,
        m.orig_srvgrp,
        m.unit_code,
        m.shareflag,
        m.cocflag,
        m.orderflag,
        m.reducecomponents,
        m.containerflag,
        m.analyte_flag,
        m.std_type,
        m.autorelease_inventory,
        m.exptimeframe_interval,
        m.exptimeframe_unit,
        '~' AS eol
      FROM &SourceSchema.materials&Exadata  m
        INNER JOIN &SourceSchema.testreagents tr ON (m.matcode = tr.matcode)
        INNER JOIN &SourceSchema.tests t ON (tr.testcode = t.testcode)
      WHERE 1=1
        AND t.testno = '&TestName'
      ORDER BY
        m.dept ASC,
        m.mattype ASC,
        m.matcode ASC) t2
    ON ( 1=1
      AND (t1.dept = t2.dept)
      AND (t1.mattype = t2.mattype)
      AND (t1.matcode = t2.matcode)
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.dept,
        t1.mattype,
        t1.matcode,
        t1.matname,
        t1.needqcprep,
        t1.identifyindunits,
        t1.needinvmng,
        t1.origsts,
        t1.orig_srvgrp,
        t1.unit_code,
        t1.shareflag,
        t1.cocflag,
        t1.orderflag,
        t1.reducecomponents,
        t1.containerflag,
        t1.analyte_flag,
        t1.std_type,
        t1.autorelease_inventory,
        t1.exptimeframe_interval,
        t1.exptimeframe_unit
      )
      VALUES (
        t2.dept,
        t2.mattype,
        t2.matcode,
        t2.matname,
        t2.needqcprep,
        t2.identifyindunits,
        t2.needinvmng,
        t2.origsts,
        t2.orig_srvgrp,
        t2.unit_code,
        t2.shareflag,
        t2.cocflag,
        t2.orderflag,
        t2.reducecomponents,
        t2.containerflag,
        t2.analyte_flag,
        t2.std_type,
        t2.autorelease_inventory,
        t2.exptimeframe_interval,
        t2.exptimeframe_unit
      );

    ----- -----
    -----02.02 Labels Migration-----
    MERGE INTO &TargetSchema.prod_suppliers t1
    USING (
      SELECT DISTINCT
        ps.suppcode,
        ps.matcode,
        ps.low_level,
        ps.catno,
        ps.high_level,
        ps.origsts,
        ps.requalification_interval,
        '~' AS eol
      FROM &SourceSchema.prod_suppliers&Exadata ps
        INNER JOIN &SourceSchema.testreagents tr ON (ps.matcode = tr.matcode)
        INNER JOIN &SourceSchema.tests t ON (tr.testcode = t.testcode)     
      WHERE 1=1
        AND t.testno = '&TestName'
      ORDER BY
        ps.suppcode ASC,
        ps.matcode ASC
    ) t2
    ON (1=1
      AND (t1.suppcode = t2.suppcode)
      AND (t1.matcode = t2.matcode)
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.suppcode,
        t1.matcode,
        t1.low_level,
        t1.catno,
        t1.high_level,
        t1.origsts,
        t1.requalification_interval
      )
      VALUES (
        t2.suppcode,
        t2.matcode,
        t2.low_level,
        t2.catno,
        t2.high_level,
        t2.origsts,
        t2.requalification_interval
      );
      
  -----02.03 MetaData Template for Material Migration-----
    MERGE INTO &TargetSchema.metadata_references t1
    USING (
      SELECT DISTINCT
        'N' AS origsts,
        'MaterialsGeneral' AS metadatamethodcode,    
        m.origrec AS original_origrec,
        'MATERIALS' AS tablereference,
        '199' AS metadata_type_id
      FROM  &TargetSchema.materials m
        INNER JOIN &SourceSchema.testreagents&Exadata tr ON (m.matcode = tr.matcode)
        INNER JOIN &SourceSchema.tests&Exadata t ON (tr.testcode = t.testcode)          
      WHERE 1=1
        AND t.testno = '&TestName'
    ) t2
    ON ( 1=1
      AND t1.metadatamethodcode = t2.metadatamethodcode
      AND t1.original_origrec = t2.original_origrec
      AND t1.tablereference = t2.tablereference
      AND t1.metadata_type_id = t2.metadata_type_id 
    )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.origsts,
        t1.metadatamethodcode,
        t1.original_origrec,
        t1.tablereference,
        t1.metadata_type_id
      )
      VALUES (
        t2.origsts,
        t2.metadatamethodcode,
        t2.original_origrec,
        t2.tablereference,
        t2.metadata_type_id
      );
*/      
  ----- -----

/*---------------------------------------------------------------------------*/

