


/*-----Migrate_NewMicroComponent-----------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Scripts here are for migrating a new MicroComponent and associated objects
    --to the targeted envrionment.
    --It Assumes this MicroComponent Does NOT already exists in the targeted 
    --Environment
  /*----- -----*/
  
  /*-----Limitations/Assumptions-----*/
    --Scripts are restricted strictly to updating tables associated directly
    --with controls in indicated tabs.  This means new objects that were created
    --outside of the MicroComponents application (ie Materials, Equipment, etc)
    --to support the controls will need to be taken care of seperatly from
    --this application.
  /*----- -----*/

--NOTE: If you have an existing MicroComponent that just needs to be updated
--      from one environment to another, you can Delete the target environment
--      microcomponent using the Delete_MicroComponent script and migrate the 
--      MicroComponent from the source as a new MicroComponent using this script.

--NOTE2: DEV/TEST can be accessed from PROD by adding suffix "@exastart"
--      to table name in JOIN.  IE: 
--         SELECT * FROM sundata_sat.tests@exastart t 
    
    
  --&DBLink = @exastart for accessing DEV/TEST from PROD    


  /*-----Scripts-----*/

    --01. Preliminary Tasks
      --01. Target Schema Permissions
      --02. Identify Required Items
      --03. New MicroComponent Verification
    --02. Create Component:
    --03. Possible Results Tab
    --04. Micro Panels tab
    --05. Quality Control tab
    --06. Reagents tab
    --07. LOINC tab
  /*----- -----*/

  /*-----HISTORY-----*/
    --2016.05.11 JTY: Created Srcipt
  /*----- -----*/

/*---------------------------------------------------------------------------*/





/*-----01. Preliminary Tasks-------------------------------------------------*/
  /*-----01. Target Schema Permissions-----*/
    --Make sure TargetSchema can read relavant SourceSchema tables
    --Note: You must be logged into Source Schema to run these scripts.
/*
    GRANT SELECT ON microcomponents TO &TargetSchema;
    GRANT SELECT ON microcompresponse TO &TargetSchema;
    GRANT SELECT ON micropanels TO &TargetSchema;
    GRANT SELECT ON micropanelcomp TO &TargetSchema;
    GRANT SELECT ON microconditions TO &TargetSchema;
    GRANT SELECT ON micropanelconditions TO &TargetSchema;
    GRANT SELECT ON microqccontrols TO &TargetSchema;
    GRANT SELECT ON materials TO &TargetSchema;  
    GRANT SELECT ON microcompreagents TO &TargetSchema;
    GRANT SELECT ON microcomploinc TO &TargetSchema;
    GRANT SELECT ON microcompequipments TO &TargetSchema;
*/  
  /*----- -----*/  

  /*-----02. Identify Required Items-----*/
    --Identify any Materials, Equipment that must be added to the target
    --schema before proceeding with the update scripts.
/*    

    ---Identify Missing Materials for Quality Control tab---
      SELECT DISTINCT
        mcq.comptype,
        mcq.compid,
        mcq.qctype,
        mcq.matcode,
        '~' AS eol
      FROM &SourceSchema.microqccontrols&DBLink mcq
        LEFT OUTER JOIN &TargetSchema.materials m ON (mcq.matcode = m.matcode)
      WHERE 1=1
        AND m.matcode IS NULL
        AND mcq.comptype = '&ComponentType'
        AND mcq.compid = '&ComponentID';

    --- ---
    ---Identify Missing Materials for Reagents tab---
      SELECT DISTINCT
        mcr.comptype,
        mcr.compid,
        mcr.matcode,
        '~' AS eol
      FROM &SourceSchema.microcompreagents&DBLink mcr
        LEFT OUTER JOIN &TargetSchema.materials m ON (mcr.matcode = m.matcode)
      WHERE 1=1
        AND m.matcode IS NULL
        AND mcr.comptype = '&ComponentType'
        AND mcr.compid = '&ComponentID';

    --- ---
    ---Identify Missing Equipment---
      SELECT DISTINCT
        mce.comptype,
        mce.compid,
        mce.eqtype,
        mce.eqid,
        '~' AS eol
      FROM &SourceSchema.microcompequipments&DBLink mce
        LEFT OUTER JOIN &TargetSchema.equipment e ON (1=1
          AND mce.eqtype = e.eqtype
          AND mce.eqid = e.eqid)
      WHERE 1=1
        AND e.eqid IS NULL
        AND mce.comptype = '&ComponentType'
        AND mce.compid = '&ComponentID';
    --- ---
*/


  /*----- -----*/  

  /*-----03. New MicroComponent Verification-----*/
    --Verify that the targeted Environment doesn NOT already have the MC.
/*    
    SELECT DISTINCT
      mc.comptype,
      mc.compid,
      mc.acronym,
      mc.compname,
      mc.origsts,
      mc.hidefromreport,
      mc.eqid,
      mc.eqtype,
      mc.reportinterpretation,      
      '~' AS eol  
    FROM &TargetSchema.microcomponents mc
    WHERE 1=1
      AND mc.comptype = '&ComponentType' --'HPLC'
      AND mc.compid = '&ComponentID'     --'MALDI-TOF'
    ORDER BY
      mc.compid ASC;
*/
  /*----- -----*/  

/*---------------------------------------------------------------------------*/




-------02. Create Component----------------------------------------------------
  --Create MicroComponent in Target Schema

    MERGE INTO &TargetSchema.microcomponents T1
    USING (
      SELECT DISTINCT
        mc.comptype,
        mc.compid,
        mc.acronym,
        mc.compname,
        mc.origsts,
        mc.hidefromreport,
        mc.eqid,
        mc.eqtype,
        mc.reportinterpretation, 
        '~' AS eol  
      FROM &SourceSchema.microcomponents&DBLink mc
      WHERE 1=1
        AND mc.comptype = '&ComponentType' --'HPLC'
        AND mc.compid = '&ComponentID'     --'MALDI-TOF'
      ORDER BY
        mc.compid ASC    
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
       )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.comptype,
        t1.compid,
        t1.acronym,
        t1.compname,
        t1.origsts,
        t1.hidefromreport,
        t1.eqid,
        t1.eqtype,
        t1.reportinterpretation  
      )
      VALUES (
        t2.comptype,
        t2.compid,
        t2.acronym,
        t2.compname,
        t2.origsts,
        t2.hidefromreport,
        t2.eqid,
        t2.eqtype,
        t2.reportinterpretation  
      );
-------------------------------------------------------------------------------





-------03. Possible Results Tab------------------------------------------------
  --Add Possible Results to MicroComponent

    MERGE INTO &TargetSchema.microcompresponse T1
    USING (
      SELECT DISTINCT
        mcr.comptype,
        mcr.compid,
        mcr.ressorter,  
        mcr.response,
        mcr.status,
        mcr.interpretation,
        mcr.is_negative,
        mcr.origsts,
        mcr.snomedcode,
        mcr.code_system_oid,
        mcr.loincnumber,
        mcr.hidefromreport,
        mcr.localnumber,
        mcr.cdc_reportable,
        mcr.elr_reportable,
        '~' AS eol  
      FROM &SourceSchema.microcompresponse&DBLink mcr
      WHERE 1=1
        AND mcr.comptype = '&ComponentType' --'Drug'
        AND mcr.compid = '&ComponentID'     --'Imipenem E test'    
      ORDER BY
        mcr.compid ASC,
        mcr.ressorter ASC    
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
      AND T1.response = T2.response
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.compid,
        T1.ressorter,  
        T1.response,
        T1.status,
        T1.interpretation,
        T1.is_negative,
        T1.origsts,
        T1.snomedcode,
        T1.code_system_oid,
        T1.loincnumber,
        T1.hidefromreport,
        T1.localnumber,
        T1.cdc_reportable,
        T1.elr_reportable    
      )
      VALUES (
        T2.comptype,
        T2.compid,
        T2.ressorter,  
        T2.response,
        T2.status,
        T2.interpretation,
        T2.is_negative,
        T2.origsts,
        T2.snomedcode,
        T2.code_system_oid,
        T2.loincnumber,
        T2.hidefromreport,
        T2.localnumber,
        T2.cdc_reportable,
        T2.elr_reportable    
      );
-------------------------------------------------------------------------------





-------04. Micro Panels tab----------------------------------------------------
  -------01. Create Any NEW MicroPanels Asscoiated with new MicroComponent-------

    MERGE INTO &TargetSchema.micropanels T1
    USING (
      SELECT DISTINCT
        mcc.compid, 
        '~' AS sp1,
        mp.comptype,
        mp.panelid,
        mp.panelname,
        mp.origsts
      FROM &SourceSchema.micropanels&DBLink mp
      INNER JOIN &SourceSchema.micropanelcomp&DBLink mcc ON (1=1
        AND mcc.comptype = mp.comptype
        AND mcc.panelid = mp.panelid)    
      WHERE 1=1
        AND UPPER(mp.comptype) = UPPER('&ComponentType')
        AND UPPER(mcc.compid) = UPPER('&ComponentID')
      ORDER BY
        mp.comptype ASC,
        mp.panelid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.panelid = T2.panelid
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.panelid,
        T1.panelname,  
        T1.origsts
      )
      VALUES (
        T2.comptype,
        T2.panelid,
        T2.panelname,  
        T2.origsts
      );
  ------- -------
  
  -------02. Add new MicroComponent to MicroPanels-------

    MERGE INTO &TargetSchema.micropanelcomp T1
    USING (
      SELECT DISTINCT
        mcc.compid,
        mcc.comptype,
        mcc.panelid,
        mcc.origsts
      FROM &SourceSchema.micropanelcomp&DBLink mcc
      WHERE 1=1
        AND UPPER(mcc.comptype) = UPPER('&ComponentType')
        AND UPPER(mcc.compid) = UPPER('&ComponentID')
      ORDER BY
        mcc.comptype ASC,
        mcc.panelid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.panelid = T2.panelid
      AND T1.compid = T2.compid
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.compid,
        T1.comptype,
        T1.panelid,
        T1.origsts
      )
      VALUES (
        T2.compid,
        T2.comptype,
        T2.panelid,
        T2.origsts
      );
  ------- -------
  
  -------03. Create Any NEW MicroConditions If Needed for new MicroComponent-------

    MERGE INTO &TargetSchema.microconditions T1
    USING (
      SELECT DISTINCT
        mcc.compid,
        '~' AS sp1,
        mc.condition,
        mc.origsts
      FROM &SourceSchema.micropanelconditions&DBLink mpc
        INNER JOIN &SourceSchema.micropanels&DBLink mp ON (mpc.panelid = mp.panelid)
        INNER JOIN &SourceSchema.micropanelcomp&DBLink mcc ON (1=1
          AND mcc.comptype = mp.comptype
          AND mcc.panelid = mp.panelid)
        INNER JOIN &SourceSchema.microconditions&DBLink mc ON (mpc.condition = mc.condition)
      WHERE 1=1
          AND UPPER(mpc.comptype) = UPPER('&ComponentType')
          AND UPPER(mcc.compid) = UPPER('&ComponentID')
      ORDER BY
        mc.condition ASC,
        mcc.compid ASC
    ) T2
    ON ( 1=1
      AND T1.condition = T2.condition
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.condition,
        T1.origsts
      )
      VALUES (
        T2.condition,
        T2.origsts
      );
   ------- -------

  -------04. Associate MicroPanels with New MicroComponent to MicroPanelCondition-------

    MERGE INTO &TargetSchema.micropanelconditions T1
    USING (
      SELECT DISTINCT
        mcc.compid,
        '~' AS sp1,
        mpc.comptype,
        mpc.condition,
        mpc.panelid,
        mpc.origsts
      FROM &SourceSchema.micropanelconditions&DBLink mpc
        INNER JOIN &SourceSchema.micropanels&DBLink mp ON (mpc.panelid = mp.panelid)
        INNER JOIN &SourceSchema.micropanelcomp&DBLink mcc ON (1=1
          AND mcc.comptype = mp.comptype
          AND mcc.panelid = mp.panelid)    
      WHERE 1=1
          AND UPPER(mpc.comptype) = UPPER('&ComponentType')
          AND UPPER(mcc.compid) = UPPER('&ComponentID')
      ORDER BY
        mpc.comptype ASC,
        mpc.panelid ASC,        
        mcc.compid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.panelid = T2.panelid
      AND T1.condition = T2.condition
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.condition,
        T1.panelid,
        T1.origsts
      )
      VALUES (
        T2.comptype,
        T2.condition,
        T2.panelid,
        T2.origsts
      );
  ------- -------
-------------------------------------------------------------------------------





------05. Quality Control tab--------------------------------------------------

    MERGE INTO &TargetSchema.microqccontrols T1
    USING (
      SELECT DISTINCT
        mq.compid,
        mq.qctype,
        mq.comptype,
        mq.expectedresponse,
        mq.matcode,
        mq.matquantity,
        mq.units,
        mq.origsts,
        mq.frequency,
        mq.organism,
        mq.is_default,
        mq.strainno
      FROM &SourceSchema.microqccontrols&DBLink mq
      WHERE 1=1
          AND UPPER(mq.comptype) = UPPER('&ComponentType')
          AND UPPER(mq.compid) = UPPER('&ComponentID')
      ORDER BY
        mq.comptype ASC,
        mq.compid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
      AND T1.qctype = T2.qctype
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.compid,
        T1.qctype,
        T1.comptype,
        T1.expectedresponse,
        T1.matcode,
        T1.matquantity,
        T1.units,
        T1.origsts,
        T1.frequency,
        T1.organism,
        T1.is_default,
        T1.strainno
      )
      VALUES (
        T2.compid,
        T2.qctype,
        T2.comptype,
        T2.expectedresponse,
        T2.matcode,
        T2.matquantity,
        T2.units,
        T2.origsts,
        T2.frequency,
        T2.organism,
        T2.is_default,
        T2.strainno
      );
-------------------------------------------------------------------------------





-------06. Reagents tab--------------------------------------------------------
 
    MERGE INTO &TargetSchema.microcompreagents T1
    USING (
      SELECT DISTINCT
        mcr.comptype,
        mcr.compid,
        mcr.matcode,
        mcr.matquantity,
        mcr.units,
        mcr.origsts
      FROM &SourceSchema.microcompreagents&DBLink mcr
      WHERE 1=1
          AND UPPER(mcr.comptype) = UPPER('&ComponentType')
          AND UPPER(mcr.compid) = UPPER('&ComponentID')
      ORDER BY
        mcr.comptype ASC,
        mcr.compid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
      AND T1.matcode = T2.matcode
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.compid,
        T1.matcode,
        T1.matquantity,
        T1.units,
        T1.origsts
      )
      VALUES (
        T2.comptype,
        T2.compid,
        T2.matcode,
        T2.matquantity,
        T2.units,
        T2.origsts
      );
      
-------------------------------------------------------------------------------





-------07. LOINC tab-----------------------------------------------------------

    MERGE INTO &TargetSchema.microcomploinc T1
    USING (
      SELECT DISTINCT
        mcl.comptype,
        mcl.compid,
        mcl.loinccomponenet,
        mcl.loincshortname,
        mcl.codestatus,
        mcl.loincmethod,
        mcl.loincnumber,
        mcl.loincproperty,
        mcl.loincscale,
        mcl.loincsystems,
        mcl.loinctime,
        mcl.version,
        mcl.loincdefault,
        mcl.code_system_oid,
        mcl.origsts,
        '~' AS eol
      FROM &SourceSchema.microcomploinc&DBLink mcl
      WHERE 1=1
          AND UPPER(mcl.comptype) = UPPER('&ComponentType')
          AND UPPER(mcl.compid) = UPPER('&ComponentID')
      ORDER BY
        mcl.comptype ASC,
        mcl.compid ASC,
        mcl.loinccomponenet ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
      AND T1.loincnumber = T2.loincnumber
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.compid,
        T1.loinccomponenet,
        T1.loincshortname,
        T1.codestatus,
        T1.loincmethod,
        T1.loincnumber,
        T1.loincproperty,
        T1.loincscale,
        T1.loincsystems,
        T1.loinctime,
        T1.version,
        T1.loincdefault,
        T1.code_system_oid,
        T1.origsts
      )
      VALUES (
        T2.comptype,
        T2.compid,
        T2.loinccomponenet,
        T2.loincshortname,
        T2.codestatus,
        T2.loincmethod,
        T2.loincnumber,
        T2.loincproperty,
        T2.loincscale,
        T2.loincsystems,
        T2.loinctime,
        T2.version,
        T2.loincdefault,
        T2.code_system_oid,
        T2.origsts
      );  
-------------------------------------------------------------------------------





-------07. Equipment tab--------------------------------------------------------
  
    MERGE INTO &TargetSchema.microcompequipments T1
    USING (
      SELECT DISTINCT
        mce.comptype,
        mce.compid,
        mce.eqtype,
        mce.eqid,
        mce.origsts,
        '~' AS eol
      FROM &SourceSchema.microcompequipments&DBLink mce
      WHERE 1=1
          AND UPPER(mce.comptype) = UPPER('&ComponentType')
          AND UPPER(mce.compid) = UPPER('&ComponentID')
      ORDER BY
        mce.comptype ASC,
        mce.compid ASC,
        mce.eqid ASC
    ) T2
    ON ( 1=1
      AND T1.comptype = T2.comptype
      AND T1.compid = T2.compid
      AND T1.eqtype = T2.eqtype
      AND T1.eqid = T2.eqid
       )
    WHEN NOT MATCHED THEN
      INSERT (
        T1.comptype,
        T1.compid,
        T1.eqtype,
        T1.eqid,
        T1.origsts
      )
      VALUES (
        T2.comptype,
        T2.compid,
        T2.eqtype,
        T2.eqid,
        T2.origsts
      );        

-------------------------------------------------------------------------------


-------xx. Next Item tab-------------------------------------------------------
  ------- -------
  ------- -------
-------------------------------------------------------------------------------

