/*=================================================================*/
/*=====RenameMicroComponentID======================================*/
  -----Description-----
    --Utilize these scripts to change an MicroComponent ID.
    --The following tables will need to be updated:
      --001: [MICROCOMPONENTS].COMPID
      --002: [MICROCOMPREAGENTS].COMPID
      --003: [MICROCOMPRESPONSE].COMPID
      --004: [MICROPANELCOMP].COMPID
      --005: [MICROTASKREAGENTS].COMPID
      --006: [MICROTASKSTEPS].COMPID        
    
    --Script Location: \\HSPHXVSTRLMS03\Starlims Online Help\SQL Repository\Version10\UpdateScripts\RenameMicroComponentID.sql
  -----
  
  -----Environment-----
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod  
  -----
  
  -----History-----
    --2014.10.03 JTY: Created script
  -----
/*=================================================================*/


/*=====Scripts to update MicroComponent_ID=========================*/

/*-----Review Tables to be updated---------------------------------*/  
  --MiocroComponent ID & Name review

  ---01. [MICROCOMPONENTS]---
  SELECT DISTINCT
    '&Environment' AS environment,
    mc.origrec,
    mc.comptype,
    mc.compid,
    mc.compname,
    '~' AS eol
    FROM &Environment.MicroComponents mc 
    WHERE 1=1 
      --AND mc.comptype = '&ComponentType'
      AND (
        mc.compid IN ('&OldComponentID', '&NewComponentID')
          )
    ORDER BY
      mc.comptype ASC,
      mc.compid ASC;
  ---

  ---02. [MICROCOMPREAGENTS]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mcr.origrec,
    mcr.comptype,
    mcr.compid,
    '~' AS eol
    FROM &Environment.MicroCompReagents mcr
    WHERE 1=1 
      AND (mcr.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mcr.comptype ASC,
      mcr.compid ASC;    
  ---
  
  ---03. [MICROCOMPRESPONSE]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mcr.origrec,
    mcr.comptype,
    mcr.compid,
    mcr.ressorter,
    mcr.response,
    '~' AS eol
    FROM &Environment.MicroCompResponse mcr
    WHERE 1=1 
      AND (mcr.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mcr.comptype ASC,
      mcr.compid ASC,
      mcr.ressorter ASC,
      mcr.response ASC;
  ---
  
  ---04. [MICROPANELCOMP]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mpc.origrec,
    mpc.comptype,
    mpc.panelid,
    mpc.compid,
    '~' AS eol
    FROM &Environment.MicroPanelComp mpc
    WHERE 1=1 
      AND (mpc.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mpc.comptype ASC,
      mpc.panelid ASC,
      mpc.compid ASC;
  ---  
  
  ---05. [MICROTASKREAGENTS]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mtr.origrec,
    mtr.comptype,
    mtr.compid,
    mtr.ordno,
    '~' AS eol
    FROM &Environment.MicroTaskReagents mtr
    WHERE 1=1 
      AND (mtr.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mtr.comptype ASC,
      mtr.compid ASC,
      mtr.ordno ASC;
  ---    

  ---06. [MICROTASKSTEPS]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mts.origrec,
    mts.comptype,
    mts.compid,
    mts.ordno,
    mts.stepcode,
    mts.res01,
    '~' AS eol
    FROM &Environment.MicroTaskSteps mts
    WHERE 1=1 
      AND (mts.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mts.comptype ASC,
      mts.compid ASC,
      mts.ordno ASC,
      mts.stepcode ASC,
      mts.res01 ASC;
  ---

  ---07. [MICROQCCONTORLS]---      
  SELECT DISTINCT
    '&Environment' AS environment,
    mqc.origrec,
    mqc.comptype,
    mqc.compid,
    mqc.expectedresponse,
    '~' AS eol
    FROM &Environment.MicroQcControls mqc
    WHERE 1=1 
      AND (mqc.compid IN ('&OldComponentID', '&NewComponentID'))
    ORDER BY
      mqc.comptype ASC,
      mqc.compid ASC,
      mqc.expectedresponse ASC;
  ---      
  
/*-----------------------------------------------------------------*/  



/*-----Change Component_ID-----------------------------------------*/  
  --Run these scripts one at a time to update database.  This way
  --we can roll-back changes if we have a problem.
  
/*  
  
  
  ---Disable Constraints---
    ALTER TABLE &Environment.MicroCompReagents 
        DISABLE CONSTRAINT FK_MICROCOMPREA_MICROCOMPONE01;
    ALTER TABLE &Environment.MicroCompReagents 
        DISABLE CONSTRAINT FK_MICROCOMPREA_MICROCOMPONE01;
    ALTER TABLE &Environment.MicroCompResponse
        DISABLE CONSTRAINT FK_MICROCOMPRES_MICROCOMPONE01;        
    ALTER TABLE &Environment.MicroPanelComp 
        DISABLE CONSTRAINT FK_MICROPANELCO_MICROCOMPONE02;
    ALTER TABLE &Environment.MicroQcControls 
        DISABLE CONSTRAINT FK_MICROQCCONTR_MICROCOMPONE01;
  ---  


  ---01. [MicroComponents]---
    UPDATE &Environment.MicroComponents mc   
    SET
      mc.compid = '&NewComponentID'
    WHERE 1=1
      AND mc.comptype = '&ComponentType'
      AND (mc.compid IN ('&OldComponentID', '&NewComponentID'));
  --- 
  ---02. [MicroCompReagents]---   
    UPDATE &Environment.MicroCompReagents mcr   
    SET
      mcr.compid = '&NewComponentID'
    WHERE 1=1
      AND mcr.comptype = '&ComponentType'
      AND (mcr.compid IN ('&OldComponentID', '&NewComponentID'));
  ---
  ---03. [MicroCompResponse]---   
    UPDATE &Environment.MicroCompResponse mcr  
    SET
      mcr.compid = '&NewComponentID'
    WHERE 1=1
      AND mcr.comptype = '&ComponentType'
      AND (mcr.compid IN ('&OldComponentID', '&NewComponentID'));
  ---
  ---04. [MicroPanelComp]---   
    UPDATE &Environment.MicroPanelComp mpc  
    SET
      mpc.compid = '&NewComponentID'
    WHERE 1=1
      AND mpc.comptype = '&ComponentType'
      AND (mpc.compid IN ('&OldComponentID', '&NewComponentID'));
  ---
  ---05. [MicroTaskReagents]---   
    UPDATE &Environment.MicroTaskReagents mtr  
    SET
      mtr.compid = '&NewComponentID'
    WHERE 1=1
      AND mtr.comptype = '&ComponentType'
      AND (mtr.compid IN ('&OldComponentID', '&NewComponentID'));
  ---
  ---06. [MicroTaskSteps]---   
    UPDATE &Environment.MicroTaskSteps mts 
    SET
      mts.compid = '&NewComponentID'
    WHERE 1=1
      AND mts.comptype = '&ComponentType'
      AND (mts.compid IN ('&OldComponentID', '&NewComponentID'));
  ---
  ---07. [MicroQcControls]---   
    UPDATE &Environment.MicroQcControls mqc 
    SET
      mqc.compid = '&NewComponentID'
    WHERE 1=1
      AND mqc.comptype = '&ComponentType'
      AND (mqc.compid IN ('&OldComponentID', '&NewComponentID'));
  ---



  ---Enable Constraints---
    ALTER TABLE &Environment.MicroCompReagents 
        ENABLE CONSTRAINT FK_MICROCOMPREA_MICROCOMPONE01;
    ALTER TABLE &Environment.MicroCompResponse
        ENABLE CONSTRAINT FK_MICROCOMPRES_MICROCOMPONE01;        
    ALTER TABLE &Environment.MicroPanelComp 
        ENABLE CONSTRAINT FK_MICROPANELCO_MICROCOMPONE02;
    ALTER TABLE &Environment.MicroQcControls 
        ENABLE CONSTRAINT FK_MICROQCCONTR_MICROCOMPONE01;
  ---  

*/

  
/*-----------------------------------------------------------------*/  
/*=================================================================*/


  


/*=====Misc SQL ====================================================*/
  --This is where we are keeping misc code that might be needed.
 
/*=================================================================*/
