/*---------------------------------------------------------------------------*/
/*-----SecureEmail-----------------------------------------------------------
    ---DESCRIIPTION---
      Utilize this set of scripts related to secure email actions.
      The following scripts are included:
        01. Assign PDF Password - Generate PDF password for client encrypted 
            PDF files.
        02. Review any reports sent via Email to clients
        20. Identify Active Samples for identified Client
        30. Udate Delivery Method for Existing Samples
        31. Report Delivery Queue Update
        
        
    --- ---
  
    ---HISTORY---
      2017.02.13 JTY: Created script
      2017.04.07 JTY: Script Cleanup
    --- ---
-----------------------------------------------------------------------------*/




/*-----01. Assign PDF Password----------------------------------------------*/
  --Gnerate password to be stored in the URL field of the [Client List] 
  --application to be used for the password for encrypted PDF files.
/*
  UPDATE &Environment.rasclients rc
  SET
    rc.url = (
      rc.rasclientid || '_' ||
      DBMS_RANDOM.STRING('L',3)    
    )
  WHERE 1=1
    AND rc.rasclientid = '&RasClientID'
*/
/*---------------------------------------------------------------------------*/


/*-----02. Review any reports sent via Email to clients----------------------*/
/*  
  SELECT DISTINCT
    rdq.rasclientid,
    rdq.dept,
    f.external_id,
    rdq.testgroupname,
    rdh.sent_date,
    rdq.delivery_method,
    rdq.status,
    rdq.delivery_address,
    '~' AS sp1,
    rdq.batch_id,
    rdq.queue_item_no,
    (rc.compname || '(' || rdq.rasclientid || ')' ) AS client,
    rcx.fullname,
    (cr.last_name || ', ' || cr.first_name) AS patient_name,
    f.apprdate,
    rdq.extra_info,    
    '~' AS eol
  FROM &Environment.rr_report_delivery_queue rdq
    INNER JOIN &Environment.rasclients rc ON (rdq.rasclientid = rc.rasclientid)
    INNER JOIN &Environment.rasclientcontactsext rcx ON (1=1
      AND rdq.rasclientid = rcx.rasclientid
      AND rdq.contactid = rcx.contactid)
    INNER JOIN &Environment.folders f ON (rdq.folderno = f.folderno)
    INNER JOIN &Environment.centralreceiving cr ON (f.external_id = cr.external_id)
    INNER JOIN &Environment.rr_rdq_history rdh ON (rdh.queue_item_no = rdq.queue_item_no)
  WHERE 1=1
    AND rdq.rasclientid = '&RasClientID'
    AND rdq.delivery_method = 'E-mail'
    AND rdh.sent_date = to_date('&SendDate', 'DD-MON-YY')
  ORDER BY
    rdq.rasclientid ASC,
    rdq.dept ASC,
    f.external_id ASC,
    rdq.batch_id DESC,
    rdq.queue_item_no ASC
*/
/*---------------------------------------------------------------------------*/



/*-----20. Identify Active Samples for identified Client----------------------*/
  --Identify active samples for identified client(s) if you want to switch them
  --to Secure eMail delivery.
/*
    SELECT DISTINCT
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      f.folderno,
      f.dept,
      f.testgroupname AS panel,
      '~' AS eol
    FROM sundata_prod.centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc. rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
    WHERE 1=1
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
      AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
      AND rc.rasclientid = '&RasClientID'  ---CLIENT(s) OF INTEREST HERE---
      AND (f.apprdate IS NULL OR fc.approveddate IS NULL)
    ORDER BY
      client ASC,
      f.dept ASC,
      f.folderno ASC
*/
/*---------------------------------------------------------------------------*/


/*-----30. Update Delivery Method for Existing Samples------------------------*/
  --Update delivery method for active samples in system to match the Exetrnal
  --Contact as defined in the Client List application.  This should be used when
  --a Client has just converted over to a new delivery method, and you want to sync
  --existing samples in the system with this new method.  
  --
  /*
  MERGE INTO sundata_prod.folderscontactsext t1
  USING (
    SELECT DISTINCT
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      f.dept,
      fcx.folderno,
      f.testgroupname AS panel,
      fcx.contactid,
      fcx.submit_method,
      rcx.submit_method AS rcx_submit_method,
      rcx.fax AS rcx_fax,
      fcx.rasclientid,
      fcx.origrec AS fcx_origrec,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc. rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
      INNER JOIN folderscontactsext fcx ON (1=1
        AND fcx.folderno = f.folderno
        AND fcx.rasclientid = rcx.rasclientid
        AND fcx.contactid = rcx.contactid)
    WHERE 1=1
      AND (rcx.submit_method <> fcx.submit_method)
      AND rc.rasclientid = '&RasClientID'  ---CLIENT(s) OF INTEREST HERE---
      AND (f.apprdate IS NULL OR fc.approveddate IS NULL)
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
    ORDER BY
      client ASC,
      f.dept ASC,
      fcx.folderno ASC  
  ) t2
  ON (1=1
    AND t1.origrec = t2.fcx_origrec
    AND t1.folderno = t2.folderno 
    AND t1.rasclientid = t2.rasclientid
    AND t1.contactid = t2.contactid
  )    
  WHEN MATCHED THEN
    UPDATE SET
      t1.submit_method = rcx_submit_method
*/      
/*---------------------------------------------------------------------------*/

/*-----31. Report Delivery Queue Update--------------------------------------*/
  --Update RDQ to utlize Delivery method as defined by the ExternalContact
  --info in the Client List application for the identified Client.
  --This can also be used if the FaxNumber, EmailAddress or DeliveryMethod 
  --has changed, as defined for the external client in the Client List 
  --application, and you want to sinc existing samples with the new number.
/*
  MERGE INTO sundata_prod.rr_report_delivery_queue t1
  USING (
    SELECT DISTINCT
      (rc.compname || ' (' || rc.rasclientid || ')') AS client,
      f.dept,
      rdq.folderno,
      rdq.status,
      rcx.fullname,
      rcx.contactid,
      rcx.submit_method AS rcx_method,
      rcx.fax AS rcx_address,
      rdq.delivery_method,
      ci.itemid AS distribution_method,
      rdq.delivery_address,
      rdq.origrec AS rdq_origrec,
      rc.rasclientid,
      '~' AS eol
    FROM rr_report_delivery_queue rdq
      INNER JOIN folders f ON (rdq.folderno = f.folderno)
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (1=1
        AND rdq.rasclientid = rcx.rasclientid
        AND rdq.contactid = rcx.contactid)
      INNER JOIN rr_categoryitems ci ON (1=1
        AND ci.itemname = 'Default Email Config')
    WHERE 1=1
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
      AND (
        (rdq.delivery_method <> rcx.submit_method )
        OR (rdq.delivery_address <> rcx.fax )
      )
      AND rdq.status = 'QUEUED'
      AND rdq.rasclientid = '&RasClientID'      
    ORDER BY
      client ASC,
      f.dept ASC,
      rdq.folderno ASC
  ) t2
  ON (1=1
    AND t1.origrec = t2.rdq_origrec
    AND t1.rasclientid = t2.rasclientid
    AND t1.contactid = t2.contactid
    AND t1.folderno = t2.folderno
  )    
  WHEN MATCHED THEN
    UPDATE SET
      t1.delivery_method = t2.rcx_method,
      t1.delivery_address = t2.rcx_address,
      t1.itemid = t2.distribution_method
*/
/*---------------------------------------------------------------------------*/
