
/*-----------------------------------------------------------------*/
/*=====PermissionsAccessUpdate=====================================*/
  /*----------Summary----------*/
    --This set of queries can be utilized to add/update access to 
    --variouse components of the STARLIMS application.  The access
    --is controled in the [uac_rights] table.
    --Currently the following scripts are included:
      --1. Base User Accesss Control Query
      --2. Custom QBE Template Access
    
  /*---------- ----------*/  


  /*----------SL10 Environments----------*/
    --DEV:  sunrise_data
    --TEST: sundata_sat
    --PROD: sundata_prod
  /*----------  ----------*/

  /*----------History----------*/
    --2014.05.09 JTY: Created script
  /*---------- ----------*/  

/*-----------------------------------------------------------------*/
/*=================================================================*/




/*=====1. Base User Accesss Control Query==========================*/
  --Presented here is a basline query that can be used as inital 
  --inspection of User Access Control for various objects within the
  --STARLIMS application.

     SELECT DISTINCT
       acr.resource_type,
       acr.resource_name,
       acr.permission,
       acr.access_type,
       acr.entity_type,
       acr.entity_id,
       (COALESCE(r.role, u.fullname)) AS entity_name,
       '~' AS eol
     FROM &Environment.uac_rights acr 
       LEFT OUTER JOIN &Environment.roles r ON (acr.entity_type = 'ROLE' AND acr.entity_id = r.Treeauth)
       LEFT OUTER JOIN &Environment.users u ON (acr.entity_type = 'USER' AND acr.entity_id = u.usrnam)   
     WHERE 1=1
--       AND acr.resource_type = '&ResourceType'  --QBE_TEMPLATE
--       AND acr.resource_name = '&ResourceName'  --AdhsRej1
--       AND acr.entity_type = '&EntityType'      --USER,ROLE
--       AND COALESCE(r.role, u.fullname) = '&EntityName'
     ORDER BY
       acr.resource_type ASC,
       acr.resource_name ASC,
       acr.permission ASC,
       acr.access_type ASC,
       acr.entity_id ASC; 
/*=================================================================*/




/*=====2. Custom QBE Template Access==============================*/
  --DESCRIPTON--
    --Use these queries to identify user custom QBE templates amd
    --grant duplicate access to the templates for the identified
    --user.
    --The following scripts are included:
      --1. Review QBE Template Access
      --2. Grant QBE Template Access
      --3. Remove QBE Template Access
  --
  /*----------1. Review QBE Template Access----------*/
    --Modify this query to identify and review QBE objects
    --and asscoiated permissions.
/*      
     SELECT DISTINCT
       u.usrnam,
       u.fullname,
       qt.name,
       qt.qbetemplateid,
       qt.author,
       qt.description,
       acr.permission,
       acr.access_type,
       acr.entity_type,
       acr.entity_id,
       '~' AS eol
     FROM &Environment.uac_rights acr 
       LEFT OUTER JOIN &Environment.roles r ON (acr.entity_type = 'ROLE' AND acr.entity_id = r.Treeauth)
       LEFT OUTER JOIN &Environment.users u ON (acr.entity_type = 'USER' AND acr.entity_id = u.usrnam)   
       LEFT OUTER JOIN &Environment.Qbetemplates qt ON (acr.resource_name = qt.qbetemplateid)       
     WHERE 1=1
       AND UPPER(acr.resource_type) = UPPER('QBE_TEMPLATE')
       AND UPPER(qt.qbetemplateid) = UPPER('&QbeTemplateID')
--       AND UPPER(u.usrnam) = UPPER('&UserID')
--       AND UPPER(qt.author) = UPPER('&AurthorID')
     ORDER BY
       u.usrnam ASC,
       qt.qbetemplateid ASC,
       acr.entity_id ASC,
       acr.permission ASC,
       acr.access_type ASC;   
*/       
  /*---------- ----------*/
  
  /*----------2. Grant QBE Template Access----------*/
    --This query will duplicate permissions to the identified
    --QBEquery for the Identified person.
    --The following Parameters are provided:
      --Environment: The database environment
      --QqeTemplateID: The QBE Template ID from the qbetemplates table.
      --SourceUserRights: The UserID who has the permissions we 
          --want to dupliate.
      --NewUserRights: The target user we want to grant right
          --to the identified QBE template.
/*          
    MERGE INTO &Environment.uac_rights t1
    USING (
      SELECT DISTINCT
        qt.qbetemplateid,
        qt.name,
        --Values for entry--
          ur.origsts,
          ur.resource_type,
          ur.resource_name,
          ur.permission,
          ur.access_type,
          ur.entity_type,
          ur.entity_id,
          UPPER('&NewUserRights') AS add_entity_id,
        --
        '~' AS eol
      FROM &Environment.uac_rights ur
        INNER JOIN &Environment.Qbetemplates qt ON (
            ur.resource_name = qt.qbetemplateid)
      WHERE 1=1
        AND UPPER(ur.resource_type) = UPPER('QBE_TEMPLATE')
        AND UPPER(qt.qbetemplateid) = UPPER('&QqeTemplateID')
        AND UPPER(ur.entity_id) IN (
            UPPER('&SourceUserRights'), UPPER('&NewUserRights'))
      ORDER BY
        ur.resource_type ASC,
        ur.resource_name ASC,
        ur.entity_id ASC
          ) t2
    ON ( 1=1
      AND t1.resource_type = t2.resource_type
      AND t1.resource_name = t2.resource_name
      AND t1.permission = t2.permission
      AND t1.access_type = t2.access_type
      AND t1.entity_type = t2.entity_type
      AND t1.entity_id = t2.add_entity_id
       )
    WHEN NOT MATCHED THEN
      INSERT (
        t1.origsts, t1.resource_type, t1.resource_name,
        t1.permission, t1.access_type, t1.entity_type,
        t1.entity_id
             )
      VALUES (
        t2.origsts, t2.resource_type, t2.resource_name,
        t2.permission, t2.access_type, t2.entity_type,
        t2.add_entity_id
             );     
*/              
  /*---------- ----------*/  

  /*----------3. Remove QBE Template Access----------*/
    --This query will duplicate permissions to the identified
    --QBEquery for the Identified person.
    --The following Parameters are provided:
      --Environment: The database environment
      --QqeTemplateID: The QBE Template ID from the qbetemplates table.
      --SourceUserRights: The UserID who has the permissions we 
          --want to dupliate.
      --RemoveUserRights: The target user we want to remove the
          --rights to the identified objedct.
/*          
    MERGE INTO &Environment.uac_rights t1
    USING (
      SELECT DISTINCT
        ur.origrec,
        qt.qbetemplateid,
        qt.name,
        --Values for entry--
          ur.origsts,
          ur.resource_type,
          ur.resource_name,
          ur.permission,
          ur.access_type,
          ur.entity_type,
          ur.entity_id,
          UPPER('&RemoveUserRights') AS delete_entity_id,
        --
        '~' AS eol
      FROM &Environment.uac_rights ur
        INNER JOIN &Environment.Qbetemplates qt ON (
            ur.resource_name = qt.qbetemplateid)
      WHERE 1=1
        AND UPPER(ur.resource_type) = UPPER('QBE_TEMPLATE')
        AND UPPER(qt.qbetemplateid) = UPPER('&QqeTemplateID')
        AND UPPER(ur.entity_id) = ( UPPER('&RemoveUserRights'))
      ORDER BY
        ur.resource_type ASC,
        ur.resource_name ASC,
        ur.entity_id ASC
          ) t2
    ON (t1.origrec = t2.origrec)
    WHEN MATCHED THEN
      UPDATE SET t1.origsts = 'D'
      DELETE WHERE (1=1
        AND t1.resource_type = t2.resource_type
        AND t1.resource_name = t2.resource_name
        AND t1.permission = t2.permission
        AND t1.access_type = t2.access_type
        AND t1.entity_type = t2.entity_type
        AND t1.entity_id = t2.delete_entity_id
       );
*/
  /*---------- ----------*/  

/*=================================================================*/  
