
/*-----UserRetirementScripts-------------------------------------------------*/
  -----DESCRIPTION-----
    --This set of scripts can be run periodically to update th database for
    --retired users as clean-up to ensure they cannot perform task in STARLiMS
  ----- -----
  
  
  -----Scripts-----
    --01. Remove Retired from Panel Responsibility
    --02. Remove From Site Storage Locations
    --03. Remove From Site Members List
    --04. Remove Access TO QBE Objects
    --05. Review User Access To Objects
  ----- -----
  
  -----COMMENTS-----
  ----- -----    
  
  -----HISTORY-----
    --2015.02.02 JTY: Created Script
  ----- ----- 
/*---------------------------------------------------------------------------*/



/*-----01. Remove Retired from Panel Responsibility--------------------------*/
  --This script will identify and remove all Retired users from the 
  --Responsible list for panels.
/* 
    MERGE INTO &Environment.testgroup_users t1
    USING (
    ---CORE QUERY---    
      SELECT DISTINCT
          ctt.dept,
          tgn.testgroupname AS Panel,
          tgn.status,
          tgu.usrnam,
          'N' AS origsts,
          '1' AS appr_level,
          'N' AS appr_required,
          tgu.origrec,
        '~' AS eol
      FROM &Environment.testgroupnames tgn    
        INNER JOIN &Environment.conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
        INNER JOIN &Environment.tests t ON (ctt.testcode = t.testcode)
        INNER JOIN &Environment.Testgroup_Users tgu ON (tgn.testgroupname = tgu.testgroupname) 
        INNER JOIN &Environment.users u ON (tgu.usrnam = u.usrnam)
      WHERE 1=1
        AND u.status = 'Retired'
      ORDER BY 
          ctt.dept ASC,
          tgn.testgroupname ASC,
          tgu.usrnam ASC
    ---          
     ) t2
     ON (1=1
         AND t1.testgroupname = t2.Panel
         AND t1.usrnam = t2.usrnam)
     WHEN MATCHED THEN
       UPDATE SET t1.appr_required = t1.appr_required
       DELETE WHERE ( 1=1
         AND t1.origrec = t2.origrec)
*/         
/*---------------------------------------------------------------------------*/





/*-----02. Remove From Site Storage Locations--------------------------------*/
  --Remove access to any storage locations
/*  
  MERGE INTO &Environment.benchlocations t1
  USING (
    ---CORE QUERY---
    SELECT DISTINCT
    u.usrnam,
    u.fullname,
    bl.locationcode,
    bl.modifyflag,
    bl.origsts,
    u.status,
    bl.origrec,
    '~' AS eol
    FROM &Environment.benchlocations bl
      INNER JOIN &Environment.users u ON (bl.usrnam = u.usrnam)
    WHERE 1=1
      AND u.status = 'Retired'
    ORDER BY
      u.usrnam ASC,
      bl.locationcode ASC  
    ---
  ) t2
  ON (1=1
      AND t1.usrnam = t2.usrnam
      AND t1.locationcode = t2.locationcode
     )
     WHEN MATCHED THEN
       UPDATE SET t1.origsts = t1.origsts
       DELETE WHERE t1.origrec = t2.origrec;
*/
/*---------------------------------------------------------------------------*/





/*-----03. Remove From Site Members List-------------------------------------*/
  --Remove access to any storage locations
/*  
  MERGE INTO &Environment.servganalyst t1
  USING (
    ---CORE QUERY---
    SELECT DISTINCT
    u.usrnam,
    u.fullname,
    u.status,
    sga.dept,
    sga.leader,
    sga.servgrp,
    sga.origsts,
    sga.origrec,
    '~' AS eol
    FROM &Environment.servganalyst sga
      INNER JOIN &Environment.users u ON (sga.usrnam = u.usrnam)
    WHERE 1=1
      AND u.status = 'Retired'
    ORDER BY
      u.usrnam ASC,
      sga.servgrp ASC
    ---
  ) t2
  ON (1=1
      AND t1.usrnam = t2.usrnam
      AND t1.servgrp = t2.servgrp
     )
     WHEN MATCHED THEN
       UPDATE SET t1.origsts = t1.origsts
       DELETE WHERE t1.origrec = t2.origrec;
*/
/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/*-----04. Remove Access TO QBE Objects--------------------------------------*/
  --Remove access to any storage locations.  Getting ORA-08006 error when
  --attempting to run this script, not sure what that's about.

  --delete from sundata_prod.uac_rights uac WHERE uac.origrec IN ('6588','6589','2888','2889')

/*  
  MERGE INTO &Environment.uac_rights t1
  USING (
    ---CORE QUERY---
    SELECT DISTINCT
    u.usrnam,
    u.fullname,
    u.status,
    uac.resource_type,
    uac.resource_name,
    uac.permission,
    uac.access_type,
    uac.entity_type,
    uac.entity_id,
    uac.origrec,
    '~' AS eol
    FROM &Environment.uac_rights uac
      INNER JOIN &Environment.users u ON (uac.entity_id = u.usrnam)
    WHERE 1=1
      AND u.status = 'Retired'
      AND uac.entity_type = 'USER'
      AND uac.resource_type = 'QBE_TEMPLATE'
    ORDER BY
      u.usrnam ASC,
      uac.resource_type ASC,
      uac.resource_name
    ---
  ) t2
  ON (1=1
      AND t1.resource_type = t2.resource_type
      AND t1.entity_type = t2.entity_type
      AND t1.entity_id = t2.usrnam
     )
     WHEN MATCHED THEN
       UPDATE SET t1.origsts = t1.origsts
       DELETE WHERE t1.origrec = t2.origrec;
*/
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
/*-----05. Review User Access To Objects-------------------------------------*/
  --Review access to objects for retired users
/*  
    SELECT DISTINCT
    u.usrnam,
    u.fullname,
    u.status,
    uac.resource_type,
    uac.resource_name,
    uac.permission,
    uac.access_type,
    uac.entity_type,
    uac.entity_id,
    '~' AS eol
    FROM &Environment.uac_rights uac
      INNER JOIN &Environment.users u ON (uac.entity_id = u.usrnam)
    WHERE 1=1
      AND u.status = 'Retired'
    ORDER BY
      u.usrnam ASC,
      uac.resource_type ASC,
      uac.resource_name
*/      
/*---------------------------------------------------------------------------*/
