/*-----------------------------------------------------------------*/     
/*-----DefaultTest Config Information------------------------------*/
  /*----------Summary----------*/
    --Queries to retreive information from STARLiMS related to the
    --test configuration.  Queries Include:
      --00-01 General And Panel Information
      --02. Test Information
      --03. Analyte(s) Information
      --04. Test Reagents
      --05. Test Possible Results (P.R.)
      --06. Canned Comments (CC)
      --07. Triggers
      --08. Specifications
      --09. Equipment Setup
  /*---------- ----------*/  

  /*----------History----------*/
    --2020.05.23 JTY: Updated for V3 of specifications form.  
    --2019.12.09 JTY: Updated for changes in V12 tables
    --....Time Between....
    --2018.02.21 JTY: Begin script creation
  /*---------- ----------*/  

/*-----------------------------------------------------------------*/






/*-----------------------------------------------------------------*/

/*-----00-01 General And Panel Information-------------------------*/
  --Section 01.General Information
  --Section 02. Panel Information

  SELECT
      '~GeneralInfo~' AS general_info,
      ctt.dept,
      t.testno,
      '~PanelInfo~' AS panel_info,
      cta.testgroupname AS panel,
      'N' AS new_panel,
      ctt.defaultselect,
      rrr.reportname AS report_name,
    '~' AS eol
  FROM conditiontesttriggers ctt
    INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
    INNER JOIN conditiontestanalytes cta ON ( 1=1
      AND ctt.dept = cta.dept
      AND ctt.testcode = cta.testcode
      AND ctt.testgroupname = cta.testgroupname
      AND ctt.method = cta.method)
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
---    
    LEFT OUTER JOIN rr_reportingruleslevels rrl ON (1=1
      AND SUBSTR(rrl.caption, 10) = cta.testgroupname)     
    LEFT OUTER JOIN rr_reportingrulereports rrr on (1=1
      AND rrl.ruleid = rrr.ruleid
      AND rrl.ruleselectionid = rrr.ruleselectionid)
---    
  WHERE 1=1
    AND tgn.status = 'Active'
    AND t.testno = '&TestName'
  GROUP BY
    ctt.dept,
    cta.testgroupname,
    ctt.defaultselect,
    rrr.reportname,
    t.testno
  ORDER BY 
    ctt.dept ASC,
    t.testno ASC,
    cta.testgroupname ASC;
    
  ---HL7 Reports tab---
        SELECT
          ctt.testgroupname AS panel,
          hm.header_name AS mapping_name,
          rc.rasclientid,
          t.testno,
          hl.analyte,
          hl.loincnumber,
          hl.value_type,
          hl.reportable_condition,
          Coalesce(hl.reportsection, '') AS reportsection,
          '~' AS eol
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN hl7_dist_messages hm ON (ctt.testgroupname = hm.testgroupname)
          LEFT OUTER JOIN hl7_dist_submitters hs ON (ctt.testgroupname = hs.testgroupname)
          INNER JOIN rasclients rc ON (hs.rasclientid = rc.rasclientid)
          LEFT OUTER JOIN hl7_dist_loincs hl ON (1=1
            AND ctt.testgroupname = hl.testgroupname
            AND t.testcode = hl.testcode
            AND hm.header_name = hl.header_name)
        WHERE 1=1
          AND t.testno = '&TestName'
        ORDER BY
          ctt.testgroupname ASC,
          hm.header_name ASC,
          rc.rasclientid ASC;
  --- ---
    
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----02. Test Information----------------------------------------*/
  SELECT DISTINCT
    mrt.dept,
    sp.progname AS program_name,
    t.testcatcode AS "LIBRARY",
    t.testno AS test_name,
    t.testflag AS testing_method,
    --t.testcode,
    mrt.eqtype AS equipment_type,
    mrt.instverify AS instrument_cert,
    mrt.assign_type AS analysts_cert,
    (TRIM(t.holdingtime || ' ' ||  t.holdingtimeunits)) AS holding_time,
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    INNER JOIN methodsrelatedtotests mrt ON (1=1
      AND t.testcode = mrt.testcode)
  WHERE 1=1
    AND (sp.progname IN ('Human', 'LRN-B', 'Ad Hoc', 'Environmental Microbiology', 'Animal'))
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    AND t.testflag = 'Default'
    AND t.testno = '&TestName'
  ORDER BY
    sp.progname ASC,
    t.testcatcode ASC,
    test_name ASC;
/*-----------------------------------------------------------------*/





/*-----03. Analyte(s) Information----------------------------------*/
/*-----------------------------------------------------------------*/
--Need to update test configuration documentation to remove duplicates due to
--multiple panels.
  SELECT
    sp.prodgroup AS "GROUP",
    ctt.dept AS  department,
    ctt.testgroupname AS panel,
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    a.analyte AS analyte_name,
    a.sinonym AS analyte_synonym,
--SchemaGroup
    (scs.specschemagroup || ' / ' || a.schemaname) AS schema_group_name,
    --sa.schemaname,
    CASE a.analtype
     WHEN 'AT' THEN 'AT-Attachment'
     WHEN 'C' THEN 'C-Character'
     WHEN 'MC' THEN 'MC-Multichoice'
     WHEN 'N' THEN 'N-Numeric'
     WHEN 'NP' THEN 'NP-Numeric Prompt'
     WHEN 'SD' THEN 'SD-Single With Details'
     WHEN 'ANALYTE_TYPE' THEN 'ANALYTE_TYPE_TEXT'
     ELSE a.analtype
   END AS data_type,
    a.units,
--    tlc.loinccomponenet AS loinc_report_name,
--    tlc.loincnumber AS loinc_code,
    '--' AS sp2,
    a.sorter,
    '~' AS eol
  FROM tests t
    LEFT OUTER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    LEFT OUTER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
    LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
    LEFT OUTER JOIN testloinccodes tlc ON (1=1
      AND a.testcode = tlc.testcode
      AND a.analyte = tlc.analyte)
    LEFT OUTER JOIN sp_tests st ON (t.testcode = st.testcode)
    LEFT OUTER JOIN sample_programs sp ON (st.sp_code = sp.sp_code)
    LEFT OUTER JOIN spec_sets ss ON (1=1
      AND ss.matcode = sp.matcode
      AND ss.typeofspec = 'PRODSPEC')
    LEFT OUTER JOIN spec_analytes sa ON (1=1
      AND a.testcode = sa.testcode
      AND ss.specno = sa.specno
      AND a.analtype = sa.analtype
      AND a.analyte = sa.analyte)
    LEFT OUTER JOIN specschemas scs ON (a.schemaname = scs.schemaname)   
  WHERE 1=1
    AND tgn.status = 'Active'  
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    AND t.testflag = 'Default'
    AND t.testno = '&TestName'
  ORDER BY
    sp.prodgroup ASC,
    ctt.dept ASC,
    ctt.testgroupname ASC,
    t.testno ASC,
    a.sorter ASC;
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----04. Analyte LOINC Codes-------------------------------------*/
    SELECT
      t.testno,
      t.testcode,
      '~' AS sp1,
      tlc.analyte,
      a.analtype,
      tlc.status,
      tlc.loincnumber,
      tlc.loinccomponenet,
      tlc.version,
      tlc.loincdefault,
      '~' AS sp_1,
      tlc.analyte,
      tlc.loincmethod,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems AS sample_type,
      tlc.loinctime,
      tlc.hl7_reportable,
      tlc.code_system_oid,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
      INNER JOIN analytes a ON (1=1
        AND tlc.testcode = a.testcode 
        AND tlc.analyte = a.analyte)
    WHERE 1=1
      AND tlc.analyte <> 'TESTLOINC'
      AND t.testno = '&TestName'
    ORDER BY
      t.testno ASC,
      t.testcode ASC,
      tlc.analyte,
      tlc.loincnumber ASC;
/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/

/*-----05. Test PR SNOMED CODES: ----------------------------------*/
  --Unique SNOMED Codes associated with test.
      SELECT DISTINCT
        t.testno,
--        pr.result,
        '~' AS sp_1,
        sc.snomedcode,
        sc.snomed_group,
        sc.snomedelement,
        sc.snomedconceptid,
        sc.snomeddescriptionid,
        '~' AS eol
      FROM tests t
        INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
        INNER JOIN snomedcodes sc ON (pr.snomedcode = sc.snomedcode)
      WHERE 1=1
        AND t.testno = '&TestName' 
      ORDER BY
        t.testno ASC,
        sc.snomedcode ASC
      ;        
/*-----------------------------------------------------------------*/





/*-----06. Test Possible Results (P.R.)----------------------------*/
  SELECT DISTINCT
    ctt.dept,
    (t.testno || ' (' || t.testcode || ')' ) AS testname,
    pr.sorter,
    '--' AS sp1,
    pr.analyte,
    pr.snomedcode AS snomed_code,
    pr.result AS possible_result,
    pr.conclusion_report AS reported_as,
    pr.result_status AS status,
    '~' AS eol
  FROM tests t
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
  WHERE 1=1
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    AND t.testflag = 'Default'
    AND t.testno = '&TestName'
  ORDER BY
      ctt.dept ASC,
      UPPER(testname) ASC,
      UPPER(pr.analyte) ASC,
      UPPER(pr.sorter) ASC,
      UPPER(pr.result);
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/





/*-----07-B. SNOMED CODES: For Possible Results----------------------*/
  --Codes associated with test results.
      SELECT DISTINCT
        t.testno,
        '~' AS sp_1,
        pr.analyte,
        pr.result,
        sc.snomedcode,
        COALESCE(pr.cdc_reportable, 'N') AS cdc_reportable,
        COALESCE(pr.elr_reportable, 'N') AS elr_reportable,
        pr.code_system_oid,
        pr.localnumber,
        '~' AS eol
      FROM tests t
        INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
        INNER JOIN snomedcodes sc ON (pr.snomedcode = sc.snomedcode)
      WHERE 1=1
        AND t.testno = '&TestName' 
      ORDER BY
        t.testno ASC,
        pr.result ASC
      ;        
/*-----------------------------------------------------------------*/





/*-----05. Test Reagents-------------------------------------------*/
/*-----------------------------------------------------------------*/
  WITH
    --UniqueMaterialSuppliers--
      UniqueMaterialSuppliers AS (
        SELECT DISTINCT
          ps.matcode,
          ps.suppcode
        FROM  prod_suppliers ps
        WHERE 1=1
      )
    -- --
    -- --
    SELECT 
      ctt.testgroupname AS panel,
      ctt.dept,
      (t.testno || ' (' || t.testcode || ')') AS testname,
      '--' AS sp1,
      'N' AS new_Material,      
      tr.matcode,
      m.mattype,
      m.unit_code,
      tr.qty,
      m.matname,
      ListAgg(ums.suppcode, ', ')WITHIN GROUP (ORDER BY ums.suppcode) AS suppliers,
      '~' AS eol
    FROM tests t
      INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
      INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
      INNER JOIN testreagents tr ON (t.testcode = tr.testcode)
      INNER JOIN materials m ON (tr.matcode = m.matcode)
      LEFT OUTER JOIN UniqueMaterialSuppliers ums ON (m.matcode = ums.matcode)
    WHERE 1=1
      AND tgn.status = 'Active'
      AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
      AND t.testflag = 'Default'
      AND t.testno = '&TestName'
    GROUP BY
      ctt.testgroupname,
      ctt.dept,
      (t.testno || ' (' || t.testcode || ')'),
      tr.matcode,
      m.mattype,
      m.unit_code,
      tr.qty,
      m.matname
    ORDER BY
      ctt.testgroupname ASC,
      ctt.dept ASC,
      testname ASC,
      UPPER(tr.matcode) ASC;
/*-----------------------------------------------------------------*/





/*-----08. Canned Comments (CC)------------------------------------*/
/*-----------------------------------------------------------------*/
  WITH  
    ---MyRef---
      --All panels in environment and associated test, 
      --and analytes.
      MyRef AS (
        SELECT DISTINCT
          ctt.dept,
          tc.testcatcode,
          ctt.servgrp,
          ctt.testgroupname AS panel,
          ctt.testcode,
          t.testno,
          a.analtype,
          a.analyte,
          '~' AS eol
        FROM conditiontesttriggers ctt
          INNER JOIN tests t ON (ctt.testcode = t.testcode)
          INNER JOIN testcategory tc ON (t.testcatcode = tc.testcatcode)
          INNER JOIN analytes a ON (t.testcode = a.testcode)
        WHERE 1=1
        ORDER BY 
          ctt.dept ASC,
          tc.testcatcode ASC,
          ctt.servgrp ASC,
          ctt.testgroupname  ASC,
          ctt.testcode ASC,
          t.testno ASC,
          a.analtype ASC,
          a.analyte ASC),
    ---
    ---MyCannedComments---              
      MyCannedComments AS (
        SELECT DISTINCT 
          (Coalesce(mr1.dept, mr2.dept, mr3.dept, 'All')) AS MyDept,
          CASE
            WHEN (mr3.analyte IS NOT NULL) THEN '04_Result'
            WHEN (mr2.testno IS NOT NULL) THEN '03_Test'
            WHEN (mr1.panel IS NOT NULL) THEN '02_Panel'
            ELSE '01_Folder'
          END AS CC_Level,     
          mr1.panel,    
          mr2.testno AS test_name,
          mr2.testcode,
          mr3.analyte,
          (cc.conditionfield || ' ' || cc.qualifier || ' '  || cc.conditionvalue ) AS cond_calc,
          cc.canned_comment,
          cc.attachment_scope AS cc_scope,
          cc.printonreport AS print,
          '~' AS eol    
        FROM canned_comments cc
          LEFT OUTER JOIN MyRef mr1 ON (cc.testgroupname = mr1.panel)
          LEFT OUTER JOIN MyRef mr2 ON (cc.testcode = mr2.testcode)
          LEFT OUTER JOIN MyRef mr3 ON (cc.analyte = mr3.analyte)
        WHERE 1=1
          AND cc.status = 'Released'
        ORDER BY 
          cc_level ASC,
          mr1.panel ASC,
          mr2.testno ASC,
          mr3.analyte ASC,
          cc.canned_comment ASC),
    ---
    ---MySummary---
      MySummary AS (
        SELECT DISTINCT
          mcc.MyDept AS dept,
          mcc.cc_level,
          mcc.panel,
          mcc.test_name,
          mcc.testcode,
          mcc.analyte,
          mcc.cond_calc,
          mcc.canned_comment,
          mcc.cc_scope,
          mcc.print,
          mcc.eol
        FROM MyCannedComments mcc
        WHERE 1=1
        ORDER BY 
          mcc.MyDept ASC,
          mcc.cc_level ASC,
          mcc.panel ASC,
          mcc.test_name ASC,
          mcc.analyte ASC,
          mcc.canned_comment ASC),
    ---
    ---PanelAndTestLevel---
      PanelAndTestLevel AS (    
        SELECT DISTINCT
          ctt.testgroupname AS panel,
          t.testno,
          ctt.testcode
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
          AND t.testflag = 'Default'
--          AND ctt.dept = '&Dept'
          )
    --- ---
    ---Final Query---
      SELECT DISTINCT
          ms.dept,
          ptl.testno AS associated_test,
          ms.cc_level,
          ms.panel,
          ms.test_name,
          ms.analyte,
          ms.cond_calc,
          ms.canned_comment,
          ms.cc_scope,
          ms.print,
          ms.testcode,
          ms.eol
      FROM MySummary ms
        INNER JOIN PanelAndTestLevel ptl ON (
          (ms.panel = ptl.panel) OR (ms.testcode = ptl.testcode)
          )
      WHERE 1=1
        AND ms.test_name = '&TestName' 
      ORDER BY
        ms.Dept ASC,
        ptl.testno ASC,
        ms.cc_level ASC,
        ms.panel ASC,
        ms.test_name ASC,
        ms.analyte ASC,
        ms.canned_comment ASC;
/*-----------------------------------------------------------------*/




/*-----09. Triggers------------------------------------------------*/
/*-----------------------------------------------------------------*/
  --Not sure about properties_1 and Properties_2
  SELECT DISTINCT
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    sp.prodgroup AS "GROUP",
    tf.condition,
    tf.triggeraction AS action,
    tf.executeonevent,
    tf.analyte,    
    tf.notifype AS properites_1,
    tf.specreport AS properties_2,
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN triggeriffail tf ON (1=1
      AND sp.sp_code = tf.sp_code
      AND t.testcode = tf.testcode)
    INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
  WHERE 1=1
    AND tgn.status = 'Active'
    AND t.testno = '&TestName'
  ORDER BY
    --ctt.dept ASC,
    sp.prodgroup ASC,
    testname ASC;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/



/*-----10. Specifications------------------------------------------*/
/*-----------------------------------------------------------------*/
  WITH
    ---SampleSpecs---
      SampleSpecs AS (
        SELECT
          sp.prodgroup AS plan_group,
          ctt.dept AS  department,
          ctt.testgroupname AS panel,
          (t.testno || ' (' || t.testcode || ')') AS testname,
          t.testcode,
          '--' AS sp1,
          'Sample' AS spec_type,
          ss.qctype,
          a.analyte,
          sa.printflag AS print,
         COALESCE(sa.qc_expected_result, 'N/A') AS expected_result,
          COALESCE(sa.pass_text, 'N/A') AS pass_text,    
          sa.schemaname AS schema_name,
          '--' AS sp2,
          (a.sorter || '-0') AS sorter,
          '~' AS eol
        FROM tests t
          LEFT OUTER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)    
          LEFT OUTER JOIN sp_tests st ON (t.testcode = st.testcode)
          LEFT OUTER JOIN sample_programs sp ON (st.sp_code = sp.sp_code)
          LEFT OUTER JOIN spec_sets ss ON (1=1
            AND ss.matcode = sp.matcode
            AND ss.typeofspec = 'PRODSPEC')
          LEFT OUTER JOIN spec_analytes sa ON (1=1
            AND a.testcode = sa.testcode
            AND ss.specno = sa.specno
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
          LEFT OUTER JOIN specschemas scs ON (a.schemaname = scs.schemaname)   
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
          AND t.testflag = 'Default'
        ORDER BY
          sp.prodgroup ASC,
          ctt.dept ASC,
          ctt.testgroupname ASC,
          t.testno ASC,
          a.sorter ASC
        ),
    --- ---   
    ---QCSpecs---
      QCSpecs AS (
        SELECT
          sp.prodgroup AS plan_group,
          ctt.dept AS  department,
          ctt.testgroupname AS panel,
          t.testno AS testname,
          t.testcode,
          '--' AS sp1,
          'QC specs' AS spec_type,
          ss.qctype,        
          a.analyte,
          sa.printflag AS print,
          sa.qc_expected_result AS expected_result,
          sa.pass_text,
          sa.schemaname AS schema_name,
          '--' AS sp2,
          (a.sorter || '-' || qsl.cupno) AS sorter,
          '~' AS eol
        FROM testgroupnames tgn  
          INNER JOIN sample_programs sp ON (tgn.sp_code = sp.sp_code)
          INNER JOIN testgroupsynonims syn ON (tgn.testgroupname = syn.testgroupname)
          INNER JOIN conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
          INNER JOIN tests t ON (ctt.testcode = t.testcode)
          INNER JOIN Conditiontestanalytes cta ON (1=1
            AND ctt.dept = cta.dept
            AND ctt.testcode = cta.testcode
            AND ctt.testgroupname = cta.testgroupname
            AND ctt.method = cta.method)
          INNER JOIN analytes a ON (t.testcode = a.testcode)    
          INNER JOIN sp_tests st ON (t.testcode = st.testcode)
          INNER JOIN methodsrelatedtotests mrt ON (t.testcode = mrt.testcode)
          INNER JOIN equip_tests et ON (1=1
            AND t.testcode = et.testcode
            AND mrt.method = et.method)
          INNER JOIN equipment e ON (et.eqid = e.eqid)
          INNER JOIN equip_standards es ON (1=1
            AND e.eqid = es.eqid
            AND et.batch_id = es.batch_id
            AND mrt.method = es.method)
          INNER JOIN qcsampslayout qsl ON (1=1
            AND es.eqid = qsl.eqid
            AND es.batch_id = qsl.batch_id
            AND es.qctype = qsl.qctype)
          INNER JOIN spec_sets ss ON (1=1
            AND ss.matcode = sp.matcode
            AND ss.typeofspec = 'PRODQC'
            AND es.qctype = ss.qctype)
          INNER JOIN spec_analytes sa ON (1=1
            AND a.testcode = sa.testcode
            AND ss.specno = sa.specno
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
          AND t.testflag = 'Default'
        ORDER BY
          sp.prodgroup ASC,
          ctt.dept ASC,
          ctt.testgroupname ASC,
          testname ASC,
          sorter ASC,
          ss.qctype ASC          
        ),
    --- ---
    ---AllTogether---
      AllTogether AS (
        SELECT ss.* FROM SampleSpecs ss
        UNION
        SELECT qs.* FROM QCSpecs qs
      )
    --- ---
    ---Final Query---
        SELECT
          alt.plan_group,
          alt.department,
          alt.panel,
          alt.testname,
          alt.sp1,
          alt.spec_type,
          alt.qctype,
          alt.analyte,
          alt.print,
          alt.expected_result,
          alt.pass_text,
          alt.schema_name,
          alt.sp2,
          alt.sorter,
          alt.eol
        FROM AllTogether alt
        WHERE 1=1
--          AND alt.department = '&Dept'
          AND alt.testname = '&TestName'
        ORDER BY
          alt.plan_group ASC,
          alt.department ASC,
          alt.panel ASC,
          UPPER(alt.testname) ASC,
          UPPER(alt.analyte) ASC,
          UPPER(alt.spec_type) ASC,
          UPPER(alt.qctype) ASC,
          UPPER(alt.sorter) ASC;
    --- ---
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/
/*-----11. Equipment Setup-----------------------------------------*/
  SELECT DISTINCT
    sp.prodgroup AS "GROUP",
    ctt.dept AS  department,
    ctt.testgroupname AS panel,
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    mrt.method AS method,
    e.eqtype AS equip_type,
    e.eqid AS equip_id,
    e.mfg AS manufacturer,
    qsl.cupno AS position,
    'QC' AS sample_type,
    es.qctype AS identifier,  
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    LEFT OUTER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    LEFT OUTER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)    
    LEFT OUTER JOIN methodsrelatedtotests mrt ON (t.testcode = mrt.testcode)
    LEFT OUTER JOIN equip_tests et ON (1=1
      AND t.testcode = et.testcode
      AND mrt.method = et.method)
    LEFT OUTER JOIN equipment e ON (et.eqid = e.eqid)
    LEFT OUTER JOIN equip_standards es ON (1=1
      AND e.eqid = es.eqid
      AND et.batch_id = es.batch_id
      AND mrt.method = es.method)
    LEFT OUTER JOIN qcsampslayout qsl ON (1=1    
      AND es.eqid = qsl.eqid
      AND es.batch_id = qsl.batch_id
      AND es.qctype = qsl.qctype
      )
  WHERE 1=1
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    AND tgn.status = 'Active'
    AND t.testflag = 'Default'
    AND e.eqtype <> 'Retired'
    AND t.testno = '&TestName'
  ORDER BY
    sp.prodgroup ASC,
    ctt.dept ASC,
    ctt.testgroupname ASC,
    testname ASC,
    mrt.method ASC,
    e.eqtype ASC,
    e.eqid ASC,
    qsl.cupno ASC;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/
