/*-----------------------------------------------------------------*/     
/*-----DefaultTest Config Information------------------------------*/
  /*----------Summary----------*/
    --Queries to retreive information from STARLiMS related to the
    --test configuration.  Queries Include:
      --00-01 General And Panel Information
      --02. Test Information
      --03. Analyte(s) Information
      --04. Test Reagents
      --05. Test Possible Results (P.R.)
      --06. Canned Comments (CC)
      --07. Triggers
      --08. Specifications
      --09. Equipment Setup
  /*---------- ----------*/  

  /*----------History----------*/
    --2019.12.20 JTY: Create script based on Default Test Config Script
  /*---------- ----------*/  

/*-----------------------------------------------------------------*/






/*-----------------------------------------------------------------*/

/*-----00-01 General And Panel Information-------------------------*/
  --Section 01.General Information
  --Section 02. Panel Information

  SELECT
      '~GeneralInfo~' AS general_info,
      ctt.dept,
      t.testno,
      --ctt.testcode,
      --cta.analyte,
      ListAgg(cta.analyte, ', ')WITHIN GROUP (ORDER BY cta.analyte) AS analytes,
      '~PanelInfo~' AS panel_info,
      cta.testgroupname AS panel,
      ctt.defaultselect,
      rrr.reportname AS report_name,
    '~' AS eol
  FROM conditiontesttriggers ctt
    INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
    INNER JOIN conditiontestanalytes cta ON ( 1=1
      AND ctt.dept = cta.dept
      AND ctt.testcode = cta.testcode
      AND ctt.testgroupname = cta.testgroupname
      AND ctt.method = cta.method)
    INNER JOIN tests t ON (ctt.testcode = t.testcode)
---    
    LEFT OUTER JOIN rr_reportingruleslevels rrl ON (1=1
      AND SUBSTR(rrl.caption, 10) = cta.testgroupname)     
    LEFT OUTER JOIN rr_reportingrulereports rrr on (1=1
      AND rrl.ruleid = rrr.ruleid
      AND rrl.ruleselectionid = rrr.ruleselectionid)
---    
  WHERE 1=1
    AND tgn.status = 'Active'
--    AND ctt.dept = '&Dept'
    --AND cta.testgroupname = '&PanelName'
--    AND t.testno = '&TestName'
    AND t.testcode = '&TestCode'
  GROUP BY
    ctt.dept,
    cta.testgroupname,
    ctt.defaultselect,
    rrr.reportname,
    t.testno
  ORDER BY 
    ctt.dept ASC,
    t.testno ASC,
    cta.testgroupname ASC;
/*-----------------------------------------------------------------*/



/*-----------------------------------------------------------------*/
/*-----02. Test Information----------------------------------------*/
  SELECT DISTINCT
    mrt.dept,
    sp.progname AS program_name,
    t.testcatcode AS "LIBRARY",
    t.testno AS test_name,
    t.testflag AS testing_method,
    --t.testcode,
    mrt.eqtype AS equipment_type,
    mrt.instverify AS instrument_cert,
    mrt.assign_type AS analysts_cert,
    (TRIM(t.holdingtime || ' ' ||  t.holdingtimeunits)) AS holding_time,
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    INNER JOIN methodsrelatedtotests mrt ON (1=1
      AND t.testcode = mrt.testcode)
  WHERE 1=1
    AND (sp.progname IN ('Human', 'LRN-B', 'Ad Hoc', 'Environmental Microbiology', 'Animal'))
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    --AND mrt.dept = '&Dept'
    --AND t.testno = '&TestName'
    AND t.testcode = '&TestCode'
  ORDER BY
    sp.progname ASC,
    t.testcatcode ASC,
    test_name ASC;
/*-----------------------------------------------------------------*/





/*-----03. Analyte(s) Information----------------------------------*/
/*-----------------------------------------------------------------*/
  SELECT
    sp.prodgroup AS "GROUP",
    ctt.dept AS  department,
    ctt.testgroupname AS panel,
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    a.analyte AS analyte_name,
    a.sinonym AS analyte_synonym,
--SchemaGroup
    (scs.specschemagroup || ' / ' || a.schemaname) AS schema_group_name,
    --sa.schemaname,
    CASE a.analtype
     WHEN 'AT' THEN 'AT-Attachment'
     WHEN 'C' THEN 'C-Character'
     WHEN 'MC' THEN 'MC-Multichoice'
     WHEN 'N' THEN 'N-Numeric'
     WHEN 'NP' THEN 'NP-Numeric Prompt'
     WHEN 'SD' THEN 'SD-Single With Details'
     WHEN 'ANALYTE_TYPE' THEN 'ANALYTE_TYPE_TEXT'
     ELSE a.analtype
   END AS data_type,
    a.units,
    tlc.loinccomponenet AS loinc_report_name,
    tlc.loincnumber AS loinc_code,
    '--' AS sp2,
    a.sorter,
    '~' AS eol
  FROM tests t
    LEFT OUTER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    LEFT OUTER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
    LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
    LEFT OUTER JOIN testloinccodes tlc ON (1=1
      AND a.testcode = tlc.testcode
      AND a.analyte = tlc.analyte)
    LEFT OUTER JOIN sp_tests st ON (t.testcode = st.testcode)
    LEFT OUTER JOIN sample_programs sp ON (st.sp_code = sp.sp_code)
    LEFT OUTER JOIN spec_sets ss ON (1=1
      AND ss.matcode = sp.matcode
      AND ss.typeofspec = 'PRODSPEC')
    LEFT OUTER JOIN spec_analytes sa ON (1=1
      AND a.testcode = sa.testcode
      AND ss.specno = sa.specno
      AND a.analtype = sa.analtype
      AND a.analyte = sa.analyte)
    LEFT OUTER JOIN specschemas scs ON (a.schemaname = scs.schemaname)   
  WHERE 1=1
    AND tgn.status = 'Active'  
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
--    AND t.testflag = 'Default'
--    AND sp.prodgroup = '&ProdGroup'  --'LRN-B'
    AND t.testcode = '&TestCode'
    --AND ctt.dept = '&Dept'
    --AND t.testno = '&TestName'
  ORDER BY
    sp.prodgroup ASC,
    ctt.dept ASC,
    ctt.testgroupname ASC,
    t.testno ASC,
    a.sorter ASC;
/*-----------------------------------------------------------------*/


/*-----04. LOINC Codes---------------------------------------------*/
  --Section 04 Identify LOINC codes associated with test 
  SELECT DISTINCT
    lc.version,
    lc.classcode,
    cl.classname,
    lc.loincnumber,
    lc.loinccomponenet AS component,
    lc.loincshortname AS short_name,
    lc.loincproperty AS property,
    lc.loinctime AS "time",
    lc.loincsystems AS sample_type,
    lc.loincscale AS scale,
    lc.loincmethod AS method,
    '~' AS eol
  FROM tests t
    LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)
    INNER JOIN testloinccodes tc ON (t.testcode = tc.testcode)
    INNER JOIN loinccodes lc ON (1=1
      AND tc.loinccomponenet = lc.loinccomponenet
      AND tc.version = lc.version
      AND tc.loincnumber = lc.loincnumber)
    INNER JOIN loincclasses cl ON (1=1
      AND lc.classcode = cl.classcode
      AND lc.version = cl.version)
--      tc.analyte
  WHERE 1=1
   AND t.testcode = '&TestCode'
  ORDER BY
    lc.classcode ASC,
    lc.loinccomponenet ASC;
/*-----------------------------------------------------------------*/


/*-----05. Test Reagents-------------------------------------------*/
/*-----------------------------------------------------------------*/

  WITH
    --UniqueMaterialSuppliers--
      UniqueMaterialSuppliers AS (
        SELECT DISTINCT
          ps.matcode,
          ps.suppcode
        FROM  prod_suppliers ps
        WHERE 1=1
      )
    -- --
    -- --
    SELECT 
      ctt.testgroupname AS panel,
      ctt.dept,
      (t.testno || ' (' || t.testcode || ')') AS testname,
      '--' AS sp1,
      tr.matcode,
      m.mattype,
      m.unit_code,
      tr.qty,
      m.matname,
      ListAgg(ums.suppcode, ', ')WITHIN GROUP (ORDER BY ums.suppcode) AS suppliers,
      '~' AS eol
    FROM tests t
      INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
      INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
      INNER JOIN testreagents tr ON (t.testcode = tr.testcode)
      INNER JOIN materials m ON (tr.matcode = m.matcode)
      LEFT OUTER JOIN UniqueMaterialSuppliers ums ON (m.matcode = ums.matcode)
  --    INNER JOIN suppliers s ON (pr.suppcode = s.suppcode)
    WHERE 1=1
      AND tgn.status = 'Active'
      AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
      --AND ctt.dept = '&Dept'
      --AND t.testno = '&TestName'
      AND t.testcode = '&TestCode'
    GROUP BY
      ctt.testgroupname,
      ctt.dept,
      (t.testno || ' (' || t.testcode || ')'),
      tr.matcode,
      m.mattype,
      m.unit_code,
      tr.qty,
      m.matname
    ORDER BY
      ctt.testgroupname ASC,
      ctt.dept ASC,
      testname ASC,
      UPPER(tr.matcode) ASC;
    -- --    
/*-----------------------------------------------------------------*/




/*-----------------------------------------------------------------*/
/*-----06. SNOMED CODES: For Possible Results----------------------*/
  --Codes associated with test results.
  
  SELECT DISTINCT
    t.testno,
    pr.analyte,
    '~' AS sp1,
    sc.snomedcode,
    sc.snomed_group,
    sc.snomeddescriptionid AS description_id,
    sc.snomedconceptid AS concept_id,
    sc.snomedelement AS element,
    '~' AS eol
  FROM tests t
    INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
    LEFT OUTER JOIN snomedcodes sc ON (pr.snomedcode = sc.snomedcode)
  WHERE 1=1
    AND t.testcode = '&TestCode'
  ORDER BY
    t.testno ASC,
    pr.analyte ASC
    ;
/*-----------------------------------------------------------------*/






/*-----07. Test Possible Results (P.R.)----------------------------*/

  SELECT DISTINCT
--    ctt.testgroupname AS panel,
    ctt.dept,
    (t.testno || ' (' || t.testcode || ')' ) AS testname,
    pr.sorter,
    '--' AS sp1,
    pr.analyte,
    pr.snomedcode AS result_code,
--    pr.snomedconceptid AS result_code,
    pr.result,
    pr.conclusion_report AS reported_as,
    pr.result_status AS status,
    '~' AS eol
  FROM tests t
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
  WHERE 1=1
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    --AND ctt.dept = '&Dept'
    --AND t.testno = '&TestName'
      AND t.testcode = '&TestCode'
  ORDER BY
      ctt.dept ASC,
      UPPER(testname) ASC,
      UPPER(pr.analyte) ASC,
      UPPER(pr.sorter) ASC,
      UPPER(pr.result);
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/





/*-----08. Canned Comments (CC)------------------------------------*/
/*-----------------------------------------------------------------*/
  WITH  
    ---MyRef---
      --All panels in environment and associated test, 
      --and analytes.
      MyRef AS (
        SELECT DISTINCT
          ctt.dept,
          tc.testcatcode,
          ctt.servgrp,
          ctt.testgroupname AS panel,
          ctt.testcode,
          t.testno,
          a.analtype,
          a.analyte,
          '~' AS eol
        FROM conditiontesttriggers ctt
          INNER JOIN tests t ON (ctt.testcode = t.testcode)
          INNER JOIN testcategory tc ON (t.testcatcode = tc.testcatcode)
          INNER JOIN analytes a ON (t.testcode = a.testcode)
        WHERE 1=1
        ORDER BY 
          ctt.dept ASC,
          tc.testcatcode ASC,
          ctt.servgrp ASC,
          ctt.testgroupname  ASC,
          ctt.testcode ASC,
          t.testno ASC,
          a.analtype ASC,
          a.analyte ASC),
    ---
    ---MyCannedComments---              
      MyCannedComments AS (
        SELECT DISTINCT 
          (Coalesce(mr1.dept, mr2.dept, mr3.dept, 'All')) AS MyDept,
          CASE
            WHEN (mr3.analyte IS NOT NULL) THEN '04_Result'
            WHEN (mr2.testno IS NOT NULL) THEN '03_Test'
            WHEN (mr1.panel IS NOT NULL) THEN '02_Panel'
            ELSE '01_Folder'
          END AS CC_Level,     
          mr1.panel,    
          mr2.testno AS test_name,
          mr2.testcode,
          mr3.analyte,
          (cc.conditionfield || ' ' || cc.qualifier || ' '  || cc.conditionvalue ) AS cond_calc,
          cc.canned_comment,
          cc.attachment_scope AS cc_scope,
          cc.printonreport AS print,
          '~' AS eol    
        FROM canned_comments cc
          LEFT OUTER JOIN MyRef mr1 ON (cc.testgroupname = mr1.panel)
          LEFT OUTER JOIN MyRef mr2 ON (cc.testcode = mr2.testcode)
          LEFT OUTER JOIN MyRef mr3 ON (cc.analyte = mr3.analyte)
        WHERE 1=1
          AND cc.status = 'Released'
          --AND Coalesce(mr1.dept, mr2.dept, mr3.dept) IN ('PHX-TB')
        ORDER BY 
          cc_level ASC,
          --Coalesce(mr1.dept, mr2.dept, mr3.dept) DESC,
          mr1.panel ASC,
          mr2.testno ASC,
          mr3.analyte ASC,
          cc.canned_comment ASC),
    ---   
    ---MySummary---
      MySummary AS (
        SELECT DISTINCT
          mcc.MyDept AS dept,
          mcc.cc_level,
          mcc.panel,
          mcc.test_name,
          mcc.testcode,
          mcc.analyte,
          mcc.cond_calc,
          mcc.canned_comment,
          mcc.cc_scope,
          mcc.print,
          mcc.eol
        FROM MyCannedComments mcc
        WHERE 1=1
        ORDER BY 
          mcc.MyDept ASC,
          mcc.cc_level ASC,
          mcc.panel ASC,
          mcc.test_name ASC,
          mcc.analyte ASC,
          mcc.canned_comment ASC),
    ---
    ---PanelAndTestLevel---
      PanelAndTestLevel AS (    
        SELECT DISTINCT
          ctt.testgroupname AS panel,
          t.testno,
          ctt.testcode
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
          AND ctt.dept = '&Dept')
    --- ---
    ---Final Query---
      SELECT DISTINCT
          ms.dept,
          ptl.testno AS associated_test,
          ms.cc_level,
          ms.panel,
          ms.test_name,
          ms.analyte,
          ms.cond_calc,
          ms.canned_comment,
          ms.cc_scope,
          ms.print,
          ms.testcode,
          ms.eol
      FROM MySummary ms
        INNER JOIN PanelAndTestLevel ptl ON (
          (ms.panel = ptl.panel) OR (ms.testcode = ptl.testcode)
          )
      WHERE 1=1
        --AND ptl.testno = '&TestName'    
        AND ptl.testcode = '&TestCode'
---Filter parameters---      
--        AND (ms.dept IS NULL or ms.dept IN ('All' ,'PHX-BAC'))  --PHX-BAC, PHX-BT, PHX-EM, PHX-SER, PHX-TB, PHX-VIR
---        
      ORDER BY
        ms.Dept ASC,
        ptl.testno ASC,
        ms.cc_level ASC,
        ms.panel ASC,
        ms.test_name ASC,
        ms.analyte ASC,
        ms.canned_comment ASC;
/*-----------------------------------------------------------------*/





/*-----09. Triggers------------------------------------------------*/
/*-----------------------------------------------------------------*/
  --Not sure about properties_1 and Properties_2
  SELECT DISTINCT
    --ctt.dept AS  department,
    --ctt.testgroupname AS panel,
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    sp.prodgroup AS "GROUP",
    --tf.cond_load AS condition,
    tf.condition,
    tf.triggeraction AS action,
    tf.executeonevent,
    tf.analyte,    
    tf.notifype AS properites_1,
    tf.specreport AS properties_2,
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN triggeriffail tf ON (1=1
      AND sp.sp_code = tf.sp_code
      AND t.testcode = tf.testcode)
    INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)
  WHERE 1=1
    AND tgn.status = 'Active'
    --AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    --AND t.testflag = 'Default'
    --AND sp.prodgroup = '&ProdGroup'  --'LRN-B'
    AND t.testcode = '&TestCode'
    --AND ctt.dept = '&Dept'
--    AND t.testno = '&TestName' -- This may not work.
  ORDER BY
    --ctt.dept ASC,
    sp.prodgroup ASC,
    testname ASC;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/



/*-----10. Specifications------------------------------------------*/
/*-----------------------------------------------------------------*/
  WITH
    ---SampleSpecs---
      SampleSpecs AS (
        SELECT
          sp.prodgroup AS plan_group,
          ctt.dept AS  department,
          ctt.testgroupname AS panel,
          (t.testno || ' (' || t.testcode || ')') AS testname,
          t.testcode,
          '--' AS sp1,
          'Sample' AS spec_type,
          ss.qctype,
          a.analyte,
          sa.printflag AS print,
         COALESCE(sa.qc_expected_result, 'N/A') AS expected_result,
          COALESCE(sa.pass_text, 'N/A') AS pass_text,    
          sa.schemaname AS schema_name,
          '--' AS sp2,
          (a.sorter || '-0') AS sorter,
          '~' AS eol
        FROM tests t
          LEFT OUTER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN analytes a ON (t.testcode = a.testcode)    
          LEFT OUTER JOIN sp_tests st ON (t.testcode = st.testcode)
          LEFT OUTER JOIN sample_programs sp ON (st.sp_code = sp.sp_code)
          LEFT OUTER JOIN spec_sets ss ON (1=1
            AND ss.matcode = sp.matcode
            AND ss.typeofspec = 'PRODSPEC')
          LEFT OUTER JOIN spec_analytes sa ON (1=1
            AND a.testcode = sa.testcode
            AND ss.specno = sa.specno
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
          LEFT OUTER JOIN specschemas scs ON (a.schemaname = scs.schemaname)   
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
        ORDER BY
          sp.prodgroup ASC,
          ctt.dept ASC,
          ctt.testgroupname ASC,
          t.testno ASC,
          a.sorter ASC
        ),
    --- ---   
    ---QCSpecs---
      QCSpecs AS (
        SELECT
          sp.prodgroup AS plan_group,
          ctt.dept AS  department,
          ctt.testgroupname AS panel,
          t.testno AS testname,
          t.testcode,
          '--' AS sp1,
          'QC specs' AS spec_type,
          ss.qctype,        
          a.analyte,
          sa.printflag AS print,
          sa.qc_expected_result AS expected_result,
          sa.pass_text,
          sa.schemaname AS schema_name,
          '--' AS sp2,
          (a.sorter || '-' || qsl.cupno) AS sorter,
          '~' AS eol
        FROM testgroupnames tgn  
          INNER JOIN sample_programs sp ON (tgn.sp_code = sp.sp_code)
          INNER JOIN testgroupsynonims syn ON (tgn.testgroupname = syn.testgroupname)
          INNER JOIN conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
          INNER JOIN tests t ON (ctt.testcode = t.testcode)
          INNER JOIN Conditiontestanalytes cta ON (1=1
            AND ctt.dept = cta.dept
            AND ctt.testcode = cta.testcode
            AND ctt.testgroupname = cta.testgroupname
            AND ctt.method = cta.method)
          INNER JOIN analytes a ON (t.testcode = a.testcode)    
          INNER JOIN sp_tests st ON (t.testcode = st.testcode)
          INNER JOIN methodsrelatedtotests mrt ON (t.testcode = mrt.testcode)
          INNER JOIN equip_tests et ON (1=1
            AND t.testcode = et.testcode
            AND mrt.method = et.method)
          INNER JOIN equipment e ON (et.eqid = e.eqid)
          INNER JOIN equip_standards es ON (1=1
            AND e.eqid = es.eqid
            AND et.batch_id = es.batch_id
            AND mrt.method = es.method)
          INNER JOIN qcsampslayout qsl ON (1=1
            AND es.eqid = qsl.eqid
            AND es.batch_id = qsl.batch_id
            AND es.qctype = qsl.qctype)
          INNER JOIN spec_sets ss ON (1=1
            AND ss.matcode = sp.matcode
            AND ss.typeofspec = 'PRODQC'
            AND es.qctype = ss.qctype)
          INNER JOIN spec_analytes sa ON (1=1
            AND a.testcode = sa.testcode
            AND ss.specno = sa.specno
            AND a.analtype = sa.analtype
            AND a.analyte = sa.analyte)
        WHERE 1=1
          AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
          AND t.testflag = 'Default'
        ORDER BY
          sp.prodgroup ASC,
          ctt.dept ASC,
          ctt.testgroupname ASC,
          testname ASC,
          sorter ASC,
          ss.qctype ASC          
        ),
    --- ---

    ---AllTogether---
      AllTogether AS (
        SELECT ss.* FROM SampleSpecs ss
        UNION
        SELECT qs.* FROM QCSpecs qs
      )
    --- ---
    ---Final Query---
        SELECT
          alt.plan_group,
          alt.department,
          alt.panel,
          alt.testname,
          alt.sp1,
          alt.spec_type,
          alt.qctype,
          alt.analyte,
          alt.print,
          alt.expected_result,
          alt.pass_text,
          alt.schema_name,
          alt.sp2,
          alt.sorter,
          alt.eol
        FROM AllTogether alt
        WHERE 1=1
          AND alt.department = '&Dept'
          AND alt.testcode = '&TestCode'
          --AND alt.testname = '&TestName'
        ORDER BY
          alt.plan_group ASC,
          alt.department ASC,
          alt.panel ASC,
          UPPER(alt.testname) ASC,
          UPPER(alt.spec_type) DESC,
          UPPER(alt.analyte) ASC,
          UPPER(alt.sorter) ASC,
          UPPER(alt.qctype) ASC;
    --- ---
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/





/*-----------------------------------------------------------------*/
/*-----11. Equipment Setup-----------------------------------------*/
  SELECT DISTINCT
    sp.prodgroup AS "GROUP",
    ctt.dept AS  department,
    ctt.testgroupname AS panel,
    (t.testno || ' (' || t.testcode || ')') AS testname,
    '--' AS sp1,
    mrt.method AS method,
    e.eqtype AS equip_type,
    e.eqid AS equip_id,
    e.mfg AS manufacturer,
    qsl.cupno AS position,
    'QC' AS sample_type,
    es.qctype AS identifier,  
    '~' AS eol
  FROM sample_programs sp
    LEFT OUTER JOIN sp_tests st ON (sp.sp_code = st.sp_code)
    LEFT OUTER JOIN tests t ON (st.testcode = t.testcode)
    INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
    INNER JOIN testgroupnames tgn ON (ctt.testgroupname = tgn.testgroupname)    
    INNER JOIN methodsrelatedtotests mrt ON (t.testcode = mrt.testcode)
    INNER JOIN equip_tests et ON (1=1
      AND t.testcode = et.testcode
      AND mrt.method = et.method)
    INNER JOIN equipment e ON (et.eqid = e.eqid)
    INNER JOIN equip_standards es ON (1=1
      AND e.eqid = es.eqid
      AND et.batch_id = es.batch_id
      AND mrt.method = es.method)
    INNER JOIN qcsampslayout qsl ON (1=1    
      AND es.eqid = qsl.eqid
      AND es.batch_id = qsl.batch_id
      AND es.qctype = qsl.qctype
      )
  WHERE 1=1
    AND (t.testcatcode NOT IN ('Retired', 'Safety and Training', 'Certifications', 'Clinical', 'QC Inventory'))
    AND tgn.status = 'Active'
    AND e.eqtype <> 'Retired'
    --AND t.testno = '&TestName'
    --AND sp.prodgroup = '&ProdGroup'  --'LRN-B'
    AND t.testcode = '&TestCode'
    --AND ctt.dept = '&Dept'
  ORDER BY
    sp.prodgroup ASC,
    ctt.dept ASC,
    ctt.testgroupname ASC,
    testname ASC,
    mrt.method ASC,
    e.eqtype ASC,
    e.eqid ASC,
    qsl.cupno ASC;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/








/*-----------------------------------------------------------------*/
/*-----12. MicroSteps Famework-----------------------------------------*/
  SELECT DISTINCT
    t.testno,
    '~' AS sp1,
    tws.sorter,
    tws.onoff AS auto,
    tws.stepcode,
    tws.description,
    tws.createcolony AS colonies,
    tws.entrytype,
    tws.needrun,
    tws.needapprove AS approval,
    tws.prelimreport AS reportable,
    '~' AS eol
  FROM tests t
    INNER JOIN testwfmethods twm ON (t.tmname = twm.tmname)
    INNER JOIN testwfsteps tws ON (twm.tmcode = tws.tmcode)
  WHERE 1=1
    AND t.testcode = '&TestCode'
  ORDER BY
    t.testno ASC,
    tws.sorter ASC;
    --- ---
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/
  


/*-----------------------------------------------------------------*/
/*-----13. MicroStepInformation------------------------------------*/

  WITH
    ---MircoSteps--
      MicroSteps AS (
        SELECT DISTINCT
          t.dept,
          t.testno,
          t.testcode,
          tws.tmcode,
          tws.stepcode,
          tws.sorter,
          tws.description,
          '~' AS eol
        FROM tests t
          INNER JOIN testwfmethods twm ON (t.tmname = twm.tmname)
          INNER JOIN testwfsteps tws ON (twm.tmcode = tws.tmcode)
        WHERE 1=1
          AND t.testcode = '&TestCode'
--          AND t.testcode = '447'
  --        AND tws.stepcode = 'Isolate'
        ORDER BY
          t.testno ASC,
          tws.sorter ASC
      ),
    --- ---
    ---ChildSteps---
      ChildSteps AS (
        SELECT DISTINCT
          ms.testcode,
          ms.tmcode,
          ms.stepcode,
          LISTAGG(twc.childstepcode, ',' || CHR(13)) WITHIN GROUP (ORDER BY twc.childstepcode) AS child_steps,
          '~' AS eol
        FROM MicroSteps ms
        LEFT OUTER JOIN testwfchildsteps twc ON (1=1
          AND twc.tmcode = ms.tmcode
          AND twc.stepcode = ms.stepcode
          AND twc.childstepcode IN (SELECT DISTINCT ms2.stepcode FROM MicroSteps ms2)
        
        )
        GROUP BY
          ms.testcode,
          ms.tmcode,
          ms.stepcode
      ),
    --- ---
    ---TypeAndCondition---
      TypeAndCondition AS (
        SELECT DISTINCT
          ms.testcode,
          ms.tmcode,
          ms.stepcode,
          LISTAGG(mp.fromcomptype || ': ' || decode(mp.selectionparam, NULL, '[NULL],',(mp.selectionparam || ',' || CHR(13) )))
              WITHIN GROUP (ORDER BY (mp.fromcomptype || ': ' || mp.selectionparam)) AS type_and_Condition,
          '~' AS eol
        FROM MicroSteps ms
        LEFT OUTER JOIN microplates mp ON (1=1
          AND mp.tmcode = ms.tmcode
          AND mp.stepcode = ms.stepcode)
        GROUP BY
          ms.testcode,
          ms.tmcode,
          ms.stepcode
      ),
    --- ---    
    ---DefaultComponents---
      DefaultComponents AS (
        SELECT DISTINCT
          ms.testcode,
          ms.tmcode,
          ms.stepcode,
          LISTAGG(dc.compid, ',' || CHR(13)) WITHIN GROUP (ORDER BY dc.compid) AS default_components,
          '~' AS eol
        FROM MicroSteps ms
        LEFT OUTER JOIN microplates mp ON (1=1
          AND mp.tmcode = ms.tmcode
          AND mp.stepcode = ms.stepcode        
        )
        LEFT OUTER JOIN microplatedefcomp dc ON (1=1
          AND mp.tmcode = dc.tmcode
          AND mp.stepcode = dc.stepcode
          AND mp.platecode = dc.Platecode)
        
        GROUP BY
          ms.testcode,
          ms.tmcode,
          ms.stepcode
      ),
    --- ---    
   
    ---StepActions---
      StepActions AS(
        SELECT DISTINCT
          ms.testcode,
          ms.tmcode,
          ms.stepcode,
          LISTAGG(twa.action_name, ',' || CHR(13)) WITHIN GROUP (ORDER BY twa.sorter) AS action_caption,
          '~' AS eol
        FROM MicroSteps ms
          LEFT OUTER JOIN testwfactions twa ON (1=1
            AND ms.tmcode = twa.tmcode
            AND ms.stepcode = twa.stepcode)      
        WHERE 1=1
        GROUP BY
          ms.testcode,
          ms.tmcode,
          ms.stepcode
      ),
    --- ---
    ---All Together---
      AllTogether AS (
        SELECT DISTINCT
          ms.dept,
          ms.testno,
          ms.tmcode,          
          ms.testcode,
          '~' AS sp1,
          ms.sorter,
          ms.stepcode,
          ms.description,
          cs.child_steps,
          tc.type_and_Condition,
--ComponentTypeAndCondition,
          dc.default_components,
          sa.action_caption,
          ms.eol
        FROM MicroSteps ms
          LEFT OUTER JOIN ChildSteps cs ON (1=1
            AND ms.testcode = cs.testcode
            AND ms.tmcode = cs.tmcode
            AND ms.stepcode = cs.stepcode)
          LEFT OUTER JOIN TypeAndCondition tc ON (1=1
            AND ms.testcode = tc.testcode
            AND ms.tmcode = tc.tmcode
            AND ms.stepcode = tc.stepcode)
          LEFT OUTER JOIN DefaultComponents dc ON (1=1
            AND ms.testcode = dc.testcode
            AND ms.tmcode = dc.tmcode
            AND ms.stepcode = dc.stepcode)
          LEFT OUTER JOIN StepActions sa ON (1=1
            AND ms.testcode = sa.testcode
            AND ms.tmcode = sa.tmcode
            AND ms.stepcode = sa.stepcode)
            
        WHERE 1=1
        ORDER BY
          ms.testcode ASC,
          ms.sorter ASC
      )
    --- ---    
  SELECT * FROM  AllTogether;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/






/*-----------------------------------------------------------------*/
/*-----14. Micro Panels--------------------------------------------*/
    SELECT DISTINCT
      mpcm.comptype,
      mpcm.panelid,            
      mpc.condition,
      mpcm.compid,
      mcr.matcode,
      --Linked Components datagrid--
        mpcm.sorter,
      --
      '~' AS eol
    FROM testgroupnames tgn
      INNER JOIN conditiontesttriggers ctt ON (tgn.testgroupname = ctt.testgroupname)
      INNER JOIN tests t ON (ctt.testcode = t.testcode)    
      INNER JOIN testwfmethods twm ON (t.tmname = twm.tmname)    
      INNER JOIN microplates mp ON (twm.tmcode = mp.tmcode)
      INNER JOIN micropanelconditions mpc ON (
          mp.fromcomptype = mpc.comptype AND mp.selectionparam = mpc.condition)
      INNER JOIN micropanels mpn ON (mpc.panelid = mpn.panelid)
      INNER JOIN micropanelcomp mpcm ON (
          mpn.panelid = mpcm.panelid AND mpn.comptype = mpcm.comptype )
      LEFT OUTER JOIN microcompreagents mcr ON (mpcm.comptype = mcr.comptype AND mpcm.compid = mcr.compid)
    WHERE 1=1
      ---Filter Results here---
          AND t.testcode = '&TestCode'
      ---
    ORDER BY
      mpcm.comptype ASC,
      mpcm.compid ASC,
      mpcm.panelid ASC,
      mpc.condition ASC,
      mpcm.sorter ASC,
      mpcm.compid ASC;
/*-----------------------------------------------------------------*/
/*-----------------------------------------------------------------*/
