
/*=====RenameAnalyte===============================================*/
  -----Description-----
    --Utilize these scripts to change an analyte name when we
    --want to change an existing analyte.  
    --The following tables will need to be updated:
      --RESULTS
      --SPEC_ANALYTES
      --ANALYTES
    
    --NOTE:  I have only utilized this script on new analytes, so
    --there may be more tables that need to be updated and documented
    --here.
    --Also, these scripts were developed in segments and are just now
    --being put together, so there may be some errors or issues that
    --have not been flushed out.
    
    --Script Location: \\HSPHXVSTRLMS03\Starlims Online Help\SQL Repository\Version10\UpdateScripts\RenameAnalyte.sql
  -----
   
  -----History-----
    --2019.12.02 JTY: Remove Environmet variable and save to V12
    --2013.11.18 JTY: Created script
    --2013.12.05 JTY: Updated to include more tables
    --2013.12.24 JTY: Slight modifications to include testno on some scripts
    --2014.09.04 JTY: Updated for Chemistry tables:
      --[CALIB_ANALYTES].ANALYTE
      --[CANNED_COMMENTS].ANALYTE
      --[DCUTRANSLATIONS].ANALYTE
      --[DYNAMICDATA].ANALYTE*
  -----
/*=================================================================*/



/*=====Scripts to update Analyte===================================*/

/*-----Review Tables to be updated---------------------------------*/  
  --Analyte Name/sinonym review
--SELECT * FROM  AnalyteProperties ap  ORDER BY AP.ANALYTE asc
/*
  ---[AnalyteProperties]---
  SELECT DISTINCT
    ap.origrec,
    ap.analyte,
    '~' AS eol
    FROM AnalyteProperties ap 
    WHERE 1=1 
      AND ap.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
    ORDER BY
      ap.origrec DESC;
  ---
  ---[ConditionTestAnalytes]---      
  SELECT DISTINCT
    cta.origrec,
    cta.analyte,
    cta.testcode,
    cta.testgroupname,    
    '~' AS eol
    FROM ConditionTestAnalytes cta 
    WHERE 1=1 
      AND cta.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND cta.testcode = '&TestCode'
    ORDER BY
      cta.origrec DESC;      
  ---
  ---[HL7_Analytes]---
  SELECT DISTINCT
    ha.origrec,
    ha.analyte,
    ha.testcode,
    '~' AS eol
    FROM HL7_Analytes ha
    WHERE 1=1 
      AND ha.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND ha.testcode = '&TestCode'
    ORDER BY
      ha.origrec DESC;      
  ---  
  ---[results]---    
  SELECT DISTINCT
    r.testcode,
    r.origrec,
    r.analyte,
    r.sinonym,
    r.testno,
    '~' AS eol    
    FROM results r 
    WHERE 1=1 
      AND r.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND r.testcode = '&TestCode'      
    ORDER BY
      r.origrec DESC;
  ---
  ---[spec_analytes]---    
  SELECT DISTINCT
    sa.origrec,
    sa.testcode,
    sa.analyte,
    sa.specno,
    sa.synonim,
    sa.testcode,
    '~' AS eol
  FROM spec_analytes sa 
    WHERE 1=1 
      AND sa.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND sa.testcode  = '&TestCode'   
    ORDER BY
      sa.origrec DESC;
  ---

  ---[sp_analytes]---    
  SELECT DISTINCT
    spa.origrec,
    spa.testcode,
    spa.analyte,
    spa.sp_synonym,
    '~' AS eol
  FROM sp_analytes spa 
    WHERE 1=1 
      AND spa.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND spa.testcode  = '&TestCode'   
    ORDER BY
      spa.origrec DESC;
  ---

  ---[analytes]---
  SELECT DISTINCT
    a.origrec,
    a.analyte,
    a.sinonym,
    a.testcode,
    '~' AS eol
    FROM analytes a 
    WHERE 1=1 
      AND a.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND a.testcode = '&TestCode'
    ORDER BY
      a.origrec DESC;
  ---
  ---[PossibleResults]---
  SELECT DISTINCT
    pr.origrec,
    pr.analyte,
    pr.testcode,
    pr.result,
    '~' AS eol
    FROM PossibleResults pr 
    WHERE 1=1 
      AND pr.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND pr.testcode = '&TestCode'      
    ORDER BY
      pr.origrec DESC;
  ---
  ---[TestLoincCodes]---
  SELECT DISTINCT
    tlc.origrec,
    tlc.testcode,
    tlc.analyte,
    tlc.loincnumber,
    tlc.version,
    '~' AS eol
    FROM TestLoincCodes tlc
    WHERE 1=1 
      AND tlc.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND tlc.testcode = '&TestCode'      
    ORDER BY
      tlc.origrec DESC;
  ---
  ---[floweventlog]---
  SELECT DISTINCT
    fel.origrec,
    fel.testcode,
    fel.analyte,
    fel.thecomment,
    '~' AS eol
    FROM floweventlog fel
    WHERE 1=1 
      AND fel.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND fel.testcode = '&TestCode'      
    ORDER BY
      fel.origrec DESC;
  ---
  ---[resultsaudittrail]---
  SELECT DISTINCT
    rat.origrec,
    rat.testcode,
    rat.analyte,
    rat.currentvalue,
    rat.previousvalue,
    '~' AS eol
    FROM resultsaudittrail rat
    WHERE 1=1 
      AND rat.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND rat.testcode = '&TestCode'      
    ORDER BY
      rat.origrec DESC;
  ---
  ---[res_attachments]---
  SELECT DISTINCT
    ra.origrec,
    ra.testcode,
    ra.analyte,
    ra.mycomment,
    '~' AS eol
    FROM res_attachments ra
    WHERE 1=1 
      AND ra.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND ra.testcode = '&TestCode'      
    ORDER BY
      ra.origrec DESC;
  ---
  ---[retestresults]---
  SELECT DISTINCT
    rr.origrec,
    rr.testcode,
    rr.analyte,
    rr.runno,
    rr.numres,
    '~' AS eol
    FROM retestresults rr
    WHERE 1=1 
      AND rr.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND rr.testcode = '&TestCode'      
    ORDER BY
      rr.origrec DESC;
  ---
  ---[calib_analytes]---
  SELECT DISTINCT
    ca.origrec,
    ca.analyte,
    ca.testcode,    
    ca.inventoryid,
    '~' AS eol
    FROM calib_analytes ca
    WHERE 1=1 
      AND ca.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND ca.testcode = '&TestCode'      
    ORDER BY
      ca.origrec DESC;
  ---
  ---[canned_comments]---
  SELECT DISTINCT
    cc.origrec,
    cc.analyte,
    cc.testcode,    
    cc.status,
    cc.start_date,
    cc.expiration_date,
    cc.code,
    '~' AS eol
    FROM canned_comments cc
    WHERE 1=1 
      AND cc.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
      AND cc.testcode = '&TestCode'      
    ORDER BY
      cc.origrec DESC;
  ---
  ---[DcuTranslations]---
  SELECT DISTINCT
    dcu.origrec,
    dcu.eqid,
    dcu.analyte,
    dcu.instanalyte,
    '~' AS eol
    FROM DcuTranslations dcu
    WHERE 1=1 
      AND dcu.analyte IN ('&OldAnalyteName', '&NewAnalyteName')
    ORDER BY
      dcu.origrec DESC;
  ---
  */
/*-----------------------------------------------------------------*/  



/*-----Change Analyte Name and Synonim-----------------------------*/  
  --Run these scripts one at a time to update database.  This way
  --we can roll-back changes if we have a problem.
  

  -----Disable Table Constraints----
/*  
    ALTER TABLE results DISABLE CONSTRAINT RESULTS_FK2;
    ALTER TABLE spec_analytes DISABLE CONSTRAINT SPEC_ANALYTES_FK2;
    ALTER TABLE SP_ANALYTES DISABLE CONSTRAINT SP_ANALYTES_ANALYTES_FK;
    ALTER TABLE calib_analytes DISABLE CONSTRAINT calib_analytes_fk2; 
    ALTER TABLE calib_analytes DISABLE CONSTRAINT calib_analytes_fk2; 
    ALTER TABLE TestLoincCodes DISABLE CONSTRAINT TESTLOINCCODES_PK;  
*/    
  ----- ----

/*
  ---Update [AnalyteProperties] table, [analyte] value       
    UPDATE AnalyteProperties ap  
    SET
      ap.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (ap.analyte IN ('&OldAnalyteName', '&NewAnalyteName'));
  --- 
        
  ---Update [ConditionTestAnalytes] table, [analyte] value       
    UPDATE ConditionTestAnalytes cta  
    SET
      cta.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (cta.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (cta.testcode = '&TestCode');      
  --- 
  
  ---Update [HL7_Analytes] table, [analyte] value       
    UPDATE HL7_Analytes ha
    SET
      ha.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (ha.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (ha.testcode = '&TestCode');      
  --- 
  
  ---Update [RESULTS] table [analyte] and [sinonym] column values---
    UPDATE results r  
    SET
      r.analyte = '&NewAnalyteName',
      r.sinonym = '&NewAnalyteName'
    WHERE 1=1
      AND (r.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      --AND (r.analyte = '&OldAnalyteName' OR r.sinonym = '&OldAnalyteName')
      AND r.testcode = '&TestCode';
  ---

  ---Update [SPEC_ANALYTES] table [analyte] & [synonim] column values---   
    UPDATE spec_analytes sa 
    SET
      sa.analyte = '&NewAnalyteName',
      sa.synonim = '&NewAnalyteName'
    WHERE 1=1
      AND sa.testcode = '&TestCode'
      AND sa.analyte  IN ('&OldAnalyteName', '&NewAnalyteName');
  ---
  
  ---Update [sp_analytes] table [analyte] & [sp_synonym] column values---
    UPDATE sp_analytes spa 
    SET
      spa.analyte = '&NewAnalyteName',
      spa.sp_synonym = '&NewAnalyteName'
    WHERE 1=1
      AND spa.testcode = '&TestCode'
      AND spa.analyte IN ('&OldAnalyteName', '&NewAnalyteName');
  ---  
  
  ---Update [analytes] table, [analyte] value    
    UPDATE analytes a  
    SET
      a.analyte = '&NewAnalyteName',
      a.sinonym = '&NewAnalyteName'
    WHERE 1=1
      AND a.analyte IN ('&OldAnalyteName', '&NewAnalyteName')    
      AND (a.testcode = '&TestCode');
  ---

  ---Update [PossibleResults] table, [analyte] value   
    UPDATE PossibleResults pr
    SET
      pr.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (pr.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (pr.testcode = '&TestCode');      
  --- 

  ---Update [TestLoincCodes] table, [analyte] value
    UPDATE TestLoincCodes tlc
    SET
      tlc.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (tlc.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (tlc.testcode = '&TestCode');      
  --- 
  
  ---Update [floweventlog] table, [analyte] value   
    UPDATE floweventlog fel
    SET
      fel.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (fel.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (fel.testcode = '&TestCode');      
  ---   
  
  ---Update [resultsaudittrail] table, [analyte] value   
    UPDATE resultsaudittrail rat
    SET
      rat.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (rat.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (rat.testcode = '&TestCode');      
  ---   

  ---Update [res_attachments] table, [analyte] value   
    UPDATE res_attachments ra
    SET
      ra.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (ra.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (ra.testcode = '&TestCode');      
  ---   

  ---Update [retestresults] table, [analyte] value   
    UPDATE retestresults rr
    SET
      rr.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (rr.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (rr.testcode = '&TestCode');      
  ---   
  ---Update [calib_analytes] table, [analyte] value   
    UPDATE calib_analytes ca
    SET
      ca.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (ca.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (ca.testcode = '&TestCode');      
  --- 
  ---Update [canned_comments] table, [analyte] value   
    UPDATE canned_comments cc
    SET
      cc.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (cc.analyte IN ('&OldAnalyteName', '&NewAnalyteName'))
      AND (cc.testcode = '&TestCode');      
  --- 
  ---Update [DcuTranslations] table, [analyte] value   
    UPDATE DcuTranslations dcu
    SET
      dcu.analyte = '&NewAnalyteName'
    WHERE 1=1
      AND (dcu.analyte IN ('&OldAnalyteName', '&NewAnalyteName'));      
  --- 
*/  
  
/*
  ---Enable Constraints---
    ALTER TABLE results ENABLE CONSTRAINT RESULTS_FK2;
    ALTER TABLE spec_analytes ENABLE CONSTRAINT SPEC_ANALYTES_FK2;
    ALTER TABLE SP_ANALYTES ENABLE CONSTRAINT SP_ANALYTES_ANALYTES_FK;
    ALTER TABLE calib_analytes ENABLE CONSTRAINT calib_analytes_fk2; 
    ALTER TABLE calib_analytes ENABLE CONSTRAINT calib_analytes_fk2; 
    ALTER TABLE TestLoincCodes ENABLE CONSTRAINT TESTLOINCCODES_PK;      
  ---  
*/


  
/*-----------------------------------------------------------------*/  
/*=================================================================*/


  


/*=====Misc SQL ====================================================*/
  --This is where we are keeping misc code that might be needed.
  
--UPDATE results r set testno = 'Molecular Salmonella Serotyping' WHERE r.analyte = 'Molecular Serotyping'
/*----------Troubleshooting----------*/
/*


/*----------SPEC_ANALYTES check----------*/
/*
    SELECT DISTINCT
      sa.testcode AS sa_testcode,
      a.testcode AS a_testcode,
      sa.analyte AS sa_analyte,
      a.analyte AS a_analyte,
      sa.origrec AS sa_origrec,
      a.origrec AS a_origrec,
    --  a.origrec AS a_origrec,
    --  sa.origrec AS sa_origrec  
      '~' AS eol
    FROM spec_analytes sa
      LEFT OUTER JOIN analytes a ON (sa.testcode = a.testcode AND sa.analyte = a.analyte)
    WHERE 1=1
    --  AND sa.testcode = '&TestCode'
      AND ((a.testcode IS NULL) OR (a.analyte IS NULL))
    ORDER BY 
      sa.testcode ASC,
      sa.analyte ASC;
      
      SELECT DISTINCT
      sa.testcode AS sa_testcode,
      a.testcode AS a_testcode,
      sa.analyte AS sa_analyte,
      a.analyte AS a_analyte,
      a.origrec AS a_origrec,
      sa.origrec AS sa_origrec,
      '~' AS eol
    FROM analytes a
      LEFT OUTER JOIN spec_analytes sa ON (sa.testcode = a.testcode AND sa.analyte = a.analyte)
    WHERE 1=1
    --  AND sa.testcode = '&TestCode'
      AND ((sa.testcode IS NULL) OR (sa.analyte IS NULL))
    ORDER BY 
      a.testcode ASC,
      a.analyte ASC;
    --- ---
*/
/*
    SELECT DISTINCT a.testcode, a.sinonym FROM Analytes a where a.testcode IN ('4','397','398') ORDER BY a.testcode ASC;
    SELECT DISTINCT sa.testcode, sa.analyte, sa.synonim, sa.specno FROM spec_analytes sa where sa.testcode IN ('4','397','398') ORDER BY sa.testcode ASC;
    SELECT DISTINCT sa.testcode, sa.analyte, sa.sp_synonym  FROM sp_analytes sa where sa.testcode IN ('4','397','398') ORDER BY sa.testcode ASC;
*/
    --UPDATE sundata_sat.spec_analytes sa SET sa.analyte = 'E. coli' WHERE testcode = '422';
    --UPDATE sundata_sat.spec_analytes sa SET sa.synonim = 'E. coli MTF' WHERE testcode = '422';

    --UPDATE Analytes a SET a.sinonym = 'E. coli' WHERE a.origrec = '5019'
    --UPDATE sp_analytes sa SET sa.analyte = 'E. coli' WHERE sa.testcode = '4'
    --UPDATE spec_analytes sa SET sa.synonim = 'E. coli' WHERE sa.testcode = '397'
/*---------- ----------*/



/*----------SP_ANALYTES check----------*/
/*
    SELECT DISTINCT
      sa.testcode AS sa_testcode,
      a.testcode AS a_testcode,
      sa.analyte AS sa_analyte,
      a.analyte AS a_analyte,
--      sa.origrec AS sa_origrec,
--      a.origrec AS a_origrec,
    --  a.origrec AS a_origrec,
    --  sa.origrec AS sa_origrec  
      '~' AS eol
    FROM sp_analytes sa
      LEFT OUTER JOIN analytes a ON (sa.testcode = a.testcode AND sa.analyte = a.analyte)
    WHERE 1=1
--      AND sa.testcode IN ('397','398')
      AND ((a.testcode IS NULL) OR (a.analyte IS NULL))
    ORDER BY 
      sa.testcode ASC,
      sa.analyte ASC;
      
      SELECT DISTINCT
      sa.testcode AS sa_testcode,
      a.testcode AS a_testcode,
      sa.analyte AS sa_analyte,
      a.analyte AS a_analyte,
--      a.origrec AS a_origrec,
--      sa.origrec AS sa_origrec,
      '~' AS eol
    FROM analytes a
      LEFT OUTER JOIN sp_analytes sa ON (sa.testcode = a.testcode AND sa.analyte = a.analyte)
    WHERE 1=1
--      AND sa.testcode IN ('397','398')
      AND ((sa.testcode IS NULL) OR (sa.analyte IS NULL))
    ORDER BY 
      a.testcode ASC,
      a.analyte ASC;
    --- ---
*/    
/*---------- ----------*/

/*=================================================================*/
