/*-----Test HL7 Messaging Sync-----------------------------------------------*/

  -----DESCRIPTION-----
    --These sets of scripts can be utilized to help ensure HL7 Messaging for
    --the selected test(s) match between environments.
    --This is accomplished by in the following steps:
      --01. Setup LOINC Codes: Make sure LOINC codes are in the target Environment.
      --02. Setup SNOMED Codes: Make sure SNOMED codes are in the target Environment.
      --03. Sync Test Codes: Match Test codes as listed in the tests datagrid.
      --04. Sync AnalyteLOINC Codes: Match Analyte LOINC Codes in Target Environment.
      --05. Sync PossibleResultsSNOMED Codes: Match the SNOMED codes from the Possible
      --    Results to the target Environment.
      
    --NOTE: The SNOMED and LOINC codes may need to be cleaned up before performing
    --      this tasks since there seems to be a number of these codes that are duplicate
    --      and this will cause a "Unstable Records" error.
  ----- -----
  
  -----HISTORY-----
    --2020-09-05 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Setup LOINC Codes-------------------------------------------------*/
  -----DESCRIPTION-----
    --Take the unique LOINC codes associated with the tests analytes and 
    --make sure they are in the target envionment.
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT
      t.testno,
      tlc.analyte,
      '~' AS sp1,
      lc.loincnumber,
      lc.origrec,
      lc.loinccomponenet,
      lc.codestatus,
      lc.loincmethod,      
      lc.loincproperty,            
      lc.classcode,
      lc.loincscale, 
      lc.loincshortname,
      lc.loincsystems,
      lc.loinctime,
      lc.mapto,
      lc.version,
      lc.origsts,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
      INNER JOIN loinccodes lc ON (tlc.loincnumber = lc.loincnumber)
      INNER JOIN loincversion lv ON (lc.version = lv.version)
    WHERE 1=1
      AND lv.status = 'Active'
      AND t.testno IN (&TestNameList)
    ORDER BY
      lc.loincnumber ASC,
      t.testno ASC;
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      testno          VARCHAR2(50 CHAR),
      analyte         VARCHAR2(50 CHAR),
      sp1             VARCHAR2(1 CHAR),      
      loincnumber     VARCHAR2(255 CHAR),
      origrec         NUMBER(22),
      loinccomponenet VARCHAR2(255 CHAR),
      codestatus      VARCHAR2(255 CHAR),
      loincmethod     VARCHAR2(255 CHAR),
      loincproperty   VARCHAR2(255 CHAR),
      classcode       VARCHAR2(255 CHAR),
      loincscale      VARCHAR2(255 CHAR),
      loincshortname  VARCHAR2(3000 CHAR),
      loincsystems    VARCHAR2(255 CHAR),
      loinctime       VARCHAR2(255 CHAR),
      mapto           VARCHAR2(255 CHAR),
      version         VARCHAR2(255 CHAR),
      origsts         CHAR(1 CHAR)      
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: the LOINC Component can cause issues on importing.  Double check to make sure the tool
      --hasn't added a date converstion to this field automatically, if it has, remove it.
  ----- -----

  -----08. Merge/Upate LOINC CODE table-----
    --Here we are going to update the LOINC codes.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.

    MERGE INTO loinccodes t1
    USING (
    SELECT DISTINCT
      --tmp.testno,
      tmp.loincnumber,
      tmp.origrec,      
      tmp.loinccomponenet,
      tmp.codestatus,
      tmp.loincmethod,      
      tmp.loincproperty,            
      tmp.classcode,
      tmp.loincscale, 
      tmp.loincshortname,
      tmp.loincsystems,
      tmp.loinctime,
      tmp.mapto,
      tmp.version,
      tmp.origsts
    FROM adhs_temp tmp
    WHERE 1=1
--      AND tmp.classcode = 'LRN.LOCAL'
    ORDER BY
      tmp.loincnumber ASC,
      tmp.origrec ASC
    ) t2
    ON (1=1
        AND t1.loincnumber = t2.loincnumber
        AND t1.version = t2.version
        AND t1.classcode = t2.classcode
        )
    WHEN MATCHED THEN
      UPDATE SET 
        t1.loinccomponenet = t2.loinccomponenet,
        t1.loincmethod = t2.loincmethod,
        t1.loincproperty = t2.loincproperty,
        t1.loincscale =  t2.loincscale,
        t1.loincshortname = t2.loincshortname,
        t1.loincsystems = t2.loincsystems,
        t1.loinctime = t2.loinctime,
        t1.mapto = t2.mapto,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.loincnumber,
        t1.loinccomponenet,
        t1.codestatus,
        t1.loincmethod,      
        t1.loincproperty,            
        t1.classcode,
        t1.loincscale, 
        t1.loincshortname,
        t1.loincsystems,
        t1.loinctime,
        t1.origrec,      
        t1.mapto,
        t1.version,
        t1.origsts
      )
      VALUES (
        t2.loincnumber,
        t2.loinccomponenet,
        t2.codestatus,
        t2.loincmethod,      
        t2.loincproperty,            
        t2.classcode,
        t2.loincscale, 
        t2.loincshortname,
        t2.loincsystems,
        t2.loinctime,
        t2.origrec,      
        t2.mapto,
        t2.version,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/  
/*---------------------------------------------------------------------------*/





/*---------------------------------------------------------------------------*/
/*-----02. Setup SNOMED Codes------------------------------------------------*/
  -----DESCRIPTION-----
    --We will take the SNOMED codes associated with all of the Possible Results
    --for the identified test and migrate/Sync them in the Target Environment.
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT
      t.testno,
      t.testcode,
      pr.analyte,
      pr.result,
      pr.result_status,
      pr.code_system_oid,
      pr.localnumber,
      pr.loincnumber,
      '~' AS sp1,
      sc.origrec,
      sc.snomedcode,
      sc.snomeddescriptionid,
      sc.snomedelement,
      sc.snomed_group,
      sc.snomedconceptid,
      sc.loinccondname,
      sc.origsts,
      '~' AS eol
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
      INNER JOIN snomedcodes sc ON (1=1 
        AND pr.snomedcode = sc.snomedcode)
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.result ASC;
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: SnomedCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      testno              VARCHAR2(50 CHAR),
      analyte             VARCHAR2(50 CHAR),
      result              VARCHAR2(120 CHAR),
      result_status       VARCHAR2(20 CHAR),
      conclusion_report   VARCHAR2(1024 CHAR),
      localnumber         VARCHAR2(10 CHAR),
      loincnumber         VARCHAR2(10 CHAR),
      sp1                 VARCHAR2(1 CHAR),
      origrec             NUMBER(22),
      snomedcode          VARCHAR2(30 CHAR),
      snomeddescriptionid VARCHAR2(255 CHAR),
      snomedelement       VARCHAR2(255 CHAR),
      snomed_group        VARCHAR2(20 CHAR),
      snomedconceptid     VARCHAR2(255 CHAR),
      loinccondname       VARCHAR2(50 CHAR),
      origsts             CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate SnomedCodes table-----
    --Here we are going to update the SnomedCodes Table.  
    --You can select the Using SQL part to preview the
    -- data comming in before executing the Merge.
    MERGE INTO snomedcodes t1
    USING (
    SELECT DISTINCT
      --tmp.testno,
      --tmp.origrec,
      tmp.snomedcode,
      tmp.snomeddescriptionid,
      tmp.snomedelement,
      tmp.snomed_group,
      tmp.snomedconceptid,
      tmp.loinccondname,
      --tmp.origsts
      'N' AS origsts
    FROM adhs_temp tmp
    ORDER BY
      --tmp.testno ASC,
      tmp.snomedcode ASC
    ) t2
    ON (  1=1
          AND t1.snomedcode =t2.snomedcode
        )
    WHEN MATCHED THEN
      UPDATE SET 
        t1.snomeddescriptionid = t2.snomeddescriptionid,
        t1.snomedelement = t2.snomedelement,
        t1.snomed_group = t2.snomed_group,
        t1.snomedconceptid = t2.snomedconceptid,
        t1.loinccondname = t2.loinccondname,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.snomedcode,
        t1.snomeddescriptionid,
        t1.snomedelement,
        t1.snomed_group,
        t1.snomedconceptid,
        t1.loinccondname
      )
      VALUES (
        t2.snomedcode,
        t2.snomeddescriptionid,
        t2.snomedelement,
        t2.snomed_group,
        t2.snomedconceptid,
        t2.loinccondname
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
  */
/*---------------------------------------------------------------------------*/










/*---------------------------------------------------------------------------*/
/*-----03. Test Code Sync----------------------------------------------------*/
  -----DESCRIPTION-----
    --Here we are going to sync the HL7 message configuration associated with the
    --identified test in in the Test Datagrid.
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT 
      t.testno,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name
    FROM tests t
    WHERE 1=1 
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC;
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: TestCode_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      testno                VARCHAR2(50 CHAR),
      phvs_code_system_code VARCHAR2(20 CHAR),
      phvs_code_system_oid  VARCHAR2(35 CHAR),
      phvs_concept_code     VARCHAR2(15 CHAR),
      phvs_concept_name     VARCHAR2(50 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate Tests table-----
    --Here we are going to update the Tests.
    --You can select the Using SQL part to preview the
    -- data comming in before executing the Merge.
    MERGE INTO tests t1
    USING (
      SELECT DISTINCT
        tmp.testno,
        t.testcode,
        tmp.phvs_code_system_code,
        tmp.phvs_code_system_oid,
        tmp.phvs_concept_code,
        tmp.phvs_concept_name
      FROM adhs_temp tmp
      INNER JOIN tests t ON (tmp.testno = t.testno)
      ORDER BY
        tmp.testno ASC
    ) t2
    ON (t1.testcode = t2.testcode)
    WHEN MATCHED THEN
      UPDATE SET 
        t1.phvs_code_system_code = t2.phvs_code_system_code,
        t1.phvs_code_system_oid = t2.phvs_code_system_oid,
        t1.phvs_concept_code = t2.phvs_concept_code,
        t1.phvs_concept_name = t2.phvs_concept_name
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/  
/*---------------------------------------------------------------------------*/







/*---------------------------------------------------------------------------*/
/*-----04. Sync AnalyteLOINC Codes-------------------------------------------------*/
  -----DESCRIPTION-----
    --Here we sync the Test Analyte LONC Codes for the identified test(s)
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT 
      t.testno,
      --tlc.testcode,
      tlc.analyte,
      tlc.loinccomponenet,
      tlc.loincdefault,
      tlc.loincmethod,
      tlc.loincnumber,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems,
      tlc.loinctime,
      tlc.origsts,
      tlc.version,
      tlc.hl7_reportable,
      tlc.code_system_oid,
      tlc.status
    FROM testloinccodes tlc
      INNER JOIN tests t ON (tlc.testcode = t.testcode)
    WHERE 1=1 
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      tlc.analyte ASC;      
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: AnalyteLoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      testno          VARCHAR2(50 CHAR),
      analyte         VARCHAR2(50 CHAR),
      loinccomponenet VARCHAR2(255 CHAR),
      loincdefault    VARCHAR2(2 CHAR),
      loincmethod     VARCHAR2(200 CHAR),
      loincnumber     VARCHAR2(50 CHAR),
      loincproperty   VARCHAR2(100 CHAR),
      loincscale      VARCHAR2(5 CHAR),
      loincsystems    VARCHAR2(100 CHAR),
      loinctime       VARCHAR2(50 CHAR),
      origsts         CHAR(1 CHAR),
      testcode        NUMBER(22),
      version         VARCHAR2(10 CHAR),
      hl7_reportable  VARCHAR2(1 CHAR),
      code_system_oid VARCHAR2(35 CHAR),
      status          VARCHAR2(10 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: the LOINC Component can cause issues on importing.  Double check to make sure the tool
      --hasn't added a date converstion to this field automatically, if it has, remove it.
  ----- -----

  -----08. Merge/Upate XXXXXX table-----
    --Here we are going to update the XXXXXXX.  
    --You can select the Using SQL part to preview the
    -- data comming in before executing the Merge.
    MERGE INTO testloinccodes t1
    USING (
    SELECT DISTINCT
      tmp.testno,
      t.testcode,
      tmp.analyte,
      tmp.loinccomponenet,
      tmp.loincdefault,
      tmp.loincmethod,
      tmp.loincnumber,
      tmp.loincproperty,
      tmp.loincscale,
      tmp.loincsystems,
      tmp.loinctime,
      tmp.origsts,
      tmp.version,
      tmp.hl7_reportable,
      tmp.code_system_oid,
      tmp.status
    FROM adhs_temp tmp
    INNER JOIN tests t ON (tmp.testno = t.testno)
    ORDER BY
      tmp.testno ASC,
      tmp.analyte ASC
    ) t2
    ON (1=1
      AND t1.testcode = t2.testcode
      AND t1.analyte = t2.analyte)
    WHEN MATCHED THEN
      UPDATE SET 
        t1.loinccomponenet = t2.loinccomponenet,
        t1.loincdefault = t2.loincdefault,
        t1.loincmethod = t2.loincmethod,
        t1.loincnumber = t2.loincnumber,
        t1.loincproperty = t2.loincproperty,
        t1.loincscale = t2.loincscale,
        t1.loincsystems = t2.loincsystems,
        t1.loinctime = t2.loinctime,
        t1.origsts = t2.origsts,
        t1.version = t2.version,
        t1.hl7_reportable = t2.hl7_reportable,
        t1.code_system_oid = t2.code_system_oid,
        t1.status = t2.status
    WHEN NOT MATCHED THEN
      INSERT (
        t1.testcode,
        t1.analyte,
        t1.loinccomponenet,
        t1.loincdefault,
        t1.loincmethod,
        t1.loincnumber,
        t1.loincproperty,
        t1.loincscale,
        t1.loincsystems,
        t1.loinctime,
        t1.origsts,
        t1.version,
        t1.hl7_reportable,
        t1.code_system_oid,
        t1.status
      )
      VALUES (
        t2.testcode,
        t2.analyte,
        t2.loinccomponenet,
        t2.loincdefault,
        t2.loincmethod,
        t2.loincnumber,
        t2.loincproperty,
        t2.loincscale,
        t2.loincsystems,
        t2.loinctime,
        t2.origsts,
        t2.version,
        t2.hl7_reportable,
        t2.code_system_oid,
        t2.status
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/
/*---------------------------------------------------------------------------*/








/*---------------------------------------------------------------------------*/
/*-----05. Sync PossibleResultsSNOMED Codes----------------------------------*/
  -----DESCRIPTION-----
    --Here we are going to Sync the Possible Results SNOMED codes for the 
    --identified tests.
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT
      t.testno,
      pr.analyte,
      pr.result,
      pr.origrec,
      pr.cdc_reportable,
      pr.elr_reportable,
      pr.snomedcode,
      pr.snomedconceptid,
      pr.snomeddescriptionid,
      pr.code_system_oid,
      pr.localnumber,
      pr.loincnumber,
      calcname,
      conclusion_report,
      result_status,
      sorter,
      pr.origsts
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.result ASC;  
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: PossibleResultsSNOMED_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment     
    CREATE TABLE adhs_temp(
      testno              VARCHAR2(50 CHAR),
--      sp1                 VARCHAR2(1 CHAR),
      analyte             VARCHAR2(50 CHAR),
      result              VARCHAR2(120 CHAR),
      origrec             NUMBER(22),
      cdc_reportable      VARCHAR2(1 CHAR),
      elr_reportable      VARCHAR2(1 CHAR),
      snomedcode          VARCHAR2(30 CHAR),
      snomedconceptid     VARCHAR2(255 CHAR),
      snomeddescriptionid VARCHAR2(255 CHAR),
      code_system_oid     VARCHAR2(35 CHAR),
      localnumber         VARCHAR2(10 CHAR),
      loincnumber         VARCHAR2(10 CHAR),
      calcname            VARCHAR2(20 CHAR),
      conclusion_report   VARCHAR2(1024 CHAR),
      result_status       VARCHAR2(20 CHAR),
      sorter              NUMBER(22),
      origsts             CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate PossibleResults table-----
    --Here we are going to update the PossibleResults.  
    --You can select the Using SQL part to preview the
    -- data comming in before executing the Merge.
    MERGE INTO possibleresults t1
    USING (
      SELECT DISTINCT
        tmp.testno,
        t.testcode,
        tmp.analyte,
        tmp.result,
        tmp.origrec,
        tmp.cdc_reportable,
        tmp.elr_reportable,
        tmp.snomedcode,
        tmp.snomedconceptid,
        tmp.snomeddescriptionid,
        tmp.code_system_oid,
        tmp.localnumber,
        tmp.loincnumber,
        tmp.calcname,
        tmp.conclusion_report,
        tmp.result_status,
        tmp.sorter,
        tmp.origsts
      FROM adhs_temp tmp
        INNER JOIN tests t ON (tmp.testno = t.testno)
      ORDER BY
        tmp.testno ASC,
        tmp.analyte ASC,
        tmp.result ASC
    ) t2
    ON (  1=1
          AND t1.testcode = t2.testcode
          AND t1.analyte = t2.analyte
          AND t1.result = t2.result
        )
    WHEN MATCHED THEN
      UPDATE SET 
        t1.cdc_reportable = t2.cdc_reportable,
        t1.elr_reportable = t2.elr_reportable,
        t1.snomedconceptid = t2.snomedconceptid,
        t1.snomeddescriptionid = t2.snomeddescriptionid,
        t1.code_system_oid = t2.code_system_oid,
        t1.loincnumber = t2.loincnumber,
        t1.localnumber = t2.localnumber,
        t1.calcname = t1.calcname,
        t1.conclusion_report = t2.conclusion_report,
        t1.result_status = t2.result_status,
        t1.sorter = t2.sorter,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.testcode,
        t1.analyte,
        t1.result,
        t1.cdc_reportable,
        t1.elr_reportable,
        t1.snomedcode,
        t1.snomedconceptid,
        t1.snomeddescriptionid,
        t1.code_system_oid,
        t1.localnumber,
        t1.loincnumber,
        t1.calcname,
        t1.conclusion_report,
        t1.result_status,
        t1.sorter,
        t1.origsts
      )
      VALUES (
        t2.testcode,
        t2.analyte,
        t2.result,
        t2.cdc_reportable,
        t2.elr_reportable,
        t2.snomedcode,
        t2.snomedconceptid,
        t2.snomeddescriptionid,
        t2.code_system_oid,
        t2.localnumber,
        t2.loincnumber,
        '', --calcname,
        t2.conclusion_report,
        t2.result_status,
        t2.sorter,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/  
/*---------------------------------------------------------------------------*/















/*---------------------------------------------------------------------------*/
/*-----XX. NextTask-------------------------------------------------*/
  -----DESCRIPTION-----
    --Description
  ----- -----
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: XXXXX_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment

  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate XXXXXX table-----
    --Here we are going to update the XXXXXXX.  
    --You can select the Using SQL part to preview the
    -- data comming in before executing the Merge.

  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/  
/*---------------------------------------------------------------------------*/
























/***************SNOMED AND LOINC CLEANUP*******************************
/*---------------------------------------------------------------------------*/
/*
Select P.SNOMEDCODE, S.SNOMEDELEMENT, P.CODE_SYSTEM_OID, P.LOCALNUMBER
                from POSSIBLERESULTS P, SNOMEDCODES S
                where   P.TESTCODE = ?model:TESTCODE? and P.ANALYTE = ?model:ANALYTE? And 
                    (P.RESULT = ?model:FINAL? or CONCLUSION_REPORT = ?model:FINAL?) and
                    P.SNOMEDCODE = S.SNOMEDCODE and S.SNOMEDCONCEPTID = P.SNOMEDCODE"
*/

--DELETE FROM snomedcodes sc WHERE sc.snomedcode = '260415000' AND sc.origrec <> '179897'
--SELECT * FROM snomedcodes sc WHERE sc.snomedcode = '260415000'
/*
    SELECT DISTINCT
--      t.testno,
--      t.testcode,
--      pr.analyte,
--      pr.result,
--      pr.result_status,
--      pr.code_system_oid,
--      pr.localnumber,
--      pr.loincnumber,
--      '~' AS sp1,

      sc.snomedcode,
      sc.origrec,      
--      sc.snomeddescriptionid,
      sc.snomedelement,
      sc.snomed_group,
      sc.snomedconceptid,
--      sc.loinccondname,
--      sc.origsts,
      '~' AS eol
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
      INNER JOIN snomedcodes sc ON (1=1 
        AND pr.snomedcode = sc.snomedcode)
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      sc.snomedcode ASC,
      sc.origrec ASC
*/      
/*
SELECT DISTINCT sc.snomedcode, sc.origrec, sc.snomeddescriptionid, sc.snomedconceptid, sc.snomedelement FROM snomedcodes sc
WHERE 1=1 AND sc.snomedcode = '&SNOMEDCode'
ORDER BY sc.origrec DESC
*/
/*
DELETE FROM snomedcodes sc WHERE 1=1 AND sc.snomedcode = '&SNOMEDCode' AND sc.origrec <> '&SnomedOrigrec'
*/
/*---------------------------------------------------------------------------*/



























