/*
-----02 Approval Date Issue------------------------------------------------
   -----Desrciption-----
     We seem to be having an issue when completing a default test run in that
     the completion date for the default run is overriding the Micro test completion
     date if the micro test has already been completed.  It appears that this situation
     only happens in the Salmonella Culture panel for the following situation:
     --Salmonella Culture (Micro test) has already been completed.
     --Salmonella Serotyping (Default test) run is completed (Not yet approved) and 
       when completed, overwrites the Salmonella Culture completion date.

     This behavior started after the V12 upgrade.
         
     The queries provided below help identify the samples with issues.
   ----- -----


   -----History-----
     2019.12.10 JTY: Created file
   ----- -----
   
---------------------------------------------------------------------------
*/


-----01. Identify Suspects-------------------------------------------------
  --Identify any samples meeting criteria of Default test being completed
  --at the same date of the micro test.

      SELECT DISTINCT
        f.external_id,
        f.dept,
        f.folderno,
        f.apprdate AS folder_app,
        f.testgroupname,  
        ot.testno AS micro_test,
        to_date(ot.apprdate, 'DD-MON-YY') AS micro_app,
        ot2.testno AS default_test,
        to_date(ot2.apprdate, 'DD-MON-YY') AS default_app,
        '~' AS eol        
      FROM folders f
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN tests t ON (ot.testcode = t.testcode)
        INNER JOIN ordtask ot2 ON (ot.folderno = ot2.folderno)
        INNER JOIN tests t2 ON (ot2.testcode = t2.testcode)        
      WHERE 1=1
--AND f.external_id = 'AZ00090111'      
        --Micro test criteria--
          AND t.testflag = 'Micro'
          AND ot.apprdate IS NOT NULL
        -- --
        --Default test criteria--
          AND t2.testflag = 'Default'
          AND ot2.apprdate IS NOT NULL
          AND to_date(ot2.apprdate, 'DD-MON-YY') >= to_date('18-OCT-2019', 'DD-MON-YY') --Default test approved after upgrade
        -- --          
        AND to_date(ot2.apprdate, 'DD-MON-YY') = to_date(ot.apprdate, 'DD-MON-YY')    --Micro and Default test approval dates identical
      ORDER BY
        f.dept ASC,
        f.testgroupname ASC,
        f.external_id ASC;
---------------------------------------------------------------------------


-----02. Identify Test Subjects--------------------------------------------
  --Identify any samples that will be good to check to see if issue is resolved.
/*  
      SELECT DISTINCT
        f.external_id,
        f.folderno,
        f.apprdate AS folder_app,
        f.testgroupname,  
        ot.testno AS micro_test,
        to_date(ot.apprdate, 'DD-MON-YY') AS micro_app,
        ot2.testno AS default_test,
        to_date(ot2.apprdate, 'DD-MON-YY') AS default_app,
        ot.tsa AS micro_tsa,
        ot.ts AS micro_ts,
        ot.apprvedby AS micro_appby,
        ot2.tsa AS default_tsa,
        ot2.ts AS default_ts,
        ot2.apprvedby AS default_appby,
        '~' AS eol        
      FROM folders f
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN tests t ON (ot.testcode = t.testcode)
        INNER JOIN ordtask ot2 ON (ot.folderno = ot2.folderno)
        INNER JOIN tests t2 ON (ot2.testcode = t2.testcode)        
      WHERE 1=1
--        AND f.testgroupname = 'Salmonella Culture'
        AND t.testflag = 'Default'
--        AND ot.testno = 'Salmonella Culture'
--        AND ot2.testno = 'Salmonella Serotyping'
        AND t2.testflag = 'Default'
--        AND ot2.apprdate IS NULL
--        AND ot.apprdate IS NOT NULL
AND f.external_id = 'AZ00082099'        
--        AND f.external_id IN ('AZ00081877', 'AZ00081982', 'AZ00082081', 'AZ00082003', 'AZ00083058')
--        AND to_date(ot2.apprdate, 'DD-MON-YY') >= to_date(ot.apprdate, 'DD-MON-YY')
--        AND to_date(f.apprdate, 'DD-MON-YY') >= to_date('18-OCT-2019', 'DD-MON-YY')
      ORDER BY
        f.external_id ASC      
*/        
---------------------------------------------------------------------------
