
/*-----EmailDistributionList--------------------------------------------------*/
  -----DESCRIPTION-----
    --Use these scripts to generate email list based on your need.  The following
    --scripts are avaliable:
      -- 01. Email Distribution List based on Classification
      -- 02. Email List Detailst Based on Lookback and Delivery Method
  ----- -----
  
  -----HISTORY-----
    --2020.05.08 JTY: Addition of Hard Delivery Method Update
    --2019.10.28 JTY: Updated for V12
    --2017.09.19 JTY: Created Script
  ----- -----
  
/*---------------------------------------------------------------------------*/







/*-----01. Email Distribution List based on Classification-------------------*/
--Get distribution list for everyone by classifications:
-- 01. lab_folks
-- 02. epi_folks
-- 03. external_users
-- 04. report_receipients

WITH
  --01. lab_folks--
  lab_folks AS (
    SELECT DISTINCT
      (u.fullname || ' (' || u.usrnam || ')') AS name,
      r.role,
      u.email,
      u.userphone AS phone,
      '~' AS eol
    FROM users u
      INNER JOIN Userroles ur ON (u.usrnam =ur.usrnam)
      INNER JOIN roles r ON (ur.treeauth = r.treeauth)
    WHERE 1=1
      AND r.role IN ('PHScientist2', 'SectionSuper', 'Receiving', 'ReceivingSuper', 'Reports')
      AND u.status = 'Active'
      AND u.email IS NOT NULL
    ORDER BY
      name ASC
  ),
  -- --
  --02. epi_folks--
  epi_folks AS (
    SELECT DISTINCT
      (u.fullname || ' (' || u.usrnam || ')') AS name,
      r.role,
      u.email,
      u.userphone AS phone,
      '~' AS eol
    FROM users u
      INNER JOIN Userroles ur ON (u.usrnam =ur.usrnam)
      INNER JOIN roles r ON (ur.treeauth = r.treeauth)
    WHERE 1=1
      AND r.role IN ('Epi')
      AND u.status = 'Active'
      AND u.email IS NOT NULL
    ORDER BY
      name ASC
  ),
  -- --
  --03. external_users--
  external_users AS (
    SELECT DISTINCT
      r.role,
      (rc.compname || ' (' || rc.rasclientid || ')') AS organization,
      rc.county,
      (u.fullname || ' (' || u.usrnam || ')') AS user_name,
      u.email AS email,
      u.fax,
      u.userphone AS phone,
      '~' AS eol
    FROM rasclientcontacts rcc
      INNER JOIN rasclients rc ON (rcc.rasclientid = rc.rasclientid)
      INNER JOIN users u ON (rcc.usrnam = u.usrnam)
      INNER JOIN userroles ur ON (u.usrnam = ur.usrnam)
      INNER JOIN roles r ON (ur.treeauth = r.treeauth)
      
    WHERE 1=1
      AND u.status = 'Active'
      AND rc.rasclientid NOT IN ('ADHS')
      AND u.usrnam NOT IN ('YODERJ')
    ORDER BY
      UPPER(r.role) ASC,
      rc.county ASC,
      organization ASC,
      user_name ASC
  ),
  -- -- 
  --04. report_recipients--
  report_recipients AS (
    SELECT DISTINCT
      (rc.compname || ' (' || rc.rasclientid || ')') AS organization,
      rc.county,
      rcx.fullname AS name,
      rcx.email,
      rcx.contactphone AS phone,
      rcx.fax,
      rcx.submit_method AS delivery,
      '~' AS eol
    FROM rasclientcontactsext rcx
      INNER JOIN rasclients rc ON (rcx.rasclientid = rc.rasclientid)
    WHERE 1=1
      AND rc.rasclientid NOT IN ('ADHS')
      AND rcx.status = 'Active'
      AND rcx.email IS NOT NULL
    ORDER BY
      organization ASC,
      county ASC,
      name ASC
  ),
  -- --
  --all_emails--
  all_emails AS (
      SELECT DISTINCT
        '01. LabFolks' AS classification,
        lf.role,
        'ADHS' AS organization,
        'Maricopa' AS county,
        lf.name,
        lf.email,      
        lf.phone,
        '' AS fax,
        '' AS delivery,      
        lf.eol
      FROM lab_folks lf
    UNION  ALL
      SELECT DISTINCT
        '02. EpiFolks' AS classification,
        ef.role,
        'ADHS' AS organization,
        'Maricopa' AS county,
        ef.name,
        ef.email,      
        ef.phone,
        '' AS fax,
        '' AS delivery,      
        ef.eol
      FROM epi_folks ef
    UNION  ALL  
      SELECT DISTINCT
        '03. ExternalUsers' AS classification,
        ex.role,
        ex.organization,
        ex.county,
        ex.user_name AS name,
        ex.email,
        ex.phone,
        ex.fax,
        '' AS delivery,
        ex.eol
      FROM external_users ex
    UNION  ALL
      SELECT DISTINCT
        '04. ReportReceipients' AS classification,
        'Rpt_Delivery' AS role,
        rr.organization,
        rr.county,
        rr.name,
        rr.email,      
        rr.phone,
        rr.fax,
        rr.delivery,
        rr.eol
      FROM report_recipients rr
  )
  -- --
  --Final Query, Get distribution List--
    SELECT DISTINCT
      ae.classification,
      ae.role,
      ListAgg(email, ';') WITHIN GROUP(ORDER BY ae.classification) AS distribution_list,
      '~' AS eol
    FROM all_emails ae
    WHERE 1=1
---      AND ae.role = 'MyLims'
--      AND ae.role IN ('myCounty', 'MyLims')    
    GROUP BY 
      ae.classification,
      ae.role
    ORDER BY 
      ae.classification ASC,
      ae.role ASC;
  -- --

/*---------------------------------------------------------------------------*/



/*-----02. Email List Detail Based on Lookback and Delivery Method---------*/
 --Get Email list based on how specified delivery method and lookback period.
/*
  WITH
    delivery_list AS (
      SELECT DISTINCT
      '&DeliveryMethod' AS method,
      '&LookBackDays' AS LookbackDays,
        f.apprdate,
        f.dept,
        f.external_id,
        fcx.submit_method,
        rcx.email,
        '~' AS eol
      FROM folders f
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
        INNER JOIN &Environment.folderscontactsext fcx ON (f.folderno = fcx.folderno)
        INNER JOIN &Environment.rasclientcontactsext rcx ON ( 1=1
          AND fcx.rasclientid = rcx.rasclientid
          AND fcx.contactid = rcx.contactid)
      WHERE 1=1
        AND f.apprdate IS NOT NULL
        AND TRUNC(f.apprdate) BETWEEN TRUNC((sysdate - &LookBackDays)) AND TRUNC(sysdate)
        AND mr.field_varchar_80 IN ('Diagnostic', 'LRN-B')
        AND fcx.submit_method = '&DeliveryMethod' --Fax, Hard Copy, E-mail
        AND rcx.email IS NOT NULL
      ORDER BY
        f.apprdate DESC
    )
  SELECT DISTINCT
    dl.method,
    dl.LookbackDays,
    ListAgg(dl.email, ';') WITHIN GROUP (ORDER BY dl.method) AS distribution_list,
    '~' AS eol
  FROM delivery_list dl
  WHERE 1=1
  GROUP BY 
    dl.LookbackDays,
    dl.method;
*/
/*---------------------------------------------------------------------------*/
