
/*-----2019 Novel Coronavirus Query--------------------------------------------------------
  ---------------------------------------------------------------------------
  -----DESCRIPTION-----
    Queries associated with the Coronavirus.
  ----- -----
  
  -----HISTORY-----
    2020.03.06 JTY: Created Query
  ----- -----
---------------------------------------------------------------------------*/


  -----01 Active Samples-----
    SELECT DISTINCT
      cr.rasclientid,
      cr.external_id,
      cr.date_received,
      (cr.last_name || ' ' || cr.first_name) AS patient_name,
      ot.testno,
      r.final,
      ot.apprdate,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno = '2019 Novel Coronavirus rRT-PCR'
      AND f.apprdate IS NULL
      AND ot.apprdate IS NULL
    ORDER BY
      cr.date_received,
      patient_name ASC;
  ----- -----

  -----01 Completed Analysis-----
    SELECT DISTINCT
      cr.rasclientid,
      cr.external_id,
      (cr.last_name || ' ' || cr.first_name) AS patient_name,
      ot.testno,
      r.final,
      ot.apprdate,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno = '2019 Novel Coronavirus rRT-PCR'
      AND f.apprdate IS NOT NULL
    ORDER BY
      patient_name ASC,
      ot.apprdate DESC;
  ----- -----

  -----03 Infected Persons List-----
    SELECT DISTINCT
      cr.rasclientid,
      (cr.last_name || ' ' || cr.first_name) AS patient_name,
      ot.testno,
      r.final,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno = '2019 Novel Coronavirus rRT-PCR'
      AND ot.apprdate IS NOT NULL
      AND r.final = 'Detected'
    ORDER BY
      patient_name ASC;
  ----- -----
  
  -----05 All Samples-----
    SELECT DISTINCT
      cr.rasclientid,
      cr.external_id,
      f.apprdate AS folder_appr,
      (cr.last_name || ' ' || cr.first_name) AS patient_name,
      ot.testno,
      r.final,
      ot.apprdate,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno = '2019 Novel Coronavirus rRT-PCR'
    ORDER BY
      patient_name ASC,
      ot.apprdate DESC;
  ----- -----


  -----06 Submitting Agencies volume by County-----
    SELECT DISTINCT
      rc.county,
      (rc.compname || ' (' || rc.rasclientid || ')') AS submitting_agency,
      cr.external_id,
      cr.date_received,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno = '2019 Novel Coronavirus rRT-PCR'
      AND rc.county = '&County'
      AND to_date(cr.date_received, 'DD-MON-YY') = to_date('&Received', 'DD-MON-YYYY')
      
    ORDER BY
      rc.county ASC,
      submitting_agency ASC,
      cr.external_id ASC;
  ----- -----


  -----07 Logged for Coronavirus or FilmArray-----
    SELECT DISTINCT
      cr.rasclientid,
      cr.external_id,
--      f.apprdate AS folder_appr,
      (cr.last_name || ' ' || cr.first_name) AS patient_name,
--      ot.testno,
--      r.final,
--      ot.apprdate,
      '~' AS eol    
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'      
        AND mr.original_origrec = cr.origrec
        AND mr.field_varchar_80 = 'Diagnostic')
    WHERE 1=1
      AND ot.testno IN ('2019 Novel Coronavirus rRT-PCR', 'FilmArray Respiratory Panel 2')
      AND cr.date_received > to_date('24-JAN-2020', 'DD-MON-YYYY')
      AND ot.apprdate IS NOT NULL      
    ORDER BY
      patient_name ASC,
      cr.external_id
      ;
  ----- -----
