/*---------------------------------------------------------------------------*/
/*-----SampleVolumeSummary---------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --This query created to get a completed samples volume summary for 
    --COVID-19 samples, breaking down the number of samples by Week, and Day.
    --This query can easily be modified to give a summary for any/all tests
    --in the system.
    
    --ASSUMPTIONS:
      --1. Sample Activity Type = Diagnostic
      --2. Sample was not canceled
      --3. Test was not canceled
      --4. Sample Approval date is NOT NULL
      --5. Client is not ADHS, ASL-P, ADHS-T      
      --6. Sample is in identified test list (this can be easily updated).
  /*----- -----*/
  
  /*-----HISTORY-----*/
    --2020.09.19 JTY: Created query
  /*----- -----*/
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
/*-----Yearly Total----------------------------------------------------------*/
    SELECT DISTINCT
      COUNT (DISTINCT cr.external_id) AS total_samples,
      '~' as EOL
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)      
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        and mr.original_origrec = cr.origrec)
      INNER JOIN tests t ON (ot.testcode = t.testcode)
    WHERE 1=1
      AND f.apprdate BETWEEN (TO_DATE('&StartDate', 'DD-MON-YYYY')) AND (TO_DATE('&EndDate', 'DD-MON-YYYY'))
      AND mr.field_varchar_80 = 'Diagnostic'
      AND fc.status NOT IN ('Cancel')
      AND ot.dispsts NOT IN ('Cancel')
      AND f.apprdate IS NOT NULL
      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P', 'ADHS-T')
      AND t.testno IN (
              'BGI SARS-2019-nCoV RT-PCR',
              'TaqPath COVID-19 rRT-PCR',
              'Xpert Xpress SARS CoV 2',
              '2019 Novel Coronavirus rRT-PCR',
              'Influenza SARS-CoV-2 Multiplex rRT-PCR',
              'FilmArray Respiratory Panel 2',
              'ID NOW COVID-19',
              'Xpert Norovirus',
              'Influenza PCR',
              'Measles PCR',
              'Platelia SARS-CoV-2 Total Ab',
              'Influenza real time RT-PCR',
              'BioFire Respiratory Panel 2.1'
      )
    ORDER BY
      f.apprdate DESC,
      cr.external_id ASC;
/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/



WITH
  ---CoreInformation---
  CoreInformation AS (
    SELECT DISTINCT
      cr.external_id,
      TO_CHAR(f.apprdate,'ww') AS week_no,
      TRUNC(f.apprdate, 'DAY') AS week_start,      
      (rc.compname || ' (' || rc.rasclientid || ')' ) AS client_name,
      f.apprdate,     
      '~' as EOL
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)      
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        and mr.original_origrec = cr.origrec)
      INNER JOIN tests t ON (ot.testcode = t.testcode)
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND fc.status NOT IN ('Cancel')
      AND ot.dispsts NOT IN ('Cancel')
      AND f.apprdate IS NOT NULL
      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P', 'ADHS-T')
      AND t.testno IN (
              'BGI SARS-2019-nCoV RT-PCR',
              'TaqPath COVID-19 rRT-PCR',
              'Xpert Xpress SARS CoV 2',
              '2019 Novel Coronavirus rRT-PCR',
              'Influenza SARS-CoV-2 Multiplex rRT-PCR',
              'BioFire Respiratory Panel 2.1'
      )
    ORDER BY
      f.apprdate DESC,
      cr.external_id ASC  
  ),
  --- ---
  ---DayCount---
    DayCount AS (
      SELECT
        ci.apprdate,
        COUNT(ci.external_id) AS day_cnt,
        '~' AS eol
       FROM CoreInformation ci
       GROUP BY
         ci.apprdate       
       ORDER BY 
         ci.apprdate ASC    
    ),
  --- ---
  ---WeekCount---
    WeekCount AS (
      SELECT
        ci.week_start,
        COUNT(ci.external_id) AS week_cnt,
        '~' AS eol
       FROM CoreInformation ci
       GROUP BY 
         ci.week_start       
       ORDER BY 
         ci.week_start ASC    
    )
  --- ---
  ---WeeklySummary---
    SELECT DISTINCT
      ci.week_no,
      wc.week_start,
      ci.apprdate,
      ci.external_id,
      ci.client_name,
      dc.day_cnt,
      wc.week_cnt,
      '~' AS eol
    FROM CoreInformation ci
      INNER JOIN DayCount dc ON (ci.apprdate = dc.apprdate)
      INNER JOIN WeekCount wc ON (ci.week_start = wc.week_start)
    WHERE 1=1
      AND ci.apprdate BETWEEN (TO_DATE('&StartDate', 'DD-MON-YYYY')) AND (TO_DATE('&EndDate', 'DD-MON-YYYY'))
    ORDER BY
      ci.week_no ASC,
      wc.week_start ASC,
      ci.apprdate ASC, 
      ci.external_id ASC;
  --- ---

/*---------------------------------------------------------------------------*/






/*---------------------------------------------------------------------------*/
/*-----Yearly Total----------------------------------------------------------*/
    SELECT DISTINCT
      COUNT (DISTINCT cr.external_id) AS total_samples,
      '~' as EOL
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)      
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        and mr.original_origrec = cr.origrec)
      INNER JOIN tests t ON (ot.testcode = t.testcode)
    WHERE 1=1
      AND f.apprdate BETWEEN (TO_DATE('&StartDate', 'DD-MON-YYYY')) AND (TO_DATE('&EndDate', 'DD-MON-YYYY'))
      AND mr.field_varchar_80 = 'Diagnostic'
      AND fc.status NOT IN ('Cancel')
      AND ot.dispsts NOT IN ('Cancel')
      AND f.apprdate IS NOT NULL
      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P', 'ADHS-T')
      AND t.testno IN (
              'BGI SARS-2019-nCoV RT-PCR',
              'TaqPath COVID-19 rRT-PCR',
              'Xpert Xpress SARS CoV 2',
              '2019 Novel Coronavirus rRT-PCR',
              'Influenza SARS-CoV-2 Multiplex rRT-PCR',
              'FilmArray Respiratory Panel 2',
              'ID NOW COVID-19',
              'Xpert Norovirus',
              'Influenza PCR',
              'Measles PCR',
              'Platelia SARS-CoV-2 Total Ab',
              'Influenza real time RT-PCR',
              'BioFire Respiratory Panel 2.1'
      )
    ORDER BY
      f.apprdate DESC,
      cr.external_id ASC;
/*---------------------------------------------------------------------------*/
 
 
 
 
