
/*-----DirectFax Queries-----------------------------------------------------*/
  --This is a set of queries related to the DirectFax Project.  The following
  --queries have been developed:
    --1. Identify Faxes in the RDQ
    --2. Identify DirectFax Clients - Identify clients and contacts participating
    --     In the DirectFax program.
    --3. Email Distribution List - Generate Email DistributionList with clients
    --     participating in DirectFax.
    --4. How Many Faxes To Date
    --5. RecentClientFaxes Identify: faxes sent to client within the last number of days specified.
/*---------------------------------------------------------------------------*/


/*-----1. Identify Faxes in the RDQ-------------------------------------------*/
  --Identify any faxes that were not delivered, or had an error message.
  
    SELECT DISTINCT
      rdq.dept,
      rdq.folderno,
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      --cr.first_name,
      rdq.testgroupname AS panel,
      rdh.sent_by AS appr_by,
      to_char(rdh.sent_date, 'YYYY.MM.DD')  || '  ' || rdh.sent_time AS approved_dt,
      to_char(fq.senddate, 'YYYY.MM.DD')  || '  ' || fq.sendtime AS faxed_dt,
      rdq.status,
      fq.tofax,      
      rdh.message,
      fq.crtmessage,
      rdq.stardoc_id,
      fq.receipt,
      fq.origrec AS fq_origrec,
      rdh.origrec AS rdh_origrec,
      rdq.origrec AS rdq_origrec,      
      '~' AS eol
    FROM rr_report_delivery_queue rdq
      LEFT OUTER JOIN rr_rdq_history rdh ON (1=1
        AND rdq.receipt_number = rdh.receipt_number
        AND rdq.queue_item_no = rdh.queue_item_no)
      INNER JOIN rasclients rc ON (rdq.rasclientid = rc.rasclientid)
      INNER JOIN folderscontactsext fcx ON (1=1
        AND rdq.rasclientid = fcx.rasclientid
        AND rdq.contactid = fcx.contactid)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
      INNER JOIN folders f ON (rdq.folderno = f.folderno)
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
    WHERE 1=1
      AND fq.tofax IS NOT NULL
      AND (
        upper(fq.crtmessage) LIKE '%ERROR%' OR
        fq.senddate IS NULL
      )
--      AND rc.rasclientid = '&RasClientID'
    ORDER BY
      rdq.dept ASC,    
      client ASC,
      approved_dt ASC,
      faxed_dt ASC;
  
/*---------------------------------------------------------------------------*/


/*-----2. Identify DirectFax Clients-----------------------------------------*/
  --Use this query to identify Clients participating in the DirectFax program.
/*
  SELECT DISTINCT
    (rc.compname || ' (' || rc.rasclientid) || ')' AS organization,
    rc.rasclientid,
    rc.defaultcontact,
    rcx.email,
    rcx.fax,
    rcx.fullname,
    rcx.submit_method,
    '~' AS eol
  FROM rasclients rc
    INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
  WHERE 1=1
    AND rcx.email IS NOT NULL
    AND rcx.submit_method IN ('Fax', 'E-mail')
  ORDER BY
    organization ASC;
  */  
/*---------------------------------------------------------------------------*/





/*-----3. Email Distribution List--------------------------------------------*/
  --Use this query to generate an email distribution list for all clients that
  --are utilizing DirectFax.
/*
  SELECT DISTINCT
    ListAgg(rcx.email,';') WITHIN GROUP (ORDER BY rcx.email) 
      AS distibution_list
  FROM rasclients rc
    INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
  WHERE 1=1
    AND rcx.email IS NOT NULL
    AND rcx.submit_method = 'Fax'
  */  
/*---------------------------------------------------------------------------*/





/*----4. How Many Faxes To Date----------------------------------------------*/ 
  --Determine how many faxes have been sent to each client over specified
  --lookback days.
/*  
  SELECT DISTINCT
    rdq.rasclientid, 
    COUNT(DISTINCT rdq.folderno) AS faxes,
    '~' AS eol
  FROM sundata_prod.rr_report_delivery_queue rdq
    INNER JOIN sundata_prod.faxqueue fq ON (rdq.receipt_number = fq.receipt)
  WHERE 1=1
    AND rdq.status = 'PROCESSED'
    AND fq.crtmessage = 'Fax sent successfully.'
    AND TO_DATE(fq.postdate, 'DD-MON-YYYY') 
        BETWEEN TO_DATE((sysdate-&LookBackDays), 'DD-MON-YYYY') AND TO_DATE(sysdate, 'DD-MON-YYYY')
  GROUP BY
    rdq.rasclientid
  ORDER BY
    rdq.rasclientid ASC;
*/    
/*---------------------------------------------------------------------------*/




/*-----5. RecentClientFaxes--------------------------------------------------*/
  --Identify faxes sent to client within the last number of days specified.
/*  
  SELECT DISTINCT
    (rc.compname || ' (' || f.rasclientid || ')') AS client,
    --rcx.fullname AS client_contact,
    f.dept,
    f.external_id AS adhs_sampleid,
    cr.pid AS patient_id,
    f.testgroupname AS panel,
    (SUBSTR(cr.last_name, 0, 3) || '... , ' || SUBSTR(cr.first_name, 0, 3) || '...') AS patient_name,
    cr.date_received AS received,
    f.apprdate,
    f.approvedby,
    (fcx.submit_method || ':  ' || fq.tofax || '   Sent: ' || to_char(fq.postdate, 'MM/DD/YY  HH24:MI'))AS delivery_details,
    rdq.status AS delivery_status,
    fq.crtmessage delivery_message,
    cr.patient_id AS adhs_pid,
--    (ot.testno || ' (' || ot.testcode || ')') AS test_name,
--    ot.apprdate AS test_appr,
    '~' AS eol
  FROM sundata_prod.rr_report_delivery_queue rdq    
    LEFT OUTER JOIN sundata_prod.faxqueue fq ON (rdq.receipt_number = fq.receipt)
    INNER JOIN sundata_prod.folders f ON (rdq.folderno = f.folderno)
    INNER JOIN sundata_prod.centralreceiving cr ON (f.external_id = cr.external_id)
    INNER JOIN sundata_prod.rasclients rc ON (cr.rasclientid = rc.rasclientid)
    INNER JOIN sundata_prod.folderscontactsext fcx ON (f.folderno = fcx.folderno)
    LEFT OUTER JOIN sundata_prod.rasclientcontactsext rcx ON (fcx.contactid = rcx.contactid)
    INNER JOIN sundata_prod.ordtask ot ON (f.folderno = ot.folderno)
  WHERE 1=1
    AND fcx.rasclientid = '&RasClientID'
    AND TO_DATE(fq.postdate, 'DD-MON-YYYY') 
        BETWEEN TO_DATE((sysdate-&LookBackDays), 'DD-MON-YYYY') AND TO_DATE(sysdate, 'DD-MON-YYYY')
  ORDER BY
    client ASC,
    f.dept ASC,
    f.apprdate DESC,
    panel ASC,
    f.external_id ASC;
*/
/*---------------------------------------------------------------------------*/
