
/*-----DirectFax_ClientMigration----------------------------------------------*/
  --This is a set of queries related to the DirectFax Project.  The following
  --queries have been developed:
    --10. Update Delivery method
    --20. Identify Active Samples for identified Client
    --31. Udate Delivery Method for Existing Samples
    --31. Report Delivery Queue Update
    --41. Released Samples
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
/*-----10. Check Client by Sample ID-----------------------------------------*/
/*
  SELECT DISTINCT
    rc.rasclientid,
    rc.compname  
  FROM sundata_prod.folders f
    INNER JOIN sundata_prod.rasclients  rc ON (f.rasclientid = rc.rasclientid)
  WHERE 1=1
    AND f.external_id = '&SampleID';
*/    
/*---------------------------------------------------------------------------*/


/*-----10. Update Delivery Method--------------------------------------------*/
  --Current version of starlims has an issue where the External Contact 
  --Prefered delivery is not being updated in the Application.  This script can
  --force the change into the database.
/*  
  UPDATE rasclientcontactsext rcx
  SET rcx.submit_method = '&DeliveryMethod'  -- | Hard Copy | Fax | E-mail |
  WHERE 1=1
    AND rcx.rasclientid = '&RasClientID'
    AND rcx.fullname = '&ExContactName'  --| Laboratory Results |
*/    
  --information is not 
/*---------------------------------------------------------------------------*/


/*-----20. Identify Active Samples for identified Client----------------------*/
  --Identify active samples for identified client(s) if you want to switch them
  --to Fax delivery.

    SELECT DISTINCT
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      f.folderno,
      f.dept,
      f.testgroupname AS panel,
      rcx.submit_method,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc. rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
    WHERE 1=1
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
      AND mr.field_varchar_80 IN ('LRN-B', 'Diagnostic')
      AND rc.rasclientid = '&RasClientID'  ---CLIENT(s) OF INTEREST HERE---
      AND (f.apprdate IS NULL OR fc.approveddate IS NULL)
    ORDER BY
      client ASC,
      f.dept ASC,
      f.folderno ASC          

/*---------------------------------------------------------------------------*/


/*-----30. Udate Delivery Method for Existing Samples-------------------------*/
  --Update delivery method for active samples in system to match the Exetrnal
  --Contact as defined in the Client List application.  This should be used when
  --a Client has just converted over to a new delivery method, and you want to sync
  --existing samples in the system with this new method.  
  --
/*
  MERGE INTO folderscontactsext t1
  USING (
    SELECT DISTINCT
      rc.compname || '(' || rc.rasclientid || ')' AS client,
      f.dept,
      fcx.folderno,
      f.testgroupname AS panel,
      fcx.contactid,
      fcx.submit_method,
      rcx.submit_method AS rcx_submit_method,
      rcx.fax AS rcx_fax,
      fcx.rasclientid,
      fcx.origrec AS fcx_origrec,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc. rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (rc.rasclientid = rcx.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
      INNER JOIN folderscontactsext fcx ON (1=1
        AND fcx.folderno = f.folderno
        AND fcx.rasclientid = rcx.rasclientid
        AND fcx.contactid = rcx.contactid)
    WHERE 1=1
      AND (rcx.submit_method <> fcx.submit_method)
      AND rc.rasclientid = '&RasClientID'  ---CLIENT(s) OF INTEREST HERE---
      AND (f.apprdate IS NULL OR fc.approveddate IS NULL)
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
    ORDER BY
      client ASC,
      f.dept ASC,
      fcx.folderno ASC  
  ) t2
  ON (1=1
    AND t1.origrec = t2.fcx_origrec
    AND t1.folderno = t2.folderno 
    AND t1.rasclientid = t2.rasclientid
    AND t1.contactid = t2.contactid
  )    
  WHEN MATCHED THEN
    UPDATE SET
      t1.submit_method = rcx_submit_method;
*/
/*---------------------------------------------------------------------------*/





/*-----31. Report Delivery Queue Update--------------------------------------*/
  --Update RDQ to utlize Delivery method as defined by the ExternalContact
  --info in the Client List application for the identified Client.
  --This can also be used if the Fax number has changed, as defined for the
  --external client in the Client List application, and you want to 
  --sinc existing samples with the new number.
/*  
  MERGE INTO rr_report_delivery_queue t1
  USING (
    SELECT DISTINCT
      (rc.compname || ' (' || rc.rasclientid || ')') AS client,
      f.dept,
      rdq.folderno,
      rdq.status,
      rcx.fullname,
      rcx.contactid,
      rcx.submit_method AS rcx_method,
      rcx.fax AS rcx_address,
      rdq.delivery_method,
      rdq.delivery_address,
      rdq.origrec AS rdq_origrec,
      rc.rasclientid,
      '~' AS eol
    FROM rr_report_delivery_queue rdq
      INNER JOIN folders f ON (rdq.folderno = f.folderno)
      INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN rasclientcontactsext rcx ON (1=1
        AND rdq.rasclientid = rcx.rasclientid
        AND rdq.contactid = rcx.contactid)
    WHERE 1=1
      AND UPPER(f.testgroupname) NOT LIKE '%SENDOUT%'
      AND UPPER(f.testgroupname) NOT LIKE '%PFGE%'
      AND (
        (rdq.delivery_method <> rcx.submit_method )
        OR (rdq.delivery_address <> rcx.fax )
      )
      AND rdq.status = 'QUEUED'
      AND rdq.rasclientid = '&RasClientID'
    ORDER BY
      client ASC,
      f.dept ASC,
      rdq.folderno ASC
  ) t2
  ON (1=1
    AND t1.origrec = t2.rdq_origrec
    AND t1.rasclientid = t2.rasclientid
    AND t1.contactid = t2.contactid
    AND t1.folderno = t2.folderno
  )    
  WHEN MATCHED THEN
    UPDATE SET
      t1.delivery_method = t2.rcx_method,
      t1.delivery_address = t2.rcx_address;
*/      
/*---------------------------------------------------------------------------*/



/*-----41. Released Samples--------------------------------------------------*/
  --Released samples take a bit more work to update.  You will need to execute
  --the two scripts provided below.


  -----Update FoldersContacsExt-----
/*
    MERGE INTO folderscontactsext t1
    USING (
      SELECT DISTINCT
        (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
        cr.external_id,
        f.folderno,
        f.testgroupname,
        fcx.submit_method AS sample_method,
        rcx.submit_method AS client_method,
        cr.rasclientid,
        '~' AS eol
      FROM centralreceiving cr
        INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        INNER JOIN folders f ON (cr.external_id = f.external_id)
        INNER JOIN rasclientcontactsext rcx ON (cr.rasclientid = rcx.rasclientid)
        INNER JOIN folderscontactsext fcx ON (f.folderno = fcx.folderno) 
        INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      WHERE 1=1
        AND cr.Rasclientid = '&RasClientID'
        AND cr.external_id IN (&SampleList)
        AND fcx.submit_method <> rcx.submit_method
    ) t2
    ON (1=1
      AND t1.rasclientid = t2.rasclientid
      AND t1.folderno = t2.folderno)
    WHEN MATCHED THEN
      UPDATE SET t1.submit_method = t2.client_method
*/      
  ----- -----

  -----Update Report Delivery Queue-----
  /*
    MERGE INTO rr_report_delivery_queue t1
    USING (
      SELECT DISTINCT
        (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
        cr.external_id,
        f.folderno,
        f.testgroupname,
        rdq.delivery_method AS rdq_method,
        rcx.submit_method AS client_method,
        COALESCE(rdq.delivery_address, '') AS rdq_delivery_address,
        CASE rcx.submit_method
          WHEN 'E-mail' THEN rcx.email
          WHEN 'Fax' THEN rcx.fax
          WHEN 'Hard Copy' THEN ''
          WHEN 'PDF Only' THEN ''      
        END as client_delivery_address,
        cr.rasclientid,
        rdq.origrec AS rdq_origrec,
        '~' AS eol
      FROM centralreceiving cr
        INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        INNER JOIN folders f ON (cr.external_id = f.external_id)
        INNER JOIN rasclientcontactsext rcx ON (cr.rasclientid = rcx.rasclientid)
        INNER JOIN folderscontactsext fcx ON (f.folderno = fcx.folderno) 
        INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)    
      WHERE 1=1
        AND cr.Rasclientid = '&RasClientID'
        AND cr.external_id IN (&SampleList)
        AND rdq.status <> 'PROCESSED'
        AND (rdq.delivery_method <> rcx.submit_method
             OR    
              CASE COALESCE(rcx.submit_method, ' ')
                WHEN 'E-mail' THEN COALESCE(rcx.email, ' ')
                WHEN 'Fax' THEN COALESCE(rcx.fax, ' ')
                WHEN 'Hard Copy' THEN ' '
                WHEN 'PDF Only' THEN ' '
                ELSE ' '
              END  <> COALESCE(rdq.delivery_address, ' ')
            )  
    ) t2
    ON (t1.origrec = t2.rdq_origrec)
    WHEN MATCHED THEN
      UPDATE SET 
        t1.delivery_method = t2.client_method,
        t1.delivery_address = t2.client_delivery_address
*/
  ----- -----
/*---------------------------------------------------------------------------*/
