
/*-----HL7 CODE SCRIPTS------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Here we have complied a number of script that can be utilized in identifing
    --codes that have been placed in STARLiMS associated with HL7 messaging.
  /*----- -----*/

  /*-----SCRIPTS-----*/
    --The following scripts are included:
      --01. Test LOINC Codes
      --03. Possible Results SNOMED CODES
  /*----- -----*/


  /*-----HISTORY-----*/
    --2020.04.10 JTY: Begin Creation of Script
  /*----- -----*/
/*---------------------------------------------------------------------------*/



/*=====ROOT TABLE DEFINITIONS================================================*/

  /*-----Specimen Sources application----------------------------------------*/
    /*----------Main Window: Specimen Sources Datagrid ----------*/
      --Application Reference: Specimen Sources - Main Window Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --SnomedCT           = [SPM-4.1]  , [SPM-4.4]
          --snomed_description = [SPM-4.2]
      SELECT DISTINCT
        ss.specimen_source,
        ss.spectype,
        ss.hl7_spec_source_code,
        ss.concept_code,
        ss.concept_name,
        ss.snomedct,
        ss.snomed_description,
        SubStr(
          (SELECT ListAgg(sample_type, ',') WITHIN GROUP (ORDER BY sample_type)
          FROM samptypes st
            INNER JOIN specimen_ref sr ON (st.origrec = sr.type_code)
          WHERE 1=1
            AND sr.source_code = ss.origrec),1,999
        ) AS specimen_type
        ,
        '~' AS eol
      FROM specimen_sources ss
      WHERE 1=1
        AND ss.spectype IN (&SpecimenTypeList) --Clinical, ENVIRONMENTAL-BT
      ORDER BY
        ss.specimen_source;
    /*---------- ----------*/
  /*---------------------------------------------------------------------------*/



  /*-----SNOMED Codes application----------------------------------------*/
    /*----------Main Window: SNOMED Library Datagrid ----------*/
      --Application Reference: SNOMED Codes - Main Window Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --SNOMED Element (snomedelement)  = [OBX-5]
      SELECT DISTINCT
        sc.snomedcode,
        sc.snomed_group,
        '~' AS sp1,
        sc.snomedcode,
        sc.snomedelement,
        sc.snomedconceptid,
        sc.snomeddescriptionid,
        '~' AS eol
      FROM snomedcodes sc
      WHERE 1=1
      ORDER BY
        sc.snomedcode ASC,
        sc.snomed_group ASC,
        sc.snomeddescriptionid ASC
      ;
    /*---------- ----------*/
  /*---------------------------------------------------------------------------*/



  /*-----LOINC Codes application----------------------------------------*/
    /*----------Main Window: LOINC Codes ----------*/
      --Application Reference: LOINC Codes - LOINC Mainenance Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --TBD          
      SELECT DISTINCT
        lv.version,
        lv.verdate,
        lv.usrnam,
        lv.status,
        '~' AS eol
      FROM loincversion lv
      WHERE 1=1
      ORDER BY
        lv.version ASC
      ;
    /*---------- ----------*/

    /*----------Main Window: LOINC Codes ----------*/
      --Application Reference: LOINC Codes - LOINC Classes Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --TBD          
      SELECT DISTINCT
        lv.version,
        '~' AS sp1,
        lc.classcode,
        lc.classname,
        '~' AS eol
      FROM  loincversion lv
      INNER JOIN loincclasses lc ON (lv.version = lc.version)
      WHERE 1=1
      ORDER BY
        lv.version ASC,
        lc.classcode ASC,
        lc.classname ASC
      ;
    /*---------- ----------*/
    
    /*----------Main Window: LOINC Codes ----------*/
      --Application Reference: LOINC Codes - LOINC Codes Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --TBD          
          
        --LOINC # (LoincNumber):             [OBR-4.1], [OBX-3.1]
        --LOINC Component (loinccomponenet): *[OBR-4.2], *[OBX-3.2]
        --Method (loincmethod):              *[OBR-4.2], *[OBX-3.2]
        --Sample Type (loincsystems):        *[OBR-4.2], *[OBX-3.2]
        --Code System OID (code_system_oid): [OBR-4.3], [OBX-3.3]

          
      SELECT DISTINCT
        lv.version,
        lc.classcode,
        lc.classname,
        '~' AS sp1,
        cd.loincnumber,
        cd.loinccomponenet,
        cd.loincproperty,
        cd.loinctime,
        cd.loincsystems,
        cd.loincscale,
        cd.loincmethod,
        '~' AS eol
      FROM  loincversion lv
      INNER JOIN loincclasses lc ON (lv.version = lc.version)
      INNER JOIN loinccodes cd ON (1=1
        AND lc.version = cd.version
        AND lc.classcode = cd.classcode)
      WHERE 1=1
AND cd.loinccomponenet = '2019-nCoV RNA'
      ORDER BY
        lv.version ASC,
        lc.classcode ASC,
        lc.classname ASC,
        cd.loinccomponenet ASC
      ;
    /*---------- ----------*/
    
  /*---------------------------------------------------------------------------*/


/*===========================================================================*/

/*---------------------------------------------------------------------------*/













/*=====CONFIGURATION DEFINITIONS================================================*/

/*---------------------------------------------------------------------------*/
/*-----TEST MANAGER CODES----------------------------------------------------*/

  /*----------Main Window: Test Datagrid ----------*/
    --Application Reference: Test Manager - Main Window Test Datagrid
    --HL7 Message Component(s): 
      --PHLIP 2.5.1 Protocol
        --phvs_concept_code = [OBR-4.2], [OBX-3.2]   
    SELECT DISTINCT
      t.testno,
      t.testcode,
      t.testflag,
      t.cpt_code,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name,
      '~' AS eol
    FROM tests t
    WHERE 1=1
      AND t.testcode IN (&TestCodeList)
    ORDER BY
      t.testno ASC;
  /*---------- ----------*/

  /*----------Analytes tab: Possible Results ----------*/
    --Application Reference: Test Manager - Main Window Test Datagrid
    --HL7 Message Component(s): 
      --PHLIP 2.5.1 Protocol
        --result = [OBX-5]        
    SELECT DISTINCT
      t.testno,
      t.testcode,
      pr.analyte,
      '~' AS sp1,
      pr.result,
      pr.snomedcode AS result_code,
      pr.result_status,
      pr.conclusion_report,
      pr.sorter,
      '~' AS eol
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
    WHERE 1=1
      AND t.testcode IN (&TestCodeList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.sorter ASC,
      pr.result ASC;
  /*---------- ----------*/

  /*----------Analyte Loinc Codes tab: Analytes LOINC Codes Datagrid ----------*/
    --Application Reference: Test Manager
      --Analyte LOINC Codes tab
        --Analytes LOINC CODES datagrid
    --HL7 Message Component(s): 
      --PHLIP 2.5.1 Protocol
        --LOINC # (LoincNumber):             [OBR-4.1], [OBX-3.1]
        --LOINC Component (loinccomponenet): *[OBR-4.2], *[OBX-3.2]
        --Method (loincmethod):              *[OBR-4.2], *[OBX-3.2]
        --Sample Type (loincsystems):        *[OBR-4.2], *[OBX-3.2]
        --Code System OID (code_system_oid): [OBR-4.3], [OBX-3.3]
    SELECT DISTINCT
      t.testno,
      t.testcode,
      tlc.analyte,
      '~' AS sp1,
      tlc.status,
      tlc.loincnumber,
      tlc.loinccomponenet,
      tlc.version,
      tlc.loincdefault,
      tlc.loincmethod,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems,                        
      tlc.loinctime,
      tlc.hl7_reportable,
       tlc.code_system_oid,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
    WHERE 1=1
      AND t.testcode IN (&TestCodeList)
    ORDER BY
      t.testno ASC,
      tlc.analyte ASC;
  /*---------- ----------*/

  /*----------Analyte Loinc Codes tab: Possible Results SNOMED Codes Datagrid ----------*/
    --Application Reference: Test Manager
      --Analyte LOINC Codes tab
        --Analytes LOINC CODES datagrid
    --HL7 Message Component(s): 
      --PHLIP 2.5.1 Protocol
        --Result (result):                   [OBX-5]
    SELECT DISTINCT
      t.testno,
      t.testcode,
      pr.analyte,
      pr.sorter,
      '~' AS sp1,
      pr.result,
      pr.snomedcode,
      pr.snomeddescriptionid,
      pr.snomedconceptid,
      pr.conclusion_report,
      pr.result_status,
      pr.cdc_reportable,
      pr.elr_reportable,      
      pr.code_system_oid,
      pr.localnumber,
      '~' AS eol
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
    WHERE 1=1
      AND t.testcode IN (&TestCodeList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.sorter ASC,
      pr.result ASC;
  /*---------- ----------*/
      
  /*----------Test Loinc Codes tab: TestLOINC Codes Datagrid ----------*/
    --Application Reference: Test Manager - Main Window Test Datagrid
    --HL7 Message Component(s): 
      --PHLIP 2.5.1 Protocol
        --Analyte = [OBR-4.5], [OBX-3.4], [OBX-3.5]
        --LoincComponent + LoincSystems + LoincMethod + ??? = [OBX-3.2], [OBR-4.2]
        
    SELECT DISTINCT
      t.testno,
      t.testcode,
      t.testflag,
      tlc.analyte,
      tlc.loinccomponenet,
      tlc.loincdefault,
      tlc.loincmethod,
      tlc.loincnumber,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems,
      tlc.loinctime,
      tlc.version,
      tlc.hl7_reportable,
      tlc.code_system_oid,
      tlc.status,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
    WHERE 1=1
      AND t.testcode IN (&TestCodeList)
    ORDER BY
      t.testno ASC,
      tlc.analyte ASC;
  /*---------- ----------*/
/*---------------------------------------------------------------------------*/

/*===========================================================================*/
