
/*-----PHLIP Validation Backload---------------------------------------------*/
/*---------------------------------------------------------------------------*/
  -----DESCRIPTION-----
    --Use this set of scripts to load identified samples into the HL7 Generator
    --application for messaging to the CDC.
  ----- -----
  
  -----HISTORY-----
    --2020-09-10 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/
/*
Select 
  t.testno,
  p.sorter,
  p.result,
  P.SNOMEDCODE,
  P.CODE_SYSTEM_OID,
  P.LOCALNUMBER
from POSSIBLERESULTS P
  INNER JOIN tests t ON (p.testcode = t.testcode)
where t.testno IN (&TestList)
ORDER BY
  t.testno ASC,
  p.sorter ASC,
  p.result ASC
*/
/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  -----Referenced Tables----- 
/*
   SELECT * FROM HL7_GENERATOR_POOL;
  ----- -----
  
  -----01. Review identified samples-----
    SELECT DISTINCT
      f.apprdate,
      f.external_id,
      f.testgroupname,
      ot.testno,
      f.folderno,
      ('PHLIP Backload SET-' || '&SetNumber' || ': ' || CHR(13) || 
       '&StartDate' || ' to ' || '&EndDate') AS comments,
      'PHLIP' AS interface_id,
      'StartDelivery' AS workflowstep,
      ('PHLIP-Backload ' || '&SetNumber') AS validationset,
      'YODERJ' AS usrnam,
      'N' AS origsts
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask OT on (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      --Selection Criteria--
      AND ot.testno IN (&TestList)
      AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      -- --      
      AND mr.field_varchar_80 IN ('Diagnostic')
--      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P')
    ORDER BY
      f.folderno ASC,
      f.apprdate ASC;
  ----- -----
*/
  -----02. Update HL7_GENERATOR_POOL table-----
  
    MERGE INTO hl7_generator_pool t1
    USING (
    SELECT DISTINCT
      cr.rasclientid,
      f.apprdate,
      f.external_id,
      f.folderno,
      f.testgroupname,
      'N' AS origsts,
      ('PHLIP Backload SET-' || '&SetNumber' || ': ' || CHR(13) || 
       '&StartDate' || ' to ' || '&EndDate') AS comments,
      'YODERJ' AS usrnam,
      sysdate AS last_updated,
      'PHLIP' AS interface_id,
      'StartDelivery' AS workflowstep,
      ('PHLIP-Backload ' || '&SetNumber') AS validationset,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask OT on (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      --Selection Criteria--
      AND ot.testno IN (&TestList)
      AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      -- --      
      AND mr.field_varchar_80 IN ('Diagnostic')
--      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P')
    ORDER BY
      f.external_id ASC,
      f.folderno ASC,
      f.apprdate ASC
    ) t2
    ON (1=1
        AND t1.external_id = t2.external_id
        AND t1.folderno = t2.folderno
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.usrnam = t2.usrnam,
        t1.comments = t2.comments,
        t1.last_updated = t2.last_updated,
        t1.interface_id = t2.interface_id,
        t1.workflowstep = t2.workflowstep,
        t1.validationset = t2.validationset,
        t1.origsts = t2.origsts        
    WHEN NOT MATCHED THEN
      INSERT (
        t1.external_id,
        t1.folderno,
        t1.comments,
        t1.interface_id,
        t1.last_updated,
        t1.workflowstep,
        t1.validationset,
        t1.usrnam,
        t1.origsts
      )
      VALUES (
        t2.external_id,
        t2.folderno,
        t2.comments,
        t2.interface_id,
        t2.last_updated,
        t2.workflowstep,
        t2.validationset,
        t2.usrnam,
        t2.origsts
      )
  ----- -----  
/*---------------------------------------------------------------------------*/



/*-----Get Count for each tests----------------------------------------------*/
  --Modify this query to get the number of sample for each identified test.
/*  
    SELECT DISTINCT
    --  cr.rasclientid,
      COUNT (DISTINCT cr.external_id) AS sample_count,
    --  f.apprdate,
    --  f.testgroupname,
      ot.testno,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND f.apprdate IS NOT NULL
      AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      AND ot.testno IN (
    --  'BGI SARS-2019-nCoV RT-PCR',
      'TaqPath COVID-19 rRT-PCR',
    --  'Xpert Xpress SARS CoV 2',
      '2019 Novel Coronavirus rRT-PCR'
    --  'Influenza SARS-CoV-2 Multiplex rRT-PCR',
    --  'BioFire Respiratory Panel 2.1',
    --  'ID NOW COVID-19',
    --  'Influenza PCR', 
    --  'FilmArray Respiratory Panel 2', 
    --  'Influenza real time RT-PCR'  
      )
    GROUP BY ot.testno
    ORDER BY
      ot.testno ASC;
*/
/*---------------------------------------------------------------------------*/


/*-----View Samples for identified test--------------------------------------*/

  --Modify this query to view information on the samples associated with the 
  --identified test.
/*
    SELECT DISTINCT
      cr.rasclientid,
      cr.external_id,
      f.apprdate,
      f.testgroupname,
      ot.testno,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
    WHERE 1=1
      AND mr.field_varchar_80 = 'Diagnostic'
      AND f.apprdate IS NOT NULL
      AND ot.testno IN (
      'BGI SARS-2019-nCoV RT-PCR',
    --  'TaqPath COVID-19 rRT-PCR',
      'Xpert Xpress SARS CoV 2',
    --  '2019 Novel Coronavirus rRT-PCR',
      'Influenza SARS-CoV-2 Multiplex rRT-PCR',
      'BioFire Respiratory Panel 2.1',
      'ID NOW COVID-19',
      'Influenza PCR', 
      'FilmArray Respiratory Panel 2', 
      'Influenza real time RT-PCR'  
      )
    ORDER BY
      ot.testno ASC,
      cr.external_id DESC
*/      
/*---------------------------------------------------------------------------*/  
  
