
/*---------------------------------------------------------------------------*/
/*-----PHLIP_HL7_Config------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Creation of these script in association with HL7 configuration for
    --PHLIP protocal validation including the following tests:
      --1. Influenza PCR
      --2. FilmArray Respiratory Panel 2 
      --3. 2019 Novel Coronavirus rRT-PCR
      --4. TaqPath COVID-19 rRT-PCR
      --5. Xpert Xpress SARS CoV 2
      --6. BGI SARS-2019-nCoV RT-PCR
      --7. Xpert Norovirus
    --HL7 configurations settins based on PHLIP Encouding Guidlines:
      --1. CDC 2019-nCOVRT-PCR_Assay_04152020
            --https://docs.google.com/spreadsheets/d/1BKibcSDP-kvIeT6Ep0RpdrbzsxcNz7veAMwIy6i0Cvw/edit#gid=1901119566
      --2. SARS-CoV-2 Comercial Assays_04152020
            --https://docs.google.com/spreadsheets/d/14rq10q0VkAIBh0Z_J0-PqLE-y8g4okwrhzt7_JwNhX4/edit#gid=983663582  
  /*----- -----*/
  
  /*-----Identified Scripts In This Package-----*/
    --1. Orders: LOINC codes as identified in the LOINC application
  /*----- -----*/


  /*-----HISTORY-----*/
    --2020.06.13 JTY: Addition of Xpert Norovirus test to scripts
    --2020.05.09 JTY: Addition of Panels for Clinical Login section
    --2020.04.30 JTY: Begin creation of Script.
  /*----- -----*/ 
/*---------------------------------------------------------------------------*/




/*-----01. Specimen Types----------------------------------------------------*/
    /*----------Main Window: Specimen Sources Datagrid ----------*/
      --Application Reference: Specimen Sources - Main Window Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --SnomedCT           = [SPM-4.1]  , [SPM-4.4]
          --snomed_description = [SPM-4.2]
      SELECT DISTINCT
        ss.specimen_source,
        ss.spectype,
        ss.hl7_spec_source_code,
        ss.concept_code,
        ss.concept_name,
        ss.snomedct,
        ss.snomed_description,
        SubStr(
          (SELECT ListAgg(sample_type, ',') WITHIN GROUP (ORDER BY sample_type)
          FROM samptypes st
            INNER JOIN specimen_ref sr ON (st.origrec = sr.type_code)
          WHERE 1=1
            AND sr.source_code = ss.origrec),1,999
        ) AS specimen_type
        ,
        '~' AS eol
      FROM specimen_sources ss
      WHERE 1=1
        AND ss.spectype IN (&SpecimenTypeList) --Clinical, ENVIRONMENTAL-BT
      ORDER BY
        ss.specimen_source;
    /*---------- ----------*/
/*---------------------------------------------------------------------------*/



/*-----01. LOINC Codes-------------------------------------------------------*/
/*---------------------------------------------------------------------------*/




    /*----------Panels for Clinical Login: HL7 Reports tab----------*/
      /*-----HL7 Message Types datagrid-----*/
        SELECT
          t.testno AS test_name,
          '~' AS sp_1,
          ctt.testgroupname AS panel,
          hm.header_name AS mapping_name,
          fmb.message_type,
          fmb.description,        
          '~' AS eol
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN hl7_dist_messages hm ON (ctt.testgroupname = hm.testgroupname)
          LEFT OUTER JOIN hl7_fieldmap_binder fmb ON (hm.header_name = fmb.header_name)
        WHERE 1=1
          AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
            '')  
        ORDER BY
          ctt.testgroupname ASC,
          hm.header_name ASC;
      /*----- -----*/
      
      /*-----HL7 Submitter Distribution datagrid-----*/
        SELECT
          ctt.testgroupname AS panel,
          hm.header_name AS mapping_name,  
          '~' AS sp_1,
          rc.rasclientid,
          rc.compname,
          '~' AS eol
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN hl7_dist_messages hm ON (ctt.testgroupname = hm.testgroupname)
          LEFT OUTER JOIN hl7_dist_submitters hs ON (ctt.testgroupname = hs.testgroupname)
          INNER JOIN rasclients rc ON (hs.rasclientid = rc.rasclientid)
        WHERE 1=1
          AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',  
            '')  
        ORDER BY
          ctt.testgroupname ASC,
          hm.header_name ASC,
          rc.rasclientid ASC;
      /*----- -----*/      
      
      /*-----Reportable LOINC Codes datagrid-----*/
        SELECT
          ctt.testgroupname AS panel,
          '~' AS sp_1,
          hm.header_name AS mapping_name,
          rc.rasclientid,
          t.testno,
          hl.analyte,
          hl.loincnumber,
          hl.value_type,
          hl.reportable_condition,
          Coalesce(hl.reportsection, '') AS reportsection,
          '~' AS eol
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          LEFT OUTER JOIN hl7_dist_messages hm ON (ctt.testgroupname = hm.testgroupname)
          LEFT OUTER JOIN hl7_dist_submitters hs ON (ctt.testgroupname = hs.testgroupname)
          INNER JOIN rasclients rc ON (hs.rasclientid = rc.rasclientid)
          LEFT OUTER JOIN hl7_dist_loincs hl ON (1=1
            AND ctt.testgroupname = hl.testgroupname
            AND t.testcode = hl.testcode
            AND hm.header_name = hl.header_name)
        WHERE 1=1
          AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
            '')  
        ORDER BY
          ctt.testgroupname ASC,
          hm.header_name ASC,
          rc.rasclientid ASC;
      /*----- -----*/      
      

      
    
      SELECT        
        ctt.dept,
        ctt.testgroupname AS panel,
        '~' AS sp1,
        hm.header_name,
        '~' AS sp2,
        rc.compname,
        hs.rasclientid,
        '~' AS sp3,  
        --t.testno AS testname,
        t.testcode,
        hl.analyte,
        hl.loincnumber,
        hl.value_type,
        hl.reportable_condition,
        hl.reportsection,
        '~' AS eol
      FROM tests t
        INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
        LEFT OUTER JOIN hl7_dist_messages hm ON (ctt.testgroupname = hm.testgroupname)
        LEFT OUTER JOIN hl7_dist_submitters hs ON (1=1
          AND hm.header_name = hs.header_name
          AND hm.testgroupname = hs.testgroupname
        )
        LEFT OUTER JOIN hl7_dist_loincs hl ON (1=1
          AND hl.header_name = hs.header_name
          AND hl.rasclientid = hs.rasclientid
          AND hl.testgroupname = hs.testgroupname
          AND hl.testcode = t.testcode
        )
        INNER JOIN rasclients rc ON (hs.rasclientid = rc.rasclientid)
      WHERE 1=1
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '')  
      ORDER BY
        ctt.dept,
        ctt.testgroupname ASC,
        hm.header_name ASC,
        rc.compname ASC,
        t.testno ASC
        ;
    /*---------- ----------*/




  /*-----1. Test Manager: Test Datagrid line values-----*/
    SELECT
      t.testcode,
      t.testno,
      t.phvs_code_system_code AS phlip_code,
      t.phvs_code_system_oid AS code_system_oid,
      t.phvs_concept_code AS concept_code,
      t.phvs_concept_name AS concept_name,
      '~' AS eol
    FROM tests t
    WHERE 1=1
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '') 
    ORDER BY
      t.testno ASC,
      t.testcode ASC;
  /*----- -----*/
  
  /*-----Test Manager: Analyte Loinc Codes tab: Analyte Loinc Codes DG-----*/
    SELECT
      t.testno,
      t.testcode,
      '~' AS sp1,
      tlc.analyte,
      a.analtype,
      tlc.status,
      tlc.loincnumber,
      tlc.loinccomponenet,
      tlc.version,
      tlc.loincdefault,
      tlc.loincmethod,
      tlc.loincproperty,
      tlc.loincscale,
      tlc.loincsystems AS sample_type,
      tlc.loinctime,
      tlc.hl7_reportable,
      tlc.code_system_oid,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
      INNER JOIN analytes a ON (1=1
        AND tlc.testcode = a.testcode 
        AND tlc.analyte = a.analyte)
    WHERE 1=1
      AND tlc.analyte <> 'TESTLOINC'
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '') 
    ORDER BY
      t.testno ASC,
      t.testcode ASC,
      tlc.analyte,
      tlc.loincnumber ASC;
  /*----- -----*/
   
  
  /*-----3. LOINC Codes application-----*/
      --Application Reference: LOINC Codes - LOINC Codes Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --TBD          
          
        --LOINC # (LoincNumber):             [OBR-4.1], [OBX-3.1]
        --LOINC Component (loinccomponenet): *[OBR-4.2], *[OBX-3.2]
        --Method (loincmethod):              *[OBR-4.2], *[OBX-3.2]
        --Sample Type (loincsystems):        *[OBR-4.2], *[OBX-3.2]
        --Code System OID (code_system_oid): [OBR-4.3], [OBX-3.3]
          
      SELECT
        t.testno,
        t.testcode,
        lv.version,
        lc.classcode,
        lc.classname,
        '~' AS sp1,
        cd.loincnumber,
        cd.loinccomponenet,
        cd.loincshortname,
        cd.loincproperty,
        cd.loinctime,
        cd.loincsystems,
        cd.loincscale,
        cd.loincmethod,
        cd.codestatus,
        cd.mapto,
        '~' AS eol
      FROM tests t
        INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
        INNER JOIN loincversion lv ON (tlc.version = lv.version)
      INNER JOIN loincclasses lc ON (lv.version = lc.version)
      INNER JOIN loinccodes cd ON (1=1
        AND lc.version = cd.version
        AND lc.classcode = cd.classcode
        AND tlc.loincnumber = cd.loincnumber)
      WHERE 1=1
        AND tlc.analyte = 'TESTLOINC'      
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '') 
      ORDER BY
        t.testno ASC,
        lv.version ASC,
        lc.classcode ASC,
        lc.classname ASC,
        cd.loinccomponenet ASC
      ;
    /*---------- ----------*/
  /*----- -----*/
  /*---------------------------------------------------------------------------*/
  
  
  
  
/*-----01. SNOMED Codes-------------------------------------------------------*/
/*---------------------------------------------------------------------------*/

    /*----------Main Window: SNOMED Library Datagrid ----------*/
      --Application Reference: SNOMED Codes - Main Window Datagrid
      --HL7 Message Component(s): 
        --PHLIP 2.5.1 Protocol
          --SNOMED Element (snomedelement)  = [OBX-5]
      SELECT DISTINCT
        t.testno,
        t.testcode,
        t.phvs_concept_code AS test_loinc,
        tl.loincnumber AS analyte_loinc,
        '~' AS sp_1,
        pr.analyte,
        pr.result,
        pr.snomedcode,
        pr.snomeddescriptionid,
        pr.snomedconceptid,
        pr.conclusion_report,
        pr.result_status,
        COALESCE(pr.cdc_reportable, 'N') AS cdc_reportable,
        COALESCE(pr.elr_reportable, 'N') AS elr_reportable,
        pr.code_system_oid,
        pr.localnumber,
        '~' AS eol
      FROM tests t
        INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
INNER JOIN testloinccodes tl ON (1=1
AND t.testcode = tl.testcode
AND pr.analyte = tl.analyte
)

--        INNER JOIN snomedcodes sc ON (1=1
--         AND pr.snomedcode = sc.snomedcode
--         AND pr.snomedconceptid = sc.snomeddescriptionid
--         )
      WHERE 1=1
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '')  
      ORDER BY
        t.testno ASC,
        pr.analyte ASC,
        pr.result ASC
      ;
    /*---------- ----------*/
  /*---------------------------------------------------------------------------*/
  
  /*-----HL7 Clients Manager---------------------------------------------------*/
    /*----- -----*/
      SELECT DISTINCT
        ha.rasclientid,
        t.testcode,
        '~' AS sp_1,
        ha.analyte,
        t.testno,
        ha.reportable,
        ha.result_fld,
        ha.value_type,
        COALESCE(ha.lrn_param, 'N'),
        '~' AS eol
      FROM tests t
        INNER JOIN hl7_analytes ha ON (t.testcode = ha.testcode)
      WHERE 1=1
        AND t.testno IN (
--          'Influenza PCR',
--          'FilmArray Respiratory Panel 2',
--          '2019 Novel Coronavirus rRT-PCR',
--          'TaqPath COVID-19 rRT-PCR',
--          'Xpert Xpress SARS CoV 2',
--          'BGI SARS-2019-nCoV RT-PCR',
            'Xpert Norovirus',
          '')  
      ORDER BY
        ha.rasclientid ASC,
        t.testno ASC,
        ha.analyte ASC;
    /*----- -----*/
   
  /*---------------------------------------------------------------------------*/      
