/*---------------------------------------------------------------------------*/
/*-----Interfaces~HL7 Mappings Sync------------------------------------------*/

  -----DESCRIPTION-----
    --These sets of scripts can be utilized to help ensure HL7 Mappings application
    --is synced for the identifired [Mapping Name]
  ----- -----
  
  -----HISTORY-----
    --2020-09-11 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Setup FieldNames--------------------------------------------------*/
  -----DESCRIPTION-----
    --Take the passed MappingNamesList and sync the hl7_filednames table
    --with the adhs_temp table values imported from the source environement.
  ----- -----
  
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT
      fm.header_name,
      '~' AS sp1,
      fn.origrec AS fn_origrec,
      fn.version,
      fn.hl7_segment,
      fn.Description,
      fn.fieldname,
      fn.mandatory,
      fn.origsts,
      '~' AS eol
    FROM  hl7_fieldmap fm
      INNER JOIN hl7_fieldnames fn ON (1=1
        AND fm.hl7_version = fn.version
        AND fm.hl7_field_name = fn.fieldname
        AND fm.hl7_segment = fn.hl7_segment)
    WHERE 1=1
      AND fm.header_name IN (&HeaderNameList)  --'PHLIP_Resulting', 'LRNB_Resulting', 'ELR_Resulting'
    ORDER BY
      fm.header_name ASC,
      fn.version ASC,
      fn.hl7_segment ASC,
      fn.Description ASC,
      fn.fieldname ASC;
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      header_name     VARCHAR2(100 CHAR),
      spacer1         CHAR(1 CHAR),
      fn_origrec      NUMBER(22),
      version         VARCHAR2(10 CHAR),
      hl7_segment     VARCHAR2(10 CHAR),
      description     VARCHAR2(150 CHAR),
      fieldname       VARCHAR2(255 CHAR),
      mandatory       CHAR(1 CHAR),
      origsts         CHAR(1 CHAR),      
      eol             CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate hl7_fieldnames table-----
    --Here we are going to update the hl7_fieldmap table.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
    MERGE INTO hl7_fieldnames t1
    USING (
      SELECT
        temp.header_name,
        temp.fn_origrec,
        temp.version,
        temp.hl7_segment,
        temp.Description,
        temp.fieldname,
        temp.mandatory,
        temp.origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.header_name ASC,
        temp.version ASC,
        temp.hl7_segment ASC,
        temp.Description ASC,
        temp.fieldname ASC
    ) t2
    ON (1=1
        AND t1.version = t2.version
        AND t1.fieldname = t2.fieldname
        AND t1.hl7_segment = t2.hl7_segment
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.Description = t2.Description,
        t1.mandatory = t2.mandatory,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.version,
        t1.hl7_segment,
        t1.Description,
        t1.fieldname,
        t1.mandatory,
        t1.origsts
      )
      VALUES (
        t2.version,
        t2.hl7_segment,
        t2.Description,
        t2.fieldname,
        t2.mandatory,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the FieldNames
  ----- -----
*/  
/*---------------------------------------------------------------------------*/




/*-----02. Setup HL7_FIELDMAP------------------------------------------------*/
  -----DESCRIPTION-----
    --Take the passed MappingNamesList and sync the hl7_fieldmap table
    --with the adhs_temp table values imported from the source environement.
  ----- -----
--SELECT * FROM hl7_fieldmap fm WHERE fm.header_name = 'PHLIP_Resulting'
/*
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
    SELECT
      fm.origrec AS fm_origrec,
      fm.header_name,
      fm.hl7_version,
      fm.hl7_segment,     
      fm.hl7_field_name,      
      fm.starlims_table,
      fm.starlims_column,
      fm.composite,
      fm.default_value,            
      fm.calcname,
      fm.mandatory,
      fm.metadata_reftbl,
      fm.upload_flag,
      fm.origsts,
      '~' AS eol
    FROM  hl7_fieldmap fm
    WHERE 1=1
      AND fm.header_name IN (&HeaderNameList)  --'PHLIP_Resulting', 'LRNB_Resulting', 'ELR_Resulting'
    ORDER BY
      fm.header_name ASC,
      fm.hl7_version ASC,
      fm.hl7_segment ASC,
      fm.hl7_field_name ASC;
  ----- -----
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      fm_origrec      NUMBER(22),
      hl7_field_name  VARCHAR2(255 CHAR),
      hl7_segment     VARCHAR2(10 CHAR),
      hl7_version     VARCHAR2(10 CHAR),
      upload_flag     CHAR(2 CHAR),
      composite       VARCHAR2(10 CHAR),
      header_name     VARCHAR2(100 CHAR),
      calcname        VARCHAR2(50 CHAR),
      default_value   VARCHAR2(254 CHAR),
      starlims_table  VARCHAR2(100 CHAR),
      starlims_column VARCHAR2(100 CHAR),
      origsts         CHAR(1 CHAR),
      mandatory       CHAR(1 CHAR),
      metadata_reftbl VARCHAR2(100 CHAR),
      eol             CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate hl7_fieldnames table-----
    --Here we are going to update the hl7_fieldmap table.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
    MERGE INTO hl7_fieldmap t1
    USING (
      SELECT
        temp.fm_origrec,
        temp.header_name,
        temp.hl7_version,
        temp.hl7_segment,     
        temp.hl7_field_name,      
        temp.starlims_table,
        temp.starlims_column,
        temp.composite,
        temp.default_value,            
        temp.calcname,
        temp.mandatory,
        temp.metadata_reftbl,
        temp.upload_flag,
        temp.origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.header_name ASC,
        temp.hl7_version ASC,
        temp.hl7_segment ASC,
        temp.hl7_field_name ASC
    ) t2
    ON (1=1
        AND t1.header_name = t2.header_name
        AND t1.hl7_version = t2.hl7_version
        AND t1.hl7_segment = t2.hl7_segment
        AND t1.hl7_field_name = t2.hl7_field_name
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.starlims_table = t2.starlims_table,
        t1.starlims_column = t2.starlims_column,
        t1.composite = t2.composite,
        t1.default_value = t2.default_value,
        t1.calcname = t2.calcname,
        t1.mandatory = t2.mandatory,
        t1.metadata_reftbl = t2.metadata_reftbl,
        t1.upload_flag = t2.upload_flag,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.header_name,
        t1.hl7_version,
        t1.hl7_segment,     
        t1.hl7_field_name,      
        t1.starlims_table,
        t1.starlims_column,
        t1.composite,
        t1.default_value,            
        t1.calcname,
        t1.mandatory,
        t1.metadata_reftbl,
        t1.upload_flag,
        t1.origsts
      )
      VALUES (
        t2.header_name,
        t2.hl7_version,
        t2.hl7_segment,     
        t2.hl7_field_name,      
        t2.starlims_table,
        t2.starlims_column,
        t2.composite,
        t2.default_value,            
        t2.calcname,
        t2.mandatory,
        t2.metadata_reftbl,
        t2.upload_flag,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
*/  
/*---------------------------------------------------------------------------*/

