


/*---------------------------------------------------------------------------*/
/*-----Interface Panel Questions Sync----------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the hl7_ci_panelquestions table between
    --environments.
    
  ----- -----
  
  -----HISTORY-----
    --2021-05-05 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/




/*-----01. Extract Questions-------------------------------------------------*/
  -----DESCRIPTION-----
    --Execute Query in source database to retrive information needed to update/
    --migrate/synronize Interface Panel Questions between environments.

  ----- -----
  

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  --InterfaceID: 'Rabies'
    SELECT
      --TESTS--
      h7pq.interface_id,
      h7pq.rasclientid,
      h7pq.testgroupname,
      h7pq.questioncaption,
      h7pq.responsetype,
      h7pq.default_value,
      h7pq.reportable,
      h7pq.server_script_name,
      h7pq.questiontype,
      h7pq.origsts,
      '~' AS eol
    FROM hl7_ci_panelquestions h7pq

    WHERE 1=1
      AND h7pq.interface_id IN (&InterfaceIDList)
    ORDER BY
      h7pq.interface_id ASC,
      h7pq.rasclientid ASC,
      h7pq.testgroupname ASC,
      h7pq.questioncaption ASC
      ;
  ----- ----- 


  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  

  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----


  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      rasclientid        VARCHAR2(30 CHAR) not null,
      interface_id       VARCHAR2(50 CHAR) not null,
      testgroupname      VARCHAR2(50 CHAR),
      questioncaption    VARCHAR2(254 CHAR) not null,
      responsetype       VARCHAR2(25 CHAR),
      default_value      VARCHAR2(254 CHAR),
      reportable         CHAR(1 CHAR) default 'N' not null,
      server_script_name VARCHAR2(293 CHAR),
      questiontype       VARCHAR2(20 CHAR) default 'SingleChoice' not null,
      origsts            CHAR(1 CHAR) default 'N' not null,
      eol                CHAR(1 CHAR) default '~'      
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Data Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: for some reason import does not work if there is only one row of data to import.
  ----- -----
select * from hl7_ci_panelquestions
  -----08. Merge/Upate SNOMEDCODES table-----
    MERGE INTO hl7_ci_panelquestions t1
    USING (
      SELECT DISTINCT
        temp.interface_id,
        temp.rasclientid,
        temp.testgroupname,
        temp.questioncaption,
        temp.responsetype,
        temp.default_value,
        temp.reportable,
        temp.server_script_name,
        temp.questiontype,
        temp.origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
        AND temp.interface_id IS NOT NULL
      ORDER BY
        temp.interface_id ASC,
        temp.rasclientid ASC,
        temp.testgroupname ASC,        
        temp.questioncaption ASC
    ) t2
    ON (1=1
        AND t1.interface_id = t2.interface_id
        AND t1.rasclientid = t2.rasclientid
        AND t1.testgroupname = t2.testgroupname
        AND t1.questioncaption = t2.questioncaption
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.responsetype = t2.responsetype,
        t1.default_value = t2.default_value,
        t1.reportable = t2.reportable,
        t1.server_script_name = t2.server_script_name,
        t1.questiontype = t2.questiontype,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.interface_id,
        t1.rasclientid,
        t1.testgroupname,
        t1.questioncaption,
        t1.responsetype,
        t1.default_value,
        t1.reportable,
        t1.server_script_name,
        t1.questiontype,
        t1.origsts
      )
      VALUES (
        t2.interface_id,
        t2.rasclientid,
        t2.testgroupname,
        t2.questioncaption,
        t2.responsetype,
        t2.default_value,
        t2.reportable,
        t2.server_script_name,
        t2.questiontype,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the SnomedCodes table
  ----- -----

/*---------------------------------------------------------------------------*/
