/*---------------------------------------------------------------------------*/
/*-----LoincCode~Lookups Tables Sync----------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the LOINC values between environments
    --This will add new LOINC codes, and associate them with the tessts supplied
    --from the test list.  It will also update the test LOINC codes.    
  ----- -----
  
  -----HISTORY-----
    --2021-05-04 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/




/*-----01. Setup LOINC Info--------------------------------------------------*/
  -----DESCRIPTION-----
    --Execute Query in source database to retrive information needed to update/
    --migrate/synronize LOINC code information associated with the specified tests.
  ----- -----
  

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  --LRN-C: 'Cyanide', 'Blood Metals (Pb, Cd, Hg)', 'Volatile Organic Compounds'
    SELECT
      lc.classcode,
      lc.codestatus,
      lc.loinccomponenet,
      lc.loincmethod,
      lc.loincnumber,
      lc.loincproperty,
      lc.loincscale,
      lc.loincshortname,
      lc.loincsystems,
      lc.loinctime,
      lc.mapto,
      lc.origsts,
      lc.version,
      '~' AS sp1,
      t.testno,
      t.testcode,
      t.phvs_code_system_code,
      t.phvs_code_system_oid,
      t.phvs_concept_code,
      t.phvs_concept_name,
      '~' AS sp2,
      analyte,
      tlc.loinccomponenet AS tlc_loinccomponenet,
      tlc.loincdefault    AS tlc_loincdefault,
      tlc.loincmethod     AS tlc_loincmethod,
      tlc.loincnumber     AS tlc_loincnumber,
      tlc.loincproperty   AS tlc_loincproperty,
      tlc.loincscale      AS tlc_loincscale,
      tlc.loincsystems    AS tlc_loincsystems,
      tlc.loinctime       AS tlc_loinctime,
      tlc.origsts         AS tlc_origsts,
      tlc.testcode        AS tlc_testcode,
      tlc.version         AS tlc_version,
      hl7_reportable,
      code_system_oid,
      status,
      '~' AS eol
    FROM tests t
      INNER JOIN testloinccodes tlc ON (t.testcode = tlc.testcode)
      LEFT OUTER JOIN loinccodes lc ON (1=1
        AND tlc.version = lc.version
        AND tlc.loincnumber = lc.loincnumber
        )    
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      tlc.analyte ASC,
      lc.loincnumber ASC
      ;
  ----- ----- 


  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  

  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----


  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      classcode             VARCHAR2(255 CHAR) not null,
      codestatus            VARCHAR2(255 CHAR),
      loinccomponenet       VARCHAR2(255 CHAR),
      loincmethod           VARCHAR2(255 CHAR),
      loincnumber           VARCHAR2(255 CHAR) not null,
      loincproperty         VARCHAR2(255 CHAR),
      loincscale            VARCHAR2(255 CHAR),
      loincshortname        VARCHAR2(3000 CHAR),
      loincsystems          VARCHAR2(255 CHAR),
      loinctime             VARCHAR2(255 CHAR),
      mapto                 VARCHAR2(255 CHAR),
      origsts               CHAR(1 CHAR) default 'N' not null,
      version               VARCHAR2(255 CHAR) not null,
      sp1                   CHAR(1 CHAR),
      testno                VARCHAR2(50 CHAR),
      testcode              NUMBER(22) not null,
      phvs_code_system_code VARCHAR2(20 CHAR),
      phvs_code_system_oid  VARCHAR2(35 CHAR),
      phvs_concept_code     VARCHAR2(15 CHAR),
      phvs_concept_name     VARCHAR2(50 CHAR),
      sp2                   CHAR(1 CHAR),
      analyte               VARCHAR2(50 CHAR) not null,
      tlc_loinccomponenet   VARCHAR2(255 CHAR),
      tlc_loincdefault      VARCHAR2(2 CHAR),
      tlc_loincmethod       VARCHAR2(200 CHAR),
      tlc_loincnumber       VARCHAR2(50 CHAR) not null,
      tlc_loincproperty     VARCHAR2(100 CHAR),
      tlc_loincscale        VARCHAR2(5 CHAR),
      tlc_loincsystems      VARCHAR2(100 CHAR),
      tlc_loinctime         VARCHAR2(50 CHAR),
      tlc_origsts           CHAR(1 CHAR) default 'N' not null,
      tlc_testcode          NUMBER(22) not null,
      tlc_version           VARCHAR2(10 CHAR) not null,
      hl7_reportable        VARCHAR2(1 CHAR),
      code_system_oid       VARCHAR2(35 CHAR),
      status                VARCHAR2(10 CHAR),
      eol                   CHAR(1 CHAR) default '~'
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: for some reason import does not work if there is only one row of data to import.
  ----- -----

  -----08. Merge/Upate LoincCodes table-----
    MERGE INTO loinccodes t1
    USING (
      SELECT DISTINCT
        temp.version,
        temp.classcode,
        temp.loincnumber,
        temp.codestatus,
        temp.loinccomponenet,
        temp.loincmethod,
        temp.loincproperty,
        temp.loincscale,
        temp.loincshortname,
        temp.loincsystems,
        temp.loinctime,
        temp.mapto,
        temp.origsts
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.version ASC,
        temp.classcode ASC,
        temp.loincnumber ASC
    ) t2
    ON (1=1
        AND t1.version = t2.version
        AND t1.classcode = t2.classcode
        AND t1.loincnumber = t2.loincnumber
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.codestatus = t2.codestatus,
        t1.loinccomponenet = t2.loinccomponenet,
        t1.loincmethod = t2.loincmethod,
        t1.loincproperty = t2.loincproperty,
        t1.loincscale = t2.loincscale,
        t1.loincshortname = t2.loincshortname,
        t1.loincsystems = t2.loincsystems,
        t1.loinctime = t2.loinctime,
        t1.mapto = t2.mapto,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.classcode,
        t1.codestatus,
        t1.loinccomponenet,
        t1.loincmethod,
        t1.loincnumber,
        t1.loincproperty,
        t1.loincscale,
        t1.loincshortname,
        t1.loincsystems,
        t1.loinctime,
        t1.mapto,
        t1.origsts,
        t1.version
      )
      VALUES (
        t2.classcode,
        t2.codestatus,
        t2.loinccomponenet,
        t2.loincmethod,
        t2.loincnumber,
        t2.loincproperty,
        t2.loincscale,
        t2.loincshortname,
        t2.loincsystems,
        t2.loinctime,
        t2.mapto,
        t2.origsts,
        t2.version
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LoincCodes names
  ----- -----

/*---------------------------------------------------------------------------*/


  -----10. Merge/Upate TestLoincCodes table-----

    MERGE INTO testloinccodes t1
    USING (
      SELECT DISTINCT
        temp.tlc_testcode        AS src_testcode,
        t.testcode,
        temp.testno,
        temp.analyte,
        temp.tlc_version         AS version,
        temp.tlc_loincnumber     AS loincnumber,
        temp.tlc_loinccomponenet AS loinccomponenet,
        temp.tlc_loincdefault    AS loincdefault,
        temp.tlc_loincmethod     AS loincmethod,
        temp.tlc_loincproperty   AS loincproperty,
        temp.tlc_loincscale      AS loincscale,
        temp.tlc_loincsystems    AS loincsystems,
        temp.tlc_loinctime       AS loinctime,
        temp.tlc_origsts         AS origsts,
        temp.hl7_reportable,
        temp.code_system_oid,
        temp.status,
        temp.eol
      FROM  adhs_temp temp
        INNER JOIN tests t ON (temp.testno = t.testno)
      WHERE 1=1
      ORDER BY
        temp.testno ASC,
        temp.analyte ASC,
        temp.tlc_version ASC,
        temp.tlc_loincnumber ASC
    ) t2
    ON (1=1
        AND t1.testcode = t2.testcode
        AND t1.analyte = t2.analyte
        AND t1.version = t2.version
        AND t1.loincnumber = t2.loincnumber
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.loinccomponenet = t2.loinccomponenet,
        t1.loincdefault = t2.loincdefault,
        t1.loincmethod = t2.loincmethod,
        t1.loincproperty = t2.loincproperty,
        t1.loincscale = t2.loincscale,
        t1.loincsystems = t2.loincsystems,
        t1.loinctime = t2.loinctime,
        t1.origsts = t2.origsts,
        t1.hl7_reportable = t2.hl7_reportable,
        t1.code_system_oid = t2.code_system_oid,
        t1.status = t2.status
    WHEN NOT MATCHED THEN
      INSERT (
        t1.analyte,
        t1.loinccomponenet,
        t1.loincdefault,
        t1.loincmethod,
        t1.loincnumber,
        t1.loincproperty,
        t1.loincscale,
        t1.loincsystems,
        t1.loinctime,
        t1.origsts,
        t1.testcode,
        t1.version,
        t1.hl7_reportable,
        t1.code_system_oid,
        t1.status
      )
      VALUES (
        t2.analyte,
        t2.loinccomponenet,
        t2.loincdefault,
        t2.loincmethod,
        t2.loincnumber,
        t2.loincproperty,
        t2.loincscale,
        t2.loincsystems,
        t2.loinctime,
        t2.origsts,
        t2.testcode,
        t2.version,
        t2.hl7_reportable,
        t2.code_system_oid,
        t2.status
      )
  ----- -----
  
  -----11. Done-----
    --Done with Syncing TestLoincCodes
  ----- -----

/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/


  -----12. Merge/Upate Test table-----

    MERGE INTO tests t1
    USING (
      SELECT DISTINCT
        temp.testno,
        temp.testcode AS src_testcode,
        t.testcode,
        temp.phvs_code_system_code,
        temp.phvs_code_system_oid,
        temp.phvs_concept_code,
        temp.phvs_concept_name,
        temp.eol
      FROM  adhs_temp temp
        INNER JOIN tests t ON (temp.testno = t.testno)
      WHERE 1=1
      ORDER BY
        temp.testno ASC
    ) t2
    ON (1=1
        AND t1.testno = t2.testno
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.phvs_code_system_code = t2.phvs_code_system_code,
        t1.phvs_code_system_oid  = t2.phvs_code_system_oid,
        t1.phvs_concept_code     = t2.phvs_concept_code,
        t1.phvs_concept_name     = t2.phvs_concept_name
    WHEN NOT MATCHED THEN
      INSERT (
        t1.testcode,
        t1.phvs_code_system_code,
        t1.phvs_code_system_oid,
        t1.phvs_concept_code,
        t1.phvs_concept_name
      )
      VALUES (
        t2.testcode,
        t2.phvs_code_system_code,
        t2.phvs_code_system_oid,
        t2.phvs_concept_code,
        t2.phvs_concept_name
      )
  ----- -----
  
  -----11. Done-----
    --Done with Syncing TestLoincCodes
  ----- -----
