/*---------------------------------------------------------------------------*/
/*-----Interfaces~Lookups Tables Sync----------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the PHVS tables between environments
  ----- -----
  
  -----HISTORY-----
    --2021-05-04 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Setup FieldNames--------------------------------------------------*/
  -----DESCRIPTION-----
    --Take the passed MappingNamesList and sync the hl7_filednames table
    --with the adhs_temp table values imported from the source environement.
  ----- -----
  
--select * from metadata_lookups;
--select * from metadata_lookup_values;
  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  --LRN-C: 'QCCMatrix'
    SELECT
      mdl.name,
      mdl.data_source,
      mdl.origsts AS mdl_origsts,
      '~' AS sp1,
      mlv.text,
      mlv.value,
      mlv.sorter,
      mlv.origsts AS mlv_origsts,
      '~' AS eol
    FROM  metadata_lookups mdl
      INNER JOIN metadata_lookup_values mlv ON (mdl.name = mlv.lookup_name)
    WHERE 1=1
      AND mdl.name IN (&LookupNameList)
    ORDER BY
      mdl.name ASC;
  ----- ----- 
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: MetaDatLookups_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----




  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      name          VARCHAR2(255 CHAR) not null,
      data_source   VARCHAR2(255 CHAR),
      mdl_origsts   CHAR(1 CHAR) default 'N' not null,
      sp1           CHAR(1 CHAR) default '~',
      text          VARCHAR2(255 CHAR),
      value         VARCHAR2(255 CHAR) not null,
      sorter        NUMBER(22) default 0 not null,
      mlv_origsts   CHAR(1 CHAR) default 'N' not null,      
      eol           CHAR(1 CHAR) default '~'
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate metadata_lookups table-----

    --Make sure there is an entry in the phvs_value_sets table before adding details.
    MERGE INTO metadata_lookups t1
    USING (
      SELECT DISTINCT
        temp.name,
        temp.data_source,
        temp.mdl_origsts AS origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.name ASC
    ) t2
    ON (1=1
        AND t1.name = t2.name
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.data_source = t2.data_source,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.name,
        t1.data_source,
        t1.origsts
      )
      VALUES (
        t2.name,
        t2.data_source,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the MetaDataLookup names
  ----- -----

/*---------------------------------------------------------------------------*/


  -----09. Merge/Upate metadata_lookup_values table-----

    --Add/update details for the valuesets.
    MERGE INTO metadata_lookup_values t1
    USING (
      SELECT DISTINCT
        temp.name,
        temp.text,
        temp.value,
        temp.sorter,
        temp.mlv_origsts AS origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.name ASC,
        temp.text ASC,
        temp.value ASC
    ) t2
    ON (1=1
        AND t1.name = t2.name
        AND t1.text = t2.text
        AND t1.value = t2.value
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.sorter = t2.sorter,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.name,
        t1.text,
        t1.value,
        t1.sorter,
        t1.origsts
      )
      VALUES (
        t2.name,
        t2.text,
        t2.value,
        t2.sorter,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the FieldNames
  ----- -----

/*---------------------------------------------------------------------------*/
