/*---------------------------------------------------------------------------*/
/*-----Interfaces~PVHS Tables Sync-------------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the PHVS tables between environments
  ----- -----
  
  -----HISTORY-----
    --2021-04-29 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Setup FieldNames--------------------------------------------------*/
  -----DESCRIPTION-----
    --Take the passed MappingNamesList and sync the hl7_filednames table
    --with the adhs_temp table values imported from the source environement.
  ----- -----
  

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  --Rabies:
      -- 'PHVS_Rabies_AgeCategory', 'PHVS_Rabies_AnimalGender', 'PHVS_Rabies_AnimalSpecies', 'PHVS_Rabies_DeathType', 'PHVS_Rabies_ExposedSpecies'
      -- 'PHVS_Rabies_ExposureType', 'PHVS_Rabies_Ownership', 'PHVS_Rabies_SpecimemRejection', 'PHVS_Rabies_SpecimenSource', 'PHVS_Rabies_Surveillance'
      -- 'PHVS_Rabies_VaccinatedStatus', 'PHVS_Rabies_YNU', 'Rabies Sex Codes'
 --LRN-C:
      -- 'LRN_C_QC_MaterialLot', 'LRN_C_ActivityType', 'LRN_C_InstrumentID', 'LRN_C_InstrumentType', 'LRN_C_PossibleResults'
      
    SELECT
      phv.value_set_name,
      phv.value_set_code,
      phv.origsts AS phvs_origsts,
      '~' AS spacer1,
      psd.concept_code,
      psd.concept_name,
      psd.code_system_code,
      psd.code_system_oid,
      psd.code_system_version,
      psd.comments,
      psd.display_name,
      psd.hl7table,
      psd.origsts AS psd_origsts,
      '~' AS eol
    FROM  phvs_value_sets phv
      INNER JOIN phvs_value_sets_details psd ON (phv.value_set_code = psd.value_set_code)
    WHERE 1=1
      AND phv.value_set_name IN (&ValueSetNameList)
    ORDER BY
      phv.value_set_name ASC,
      psd.concept_code ASC;
  ----- ----- 
  
  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: PhvsValueSets_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      value_set_name      VARCHAR2(254 CHAR),
      value_set_code      VARCHAR2(100 CHAR),
      phvs_origsts        CHAR(1 CHAR) default 'N' not null,
      spacer1             CHAR(1 CHAR),
      concept_code        VARCHAR2(50 CHAR) not null,
      concept_name        VARCHAR2(254 CHAR),
      code_system_oid     VARCHAR2(50 CHAR),
      code_system_code    VARCHAR2(100 CHAR),
      code_system_version VARCHAR2(100 CHAR),
      display_name        VARCHAR2(254 CHAR),
      comments            VARCHAR2(254 CHAR),
      hl7table            VARCHAR2(50 CHAR),
      psd_origsts         CHAR(1 CHAR) default 'N' not null,
      eol                 CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate phvs_value_sets table-----

    --Make sure there is an entry in the phvs_value_sets table before adding details.
    MERGE INTO phvs_value_sets t1
    USING (
      SELECT DISTINCT
        temp.value_set_name,
        temp.value_set_code,
        temp.phvs_origsts AS origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.value_set_name ASC,
        temp.value_set_code ASC
    ) t2
    ON (1=1
        AND t1.value_set_code = t2.value_set_code
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.value_set_name = t2.value_set_name,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.value_set_name,
        t1.value_set_code,
        t1.origsts
      )
      VALUES (
        t2.value_set_name,
        t2.value_set_code,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the FieldNames
  ----- -----

/*---------------------------------------------------------------------------*/


  -----09. Merge/Upate phvs_value_sets_details table-----

    --Add/update details for the valuesets.
    MERGE INTO phvs_value_sets_details t1
    USING (
      SELECT DISTINCT
        temp.value_set_name,
        temp.value_set_code,
        temp.concept_code,
        temp.concept_name,
        temp.code_system_oid,
        temp.code_system_code,
        temp.code_system_version,
        temp.display_name,
        temp.comments,
        temp.hl7table,
        temp.psd_origsts AS origsts,
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.value_set_name ASC,
        temp.value_set_code ASC
    ) t2
    ON (1=1
        AND t1.value_set_code = t2.value_set_code
        AND t1.concept_code = t2.concept_code
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.concept_name = t2.concept_name,
        t1.code_system_oid = t2.code_system_oid,
        t1.code_system_code = t2.code_system_code,
        t1.code_system_version = t2.code_system_version,
        t1.display_name = t2.display_name,
        t1.comments = t2.comments,
        t1.hl7table = t2.hl7table,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.value_set_code,
        t1.concept_code,
        t1.concept_name,
        t1.code_system_oid,
        t1.code_system_code,
        t1.code_system_version,
        t1.display_name,
        t1.comments,
        t1.hl7table,
        t1.origsts
      )
      VALUES (
        t2.value_set_code,
        t2.concept_code,
        t2.concept_name,
        t2.code_system_oid,
        t2.code_system_code,
        t2.code_system_version,
        t2.display_name,
        t2.comments,
        t2.hl7table,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the FieldNames
  ----- -----

/*---------------------------------------------------------------------------*/
