/*---------------------------------------------------------------------------*/
/*-----SNOMED CODES Tables Sync----------------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the various tables associeated with
    --SNOMED CODES associated with the indicated tests.  This will update the 
    --following tables:
    -- 1. snomedcodes
    -- 2. possibleresults
  ----- -----
  
  -----HISTORY-----
    --2021-05-05 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/




/*-----01. Setup SNOMED Info--------------------------------------------------*/
  -----DESCRIPTION-----
    --Execute Query in source database to retrive information needed to update/
    --migrate/synronize LOINC code information associated with the specified tests.
    --NOTE: THIS SCRIPT HAS NOT BEEN VALIDATED AT THIS POINT.
  ----- -----
  

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  --LRN-C: NONE FOR LRN-C
    SELECT
      --TESTS--
      t.testno,
      t.testcode,
      '~' AS sp1,
      --POSSIBLE RESULTS--
      pr.analyte,
      pr.result,
      pr.result_status,
      pr.conclusion_report,
      pr.sorter,
      pr.localnumber,
      pr.snomedcode            AS pr_snomedcode,
      pr.snomedconceptid       AS pr_snomedconceptid,
      pr.snomeddescriptionid   AS pr_snomeddescriptionid,
      pr.code_system_oid       AS pr_code_system_oid,
      pr.cdc_reportable,
      pr.elr_reportable,
      pr.origsts               AS pr_origsts,
      --SNOMED CODES--
      '~' AS sp2,
      sc.snomedcode,
      sc.snomed_group,
      sc.snomedelement,
      sc.snomedconceptid,
      sc.snomeddescriptionid,
      sc.loinccondname,
      sc.origsts              AS sc_origsts,
      '~' AS eol
    FROM tests t
      INNER JOIN possibleresults pr ON (t.testcode = pr.testcode)
      LEFT OUTER JOIN snomedcodes sc ON (pr.snomedcode = sc.snomedcode)
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      pr.analyte ASC,
      pr.result ASC,
      pr.snomedcode ASC
      ;
  ----- ----- 


  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  

  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----


  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      --TESTS--
      testno                 VARCHAR2(50 CHAR),
      testcode               NUMBER(22) not null,
      sp1                    CHAR(1 CHAR),
      --POSSIBLE RESULTS--
      analyte                VARCHAR2(50 CHAR) not null,
      result                 VARCHAR2(120 CHAR) not null,
      result_status          VARCHAR2(20 CHAR),
      conclusion_report      VARCHAR2(1024 CHAR),
      sorter                 NUMBER(22),
      localnumber            VARCHAR2(10 CHAR),
      pr_snomedcode          VARCHAR2(30 CHAR),
      pr_snomedconceptid     VARCHAR2(255 CHAR),
      pr_snomeddescriptionid VARCHAR2(255 CHAR),      
      pr_code_system_oid     VARCHAR2(35 CHAR),      
      cdc_reportable         VARCHAR2(1 CHAR),
      elr_reportable         VARCHAR2(1 CHAR),
      pr_origsts             CHAR(1 CHAR) default 'N' not null,      
      --SNOMED CODES--
      sp2                   CHAR(1 CHAR),
      snomedcode            VARCHAR2(30 CHAR),
      snomed_group          VARCHAR2(20 CHAR),  
      snomedelement         VARCHAR2(255 CHAR),
      snomedconceptid       VARCHAR2(255 CHAR),
      snomeddescriptionid   VARCHAR2(255 CHAR),
      loinccondname         VARCHAR2(50 CHAR),
      sc_origsts            CHAR(1 CHAR) default 'N',
      eol                   CHAR(1 CHAR) default '~'
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

  -----07. Data Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: for some reason import does not work if there is only one row of data to import.
  ----- -----

  -----08. Merge/Upate SNOMEDCODES table-----
    MERGE INTO snomedcodes t1
    USING (
      SELECT DISTINCT
        temp.snomed_group,
        temp.snomedcode,
        temp.snomedelement,
        temp.snomedconceptid,
        temp.snomeddescriptionid,
        temp.loinccondname,
        temp.sc_origsts AS origsts,        
        temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
        AND temp.snomedcode IS NOT NULL
      ORDER BY
        temp.snomed_group ASC,
        temp.snomedcode ASC
    ) t2
    ON (1=1
        AND t1.snomedcode = t2.snomedcode
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.snomed_group = t2.snomed_group,
        t1.snomedelement = t2.snomedelement,
        t1.snomedconceptid = t2.snomedconceptid,
        t1.snomeddescriptionid = t2.snomeddescriptionid,
        t1.loinccondname = t2.loinccondname,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.snomed_group,
        t1.snomedcode,
        t1.snomedelement,
        t1.snomedconceptid,
        t1.snomeddescriptionid,
        t1.loinccondname,
        t1.origsts
      )
      VALUES (
        t2.snomed_group,
        t2.snomedcode,
        t2.snomedelement,
        t2.snomedconceptid,
        t2.snomeddescriptionid,
        t2.loinccondname,
        t2.origsts
      )
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the SnomedCodes table
  ----- -----

/*---------------------------------------------------------------------------*/


  -----10. Merge/Upate PossibleResults table-----

    MERGE INTO possibleresults t1
    USING (
      SELECT DISTINCT
        temp.testno,
        t.testcode,
        temp.testcode                AS src_testcode,
        temp.analyte,
        temp.result,
        temp.result_status,
        temp.conclusion_report,
        temp.sorter,
        temp.localnumber,
        temp.pr_snomedcode            AS snomedcode,
        temp.pr_snomedconceptid       AS snomedconceptid,
        temp.pr_snomeddescriptionid   AS snomeddescriptionid,
        temp.pr_code_system_oid       AS code_system_oid,
        temp.cdc_reportable,
        temp.elr_reportable,
        temp.pr_origsts               AS origsts,      
        temp.eol
      FROM  adhs_temp temp
        INNER JOIN tests t ON (temp.testno = t.testno)
      WHERE 1=1
      ORDER BY
        temp.testno ASC,
        temp.analyte ASC,
        temp.sorter ASC,
        temp.result ASC
    ) t2
    ON (1=1
        AND t1.testcode = t2.testcode
        AND t1.analyte = t2.analyte
        AND t1.result = t2.result
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.result_status = t2.result_status,
        t1.conclusion_report = t2.conclusion_report,
        t1.sorter = t2.sorter,
        t1.localnumber = t2.localnumber,
        t1.snomedcode = t2.snomedcode,
        t1.snomedconceptid = t2.snomedconceptid,
        t1.snomeddescriptionid = t2.snomeddescriptionid,
        t1.code_system_oid = t2.code_system_oid,
        t1.cdc_reportable = t2.cdc_reportable,
        t1.elr_reportable = t2.elr_reportable,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.testcode,
        t1.analyte,
        t1.result,
        t1.result_status,
        t1.conclusion_report,
        t1.sorter,
        t1.localnumber,
        t1.snomedcode,
        t1.snomedconceptid,
        t1.snomeddescriptionid,
        t1.code_system_oid,
        t1.cdc_reportable,
        t1.elr_reportable,
        t1.origsts
      )
      VALUES (
        t2.testcode,
        t2.analyte,
        t2.result,
        t2.result_status,
        t2.conclusion_report,
        t2.sorter,
        t2.localnumber,
        t2.snomedcode,
        t2.snomedconceptid,
        t2.snomeddescriptionid,
        t2.code_system_oid,
        t2.cdc_reportable,
        t2.elr_reportable,
        t2.origsts
      )
  ----- -----
  
  -----11. Done-----
    --Done with Syncing PossibleResults
  ----- -----
