/*---------------------------------------------------------------------------*/
/*-----TestAnalyteSpec ~Table Sync.sql----------------------------------------*/

  -----DESCRIPTION-----
    --Utilze these scripts to syncrinize the  spec_analytes table between
    --environments based on the provided tests list. 
  ----- -----
  
  -----HISTORY-----
    --2021-05-13 JTY: Begin Script Creation
  ----- -----
/*---------------------------------------------------------------------------*/




/*-----01. Setup TestAnalyteSpecifications Info------------------------------*/
  -----DESCRIPTION-----
    --Execute Query in source database to retrive information needed to update/
    --migrate/synronize Anayte Spec information associated with the specified tests.
  ----- -----
  

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
 --  select * from tests t where t.testcatcode <> 'Retired'
  --LRN-C: NONE FOR LRN-C
    SELECT
      --TESTS--
      '~TEST~' AS sp1,
      t.testno,
      t.testcode,
      --SPEC SETS--
      '~SPEC_SETS~' AS sp2,
      ss.specno AS ss_specno,
      ss.matcode,
      ss.qctype,
      ss.typeofspec,
      ss.workflowcode,
      ss.dispstepcode,      
      '~SPEC_ANALYTES~' AS sp3,
      --SPEC ANALYTES--
      --sa.testcode,
      sa.analtype,
      sa.analyte,
      sa.schemaname,
      sa.specno,
      '~' AS sp4,
      sa.charlimits,
      sa.grouping,
      sa.higha,
      sa.highb,
      sa.lowa,
      sa.lowb,
      sa.pass_text,
      sa.picture,
      sa.printflag,
      sa.specsorter,
      sa.spn01,
      sa.spn02,
      sa.spn03,
      sa.spn04,
      sa.spn05,
      sa.synonim,
      sa.units,
      sa.sptestsorter,
      sa.qc_expected_result,
      sa.origsts,
      '~' AS eol
    FROM tests t
      INNER JOIN spec_analytes sa ON (t.testcode = sa.testcode)
      INNER JOIN spec_sets ss ON (sa.specno = ss.specno)
    WHERE 1=1
      AND t.testno IN (&TestNameList)
    ORDER BY
      t.testno ASC,
      ss.specno ASC,
      sa.analtype ASC,
      sa.analyte ASC
      ;
  ----- ----- 


  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  

  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----


  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      --TESTS--
      sp1             VARCHAR2(50 CHAR),
      testno          VARCHAR2(50 CHAR),
      testcode        NUMBER(22) not null,
      --SPEC SETS--
      sp2             VARCHAR2(50 CHAR),
      ss_specno       NUMBER(22) not null,  
      matcode         VARCHAR2(30 CHAR),
      qctype          VARCHAR2(20 CHAR),
      typeofspec      VARCHAR2(10 CHAR),
      workflowcode    VARCHAR2(10 CHAR),  
      dispstepcode    VARCHAR2(15 CHAR),  
      --SPEC ANALYTES--
      sp3                VARCHAR2(50 CHAR),
      analtype           VARCHAR2(2 CHAR),
      analyte            VARCHAR2(50 CHAR) not null,
      schemaname         VARCHAR2(15 CHAR),
      specno             NUMBER(22) not null,  
      sp4                CHAR(1 CHAR),
      charlimits         VARCHAR2(254 CHAR),
      grouping           VARCHAR2(25 CHAR),
      higha              VARCHAR2(10 CHAR),
      highb              VARCHAR2(10 CHAR),
      lowa               VARCHAR2(10 CHAR),
      lowb               VARCHAR2(10 CHAR),
      pass_text          VARCHAR2(254 CHAR),
      picture            VARCHAR2(16 CHAR),
      printflag          VARCHAR2(2 CHAR),
      specsorter         NUMBER(22),
      spn01              VARCHAR2(10 CHAR),
      spn02              VARCHAR2(10 CHAR),
      spn03              VARCHAR2(10 CHAR),
      spn04              VARCHAR2(10 CHAR),
      spn05              VARCHAR2(10 CHAR),
      synonim            VARCHAR2(60 CHAR),
      units              VARCHAR2(15 CHAR),
      sptestsorter       NUMBER(22),
      qc_expected_result VARCHAR2(80 CHAR),
      origsts            CHAR(1 CHAR) default 'N' not null,
      eol                CHAR(1 CHAR) default '~'
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
  -----07. Data Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
      --NOTE: for some reason import does not work if there is only one row of data to import.
  ----- -----

  -----08. Merge/Upate SPEC ANALYTES table-----
    MERGE INTO spec_analytes t1
    USING (
    SELECT
      temp.testno,
      t.testcode,
      ss.specno,
      temp.matcode,
      temp.qctype,
      temp.typeofspec,
      temp.workflowcode,
      temp.dispstepcode,      
      temp.analtype,
      temp.analyte,
      temp.schemaname,
      temp.charlimits,
      temp.grouping,
      temp.higha,
      temp.highb,
      temp.lowa,
      temp.lowb,
      temp.pass_text,
      temp.picture,
      temp.printflag,
      temp.specsorter,
      temp.spn01,
      temp.spn02,
      temp.spn03,
      temp.spn04,
      temp.spn05,
      temp.synonim,
      temp.units,
      temp.sptestsorter,
      temp.qc_expected_result,
      temp.origsts,
      temp.eol
    FROM adhs_temp temp
      INNER JOIN tests t ON (temp.testno = t.testno)
      INNER JOIN spec_sets ss ON (1=1
        AND temp.matcode = ss.matcode
        AND temp.qctype = ss.qctype
        AND temp.typeofspec = ss.typeofspec
        AND temp.workflowcode = ss.workflowcode
        AND temp.dispstepcode = ss.dispstepcode
        )
    WHERE 1=1
    ORDER BY
      t.testno ASC,
      ss.specno ASC,
      temp.analtype ASC,
      temp.analyte ASC
    ) t2
    ON (1=1
        AND t1.testcode = t2.testcode
        AND t1.analtype = t2.analtype
        AND t1.analyte = t2.analyte
        AND t1.specno = t2.specno
        AND t1.schemaname = t2.schemaname
        )
    WHEN MATCHED THEN
      UPDATE SET
      t1.charlimits = t2.charlimits,
      t1.grouping = t2.grouping,
      t1.higha = t2.higha,
      t1.highb = t2.highb,
      t1.lowa = t2.lowa,
      t1.lowb = t2.lowb,
      t1.pass_text = t2.pass_text,
      t1.picture = t2.picture,
      t1.printflag = t2.printflag,
      t1.specsorter = t2.specsorter,
      t1.spn01 = t2.spn01,
      t1.spn02 = t2.spn02,
      t1.spn03 = t2.spn03,
      t1.spn04 = t2.spn04,
      t1.spn05 = t2.spn05,
      t1.synonim = t2.synonim,
      t1.units = t2.units,
      t1.sptestsorter = t2.sptestsorter,
      t1.qc_expected_result = t2.qc_expected_result,
      t1.origsts = t2.origsts
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the SnomedCodes table
  ----- -----

/*---------------------------------------------------------------------------*/
