CREATE OR REPLACE VIEW ADHS_CRE_EXTRACT AS
WITH
  ---core_info: Core Information---
    --Information related to sample, patient, testing facility, submitting facility, etc.
    core_info AS (
      SELECT DISTINCT
        --STARLiMS Information--
        f.folderno,
        ot.ordno,
        ot.testcode,
        ot.testno,
        TRUNC(sysdate - fc.approveddate) AS days_elapsed,
        (TRUNC(fc.approveddate)) AS date_approved,
        --Patient Information--
        to_char(fc.approveddate, 'YYYYMM') AS Reporting_month,
        cr.patient_id,
        TRUNC(Months_Between(sysdate,cr.birth_date)/12) AS Patient_age,
        'year' AS Patient_age_unit,
        --
        --Submitter/Client Info--
        rc.rasclientid AS Submitter_facility_ID,
        rc.compname AS Submitter_facility_name,
        rc.state AS Submitter_facility_state,
        rc.zip AS Submitter_facility_zipcode,
        --
        --State Lab Information--
        'AZ' AS PHL,
        '03D0641866' AS Processing_Laboratory_ID,
        --Our CLIA lab number
        --
        --Assuming that the Submitter is the same as the HCF if not provided...--
        '' AS HCF_of_origin_ID,
        COALESCE (mr.field_varchar_20, rc.compname) AS HCF_of_origin_name,
        COALESCE (mr.field_varchar_24, rc.state) AS HCF_facility_of_origin_state,
        COALESCE (mr.field_varchar_25, rc.zip) AS HCF_of_origin_zipcode,
        to_char(cr.date_collected, 'YYYYMMDD') AS Specimen_collection_date,
        to_char(cr.date_received, 'YYYYMMDD') AS Specimen_received_date,
        --Need to determine how to handle this
        COALESCE('', cr.patient_id) AS Submitter_Specimen_ID,
        f.external_id AS ARLN_Specimen_ID,
        ss.snomed_description AS Specimen_type,
        (cr.last_name || ', ' || cr.first_name) AS patient_name,
        '~' AS eol
      FROM centralreceiving cr
        INNER JOIN metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
        INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        INNER JOIN folders f ON (cr.external_id = f.external_id)
        INNER JOIN Foldercondition fc ON (f.folderno = fc.folderno)
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN tests t ON (ot.testcode = t.testcode)
        INNER JOIN specimen_sources ss ON (cr.spec_source = ss.specimen_source)
      WHERE 1=1
        AND mr.field_varchar_80 IN ('Diagnostic')
        AND fc.approvalstatus IN ('Released')
        AND fc.approveddate IS NOT NULL
        --Filter by Panel--
        AND f.testgroupname IN ('Carbapenem Resistance Testing')
        --Filter by TestName--
        AND t.testno IN (
          'MALDI-TOF Identification',
          'Carbapenemase Inactivation Method',
          'Carbapenemase PCR',
          'Antibiotic Susceptibility Testing',
          'Sendout Carbapenemase')
      ORDER BY
        f.folderno ASC,
        Submitter_facility_ID ASC,
        Submitter_Specimen_ID ASC
    ),
  ---END core_info---
  ---r_scrn: MALDI-TOF Identification ---
    r_scrn AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        r.final AS Organism_tested,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.testno = 'MALDI-TOF Identification')
        INNER JOIN results r ON (1=1
          AND r.ordno = ot.ordno
          AND r.testcode = ot.testcode
          AND r.analyte = 'MALDI-TOF Identification' )
      WHERE 1=1
        AND ci.testno = 'MALDI-TOF Identification'
    ),
  ---END r_scrn---
  ---r_out: Sendout Carbapenemase---
    r_out AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        'Yes' AS is_sendout,
        oo.shipdate AS Date_forwarded_to_RegLab,
        oo.onotes AS RegLab_comment,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
            AND ot.folderno = ci.folderno
            AND ot.ordno = ci.ordno)
        INNER JOIN outsourceorders oo ON (ot.outsourceordno = oo.outsourceordno)
      WHERE 1=1
        AND ci.testno = 'Sendout Carbapenemase'
    ),
  ---END r_out---
  ---f_cre: CRE Flag---
    f_cre AS (
      SELECT DISTINCT
        r_scrn.folderno,
        r_scrn.ordno,
        r_scrn.testno,
        r_scrn.testcode,
        'Y' AS is_cre,
        '~' AS eol
      FROM r_scrn
      WHERE 1=1
        AND r_scrn.Organism_tested  <> 'Pseudomonas aeruginosa'
    ),
  ---END f_cre---
  ---f_crpa: CRPA Flag---
    f_crpa AS (
      SELECT DISTINCT
        r_scrn.folderno,
        r_scrn.ordno,
        r_scrn.testno,
        r_scrn.testcode,
        'Y' AS is_crpa,
        '~' AS eol
      FROM r_scrn
      WHERE 1=1
        AND r_scrn.Organism_tested  = 'Pseudomonas aeruginosa'
    ),
  ---END f_crpa---
  ---r_CIM: Carbapenemase Inactivation Method (Default test)results---
    r_CIM AS (
      SELECT DISTINCT
        ot.folderno,
        ot.ordno,
        ot.testno,
        ot.testcode,
        r.final AS Phenotypic_test_result,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.testno = 'Carbapenemase Inactivation Method')
        INNER JOIN results r ON (1=1
          AND r.ordno = ot.ordno
          AND r.testcode = ot.testcode
          AND r.analyte = 'Carbapenemase' )
    ),
  ---END r_CIM---
  ---t_PCR: PCR Results Set---
    t_PCR AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        r.analyte,
        r.numres,
        r.final,
        '~' AS eol
      FROM core_info ci
        INNER JOIN results r ON (1=1
          AND r.ordno = ci.ordno
          AND r.testcode = ci.testcode)
      WHERE 1=1
        AND ci.testno = 'Carbapenemase PCR'
    ),
  ---END t_PCR---
  ---KPC_gene: PCR KPC_gene Results Set---
    a_KPC AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'KPC'
    ),
  ---END KPC_gene---
  ---IMP_gene: PCR IMP_gene Results Set---
    a_IMP AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'IMP'
    ),
  ---END IMP_gene---
  ---mcr_gene: PCR mcr_gene Results Set---
    a_mcr AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'mcr-1'
    ),
  ---END mcr_gene---
  ---NDM_gene: PCR NDM_gene Results Set---
    a_NDM AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'NDM-1'
    ),
  ---END NDM_gene---
  ---OXA_48_like_gene: PCR OXA_48_like_gene Results Set---
    a_OXA AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'OXA-48-like'
    ),
  ---END OXA_48_like_gene---
  ---VIM_gene: PCR VIM_gene Results Set---
    a_VIM AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'VIM'
    ),
  ---END VIM_gene---







  ---Other_gene: PCR Other_gene Results Set---
    --put other gene name nere (maybe mcr-2?)
    a_Other AS (
      SELECT DISTINCT
        t_PCR.ordno,
        analyte AS gene_name,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND analyte = 'mcr-2'
    ),
  ---END Other_gene---
  ---t_AST: Antibiotic Susceptibility Testing Results Set---
    t_AST AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        r.analyte,
        r.numres,
        r.rn1,
        r.final,
        '~' AS eol
      FROM core_info ci
        INNER JOIN results r ON (1=1
          AND r.ordno = ci.ordno
          AND r.testcode = ci.testcode)
      WHERE 1=1
        AND ci.testno = 'Antibiotic Susceptibility Testing'
    ),
  ---END t_AST---
  ---a_Aztreonam: AST Aztreonam Results Set---
    a_Aztreonam AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Aztreonam'
    ),
  ---END a_Aztreonam---
  ---a_Cefepime: AST Cefepime Set---
    a_Cefepime AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Cefepime'
    ),
  ---END a_Cefepime---
  ---a_Ceftazidime: AST Ceftazidime Set---
    a_Ceftazidime AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Ceftazidime'
    ),
  ---END a_Ceftazidime---
  ---a_Colistin: AST Colistin Set---
    a_Colistin AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Colistin'
    ),
  ---END a_Colistin---
  ---a_Doripenem: AST Doripenem Set---
    a_Doripenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        regexp_replace(numres, '[^0-9\.]*') MIC_num, --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Doripenem'
    ),
  ---END a_Doripenem---
  ---a_Imipenem: AST Imipenem Set---
    a_Imipenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        regexp_replace(numres, '[^0-9\.]*') MIC_num, --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Imipenem'
    ),
  ---END a_Imipenem---
  ---a_Meropenem: AST Meropenem Set---
    a_Meropenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        regexp_replace(numres, '[^0-9\.]*') MIC_num, --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Meropenem'
    ),
  ---END a_Meropenem---
  ---a_Ceftriaxone: AST Ceftriaxone Set---
    a_Ceftriaxone AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Ceftriaxone'
    ),
  ---END a_Ceftriaxone---
  ---a_Ertapenem: AST Ertapenem Set---
    a_Ertapenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        regexp_replace(numres, '[^0-9\.]*') MIC_num, --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Ertapenem'
    ),
  ---END a_Ertapenem---
  ---a_O3g: AST Other_3rdGen_cephalosporin Set---
    a_O3g AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Other_3rdGen_cephalosporin'
    ),
  ---END a_O3g---
  ---a_Pt: Piperacillin/Tazobactam Set---
    a_Pt AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        numres AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND analyte = 'Piperacillin/Tazobactam'
    ),
  ---END a_Pt---
    ---f_creresistant: Confirmed_carbapenem_resistant for CRE---
    f_creresistant AS (
      SELECT DISTINCT
        ci.ordno,
        r_cim.Phenotypic_test_result AS p_test,
        a_dor.MIC_num AS dor_mic,
        a_imi.MIC_num AS imi_mic,
        a_mer.MIC_num AS mer_mic,
        a_ert.MIC_num AS ert_mic,
        CASE
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (TO_NUMBER(a_dor.MIC_num) >= 4)
                 OR (TO_NUMBER(a_imi.MIC_num) >= 4)
                 OR (TO_NUMBER(a_mer.MIC_num) >= 4)
                 OR (TO_NUMBER(a_ert.MIC_num) >= 2)
                )
            ) THEN 'Yes'
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (a_dor.MIC_num IS NULL)
                 OR (a_imi.MIC_num IS NULL)
                 OR (a_mer.MIC_num IS NULL)
                 OR (a_ert.MIC_num IS NULL)
                )
            ) THEN 'Unknown'
          ELSE 'No'
        END AS cre_resist,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN r_CIM  ON (ci.ordno = r_CIM.ordno)
        LEFT OUTER JOIN a_Doripenem a_dor ON (ci.ordno = a_dor.ordno)
        LEFT OUTER JOIN a_Imipenem a_imi ON (ci.ordno = a_imi.ordno)
        LEFT OUTER JOIN a_Meropenem a_mer ON (ci.ordno = a_mer.ordno)
        LEFT OUTER JOIN a_Ertapenem a_ert  ON (ci.ordno = a_ert.ordno)
      WHERE 1=1
        ),
    ---END f_creresistant---
    ---f_crparesistant: Confirmed_carbapenem_resistant for CRPA---
    f_crparesistant AS (
      SELECT DISTINCT
        ci.ordno,
        r_cim.Phenotypic_test_result AS p_test,
        a_dor.MIC_num AS dor_mic,
        a_imi.MIC_num AS imi_mic,
        a_mer.MIC_num AS mer_mic,
        CASE
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (TO_NUMBER(a_dor.MIC_num) >= 8)
                 OR (TO_NUMBER(a_imi.MIC_num) >= 8)
                 OR (TO_NUMBER(a_mer.MIC_num) >= 8)
                )
            ) THEN 'Yes'
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (a_dor.MIC_num IS NULL)
                 OR (a_imi.MIC_num IS NULL)
                 OR (a_mer.MIC_num IS NULL)
                )
            ) THEN 'Unknown'
          ELSE 'No'
        END AS crpa_resist,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN r_CIM  ON (ci.ordno = r_CIM.ordno)
        LEFT OUTER JOIN a_Doripenem a_dor  ON (ci.ordno = a_dor.ordno)
        LEFT OUTER JOIN a_Imipenem a_imi ON (ci.ordno = a_imi.ordno)
        LEFT OUTER JOIN a_Meropenem a_mer ON (ci.ordno = a_mer.ordno)
      WHERE 1=1
        ),
    ---END f_crparesistant---
    ---f_ConfirmedResistance---
      --Calculate  Confirmed_carbapenem_resistant value based on
      --f_creresistant and f_crparesistant flag values
    f_ConfirmedResistance AS (
      SELECT DISTINCT
        ci.ordno,
        CASE
          WHEN (f_cre.cre_resist = 'Yes') THEN 'Yes'
          WHEN (f_crpa.crpa_resist = 'Yes') THEN 'Yes'
          ELSE 'No'
        END AS confirmed_resistant,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN f_creresistant f_cre  ON (ci.ordno = f_cre.ordno)
        LEFT OUTER JOIN f_crparesistant f_crpa  ON (ci.ordno = f_crpa.ordno)
      WHERE 1=1
        )
    ---END f_ConfirmedResistance---









  ---all_together---
    --Combine all tables to one single result
    SELECT DISTINCT
      --ResistanceFlagValidation--
      --f_creres.cre_resist AS cre_flg,
      --f_crpares.crpa_resist AS crpa_flg,
      --f_creres.p_test AS cre_p,
      --f_creres.dor_mic AS cre_dor,
      --f_creres.imi_mic AS cre_imi,
      --f_creres.mer_mic AS cre_mer,
      --f_creres.ert_mic AS cre_ert,
      --STARLiMS Info--
      '~INFO_SL~' AS info_sl,
      ci.folderno,
      ci.ordno,
      COALESCE(f_cre.is_cre, 'N') AS is_cre,
      COALESCE(f_crpa.is_crpa, 'N') AS is_crpa,
      COALESCE(f_creres.cre_resist, 'No') AS resist_cre,
      COALESCE(f_crpares.crpa_resist, 'No') AS resist_crpa,
      ci.days_elapsed,
      ci.date_approved,
      ci.patient_name,
      -- --
      --core_info--
      '~INFO DEM~' AS info_demo,
      ci.Reporting_month,
      ci.patient_id,
      ci.Patient_age,
      ci.Patient_age_unit,
      ci.PHL,
      ci.HCF_of_origin_ID,
      ci.HCF_of_origin_name,
      ci.HCF_facility_of_origin_state,
      ci.HCF_of_origin_zipcode,
      ci.Processing_Laboratory_ID,
      ci.Submitter_facility_ID,
      ci.Submitter_facility_name,
      ci.Submitter_facility_state,
      ci.Submitter_facility_zipcode,
      ci.Specimen_collection_date,
      ci.Specimen_received_date,
      ci.Submitter_Specimen_ID,
      ci.ARLN_Specimen_ID,
      ci.Specimen_type,
      -- --
      --Sendout--
      COALESCE(r_out.is_sendout, 'No') AS Isolate_forwarded_to_RegLab,
      r_out.Date_forwarded_to_RegLab,
      r_out.RegLab_comment,
      -- --
      --Test_Nonspecific--
      '~INFO TEST~' AS info_test,
      r_scrn.Organism_tested,
      r_cim.Phenotypic_test_result,
      'CIM method' AS Phenotypic_method_used,
      f_resist.confirmed_resistant AS confirmed_carbapenem_resistant,
      'Broth microdilution susceptibility test' AS AST_method_used,
      'CDC assay' AS PCR_method_used,
      a_IMP.result AS IMP_gene,
      a_KPC.result AS KPC_gene,
      a_mcr.result AS mcr_gene,
      a_NDM.result AS NDM_gene,
      a_OXA.result AS OXA_48_like_gene,
      a_VIM.result AS VIM_gene,
      a_Other.gene_name AS Other_gene_name,
      a_Other.result AS Other_gene_result,
      a_Aztreonam.MIC AS Aztreonam_AST_MIC,
      a_Aztreonam.zone_diameter AS Aztreonam_AST_zone_diameter,
      a_Cefepime.MIC AS Cefepime_AST_MIC,
      a_Cefepime.zone_diameter AS Cefepime_AST_zone_diameter,
      a_Ceftazidime.MIC AS Ceftazidime_AST_MIC,
      a_Ceftazidime.zone_diameter AS Ceftazidime_AST_zone_diameter,
      a_Colistin.MIC AS Colistin_AST_MIC,
      a_Doripenem.MIC AS Doripenem_AST_MIC,
      a_Doripenem.zone_diameter AS Doripenem_AST_zone_diameter,
      a_Imipenem.MIC AS Imipenem_AST_MIC,
      a_Imipenem.zone_diameter AS Imipenem_AST_zone_diameter,
      a_Meropenem.MIC AS Meropenem_AST_MIC,
      a_Meropenem.zone_diameter AS Meropenem_AST_zone_diameter,
      -- --
      --CRE_Details--
      '~INFO_CRE~' AS info_cre,
      --Ceftriaxone--
      a_Ceftriaxone.MIC AS Ceftriaxone_AST_MIC,
      a_Ceftriaxone.zone_diameter AS Ceftriaxone_AST_zone_diameter,
      --Ertapenem--
      a_Ertapenem.MIC AS Ertapenem_AST_MIC,
      a_Ertapenem.zone_diameter AS Ertapenem_AST_zone_diameter,
      --Other_3rdGen_cephalosporin--
      a_O3g.analyte AS O3g_cep_name,
      a_O3g.MIC AS O3g_cep_AST_MIC,
      a_O3g.zone_diameter AS O3g_cep_AST_zone_diameter,
      -- --
      --CRPA_Details--
      '~INFO_CRPA~' AS info_crpa,
      --Piperacillin--
      a_Pt.MIC AS Pt_AST_MIC,
      a_Pt.zone_diameter AS Pt_AST_zone_diameter,
      -- --
      '~' AS eol
    FROM core_info ci
      -- LEFT OUTER JOIN f_crtest ON (ci.ordno = f_crtest.ordno)
      LEFT OUTER JOIN r_scrn ON (ci.ordno = r_scrn.ordno)
      LEFT OUTER JOIN r_out ON (ci.ordno = r_out.ordno)
      LEFT OUTER JOIN f_cre ON (ci.ordno = f_cre.ordno)
      LEFT OUTER JOIN f_crpa ON (ci.ordno = f_crpa.ordno)
      LEFT OUTER JOIN r_CIM ON (ci.ordno = r_CIM.ordno)
      LEFT OUTER JOIN a_KPC ON (ci.ordno = a_KPC.ordno)
      LEFT OUTER JOIN a_IMP ON (ci.ordno = a_IMP.ordno)
      LEFT OUTER JOIN a_mcr ON (ci.ordno = a_mcr.ordno)
      LEFT OUTER JOIN a_NDM ON (ci.ordno = a_NDM.ordno)
      LEFT OUTER JOIN a_OXA ON (ci.ordno = a_OXA.ordno)
      LEFT OUTER JOIN a_VIM ON (ci.ordno = a_VIM.ordno)
      LEFT OUTER JOIN a_Other ON (ci.ordno = a_Other.ordno)
      LEFT OUTER JOIN a_Aztreonam ON (ci.ordno = a_Aztreonam.ordno)
      LEFT OUTER JOIN a_Cefepime ON (ci.ordno = a_Cefepime.ordno)
      LEFT OUTER JOIN a_Ceftazidime ON (ci.ordno = a_Ceftazidime.ordno)
      LEFT OUTER JOIN a_Colistin ON (ci.ordno = a_Colistin.ordno)
      LEFT OUTER JOIN a_Doripenem ON (ci.ordno = a_Doripenem.ordno)
      LEFT OUTER JOIN a_Imipenem ON (ci.ordno = a_Imipenem.ordno)
      LEFT OUTER JOIN a_Meropenem ON (ci.ordno = a_Meropenem.ordno)
      LEFT OUTER JOIN a_Ceftriaxone ON (ci.ordno = a_Ceftriaxone.ordno)
      LEFT OUTER JOIN a_Ertapenem ON (ci.ordno = a_Ertapenem.ordno)
      LEFT OUTER JOIN a_O3g ON (ci.ordno = a_O3g.ordno)
      LEFT OUTER JOIN a_Pt ON (ci.ordno = a_Pt.ordno)
      LEFT OUTER JOIN f_creresistant f_creres  ON (ci.ordno = f_creres.ordno)
      LEFT OUTER JOIN f_crparesistant f_crpares  ON (ci.ordno = f_crpares.ordno)
      LEFT OUTER JOIN f_ConfirmedResistance f_resist  ON (ci.ordno = f_resist.ordno)
    WHERE 1=1
    ORDER BY
      folderno ASC
  ---END all_together---
/*---------------------------------------------------------------------------*/
;
