CREATE OR REPLACE VIEW ADHS_EPI_CRE AS
WITH
    ---possible_samples---
      possible_samples AS (
        SELECT DISTINCT
          f.folderno,
          --f.dispsts,
          --f.apprdate AS sample_approved,
          --t.testno,
          --ot.apprdate AS test_approved,
          '~' AS eol
        FROM  centralreceiving cr
          INNER JOIN metadata_repository mr ON (1=1
            AND mr.tablereference = 'CENTRALRECEIVING'
            AND mr.original_origrec = cr.origrec)
          INNER JOIN folders f ON (cr.external_id = f.external_id)
          INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)

        WHERE 1=1
          AND mr.field_varchar_80 IN ('Diagnostic')
          AND MONTHS_BETWEEN(sysdate, cr.date_received) <= 6
--          AND f.dispsts <> 'Cancel'
          --Filter by Panel--
          AND f.testgroupname IN ('Carbapenem Resistance Testing')
          --Filter by TestName--
          AND t.testno IN (
              'Carbapenem Resistance Testing',
              'Carbapenemase Inactivation Method',
              'Carbapenamase/mcr PCR',
              'CRE/CRPA Antibiotic Susceptibility Testing',
              'Sendout Carbapenemase'
              )
          AND (
            f.apprdate IS NOT NULL
            OR
            ot.apprdate IS NOT NULL
          )
        ORDER BY
          f.folderno DESC
      ),
    --- ---
    ---core_info: Core Information---
    --Information related to sample, patient, testing facility, submitting facility, etc.
    core_info AS (
      SELECT DISTINCT
        --STARLiMS Information--
          f.folderno,
          f.testgroupname AS panel_name,
          mr.field_varchar_80 AS activity_type,
          cr.sampdesc AS specimen_desc,
          ot.ordno,
          cr.spec_source AS sample_type,
          ot.testcode,
          ot.testno,
          to_char(fc.approveddate, 'YYYYMMDD') AS date_approved,
        --Patient Information--
          cr.first_name,
          cr.last_name,
          cr.middle_initial,
          cr.sex,
          cr.ethnicity,
          cr.patientrace AS race,
          cr.pid AS submitter_pid,
          to_char(cr.onset_date, 'YYYYMMDD') AS onset_date,
          to_char(mr.field_date_01, 'YYYYMMDD') AS exposure_date,
          to_char(fc.approveddate, 'YYYYMM') AS Reporting_month,
          cr.patient_id,
          to_char(cr.birth_date, 'YYYYMMDD') AS birth_date,
          TRUNC(Months_Between(sysdate,cr.birth_date)/12) AS Patient_age,
          'year' AS Patient_age_unit,
          mr.field_varchar_01 AS physician,
          mr.field_varchar_03 AS symptoms,
        --
        --Submitter/Client Info--
          rc.rasclientid AS Submitter_facility_ID,
          rc.compname AS Submitter_facility_name,
          rc.city AS submitter_facility_city,
          rc.county AS submitter_facility_county,
          rc.state AS Submitter_facility_state,
          rc.zip AS Submitter_facility_zipcode,
        --
        --State Lab Information--
          'AZ' AS PHL,
          '03D0641866' AS Processing_Laboratory_ID,
            --Our CLIA lab number
        --
        --Provider Information (for EPI)--
          mr.field_varchar_20 AS provider,
          mr.field_varchar_21 AS facility_name,
          mr.field_varchar_22 AS provider_address,
          mr.field_varchar_23 AS provider_city,
          mr.field_varchar_24 AS provider_state,
          mr.field_varchar_25 AS provider_zip,
          mr.field_varchar_27 AS provider_phone,
        --
        --Assuming that the Submitter is the same as the HCF if not provided...--
        '' AS HCF_of_origin_ID,
        --Need to eliminate commas in field
        COALESCE (
          REPLACE(mr.field_varchar_20, ',', '~'),
          REPLACE(rc.compname, ',', '~')) AS HCF_of_origin_name,
        COALESCE (mr.field_varchar_24, rc.state) AS HCF_facility_of_origin_state,
        COALESCE (mr.field_varchar_25, rc.zip) AS HCF_of_origin_zipcode,
        to_char(cr.date_collected, 'YYYYMMDD') AS Specimen_collection_date,
        to_char(cr.date_received, 'YYYYMMDD') AS Specimen_received_date,
  --Need to determine how to handle this
        COALESCE('', cr.patient_id) AS Submitter_Specimen_ID,
        f.external_id AS ARLN_Specimen_ID,
        ss.snomed_description AS Specimen_type,
        (cr.last_name || ', ' || cr.first_name) AS patient_name,
        '~' AS eol
      FROM  possible_samples ps
        INNER JOIN folders f ON (ps.folderno = f.folderno)
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec)
        INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        INNER JOIN specimen_sources ss ON (cr.spec_source = ss.specimen_source)
        INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
        INNER JOIN tests t ON (ot.testcode = t.testcode)
      WHERE 1=1
      ORDER BY
        f.folderno ASC,
        Submitter_facility_ID ASC,
        Submitter_Specimen_ID ASC
    ),
    ---END core_info---

    ---r_scrn: Carbapenem Resistance Testing (Micro test)---
    r_scrn AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        to_char(ot.apprdate, 'YYYYMMDD') AS test_completed,
--G02: Organism_tested - How to handle when more than one value is present for this field
--       2017.10.02: It is assumed if there are more than one results, two rows of data will be
--                   returned.  We will go with this for now, and see if there is an issue
--                   when we come to the validation phase.
        scrn.res01  AS Organism_tested,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.ordno = ci.ordno
          AND ot.testcode = ci.testcode
         )
        INNER JOIN microtasksteps scrn ON (1=1
          AND scrn.ordno = ci.ordno
          AND scrn.testcode = ci.testcode
          ---2018.02.01 JTY: Updated to use Isolate step instead of Conclusion
          --AND scrn.stepcode = 'Conclusion'
          AND scrn.stepcode = 'Isolate'
          --2018.03.18 Removed reported requirement flag,  seems some samples dont get
          --this flag set even though they are reported on the reports.  Not sure why.
          --AND scrn.reported = 'Y'
          )
      WHERE 1=1
        AND ci.testno = 'Carbapenem Resistance Testing'
    ),
    ---END r_scrn---

    ---r_out: Sendout Carbapenemase---
    r_out AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        to_char(ot.apprdate, 'YYYYMMDD') AS test_completed,
        'Yes' AS is_sendout,
        to_char(oo.shipdate, 'YYYYMMDD') AS Date_forwarded_to_RegLab,
        oo.onotes AS RegLab_comment,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.ordno = ci.ordno
          AND ot.testcode = ci.testcode
         )
        INNER JOIN outsourceorders oo ON (ot.outsourceordno = oo.outsourceordno)
     WHERE 1=1
       AND ci.testno = 'Sendout Carbapenemase'
    ),
    ---END r_out---

    ---f_cre: CRE Flag---
     f_cre AS (
       SELECT DISTINCT
         r_scrn.folderno,
         r_scrn.ordno,
         r_scrn.testno,
         r_scrn.testcode,
         'Y' AS is_cre,
         '~' AS eol
       FROM r_scrn
        INNER JOIN microtasksteps scrn ON (1=1
          AND r_scrn.ordno = scrn.ordno
          AND r_scrn.testcode = scrn.testcode
          AND scrn.stepcode = 'Isolate'
          AND scrn.res01 <> 'Pseudomonas aeruginosa'
        )
     ),
    ---END f_cre---

    ---f_crpa: CRPA Flag---
     f_crpa AS (
       SELECT DISTINCT
         r_scrn.folderno,
         r_scrn.ordno,
         r_scrn.testno,
         r_scrn.testcode,
         'Y' AS is_crpa,
         '~' AS eol
       FROM r_scrn
        INNER JOIN microtasksteps scrn ON (1=1
          AND r_scrn.ordno = scrn.ordno
          AND r_scrn.testcode = scrn.testcode
          AND scrn.stepcode = 'Isolate'
          AND scrn.res01 = 'Pseudomonas aeruginosa'
        )
     ),
    ---END f_crpa---

    ---r_CIM: Carbapenemase Inactivation Method (Default test)results---
    r_CIM AS (
      SELECT DISTINCT
        ot.folderno,
        ot.ordno,
        ot.testno,
        ot.testcode,
        to_char(ot.apprdate, 'YYYYMMDD') AS test_completed,
        r.final AS Phenotypic_test_result,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.testcode = ci.testcode
         )
        INNER JOIN results r ON (1=1
          AND r.ordno = ot.ordno
          AND r.testcode = ot.testcode
          AND r.analyte = 'Carbapenemase')
      WHERE 1=1
        AND ci.testno = 'Carbapenemase Inactivation Method'
        ),
    ---END r_CIM---

    ---t_PCR: PCR Results Set---
    t_PCR AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        to_char(ot.apprdate, 'YYYYMMDD') AS test_completed,
        r.analyte,
        r.numres,
        r.final,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.testcode = ci.testcode
         )
        INNER JOIN results r ON (1=1
          AND r.ordno = ci.ordno
          AND r.testcode = ci.testcode)
      WHERE 1=1
        AND ci.testno = 'Carbapenamase/mcr PCR'
        ),
    ---END t_PCR---

    ---KPC_gene: PCR KPC_gene Results Set---
    a_KPC AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'KPC'
        ),
    ---END KPC_gene---

    ---IMP_gene: PCR IMP_gene Results Set---
    a_IMP AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'IMP'
        ),
    ---END IMP_gene---

    ---mcr_gene: PCR mcr_gene Results Set---
    a_mcr AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'mcr-1'
        ),
    ---END mcr_gene---

    ---NDM_gene: PCR NDM_gene Results Set---
    a_NDM AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'NDM-1'
        ),
    ---END NDM_gene---

    ---OXA_48_like_gene: PCR OXA_48_like_gene Results Set---
    a_OXA AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'OXA-48-like'
        ),
    ---END OXA_48_like_gene---

    ---VIM_gene: PCR VIM_gene Results Set---
    a_VIM AS (
      SELECT DISTINCT
        t_PCR.ordno,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'VIM'
        ),
    ---END VIM_gene---

    ---Other_gene: PCR Other_gene Results Set---
      --put other gene name nere (maybe mcr-2?)
    a_Other AS (
      SELECT DISTINCT
        t_PCR.ordno,
        analyte AS gene_name,
        numres,
        DECODE(final, 'Not performed - NoPrint', 'Test not done', final) AS result
      FROM t_PCR
      WHERE 1=1
        AND  analyte = 'mcr-2'
        ),
    ---END VIM_gene---

    ---t_AST: CRE/CRPA Antibiotic Susceptibility Testing Results Set---
    t_AST AS (
      SELECT DISTINCT
        ci.folderno,
        ci.ordno,
        ci.testno,
        ci.testcode,
        to_char(ot.apprdate, 'YYYYMMDD') AS test_completed,
        r.analyte,
        r.numres,
        r.rn1,
        r.final,
        '~' AS eol
      FROM core_info ci
        INNER JOIN ordtask ot ON ( 1=1
          AND ot.folderno = ci.folderno
          AND ot.testcode = ci.testcode
         )
        INNER JOIN results r ON (1=1
          AND r.ordno = ci.ordno
          AND r.testcode = ci.testcode)
     WHERE 1=1
       AND ci.testno = 'CRE/CRPA Antibiotic Susceptibility Testing'
        ),
    ---END t_AST---

    ---a_Aztreonam: AST Aztreonam Results Set---
    a_Aztreonam AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Aztreonam'
        ),
    ---END a_Aztreonam---

    ---a_Cefepime: AST Cefepime Set---
    a_Cefepime AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Cefepime'
        ),
    ---END a_Cefepime---

    ---a_Ceftazidime: AST Ceftazidime Set---
    a_Ceftazidime AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Ceftazidime'
        ),
    ---END a_Ceftazidime---

    ---a_Colistin: AST Colistin Set---
    a_Colistin AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Colistin'
        ),
    ---END a_Colistin---

    ---a_Doripenem: AST Doripenem Set---
    a_Doripenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        regexp_replace(rn1, '[^0-9\.]*') MIC_num,  --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Doripenem'
        ),
    ---END a_Doripenem---

    ---a_Imipenem: AST Imipenem Set---
    a_Imipenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        regexp_replace(rn1, '[^0-9\.]*') MIC_num,  --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Imipenem'
        ),
    ---END a_Imipenem---

    ---a_Meropenem: AST Meropenem Set---
    a_Meropenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        regexp_replace(rn1, '[^0-9\.]*') MIC_num,  --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Meropenem'
        ),
    ---END a_Meropenem---

    ---a_Ceftriaxone: AST Ceftriaxone Set---
    a_Ceftriaxone AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Ceftriaxone'
        ),
    ---END a_Ceftriaxone---

    ---a_Ertapenem: AST Ertapenem Set---
    a_Ertapenem AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        regexp_replace(rn1, '[^0-9\.]*') MIC_num,  --Remove all text so only number exists
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Ertapenem'
        ),
    ---END a_Ertapenem---

    ---a_O3g: AST Other_3rdGen_cephalosporin Set---
    a_O3g AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Other_3rdGen_cephalosporin'
        ),
    ---END a_O3g---

    ---a_Pt: Piperacillin/Tazobactam Set---
    a_Pt AS (
      SELECT DISTINCT
        t_AST.ordno,
        analyte,
        DECODE(final, 'Not performed - NoPrint', '', final) AS result,
        numres,
        rn1 AS MIC,
        '' AS zone_diameter
      FROM t_AST
      WHERE 1=1
        AND  analyte = 'Piperacillin/Tazobactam'
        ),
    ---END a_Pt---


    ---f_creresistant: Confirmed_carbapenem_resistant for CRE---
    f_creresistant AS (
      SELECT DISTINCT
        ci.ordno,
        r_cim.Phenotypic_test_result AS p_test,
        a_dor.MIC_num AS dor_mic,
        a_imi.MIC_num AS imi_mic,
        a_mer.MIC_num AS mer_mic,
        a_ert.MIC_num AS ert_mic,
        CASE
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (TO_NUMBER(a_dor.MIC_num) >= 4)
                 OR (TO_NUMBER(a_imi.MIC_num) >= 4)
                 OR (TO_NUMBER(a_mer.MIC_num) >= 4)
                 OR (TO_NUMBER(a_ert.MIC_num) >= 2)
                )
            ) THEN 'Yes'
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (a_dor.MIC_num IS NULL)
                 OR (a_imi.MIC_num IS NULL)
                 OR (a_mer.MIC_num IS NULL)
                 OR (a_ert.MIC_num IS NULL)
                )
            ) THEN 'Unknown'
          ELSE 'No'
        END AS cre_resist,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN r_CIM  ON (ci.ordno = r_CIM.ordno)
        LEFT OUTER JOIN a_Doripenem a_dor ON (ci.ordno = a_dor.ordno)
        LEFT OUTER JOIN a_Imipenem a_imi ON (ci.ordno = a_imi.ordno)
        LEFT OUTER JOIN a_Meropenem a_mer ON (ci.ordno = a_mer.ordno)
        LEFT OUTER JOIN a_Ertapenem a_ert  ON (ci.ordno = a_ert.ordno)
      WHERE 1=1
        ),
    ---END f_creresistant---


    ---f_crparesistant: Confirmed_carbapenem_resistant for CRPA---
    f_crparesistant AS (
      SELECT DISTINCT
        ci.ordno,
        r_cim.Phenotypic_test_result AS p_test,
        a_dor.MIC_num AS dor_mic,
        a_imi.MIC_num AS imi_mic,
        a_mer.MIC_num AS mer_mic,
        CASE
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (TO_NUMBER(a_dor.MIC_num) >= 8)
                 OR (TO_NUMBER(a_imi.MIC_num) >= 8)
                 OR (TO_NUMBER(a_mer.MIC_num) >= 8)
                )
            ) THEN 'Yes'
          WHEN (
            (r_cim.Phenotypic_test_result = 'Positive')
            AND (
                    (a_dor.MIC_num IS NULL)
                 OR (a_imi.MIC_num IS NULL)
                 OR (a_mer.MIC_num IS NULL)
                )
            ) THEN 'Unknown'
          ELSE 'No'
        END AS crpa_resist,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN r_CIM  ON (ci.ordno = r_CIM.ordno)
        LEFT OUTER JOIN a_Doripenem a_dor  ON (ci.ordno = a_dor.ordno)
        LEFT OUTER JOIN a_Imipenem a_imi ON (ci.ordno = a_imi.ordno)
        LEFT OUTER JOIN a_Meropenem a_mer ON (ci.ordno = a_mer.ordno)
      WHERE 1=1
        ),
    ---END f_crparesistant---

    ---f_ConfirmedResistance---
      --Calculate  Confirmed_carbapenem_resistant value based on
      --f_creresistant and f_crparesistant flag values
    f_ConfirmedResistance AS (
      SELECT DISTINCT
        ci.ordno,
        CASE
          WHEN (f_cre.cre_resist = 'Yes') THEN 'Yes'
          WHEN (f_crpa.crpa_resist = 'Yes') THEN 'Yes'
          ELSE 'No'
        END AS confirmed_resistant,
        '~' AS eol
      FROM core_info ci
        LEFT OUTER JOIN f_creresistant f_cre  ON (ci.ordno = f_cre.ordno)
        LEFT OUTER JOIN f_crparesistant f_crpa  ON (ci.ordno = f_crpa.ordno)
      WHERE 1=1
        ),
    ---END f_ConfirmedResistance---
    ---last_approval---
      --Date of latest approval, be a test of panal approval
      last_approval AS (
        SELECT DISTINCT
          ci.ordno,
          GREATEST(
           COALESCE(to_date(ci.date_approved, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(r_scrn.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(r_out.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(r_CIM.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(r_CIM.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(t_PCR.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           COALESCE(to_date(t_AST.test_completed, 'YYYYMMDD'), to_date('19000101', 'YYYYMMDD')),
           to_date('19000101', 'YYYYMMDD')
          ) AS last_activity,
          '~' AS eol
        FROM core_info ci
          LEFT OUTER JOIN r_scrn ON (ci.ordno = r_scrn.ordno)
          LEFT OUTER JOIN r_out ON (ci.ordno = r_out.ordno)
          LEFT OUTER JOIN r_CIM ON (ci.ordno = r_CIM.ordno)
          LEFT OUTER JOIN t_PCR ON (ci.ordno = t_PCR.ordno)
          LEFT OUTER JOIN t_AST ON (ci.ordno = t_AST.ordno)
        WHERE 1=1
      )
    ---END last_approval---

    ---all_together---
    --Combine all tables to one single result
      SELECT DISTINCT
        ci.birth_date,
        ci.Specimen_collection_date AS date_collected,
        ci.Specimen_received_date AS date_received,
        ci.reporting_month,
        ci.ethnicity,
        --5
        ci.arln_specimen_id AS sample_no,
        ci.first_name,
        ci.last_name,
        ci.middle_initial,
        ci.onset_date,
        --10
        ci.race,
        ci.patient_id AS sl_patient_id,
        ci.submitter_pid AS submitter_pid,
        ci.submitter_facility_id AS submitter_code,
        ci.arln_specimen_id,
        --15
        ci.specimen_desc,
        ci.sex,
        ci.sample_type,
        ci.date_approved,
        ci.panel_name,
        --20
        ci.exposure_date,
        ci.patient_age,
        ci.physician,
        ci.symptoms,
        ci.provider,
        --25
        ci.facility_name,
        ci.provider_address,
        ci.provider_city,
        ci.provider_state,
        ci.provider_zip,
        --30
        ci.provider_phone,
        ci.activity_type,
        ci.submitter_facility_city,
        ci.submitter_facility_name,
        ci.submitter_facility_county,
        --35
        ci.submitter_facility_zipcode,
        r_cim.Phenotypic_test_result,
        'CIM method' AS Phenotypic_method_used,
        f_resist.confirmed_resistant AS Confirmed_carbapenem_resistant,
        'Broth microdilution susceptibility test' AS AST_method_used,
        --40
        'CDC assay' AS PCR_method_used,
         r_scrn.Organism_tested,
         a_IMP.result AS IMP_gene,
         a_KPC.result AS KPC_gene,
         a_mcr.result AS mcr_gene,
        --45
         a_NDM.result AS NDM_gene,
         a_OXA.result AS OXA_48_like_gene,
         a_VIM.result AS VIM_gene,
         a_Other.gene_name AS Other_gene_name,
         a_Other.result AS Other_gene_result,
         --50
         a_Aztreonam.result AS Aztreonam_result,
         a_Aztreonam.MIC AS Aztreonam_AST_MIC,
         a_Aztreonam.zone_diameter AS Aztreonam_AST_zone_diameter,
         a_Cefepime.result AS Cefepime_result,
         a_Cefepime.MIC AS Cefepime_AST_MIC,
         --55
         a_Cefepime.zone_diameter AS Cefepime_AST_zone_diameter,
         a_Ceftazidime.result AS Ceftazidime_result,
         a_Ceftazidime.MIC AS Ceftazidime_AST_MIC,
         a_Ceftazidime.zone_diameter AS Ceftazidime_AST_zone_diameter,
         a_Ceftriaxone.result AS Ceftriaxone_result,
         --60
         a_Ceftriaxone.MIC AS Ceftriaxone_AST_MIC,
         a_Ceftriaxone.zone_diameter AS Ceftriaxone_AST_zone_diameter,
         a_Colistin.result AS Colistin_result,
         a_Colistin.MIC AS Colistin_AST_MIC,
         a_Doripenem.result AS Doripenem_result,
         --65
         a_Doripenem.MIC AS Doripenem_AST_MIC,
         a_Doripenem.zone_diameter AS Doripenem_AST_zone_diameter,
         a_Ertapenem.result AS Ertapenem_result,
         a_Ertapenem.MIC AS Ertapenem_AST_MIC,
         a_Ertapenem.zone_diameter AS Ertapenem_AST_zone_diameter,
         --70
         a_Imipenem.result AS Imipenem_result,
         a_Imipenem.MIC AS Imipenem_AST_MIC,
         a_Imipenem.zone_diameter AS Imipenem_AST_zone_diameter,
         a_Meropenem.result AS Meropenem_result,
         a_Meropenem.MIC AS Meropenem_AST_MIC,
         --75
         a_Meropenem.zone_diameter AS Meropenem_AST_zone_diameter,
         a_O3g.analyte AS O3g_cep_name,
         a_O3g.MIC AS O3g_cep_AST_MIC,
         a_O3g.zone_diameter AS O3g_cep_AST_zone_diameter,
         COALESCE(r_out.is_sendout, 'No') AS Isolate_forwarded_to_RegLab,
         --80
         r_out.Date_forwarded_to_RegLab,
         r_out.RegLab_comment,
         --Completion Dates--
          TRUNC(r_scrn.test_completed) AS carb_resist_completed,
          TRUNC(r_out.test_completed) AS sendout_completed,
          TRUNC(r_cim.test_completed) AS inactivation_completed,
         --85
          TRUNC(t_pcr.test_completed) AS carb_pcr_completed,
          TRUNC(t_ast.test_completed) AS antibiotic_completed,
          --Data not Requested--
         '~~' AS not_requested,
          ci.folderno,
          ci.ordno,
         --90
          COALESCE(f_cre.is_cre, 'N') AS is_cre,
          COALESCE(f_crpa.is_crpa, 'N') AS is_crpa,
          COALESCE(f_creres.cre_resist, 'No') AS resist_cre,
          COALESCE(f_crpares.crpa_resist, 'No') AS resist_crpa,
          a_Pt.MIC AS Pt_AST_MIC,
         --95
          a_Pt.zone_diameter AS Pt_AST_zone_diameter,
          TRUNC(sysdate - la.last_activity) AS days_elapsed,
          '~' AS eol
    FROM core_info ci
     LEFT OUTER JOIN r_scrn ON (ci.ordno = r_scrn.ordno)
     LEFT OUTER JOIN r_out ON (ci.ordno = r_out.ordno)
     LEFT OUTER JOIN f_cre ON (ci.ordno = f_cre.ordno)
     LEFT OUTER JOIN f_crpa ON (ci.ordno = f_crpa.ordno)
     LEFT OUTER JOIN r_CIM  ON (ci.ordno = r_CIM.ordno)
     LEFT OUTER JOIN a_KPC ON (ci.ordno = a_KPC.ordno)
     LEFT OUTER JOIN a_IMP ON (ci.ordno = a_IMP.ordno)
     LEFT OUTER JOIN a_mcr ON (ci.ordno = a_mcr.ordno)
     LEFT OUTER JOIN a_NDM ON (ci.ordno = a_NDM.ordno)
     LEFT OUTER JOIN a_OXA ON (ci.ordno = a_OXA.ordno)
     LEFT OUTER JOIN a_VIM ON (ci.ordno = a_VIM.ordno)
     LEFT OUTER JOIN a_Other ON (ci.ordno = a_Other.ordno)
     LEFT OUTER JOIN a_Aztreonam  ON (ci.ordno = a_Aztreonam.ordno)
     LEFT OUTER JOIN a_Cefepime  ON (ci.ordno = a_Cefepime.ordno)
     LEFT OUTER JOIN a_Ceftazidime  ON (ci.ordno = a_Ceftazidime.ordno)
     LEFT OUTER JOIN a_Colistin  ON (ci.ordno = a_Colistin.ordno)
     LEFT OUTER JOIN a_Doripenem  ON (ci.ordno = a_Doripenem.ordno)
     LEFT OUTER JOIN a_Imipenem  ON (ci.ordno = a_Imipenem.ordno)
     LEFT OUTER JOIN a_Meropenem  ON (ci.ordno = a_Meropenem.ordno)
     LEFT OUTER JOIN a_Ceftriaxone  ON (ci.ordno = a_Ceftriaxone.ordno)
     LEFT OUTER JOIN a_Ertapenem  ON (ci.ordno = a_Ertapenem.ordno)
     LEFT OUTER JOIN a_O3g  ON (ci.ordno = a_O3g.ordno)
     LEFT OUTER JOIN a_Pt  ON (ci.ordno = a_Pt.ordno)
     LEFT OUTER JOIN f_creresistant f_creres  ON (ci.ordno = f_creres.ordno)
     LEFT OUTER JOIN f_crparesistant f_crpares  ON (ci.ordno = f_crpares.ordno)
     LEFT OUTER JOIN f_ConfirmedResistance f_resist  ON (ci.ordno = f_resist.ordno)
     LEFT OUTER JOIN t_PCR ON (ci.ordno = t_PCR.ordno)
     LEFT OUTER JOIN t_AST ON (ci.ordno = t_AST.ordno)
     INNER JOIN last_approval la ON (ci.ordno = la.ordno)
    WHERE 1=1
    ORDER BY
      days_elapsed ASC,
      folderno DESC
    ---END all_together---

/*---------------------------------------------------------------------------*/
;
