

/*-----BarcodeProjectScripts-------------------------------------------------*/
  -----DESCRIPTION-----
    --These scripts were developed to provide Lookup Values for the Sample
    --submission form for the Barcode project.  The following Scripts are
    --included:
      --01. US States
      --02. AZ Counties
      --03. AZ Cities
      --04. AZ Zip Codes
      --06. Clients List
      --07. BodySites
      
      --04. SpecimenTypes list
      --05. SamplesDescriptions list
      --06. Change Barcode Version Status
      --07. Clean LF and CR from field
      --08. Barcode Submittals: Identify samples submitted and what ones were via barcode
      
  ----- -----
  

  -----HISTORY-----
  ----- -----

/*---------------------------------------------------------------------------*/




/*  https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_Arizona
/*---------------------------------------------------------------------------*/


/*---01. US States List------------------------------------------------------*/
  --List All states in USA
  --REF: | Applications | CountryStates | Data Sources | dsGetStates |
/*  
  SELECT DISTINCT
    s.name,
    s.state_code,
    s.origsts,
    s.country_code,
    s.gisaidcode,
    s.hhscode
  FROM states s
  WHERE 1=1
    AND s.country_code = 'USA'
  ORDER BY
    s.name ASC,
    s.state_code ASC;
*/
/*---------------------------------------------------------------------------*/




/*---02. AZ Counties---------------------------------------------------------*/
  --List All Counties in Arizona
  --REF: | Applications | CountryStates | Data Sources | dsGetCounties |
/*  
  SELECT DISTINCT
    c.county,
    c.county_code
  FROM counties c
  WHERE 1=1
    AND c.state_code = 'AZ'
  ORDER BY
    c.county ASC,
    c.county_code ASC;   
*/    
/*---------------------------------------------------------------------------*/




/*---03. AZ Cities-----------------------------------------------------------*/
  --List All Counties in Arizona
  --REF: | Applications | CountryStates | Data Sources | dsGetCities |
/*
  SELECT DISTINCT
    c.city,
    c.city_code
  FROM city c
  WHERE 1=1
    AND c.state_code = 'AZ'
  ORDER BY
    c.city ASC,
    c.city_code ASC;   
*/    

  --We will utilize the Bulk Insert Script "Bulk Import City and ZipCodes"
  -- for this operation

/*---------------------------------------------------------------------------*/




/*---04. AZ Zip Codes--------------------------------------------------------*/
  --List All Counties in Arizona
  --REF: | Applications | CountryStates | Data Sources | dsGetZipCodes |

  --We will utilize the Bulk Insert Script "Bulk Import City and ZipCodes"
  -- for this operation
/*
  SELECT DISTINCT
    zc.state_code,
    c.city,
    zc.zip
  FROM zip_codes zc
    INNER JOIN city c ON (zc.city_code = c.city_code)
  WHERE 1=1
  ORDER BY
    zc.state_code ASC,
    c.city ASC,
    zc.zip ASC;
*/
/*---------------------------------------------------------------------------*/




/*---06. Clients List---------------------------------------------------------*/
  --We want all the clients who have submitted samples within the last 3years
  --We ar checking on the following:
    --1. Duplicate Client Name
    --2. No Contact Phone Number
    --3. Invalid City (For Arizona)
    --4. Invalid County (For Arizona)

    WITH 
      ---BaseInfo---
      BaseInfo AS (
        SELECT DISTINCT
          rc.compname,
          rc.rasclientid,
          rc.organizational_oid AS npi,
          rc.primaryphone,
          rc.adress,
          rc.city,
          rc.state,
          rc.zip,
          rc.county,
          '' AS Issue
        FROM rasclients rc
          INNER JOIN folders f ON (f.rasclientid = rc.rasclientid)
        WHERE 1=1
          --3 YEAR LOOKBACK--
          AND to_date(f.daterecv, 'DD-MON-YY') >= to_date(ADD_MONTHS(sysdate, -36), 'DD-MON-YY')
          --
          AND rc.status = 'Active'
          AND rc.rasclientid NOT IN (
          'APHL', 'ADHS-T',
          'CDC', 'ERA', 'MEDSIS',
          'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
           'CA State Lab-Ca', 'CA State Lab-Fl',
          'CDC NARMS', 'CDC WGS',
          'Regional MLVA', 'Regional WGS', 'CDC Influenza'
          )
        ORDER BY
          rc.compname ASC,
          rc.rasclientid ASC
      ),
      --- ---
      ---Duplicate Client Names---
        DupeNames AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Duplicate Client Name' AS issue
          FROM BaseInfo bi  
            INNER JOIN BaseInfo bi2 ON (bi.compname = bi2.compname)
          WHERE 1=1
            AND bi.rasclientid <> bi2.rasclientid
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---No Phone---
        NoPhone AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'No Contact Phone Number' AS issue
          FROM BaseInfo bi      
          WHERE 1=1
            AND bi.primaryphone IS NULL
         ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad Cities---
        BadCity AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad City' AS issue
          FROM BaseInfo bi 
            LEFT OUTER JOIN city c ON ( 1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND bi.city = c.city)
          WHERE 1=1
            AND bi.state = 'AZ'
            AND c.city IS NULL
            OR bi.city IS NULL
          ORDER BY
            bi.city,
            bi.zip,
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad County---
        BadCounty AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad County' AS issue
          FROM BaseInfo bi
            LEFT OUTER JOIN counties c ON (1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND c.county = bi.county
            )
          WHERE 1=1
            AND bi.state = 'AZ'
            AND bi.county <> 'In-House'
            AND c.county IS NULL
            OR bi.county IS NULL
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---UnionTables---      
        UnionTables AS (
          SELECT DISTINCT * FROM BaseInfo
          UNION SELECT DISTINCT * FROM DupeNames
          UNION SELECT DISTINCT * FROM NoPhone
          UNION SELECT DISTINCT * FROM BadCity
          UNION SELECT DISTINCT * FROM BadCounty
        ),
      --- ---      
      ---Aggrigate List with issues---
        TheAggrigate AS (
          SELECT DISTINCT
            ut.compname,
            ut.rasclientid,
            ut.npi,
            ut.primaryphone,
            ut.adress,
            ut.city,
            ut.state,
            ut.county,
            ut.zip,
            ListAgg(ut.issue, ',' || CHR(13)) WITHIN GROUP (ORDER BY ut.rasclientid) AS issues
          FROM UnionTables ut 
          WHERE 1=1
          GROUP BY 
            ut.rasclientid,
            ut.npi,
            ut.compname,
            ut.state,
            ut.county,
            ut.city,
            ut.zip,
            ut.primaryphone,
            ut.adress
          ORDER BY
            ut.compname ASC,
            ut.rasclientid ASC       
        )
      --- ---
      ---Final Query---
          SELECT DISTINCT
            ta.compname,
            ta.rasclientid,
            ta.npi,
            ta.primaryphone,
            ta.adress,
            ta.city,
            ta.state,
            ta.county,
            ta.zip,            
            ta.issues
          FROM TheAggrigate ta
          WHERE 1=1
          ORDER BY
            ta.compname ASC,
            ta.rasclientid ASC;
      --- ---
 
/*---------------------------------------------------------------------------*/


/*-----ClientInfoWithCount---------------------------------------------------*/

  --Get the same Client inforamtion, but inclued the number of samples
  --completed for each client over the last 365 days.
/*  
    WITH 
      ---BaseInfo---
      BaseInfo AS (
        SELECT DISTINCT
          rc.compname,
          rc.rasclientid,
          rc.primaryphone,
          rc.adress,
          rc.city,
          rc.state,
          rc.zip,
          rc.county,
          '' AS Issue
        FROM rasclients rc
          INNER JOIN folders f ON (f.rasclientid = rc.rasclientid)
        WHERE 1=1
          --3 YEAR LOOKBACK--
          AND to_date(f.daterecv, 'DD-MON-YY') >= to_date(ADD_MONTHS(sysdate, -36), 'DD-MON-YY')
          --
          AND rc.status = 'Active'
          AND rc.rasclientid NOT IN (
          'APHL', 'ADHS-T',
          'CDC', 'ERA', 'MEDSIS',
          'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
           'CA State Lab-Ca', 'CA State Lab-Fl',
          'CDC NARMS', 'CDC WGS',
          'Regional MLVA', 'Regional WGS', 'CDC Influenza'
          )
        ORDER BY
          rc.compname ASC,
          rc.rasclientid ASC
      ),
      --- ---
      ---Duplicate Client Names---
        DupeNames AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Duplicate Client Name' AS issue
          FROM BaseInfo bi  
            INNER JOIN BaseInfo bi2 ON (bi.compname = bi2.compname)
          WHERE 1=1
            AND bi.rasclientid <> bi2.rasclientid
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---No Phone---
        NoPhone AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'No Contact Phone Number' AS issue
          FROM BaseInfo bi      
          WHERE 1=1
            AND bi.primaryphone IS NULL
         ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad Cities---
        BadCity AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad City' AS issue
          FROM BaseInfo bi 
            LEFT OUTER JOIN city c ON ( 1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND bi.city = c.city)
          WHERE 1=1
            AND bi.state = 'AZ'
            AND c.city IS NULL
            OR bi.city IS NULL
          ORDER BY
            bi.city,
            bi.zip,
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad County---
        BadCounty AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad County' AS issue
          FROM BaseInfo bi
            LEFT OUTER JOIN counties c ON (1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND c.county = bi.county
            )
          WHERE 1=1
            AND bi.state = 'AZ'
            AND bi.county <> 'In-House'
            AND c.county IS NULL
            OR bi.county IS NULL
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---UnionTables---      
        UnionTables AS (
          SELECT DISTINCT * FROM BaseInfo
          UNION SELECT DISTINCT * FROM DupeNames
          UNION SELECT DISTINCT * FROM NoPhone
          UNION SELECT DISTINCT * FROM BadCity
          UNION SELECT DISTINCT * FROM BadCounty
        ),
      --- ---      
      ---Aggrigate List with issues---
        TheAggrigate AS (
          SELECT DISTINCT
            ut.compname,
            ut.rasclientid,
            ut.primaryphone,
            ut.adress,
            ut.city,
            ut.state,
            ut.county,
            ut.zip,
            ListAgg(ut.issue, ',' || CHR(13)) WITHIN GROUP (ORDER BY ut.rasclientid) AS issues
          FROM UnionTables ut 
          WHERE 1=1
          GROUP BY 
            ut.rasclientid,
            ut.compname,
            ut.state,
            ut.county,
            ut.city,
            ut.zip,
            ut.primaryphone,
            ut.adress
          ORDER BY
            ut.compname ASC,
            ut.rasclientid ASC       
        ),
      --- ---
      ---Client Sample Count for 1 year---
        SampleYearCount AS (
          SELECT
            COUNT (DISTINCT f.external_id) AS sample_count,
            bi.rasclientid,
            '~' AS eol
          FROM BaseInfo bi
            INNER JOIN folders f ON (bi.rasclientid = f.rasclientid)
          WHERE 1=1
            AND to_date(f.apprdate, 'DD-MON-YY') >= add_months(to_date(sysdate, 'DD-MON-YY'), -12)
          GROUP BY
            bi.rasclientid
          ORDER BY
            sample_count DESC,
            bi.rasclientid DESC
        ),
      --- ---
      ---WithSampleCount---      
        WithSampleCount AS (
           SELECT DISTINCT
            ta.compname,
            ta.rasclientid,
            '' AS NPI,
            yc.sample_count,
            ta.primaryphone,
            ta.adress,
            ta.city,
            ta.state,
            ta.county,
            ta.zip,
            ta.issues
            FROM TheAggrigate ta
              INNER JOIN SampleYearCount yc ON (ta.rasclientid = yc.rasclientid)
          WHERE 1=1
          ORDER BY
            ta.compname ASC,
            ta.rasclientid ASC
        )
      --- ---
      ---Final Query---
          SELECT DISTINCT
            wc.compname,
            wc.rasclientid,
            wc.NPI,
            wc.sample_count,
            wc.primaryphone,
            wc.adress,
            wc.city,
            wc.state,
            wc.county,
            wc.zip,
            wc.issues
          FROM WithSampleCount wc
          WHERE 1=1
          ORDER BY
            wc.sample_count DESC,
            wc.compname ASC,
            wc.rasclientid ASC
      --- ---
*/
/*---------------------------------------------------------------------------*/




/*----07. BodySites (Sample Description)-------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Get the SpecimenType drop-down list for the Clinical accessioning screen
/*  
    SELECT DISTINCT
     bsd.bs_name AS display,
     bsd.bs_name AS value
    FROM base_static_data bsd
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'BASE_STATIC_DATA'
        AND mr.original_origrec = bsd.origrec
        AND mr.field_varchar_01 = 'Clinical')
    WHERE 1=1
      AND bsd.bs_status = 'Active'
    ORDER BY
      bsd.bs_name ASC;
*/
/*---------------------------------------------------------------------------*/






/*----08. SpecimenTypes list-------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Get the SpecimenType drop-down list for the Clinical accessioning screen
  --SELECT * FROM specimen_sources ss
/*
  SELECT DISTINCT
    TRIM(ss.specimen_source) AS specimen_type,
    TRIM(ss.snomedct) AS snomedct,
    '~' AS eol
  FROM  specimen_sources ss
  WHERE 1=1
    AND ss.spectype NOT IN ('LRN_Human-Clinical','LRN_Animal-Clinical','LRN_Environmental', 'LRN_Human-Clinical')
  ORDER BY
    specimen_type ASC;
*/
/*---------------------------------------------------------------------------*/






/*----05. SamplesDescriptions list--------------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Get the Sample Description drop-down list for the clinical Accessioning screen

    
    SELECT DISTINCT
      TRIM(bsd.bs_name) AS sample_description,
      TRIM(bsd.bs_name) AS value
    FROM base_static_data bsd
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.field_varchar_01 = 'Clinical'
        AND mr.tablereference = 'BASE_STATIC_DATA'
        AND mr.original_origrec = bsd.origrec)
    WHERE 1=1        
        AND bsd.bs_type = 'Sample Descriptions'
        AND bsd.bs_status = 'Active'
    ORDER BY
      sample_description ASC

*/
/*---------------------------------------------------------------------------*/






/*-----06. Change Barcode Version Status--------------------------------------*/
  --Review and update the identified Barcode Version from Approve to Draft.
  --this will allow you to make changes to the barcode.  Of course you will need
  --to change the status of the barcode back to Approve before being able to 
  --use the barcode again.


  ---Review Barcode Versions---
  /*
    SELECT DISTINCT
      bv.*
    FROM barcode_versions bv
    WHERE 1=1
    ORDER BY bv.origrec DESC;
*/    
  --- ---

  ---Update Version Status---  
/*  
    UPDATE barcode_versions bv
    SET bv.status = '&Status'  --Draft, Approve, Retire
    WHERE 1=1
      AND bv.origrec = '&Origrec';
*/      
  --- ---  
/*---------------------------------------------------------------------------*/


/*-----07. Clean LF and CR from field----------------------------------------*/
  --Remove any LF/CR from the Phone number field.


  ---Review Barcode Versions---
  /*
    UPDATE metadata_repository mr
    SET
      mr.field_varchar_27 = 
      regexp_replace(mr.field_varchar_27, '([' || chr(10) || chr(13) || '])+','')
    WHERE 1=1
      AND mr.tablereference = 'CENTRALRECEIVING'
      AND mr.field_varchar_27 LIKE '%' || chr(10)
*/      
  --- ---

  ---Update Version Status---  
/*  
    UPDATE barcode_versions bv
    SET bv.status = '&Status'  --Draft, Approve, Retire
    WHERE 1=1
      AND bv.origrec = '&Origrec';
*/      
  --- ---  
/*---------------------------------------------------------------------------*/


/*-----Barcode Submittals----------------------------------------------------*/
  --Identify clients submitting samples via Barcode form
/*
  SELECT DISTINCT
    to_date(cr.date_received, 'DD-MON-YY') AS date_received,
    cr.external_id,
    CASE COALESCE(length(bl.scanned_by), 0)
      WHEN 0 THEN ''
      ELSE 'X'
    END AS barcode,
    (rc.compname || '(' || cr.rasclientid || ')') AS client,
    f.dept,
    f.testgroupname AS panel,
    bl.scanned_by,
--    COALESCE(bl.scanned_by AS barcode_scanned),
    '~' AS eol
  FROM centralreceiving cr
    INNER JOIN folders f ON (cr.external_id = f.external_id)
    LEFT OUTER JOIN barcode_log bl ON (cr.external_id = bl.external_id)
    INNER JOIN rasclients rc ON (f.rasclientid = rc.rasclientid)
  WHERE 1=1
    AND f.prodgroup IN ('Human')
    AND f.dept IN ('PHX-SER', 'PHX-VIR', 'PHX-TB', 'PHX-BAC')
    AND to_date(cr.date_received, 'DD-MON-YY') BETWEEN to_date('&BeginDate', 'DD-MON-YY') AND to_date('&EndDate', 'DD-MON-YY')
  ORDER BY
    date_received DESC,
    cr.external_id DESC
*/

/*---------------------------------------------------------------------------*/

