

/*-----BulkImport CityAndZipCodes--------------------------------------------*/
  --Use this script to import zip codes into STARLiMS
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/

/*-----01. Create Temp Table [ADHS_Temp]-------------------------------------*/

  -----Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----Create [adhs_temp] table-----
    CREATE TABLE adhs_temp(
      zip          VARCHAR2(15 CHAR) not null,
      city         VARCHAR2(50 CHAR) not null,
      county       VARCHAR2(50 CHAR) not null,
      country_code VARCHAR2(3 CHAR),
      state_code   VARCHAR2(3 CHAR),
      city_code    NUMBER(22)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----

/*---------------------------------------------------------------------------*/

/*-----02. Import [adhs_temp] table contents---------------------------------*/

  -----DESCRIPTION-----
   --Make a csv file with ZipCodes to be imported into the temp table.
   --import into the [adhs_temp] table.
   --Import is acheived utilizing the "Text Importer" tool located in the "Tools"
   --menu.
   --Optionally you can perform a series of instert stattments to populate the
   --table.  I have provided an example insert statement below.
  ----- -----

  -----Usefull Queries-----
--    SELECT * FROM adhs_temp;
--    SELECT * FROM zip_codes zc;
--    SELECT * FROM states s;
--    SELECT * FROM counties c;
--    SELECT * FROM city c ORDER BY c.city;
  ----- -----

  -----Sample Insert Statement-----  
    INSERT INTO adhs_temp(zip, city, county, country_code, state_code, city_code)
    VALUES ('85001', 'Phoenix', 'Maricopa', 'AZ', 'USA', '276')
  ----- -----

/*---------------------------------------------------------------------------*/


/*-----Update Cities List----------------------------------------------------*/
  --We will use this list to update the cities list in STARLiMS if a city is 
  --not already in SL, this will import the new city from the Temp Table

    MERGE INTO city t1
    USING (
        SELECT DISTINCT
          'USA' AS country_code,
          'AZ' AS state_code,
          tmp.city
        FROM adhs_temp tmp
        WHERE 1=1
          AND tmp.city IS NOT NULL
        ORDER BY tmp.city ASC) t2
    ON (UPPER(t1.city) = UPPER(t2.city))
    WHEN NOT MATCHED THEN
      INSERT (t1.country_code, t1.state_code, t1.city, t1.city_code)
      VALUES (t2.country_code, t2.state_code, t2.city, "CITY_seq".nextVal)
/*---------------------------------------------------------------------------*/



/*-----03. Import Zip Codes--------------------------------------------------*/

  -----DESCRIPTION-----
    --We will use the Merge to add new ZIP codes into the zip_codes table 
    --if the zipcode is not already in the table.
  ----- -----

  -----Usefull Queries-----
    --SELECT * FROM zip_codes zc        
  ----- -----
  -----Add ZipCodes in the Zip table -----  
    MERGE INTO zip_codes t1
    USING (
        SELECT DISTINCT
          'N' AS origsts,
          c.country_code,
          c.state_code,
          c.city,
          c.city_code,
          tmp.zip,
          '~' AS eol
        FROM adhs_temp tmp
          INNER JOIN city c ON (tmp.city = c.city)
        WHERE 1=1
        ORDER BY
          c.country_code ASC,
          c.state_code ASC,
          c.city ASC,
          tmp.zip ASC
    ) t2
    ON (t1.zip = t2.zip)
    WHEN NOT MATCHED THEN
      INSERT (t1.origsts, t1.country_code, t1.state_code, t1.city_code, t1.zip)
      VALUES (t2.origsts, t2.country_code, t2.state_code, t2.city_code, t2.zip)
  ----- -----

/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/*-----State Names Caps Fix--------------------------------------------------*/
  --Imported states are in all CAPS want to fix this so they look better.
/*
  SELECT s.* FROM states s

  UPDATE states s SET s.name = INITCAP(s.name)
  UPDATE states s SET s.name = REPLACE(s.name, ' Of', ' of') WHERE s.name LIKE ('% Of%')
  UPDATE states s SET s.name = REPLACE(s.name, ' And', ' and') WHERE s.name LIKE ('% And%')
*/  
/*---------------------------------------------------------------------------*/
