/*---------------------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
  /*----- -----*/

  /*-----HISTORY-----*/
    --2020.08.15 JTY: Updated to validate ZIP codes against zip codes as
    --                as defined in [Regions, Countries and Cities] application
    --2020.07.01 JTY: Created Script
  /*----- -----*/
  
/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
/*---Client List Review------------------------------------------------------*/
  --We want all the clients who have submitted samples within the last 3years
  --We ar checking on the following:
    --1. Duplicate Client Name
    --2. No Contact Phone Number
    --3. Invalid City (For Arizona)
    --4. Invalid County (For Arizona)
    WITH 
      ---BaseInfo---
      BaseInfo AS (
        SELECT DISTINCT
          rc.compname,
          rc.rasclientid,
          rc.organizational_oid AS NPI,
          rc.primaryphone,
          rc.adress,
          rc.city,
          rc.state,
          rc.zip,
          rc.county,
          '' AS Issue
        FROM rasclients rc
          INNER JOIN folders f ON (f.rasclientid = rc.rasclientid)
        WHERE 1=1
          --3 YEAR LOOKBACK--
          AND to_date(f.daterecv, 'DD-MON-YY') >= to_date(ADD_MONTHS(sysdate, -36), 'DD-MON-YY')
          --
          AND rc.status = 'Active'
          AND rc.rasclientid NOT IN (
          'APHL', 'ADHS-T',
          'CDC', 'ERA', 'MEDSIS',
          'MEDSIS-TEST', 'NG', 'PHLIP-FLU',
           'CA State Lab-Ca', 'CA State Lab-Fl',
          'CDC NARMS', 'CDC WGS',
          'Regional MLVA', 'Regional WGS', 'CDC Influenza'
          )
        ORDER BY
          rc.compname ASC,
          rc.rasclientid ASC
      ),
      --- ---
      ---Duplicate Client Names---
        DupeNames AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Duplicate Client Name' AS issue
          FROM BaseInfo bi  
            INNER JOIN BaseInfo bi2 ON (bi.compname = bi2.compname)
          WHERE 1=1
            AND bi.rasclientid <> bi2.rasclientid
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---No Phone---
        NoPhone AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'No Contact Phone Number' AS issue
          FROM BaseInfo bi      
          WHERE 1=1
            AND bi.primaryphone IS NULL
         ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad Cities---
        BadCity AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad City' AS issue
          FROM BaseInfo bi 
            LEFT OUTER JOIN city c ON ( 1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND bi.city = c.city)
          WHERE 1=1
            AND bi.state = 'AZ'
            AND c.city IS NULL
            OR bi.city IS NULL
          ORDER BY
            bi.city,
            bi.zip,
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad County---
        BadCounty AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad County' AS issue
          FROM BaseInfo bi
            LEFT OUTER JOIN counties c ON (1=1
              AND c.country_code = 'USA'
              AND bi.state = c.state_code
              AND c.county = bi.county
            )
          WHERE 1=1
            AND bi.state = 'AZ'
            AND bi.county <> 'In-House'
            AND c.county IS NULL
            OR bi.county IS NULL
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad ZipCode Arizona Only---
        BadZip AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad Zip' AS issue
          FROM BaseInfo bi
            INNER JOIN city c ON (1=1
              AND c.country_code = 'USA'
              AND c.state_code = bi.state
              AND bi.city = c.city)        
            LEFT OUTER JOIN zip_codes zc ON (1=1
              AND zc.country_code = 'USA'
              AND zc.state_code = bi.state
              AND zc.city_code = c.city_code
              AND zc.zip = bi.zip
            )            
          WHERE 1=1
            AND bi.state = 'AZ'
            AND bi.county <> 'In-House'
            AND (
              zc.zip IS NULL
              OR bi.zip IS NULL
              OR LENGTH(bi.zip) > 5
              )
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---Bad ZipCode Out of State---
        BadZip2 AS (
          SELECT DISTINCT
            bi.compname,
            bi.rasclientid,
            bi.npi,
            bi.primaryphone,
            bi.adress,
            bi.city,
            bi.state,
            bi.zip,
            bi.county,
            'Bad Zip' AS issue
          FROM BaseInfo bi
          WHERE 1=1
            AND bi.state <> 'AZ'
            AND (
              NOT REGEXP_LIKE(bi.zip, '^[[:digit:]]+$')
              OR LENGTH(bi.zip) > 5
              OR bi.zip IS NULL
            )
          ORDER BY
            bi.compname ASC,
            bi.rasclientid ASC
        ),
      --- ---
      ---UnionTables---      
        UnionTables AS (
          SELECT DISTINCT * FROM BaseInfo
          UNION SELECT DISTINCT * FROM DupeNames
          UNION SELECT DISTINCT * FROM NoPhone
          UNION SELECT DISTINCT * FROM BadCity
          UNION SELECT DISTINCT * FROM BadCounty
          UNION SELECT DISTINCT * FROM BadZip
          UNION SELECT DISTINCT * FROM BadZip2
        ),
      --- ---      
      ---Aggrigate List with issues---
        TheAggrigate AS (
          SELECT DISTINCT
            ut.compname,
            ut.rasclientid,
            ut.npi,
            ut.primaryphone,
            ut.adress,
            ut.city,
            ut.state,
            ut.county,
            ut.zip,
            ListAgg(ut.issue, ',' || CHR(13)) WITHIN GROUP (ORDER BY ut.rasclientid) AS issues
          FROM UnionTables ut 
          WHERE 1=1
          GROUP BY 
            ut.rasclientid,
            ut.npi,            
            ut.compname,
            ut.state,
            ut.county,
            ut.city,
            ut.zip,
            ut.primaryphone,
            ut.adress
          ORDER BY
            ut.compname ASC,
            ut.rasclientid ASC       
        )
      --- ---
      ---Final Query---
          SELECT DISTINCT
            ta.compname,
            ta.rasclientid,
            ta.npi,
            ta.primaryphone,
            ta.adress,
            ta.city,
            ta.state,
            ta.county,
            ta.zip,            
            ta.issues
          FROM TheAggrigate ta
          WHERE 1=1
          ORDER BY
            ta.compname ASC,
            ta.rasclientid ASC;
      --- ---
/*---------------------------------------------------------------------------*/
