/*-----BulkAdd_Add LRN-B Specimen Sources------------------------------------*/
/*---------------------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --These set of queries will allow you to add Specimen Sources for the LRN-B
    --program.
      --01. Create temp table [adhs_temp]
      --02. Import [adhs_temp] table contents from csv table using "Text Importer" tool.
      --03. Identify enteries in system that do not match offical list.
      --04. Merge/Update remaining enteries with Temp Table values.
      
  /*----- -----*/

  /*----- -----*/
  /*----- -----*/

  /*-----HISTORY-----*/
    --2020.08.19 JTY: Created Script
  /*----- -----*/
/*---------------------------------------------------------------------------*/





/*-----01. Create Temp Table [ADHS_Temp]-------------------------------------*/

  -----Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
--      DROP TABLE adhs_temp;
  ----- -----

  -----Create [adhs_temp] table-----
/*  
    CREATE TABLE adhs_temp(
      spectype              VARCHAR2(150 CHAR) not null,
      concept_code          VARCHAR2(20 CHAR),
      concept_name          VARCHAR2(150 CHAR),
      hl7_spec_source_code  VARCHAR2(10 CHAR),
      specimen_source       VARCHAR2(100 CHAR) not null
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
*/      
  ----- -----

/*---------------------------------------------------------------------------*/



/*-----02. Import [adhs_temp] table contents---------------------------------*/

  -----DESCRIPTION-----
   --Make a csv file with users and user information that will be used to
   --import into the [adhs_temp] table.
   --Import is acheived utilizing the "Text Importer" tool located in the "Tools"
   --menu.
   --Optionally you can perform a series of instert stattments to populate the
   --table.  I have provided an example insert statement below.
  ----- -----

  -----Usefull Queries-----
    --SELECT * FROM adhs_temp;
  ----- -----
  -----Modify spectype field to match STARLiMS-----
/*
    SELECT * FROM adhs_temp;
    UPDATE adhs_temp tmp SET tmp.spectype = 'LRN_' || tmp.spectype;
    UPDATE adhs_temp tmp SET tmp.spectype = REGEXP_REPLACE( tmp.spectype, '\s');
    SELECT * FROM adhs_temp;
*/
  ----- -----

/*---------------------------------------------------------------------------*/


/*---03. Identify enteries in system that do not match offical list----------*/
  --Compare list imported into Temp_ADHS to the current Specimen Sources list
  --and identify ones in the Specieman Sources that are not offical values for
  --LRN-B.
/*  
    SELECT DISTINCT
      ss.spectype AS ss_spectype,
      ss.concept_code AS ss_concept_code,
      ss.concept_name AS ss__concept_name,
      '~' AS sp1,  
      tmp.spectype,
      tmp.concept_name,
      tmp.concept_code,
      '~' AS eol
    FROM specimen_sources ss
      LEFT OUTER JOIN adhs_temp tmp ON ( 1=1
        AND tmp.spectype = ss.spectype
        AND tmp.concept_code = ss.concept_code)
    WHERE 1=1
      AND ss.spectype LIKE ('LRN_%')
      AND tmp.concept_code IS NULL
    ORDER BY
      tmp.concept_name ASC,
      ss.concept_name ASC
*/      
/*---------------------------------------------------------------------------*/





/*-----04. Merge/Update remaining enteries with Temp Table values------------*/
/*
  MERGE INTO specimen_sources t1
  USING (  
    SELECT DISTINCT
      tmp.spectype,
      tmp.concept_name,
      tmp.concept_code,
      tmp.hl7_spec_source_code,
      tmp.specimen_source,
      '~' AS eol
    FROM adhs_temp tmp
    WHERE 1=1
    ORDER BY
      tmp.spectype ASC,
      tmp.concept_name ASC
  ) t2
  ON (1=1
    AND t1.spectype = t2.spectype 
    AND t1.concept_code = t2.concept_code
    AND t1.specimen_source = t2.specimen_source)
  WHEN MATCHED THEN
    UPDATE SET
      t1.concept_name = t2.concept_name,
      t1.hl7_spec_source_code = t2.hl7_spec_source_code;
*/      
/*---------------------------------------------------------------------------*/

















/*-----03. Create Users -----------------------------------------------------*/

  -----DESCRIPTION-----
    --We will use the Merge Statement to import the new users into the [users]
    --table by merging it with the [adhs_temp] table that contains the critical
    --information needed to create the new users.
  ----- -----

  -----Usefull Queries-----
    --SELECT * FROM adhs_temp;
    --SELECT * FROM users u ORDER BY u.usrnam ASC;
    --SELECT DISTINCT
    --  au.usrnam,
    --  u.usrnam,
    --  '~' AS eol
    -- FROM adhs_temp au
    -- LEFT OUTER JOIN users u  ON (au.usrnam = u.usrnam)
    -- WHERE 1=1
  ----- -----

  -----Add Users in the -----  
    MERGE INTO users t1
    USING (
        SELECT DISTINCT
          --Traceability--
          'YODERJ' AS createby,
          CURRENT_DATE AS createdate,
        -- --      
        --Core Info--
          UPPER(tmp.usrnam) AS usrnam,
          tmp.fullname AS fullname,
          tmp.ROLE AS jobdescription,
          tmp.email AS email,
          '602-534-8751' AS userphone,
          '' AS fax,
        -- --
        --Application Access and settings--
          '3' AS authority, 
          tmp.dept AS deptlist, 
          'Y' AS poweruser,
          'N' AS designer,
          ''  AS designerrole,
          'N' AS methoddeveloper,
          'Y' AS showerrordetails,
          to_date('01-JAN-2100 01:00: A.M.', 'DD-MON-YYYY hh:mi A.M.') AS pwexpd,
          'E0812E4D329F2A921D752AC564B3AEF6E0110D52' AS passwrd,
          'Active' AS status,
          'I' AS ustatus,
        -- --
        --Login--
          '2' AS simultaneousloginsallowed,
          'AutoIdleExit' AS iddleaction,
          '1200' AS iddletime,
          'Exit' AS idlespec,
          'GLOBALSECURITYACTION' AS securityaction,
          '' AS pin,
          '10' AS gracelog,
          ('hs\' || tmp.usrnam) AS ldap_alias,
          'AWSDC1' AS ldap_server,
          '636' AS ldap_port,
        -- --
        --Other Stuff that will probably never change--
          'ENG' AS langid, 
          'A' AS origsts,
          'N' AS rasmanager,
          '' AS last_login_attempt_date,
          'N' AS grabber,
          '' AS reg_request_guid
        -- --
        FROM adhs_temp tmp
        ) t2
    ON (t1.usrnam = UPPER(t2.usrnam))
    WHEN NOT MATCHED THEN
      INSERT(
        --Traceability--
        t1.createby, t1.createdate,
        -- --      
        --Core Info--
        t1.usrnam, t1.fullname, t1.email,
        t1.userphone, t1.fax,
        -- --        
        --Application Access and settings--
        t1.authority, t1.jobdescription, t1.deptlist, 
        t1.poweruser, t1.designer, t1.designerrole, 
        t1.methoddeveloper, t1.showerrordetails,
        t1.pwexpd, t1.passwrd,
        t1.status, t1.ustatus,
        -- --
        --Login--
        t1.simultaneousloginsallowed,
        t1.iddleaction, t1.iddletime, t1.idlespec,
        t1.securityaction,  t1.pin,  t1.gracelog,
        t1.ldap_alias, t1.ldap_server, t1.ldap_port,
        -- --
        --Other Stuff that will probably never change--
        t1.langid, t1.origsts, t1.rasmanager,  
        t1.last_login_attempt_date, t1.grabber,
        t1.reg_request_guid
        -- --
      )
      VALUES(
        --Traceability--
        t2.createby, t2.createdate,
        -- --      
        --Core Info--
        t2.usrnam, t2.fullname, t2.email,
        t2.userphone, t2.fax,
        -- --        
        --Application Access and settings--
        t2.authority, t2.jobdescription, t2.deptlist, 
        t2.poweruser, t2.designer, t2.designerrole, 
        t2.methoddeveloper, t2.showerrordetails,
        t2.pwexpd, t2.passwrd,
        t2.status, t2.ustatus,
        -- --
        --Login--
        t2.simultaneousloginsallowed,
        t2.iddleaction, t2.iddletime, t2.idlespec,
        t2.securityaction,  t2.pin,  t2.gracelog,
        t2.ldap_alias, t2.ldap_server, t2.ldap_port,
        -- --
        --Other Stuff that will probably never change--
        t2.langid, t2.origsts, t2.rasmanager,  
        t2.last_login_attempt_date, t2.grabber,
        t2.reg_request_guid
        -- --
      )
  ----- -----

/*---------------------------------------------------------------------------*/



/*-----04. Assign Roles------------------------------------------------------*/


  -----DESCRIPTION-----
   --Here we assign role(s) to the new users.
  ----- -----

  -----Usefull Queries-----
    --SELECT * FROM adhs_temp;
    --SELECT  * FROM userroles ur WHERE ur.usrnam IN ('CHAPMAD', 'GOBESKB', 'KNAPPKE', 'YODERJ');
    --SELECT * FROM roles r;
  ----- -----

  -----Add Roles to the users-----  
    MERGE INTO userroles t1
    USING (
          SELECT DISTINCT
            UPPER(tmp.usrnam) AS usrnam,
            r.treeauth,
            'Y' AS password_policy,
            'A' AS origsts,
            '~' AS eol
          FROM adhs_temp tmp
            INNER JOIN roles r ON (tmp.role = r.role)
        ) t2
    ON (t1.usrnam = t2.usrnam)
    WHEN NOT MATCHED THEN
      INSERT(
          t1.usrnam,
          t1.treeauth,
          t1.password_policy,
          t1.origsts
          )
      VALUES(
          t2.usrnam,
          t2.treeauth,
          t2.password_policy,
          t2.origsts
          );
  ----- -----

/*---------------------------------------------------------------------------*/




/*-----05. Inventory Access--------------------------------------------------*/


  -----DESCRIPTION-----
   --Here we assign give users access to their department Inventory.
  ----- -----

  -----Usefull Queries-----
    --SELECT * FROM adhs_temp;
    --SELECT * FROM servganalyst sa WHERE sa.usrnam IN ('CHAPMAD', 'GOBESKB', 'KNAPPKE');
    --SELECT * FROM benchlocations bl WHERE bl.usrnam IN ('CHAPMAD', 'GOBESKB', 'KNAPPKE');
    --SELECT * FROM locations loc WHERE loc.parent_location_id IS NULL AND loc.storageflag = 'Y' ORDER BY DEPT ASC
  ----- -----


  -----Add users to Department-----  
    MERGE INTO servganalyst t1
    USING (
          SELECT DISTINCT
            UPPER(tmp.usrnam) AS usrnam,
            tmp.dept AS dept,
            '' AS leader,
            'N' AS origsts,
            srg.servgrp,
            '~' AS eol
          FROM adhs_temp tmp
            INNER JOIN servgrp srg ON (tmp.dept = srg.dept)
        ) t2
    ON (t1.usrnam = t2.usrnam AND t1.dept = t2.dept)
    WHEN NOT MATCHED THEN
      INSERT(
          t1.usrnam,
          t1.dept,
          t1.leader,
          t1.origsts,
          t1.servgrp
          )
      VALUES(
          t2.usrnam,
          t2.dept,
          t2.leader,
          t2.origsts,
          t2.servgrp
          );
  ----- -----
  
  -----Give Users Access to Inventory-----  
    MERGE INTO benchlocations t1
    USING (
          SELECT DISTINCT
            UPPER(tmp.usrnam) AS usrnam,
            tmp.dept AS dept,
            'Y' AS modifyflag,
            loc.locationcode,
            'N' AS origsts,
            '~' AS eol
          FROM adhs_temp tmp
            INNER JOIN locations loc ON (1=1
            AND tmp.dept = loc.dept
            AND loc.parent_location_id  IS NULL
            AND loc.storageflag = 'Y')
        ) t2
    ON (t1.usrnam = t2.usrnam AND t1.locationcode = t2.locationcode)
    WHEN NOT MATCHED THEN
      INSERT(
          t1.usrnam,
          t1.locationcode,
          t1.modifyflag,
          t1.origsts
          )
      VALUES(
          t2.usrnam,
          t2.locationcode,
          t2.modifyflag,
          t2.origsts
          );
  ----- -----
 
/*---------------------------------------------------------------------------*/

