/*---------------------------------------------------------------------------*/
/*-----BulkImport_PHVS Value Sets--------------------------------------------*/

  -----DESCRIPTION-----
    --These sets of scripts can be to syn/update the PHVS Values Set table
  ----- -----
  
  -----HISTORY-----
    --2020-10-01 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Import Data--------------------------------------------------*/
  -----DESCRIPTION-----
    --Perform Import following the steps outlined below
  ----- -----
  
    -----Tables of interest-----
/*
      SELECT * FROM phvs_value_sets vs;
      SELECT * FROM phvs_value_sets_details vsd;
*/      
    ----- -----

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  /*
    SELECT
      vs.value_set_code,
      vs.value_set_name,
      '~' AS sp1,
      vsd.display_name,
      vsd.concept_code,
      vsd.concept_name,
      vsd.code_system_code,
      vsd.code_system_oid,
      vsd.code_system_version,
      vsd.hl7table,
      vsd.comments,     
      vsd.origsts AS vsd_origsts,
      vsd.origrec AS vsd_origrec,
      vs.origsts AS vs_origsts,
      vs.origrec AS vs_origrec,
      '~' AS eol
    FROM phvs_value_sets vs
      INNER JOIN  phvs_value_sets_details vsd ON (1=1
        AND vs.value_set_code = vsd.value_set_code)
    WHERE 1=1
      AND vs.value_set_name IN (&ValueSetName)  --'Sample Type LRN-B', 'Specimen Category LRN-B', 'Specimen Condition'
    ORDER BY
      vs.value_set_name ASC,
      vs.value_set_code ASC,
      vsd.display_name ASC,
      vsd.code_system_version ASC;
*/      
  ----- -----

  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
--      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
/*    
    CREATE TABLE adhs_temp(    
      value_set_code      VARCHAR2(100 CHAR),
      value_set_name      VARCHAR2(254 CHAR),
      sp1                 CHAR(1 CHAR),
      display_name        VARCHAR2(254 CHAR),
      concept_code        VARCHAR2(50 CHAR),
      concept_name        VARCHAR2(254 CHAR),
      code_system_code    VARCHAR2(100 CHAR),
      code_system_oid     VARCHAR2(50 CHAR),
      code_system_version VARCHAR2(100 CHAR),
      hl7table            VARCHAR2(50 CHAR),
      comments            VARCHAR2(254 CHAR),     
      vsd_origsts         CHAR(1 CHAR) default 'N',
      vsd_origrec         NUMBER(22),
      vs_origsts          CHAR(1 CHAR) default 'N',
      vs_origrec          NUMBER(22),
      eol                 CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
*/
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate phvs_value_sets table-----
    --Here we are going to update the table.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
/*    
    MERGE INTO phvs_value_sets t1
    USING (
      SELECT DISTINCT
        value_set_code,
        value_set_name,
        vs_origsts,
        vs_origrec,
        '~' AS eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.value_set_code ASC,
        temp.value_set_name ASC
    ) t2
    ON (1=1
        AND t1.value_set_code = t2.value_set_code
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.value_set_name = t2.value_set_name,
        t1.origsts = t2.vs_origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.value_set_code,
        t1.value_set_name,
        t1.origsts
      )
      VALUES (
        t2.value_set_code,
        t2.value_set_name,
        t2.vs_origsts
      )
*/
  ----- -----
  -----09. Merge/Upate phvs_value_sets table-----
    --Here we are going to update the table.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
/*
    MERGE INTO phvs_value_sets_details t1
    USING (
      SELECT DISTINCT
      temp.value_set_code,
      temp.display_name,
      temp.concept_code,
      temp.concept_name,
      temp.code_system_code,
      temp.code_system_oid,
      temp.code_system_version,
      temp.hl7table,
      temp.comments,
      temp.vs_origsts,
      temp.eol
      FROM  adhs_temp temp
      WHERE 1=1
      ORDER BY
        temp.value_set_code ASC,
        temp.concept_code ASC,
        temp.display_name ASC
    ) t2
    ON (1=1
        AND t1.value_set_code = t2.value_set_code
        AND t1.concept_code = t2.concept_code
        AND t1.code_system_code = t2.code_system_code
        AND t1.code_system_oid = t2.code_system_oid
        AND t1.code_system_version = t2.code_system_version
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.display_name = t2.display_name,
        t1.concept_name = t2.concept_name,
        t1.hl7table = t2.hl7table,
        t1.comments = t2.comments,
        t1.origsts = t2.vs_origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.value_set_code,
        t1.display_name,
        t1.concept_code,
        t1.concept_name,
        t1.code_system_code,
        t1.code_system_oid,
        t1.code_system_version,
        t1.hl7table,
        t1.comments,
        t1.origsts
      )
      VALUES (
        t2.value_set_code,
        t2.display_name,
        t2.concept_code,
        t2.concept_name,
        t2.code_system_code,
        t2.code_system_oid,
        t2.code_system_version,
        t2.hl7table,
        t2.comments,
        t2.vs_origsts
      )
*/      
  ----- -----
  
  -----10. Done-----
    --Done with Syncing the FieldNames
  ----- -----

/*---------------------------------------------------------------------------*/
