/*-----BulkImport_Rabies Bulk PHVS Tables------------------------------------*/
  --Use scripts here to import/update the various PHVS Tables in STARLiMS.
  --for the Rabies Prgram.
  
 
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/*-----01. Extract PHVS_Rabies_xxxx tables from source environment-----------*/
  -- Use this script to export the table from the source environment if
  -- you are pulling info from another environment.  Otherwise create a CSV
  -- file with this information.

      SELECT DISTINCT
        pvs.value_set_name,
        pvd.value_set_code,
        pvd.display_name,
        pvd.concept_code,
        pvd.concept_name,
        pvd.hl7table,
        pvd.code_system_oid,
        pvd.code_system_version,
        pvd.code_system_code,
        pvd.comments,
        pvd.origsts
      FROM phvs_value_sets pvs
        INNER JOIN phvs_value_sets_details pvd ON (pvs.value_set_code = pvd.value_set_code)
      WHERE 1=1
        AND pvs.value_set_code IN (
          'PHVS_Rabies_AgeCategory',
          'PHVS_Rabies_AnimalGender',
          'PHVS_Rabies_AnimalSpecies',
          'PHVS_Rabies_DeathType',
          'PHVS_Rabies_ExposedSpecies',
          'PHVS_Rabies_ExposureType',
          'PHVS_Rabies_Ownership',
          'PHVS_Rabies_SpecimemRejection',
          'PHVS_Rabies_SpecimenSource',
          'PHVS_Rabies_Surveillance',
          'PHVS_Rabies_VaccinatedStatus',
          'PHVS_Rabies_YNU'
        )
      ORDER BY 
        pvd.value_set_code ASC,
        pvd.display_name ASC,
        pvd.concept_code ASC

/*---------------------------------------------------------------------------*/

/*-----02. Create Temp Table [ADHS_Temp]-------------------------------------*/
/*
  -----Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
      DROP TABLE adhs_temp;
  ----- -----

  -----Create [adhs_temp] table-----
    CREATE TABLE adhs_temp(
      value_set_name      VARCHAR2(254 CHAR),
      value_set_code      VARCHAR2(100 CHAR),
      display_name        VARCHAR2(254 CHAR),
      concept_code        VARCHAR2(50 CHAR),
      concept_name        VARCHAR2(254 CHAR),
      hl7table            VARCHAR2(50 CHAR),
      code_system_oid     VARCHAR2(50 CHAR),
      code_system_version VARCHAR2(100 CHAR),
      code_system_code    VARCHAR2(100 CHAR),            
      comments            VARCHAR2(254 CHAR),
      origsts             CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
  ----- -----
*/
/*---------------------------------------------------------------------------*/

--  ====>IMPORT PHVS Dataset file to ADHS_TEMP TABLE  <====
--delete * from adhs_temp tmp where concept_code is null
--SELECT * FROM adhs_temp
--UPDATE adhs_temp tmp SET tmp.origsts = 'N', tmp.value_set_code = '&PHVS_TableName', tmp.value_set_name = '&PHVS_TableName';
--UPDATE phvs_value_sets_details tmp SET tmp.hl7table = 'PLT535' WHERE 1=1 AND tmp.value_set_code = 'PHVS_Rabies_ExposedSpecies'
--DELETE FROM phvs_value_sets_details vsd WHERE vsd.value_set_code = 'PHVS_Rabies_VaccinatedStatus'
/*-----03. Update and phvs_value_sets table --------------------------------*/
  --select * from phvs_value_sets
/*
    MERGE INTO phvs_value_sets t1
    USING (
      SELECT DISTINCT
        tmp.value_set_name,
        tmp.value_set_code,
        tmp.origsts
      FROM adhs_temp tmp
      WHERE 1=1
      ORDER BY 
        tmp.value_set_name ASC,
        tmp.value_set_code ASC
    ) t2
    ON (1=1
      AND t1.value_set_code = t2.value_set_code
    )
    WHEN MATCHED THEN
      UPDATE SET
      t1.value_set_name = t2.value_set_name,
      t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
               t1.value_set_code,
               t1.value_set_name,
               t1.origsts
      )
      VALUES (
               t2.value_set_code,
               t2.value_set_name,
               t2.origsts
      );
*/
/*---------------------------------------------------------------------------*/


/*-----04. Update and phvs_value_sets_details table --------------------------------*/
  --select * from phvs_value_sets_details
/*
    MERGE INTO phvs_value_sets_details t1
    USING (
      SELECT DISTINCT
        tmp.value_set_name,
        tmp.value_set_code,
        tmp.display_name,
        tmp.concept_code,
        tmp.concept_name,
        tmp.hl7table,
        tmp.code_system_oid,
        tmp.code_system_version,
        tmp.code_system_code,
        tmp.comments,
        tmp.origsts
      FROM adhs_temp tmp
      WHERE 1=1
      ORDER BY 
        tmp.value_set_code ASC,
        tmp.display_name ASC,
        tmp.concept_code ASC
    ) t2
    ON (1=1
      AND t1.value_set_code = t2.value_set_code
      AND t1.concept_code = t2.concept_code
    )
    WHEN MATCHED THEN
      UPDATE SET
      t1.display_name = t2.display_name,
      t1.concept_name = t2.concept_name,
      t1.hl7table = t2.hl7table,
      t1.code_system_oid = t2.code_system_oid,
      t1.code_system_version = t2.code_system_version,
      t1.code_system_code = t2.code_system_code,
      t1.comments = t2.comments,
      t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
              t1.value_set_code,
              t1.display_name,
              t1.concept_code,
              t1.concept_name,
              t1.hl7table,
              t1.code_system_oid,
              t1.code_system_version,
              t1.code_system_code,
              t1.comments,
              t1.origsts
      )
      VALUES (
              t2.value_set_code,
              t2.display_name,
              t2.concept_code,
              t2.concept_name,
              t2.hl7table,
              t2.code_system_oid,
              t2.code_system_version,
              t2.code_system_code,
              t2.comments,
              t2.origsts
      );
*/
/*---------------------------------------------------------------------------*/



