/*---------------------------------------------------------------------------*/
/*-----BulkImport_SpecimenSource_LRNB_ENV------------------------------------*/

  -----DESCRIPTION-----
    --These sets of scripts can be to syn/update the PHVS Values Set table
  ----- -----
  
  -----HISTORY-----
    --2020-10-01 JTY: Created Script
  ----- -----
/*---------------------------------------------------------------------------*/





/*-----01. Import Data--------------------------------------------------*/
  -----DESCRIPTION-----
    --Perform Import following the steps outlined below
  ----- -----
  
    -----Tables of interest-----
/*
      SELECT
        ss.spectype,
        ss.concept_code, 
        ss.concept_name, 
        ss.hl7_spec_source_code,
        ss.specimen_source,
        ss.snomedct,
        ss.snomed_description,
        ss.upload_flag,
        ss.origsts,
        '~' AS eol
        FROM specimen_sources ss 
        WHERE ss.spectype = 'LRN_Environmental' 
        ORDER BY ss.concept_code ASC
*/      
    ----- -----

  -----01. Source Envirnment-----
   --Log into the Source Environment
  ----- -----

  -----02. Extract info from Source Environment-----
  /*
      SELECT
        ss.spectype,
        ss.concept_code, 
        ss.concept_name, 
        ss.hl7_spec_source_code,
        ss.specimen_source,
        ss.snomedct,
        ss.snomed_description,
        ss.upload_flag,
        ss.origsts,
        '~' AS eol
        FROM specimen_sources ss 
        WHERE ss.spectype = 'LRN_Environmental' 
        ORDER BY ss.concept_code ASC
*/      
  ----- -----

  -----03. Export Results to file-----
    --ACTION REQUIRED: Use Export function to export results to CSV file: LoincCodes_ENV_YYYY-MM-DD.csv  
  ----- -----
  
  -----04. Connect to Target Environment-----
   --Time to log into the Target Environment to complete the remaining steps.
  ----- -----
  
  -----05. Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
--      DROP TABLE adhs_temp;
  ----- -----

  -----06. Create [adhs_temp] table-----
    --Create temp table to hold info from soucre environment
/*
    CREATE TABLE adhs_temp(
        spectype             VARCHAR2(150 CHAR),
        concept_code         VARCHAR2(20 CHAR), 
        concept_name         VARCHAR2(150 CHAR), 
        hl7_spec_source_code VARCHAR2(10 CHAR),
        specimen_source      VARCHAR2(100 CHAR),
        snomedct             VARCHAR2(20 CHAR),
        snomed_description   VARCHAR2(100 CHAR),
        upload_flag          VARCHAR2(2 CHAR),
        origsts              CHAR(1 CHAR),
        eol                  CHAR(1 CHAR)
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
*/
  ----- -----
  
  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----
  
  -----08. Clean out old stuff-----
--    DELETE FROM specimen_sources ss WHERE ss.spectype = 'LRN_Environmental'
  ----- -----

  -----09. Merge/Update specimen_sources table-----
    --Here we are going to update the table.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
/*
    MERGE INTO specimen_sources t1
    USING (
      SELECT DISTINCT
        tmp.spectype,
        tmp.concept_code, 
        tmp.concept_name, 
        tmp.hl7_spec_source_code,
        tmp.specimen_source,
        tmp.snomedct,
        tmp.snomed_description,
        tmp.upload_flag,
        tmp.origsts,
        tmp.eol
        FROM adhs_temp tmp
        WHERE tmp.spectype = 'LRN_Environmental' 
        ORDER BY tmp.concept_code ASC
    ) t2
    ON (1=1
        AND t1.spectype = t2.spectype
        AND t1.concept_code = t2.concept_code
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.concept_name = t2.concept_name, 
        t1.hl7_spec_source_code = t2.hl7_spec_source_code,
        t1.specimen_source = t2.specimen_source,
        t1.snomedct = t2.snomedct,
        t1.snomed_description = t2.snomed_description,
        t1.upload_flag = t2.upload_flag,
        t1.origsts = t2.origsts
    WHEN NOT MATCHED THEN
      INSERT (
        t1.spectype,
        t1.concept_code, 
        t1.concept_name, 
        t1.hl7_spec_source_code,
        t1.specimen_source,
        t1.snomedct,
        t1.snomed_description,
        t1.upload_flag,
        t1.origsts
      )
      VALUES (
        t2.spectype,
        t2.concept_code, 
        t2.concept_name, 
        t2.hl7_spec_source_code,
        t2.specimen_source,
        t2.snomedct,
        t2.snomed_description,
        t2.upload_flag,
        t2.origsts
      )
*/
  ----- -----
  
  -----10. Done-----
    --Done with Syncing the FieldNames
  ----- -----

/*---------------------------------------------------------------------------*/
