

/*----------BulkLoad HL7 Generator-------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Scripts provided here can be used to bulk load samples into the HL7 Generator
    --application for re-transmitting messages to the identified program.  The
    --following scripts are included:
      --01. By DateRange and Tests List
      --02. By Imported Sample List
  /*----- -----*/
  
  /*-----HISTORY-----*/
    --2020.10.30 JTY: Created Script file
  /*----- -----*/
  
/*---------------------------------------------------------------------------*/



/*-----01. By DateRange and Test List----------------------------------------*/
  -----Referenced Tables----- 
/*
   SELECT * FROM HL7_GENERATOR_POOL;
*/   
  ----- -----
  
  -----01. Review identified samples-----
  /*
    SELECT DISTINCT
      f.apprdate,
      f.external_id,
      f.testgroupname,
      ot.testno,
      f.folderno,
      ('PHLIP Backload SET-' || '&SetNumber' || ': ' || CHR(13) || 
       '&StartDate' || ' to ' || '&EndDate') AS comments,
      'PHLIP' AS interface_id,
      'StartDelivery' AS workflowstep,
      ('PHLIP-Backload ' || '&SetNumber') AS validationset,
      'YODERJ' AS usrnam,
      'N' AS origsts
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask OT on (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      --Selection Criteria--
      AND ot.testno IN (&TestList)
      AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      -- --      
      AND mr.field_varchar_80 IN ('Diagnostic')
--      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P')
    ORDER BY
      f.folderno ASC,
      f.apprdate ASC;
*/      
  ----- -----

  -----02. Update HL7_GENERATOR_POOL table-----
  /*
    MERGE INTO hl7_generator_pool t1
    USING (
    SELECT DISTINCT
      cr.rasclientid,
      f.apprdate,
      f.external_id,
      f.folderno,
      f.testgroupname,
      'N' AS origsts,
      ('PHLIP Backload SET-' || '&SetNumber' || ': ' || CHR(13) || 
       '&StartDate' || ' to ' || '&EndDate') AS comments,
      'YODERJ' AS usrnam,
      sysdate AS last_updated,
      'PHLIP' AS interface_id,
      'StartDelivery' AS workflowstep,
      ('PHLIP-Backload ' || '&SetNumber') AS validationset,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask OT on (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      --Selection Criteria--
      AND ot.testno IN (&TestList)
      AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      -- --      
      AND mr.field_varchar_80 IN ('Diagnostic')
--      AND cr.rasclientid NOT IN ('ADHS', 'ASL-P')
    ORDER BY
      f.external_id ASC,
      f.folderno ASC,
      f.apprdate ASC
    ) t2
    ON (1=1
        AND t1.external_id = t2.external_id
        AND t1.folderno = t2.folderno
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.usrnam = t2.usrnam,
        t1.comments = t2.comments,
        t1.last_updated = t2.last_updated,
        t1.interface_id = t2.interface_id,
        t1.workflowstep = t2.workflowstep,
        t1.validationset = t2.validationset,
        t1.origsts = t2.origsts        
    WHEN NOT MATCHED THEN
      INSERT (
        t1.external_id,
        t1.folderno,
        t1.comments,
        t1.interface_id,
        t1.last_updated,
        t1.workflowstep,
        t1.validationset,
        t1.usrnam,
        t1.origsts
      )
      VALUES (
        t2.external_id,
        t2.folderno,
        t2.comments,
        t2.interface_id,
        t2.last_updated,
        t2.workflowstep,
        t2.validationset,
        t2.usrnam,
        t2.origsts
      )
*/      
  ----- -----  
  
/*---------------------------------------------------------------------------*/







/*-----02. By Imported Sample List-------------------------------------------*/
  --Import a CSV file containing list of ExternalID (Accession Numbers)
  --into a temp database table then insert these samples into the Sample Pool
  --table for messaging.


  -----05. Drop [adhs_temp] Table-----
/*    
    --If table exists already we want to drop it, who knows what's in it. 
      DROP TABLE adhs_temp;
*/      
  ----- -----

  -----06. Create [adhs_temp] table-----
/*  
    --Create temp table to hold info from soucre environment
    CREATE TABLE adhs_temp(
      external_id         VARCHAR2(30 CHAR) not null
    )
    TABLESPACE DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage(
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
*/      
  ----- -----

  -----07. Date Import into ADHS_TEMP -----
    --ACTION REQUIRED: Use the TextImport tool to import the CSV file into ADHS_TEMP table.
  ----- -----

  -----08. Merge/Upate LOINC CODE table-----
    --Here we are going to update the LOINC codes.  You can
    --Select the Using SQL part to preview the data comming in before
    --executing the Merge.
/*
    MERGE INTO hl7_generator_pool t1
    USING (
    SELECT DISTINCT
      cr.rasclientid,
      f.apprdate,
      f.external_id,
      f.folderno,
      f.testgroupname,
      'N' AS origsts,
      ('2020-10-30 Phone Backload for PHLIP') AS comments,
      'YODERJ' AS usrnam,
      sysdate AS last_updated,
      'PHLIP' AS interface_id,
      'StartDelivery' AS workflowstep,
      ('PHLIP-Backload ' || 'Phone') AS validationset,
      '~' AS eol
    FROM adhs_temp atemp
      INNER JOIN centralreceiving cr ON (atemp.external_id = cr.external_id)
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask OT on (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      --Selection Criteria--
        --AND ot.testno IN (&TestList)
        --AND f.apprdate BETWEEN to_date('&StartDate', 'DD-MON-YYYY') AND to_date('&EndDate', 'DD-MON-YYYY')
      -- --      
      AND mr.field_varchar_80 IN ('Diagnostic')
      --AND cr.rasclientid NOT IN ('ADHS', 'ASL-P')
    ORDER BY
      f.external_id ASC,
      f.folderno ASC,
      f.apprdate ASC
    ) t2
    ON (1=1
        AND t1.external_id = t2.external_id
        AND t1.folderno = t2.folderno
        )
    WHEN MATCHED THEN
      UPDATE SET
        t1.usrnam = t2.usrnam,
        t1.comments = t2.comments,
        t1.last_updated = t2.last_updated,
        t1.interface_id = t2.interface_id,
        t1.workflowstep = t2.workflowstep,
        t1.validationset = t2.validationset,
        t1.origsts = t2.origsts        
    WHEN NOT MATCHED THEN
      INSERT (
        t1.external_id,
        t1.folderno,
        t1.comments,
        t1.interface_id,
        t1.last_updated,
        t1.workflowstep,
        t1.validationset,
        t1.usrnam,
        t1.origsts
      )
      VALUES (
        t2.external_id,
        t2.folderno,
        t2.comments,
        t2.interface_id,
        t2.last_updated,
        t2.workflowstep,
        t2.validationset,
        t2.usrnam,
        t2.origsts
      )
*/      
  ----- -----
  
  -----09. Done-----
    --Done with Syncing the LOINC Codes
  ----- -----
 
/*---------------------------------------------------------------------------*/
