

-----IdentifyHL7ProgramTests------------------------------------------

  -----DESCRIPTION-----
    --Identify what tests are associated with the programs we are 
    --currently reporting
  ----- -----
  
 
  -----HISTORY-----
    --2019.10.08 JTY: Created Script
  ----- -----
----------------------------------------------------------------------




----------------------------------------------------------------------

  WITH
    -----ActiveTests-----
      ActiveTests AS (
        SELECT DISTINCT
          t.testcatcode,        
          ctt.dept,
          (t.testno || ' (' || t.testcode || ')') AS test_name,
          t.testflag AS test_type,
          t.testcode,
          '~' AS eol
        FROM tests t
          INNER JOIN conditiontesttriggers ctt ON (t.testcode = ctt.testcode)
          INNER JOIN sp_tests sp ON (ctt.testcode = sp.testcode AND sp.active = 'A')
          
        WHERE 1=1
          AND t.testcatcode IN (
          'Bacteriology', 'BioTerrorism', 'Clinical',
          'Environmental', 'Food/Miscellaneous', 'Mycobacteriology',
          'Parasitology', 'Serology', 'Virology')
       ORDER BY
         t.testcatcode ASC,
         ctt.dept ASC,
         test_name ASC
      ),
    ----- -----
    
    -----PhlipFlu-----
      PhlipFlu AS (
        SELECT DISTINCT
          'PHLIP' AS program,
          act.testcatcode,        
          act.dept,
          act.test_name,
          act.test_type,
          act.testcode,
          act.eol
        FROM ActiveTests act
          INNER JOIN hl7_dist_loincs dl ON (act.testcode = dl.testcode)        
        WHERE 1=1
        ORDER BY
          act.testcode ASC
      ),
    ----- -----   
    
    -----LrnB-----
      LrnB AS (
        SELECT DISTINCT
          'LRN-B' AS program,
          act.testcatcode,        
          act.dept,
          act.test_name,
          act.test_type,
          act.testcode,
          act.eol
        FROM ActiveTests act
          INNER JOIN hl7_analytes ha ON (1=1
            AND act.testcode = ha.testcode
            AND ha.rasclientid = 'CDC')
        WHERE 1=1
        ORDER BY
          act.testcode ASC
      ),
    ----- -----
    
    -----MEDSIS-----
      Medsis AS (
        SELECT DISTINCT
          'MEDSIS' AS program,
          act.testcatcode,        
          act.dept,
          act.test_name,
          act.test_type,
          act.testcode,
          act.eol
        FROM ActiveTests act
          INNER JOIN hl7_analytes ha ON (1=1
            AND act.testcode = ha.testcode
            AND ha.rasclientid = 'MEDSIS')
        WHERE 1=1
        ORDER BY
          act.testcode ASC
      ),
    ----- -----
    -----MEDSIS-TEST-----
      MedsisTest AS (
        SELECT DISTINCT
          'MEDSIS-TEST' AS program,
          act.testcatcode,        
          act.dept,
          act.test_name,
          act.test_type,
          act.testcode,
          act.eol
        FROM ActiveTests act
          INNER JOIN hl7_analytes ha ON (1=1
            AND act.testcode = ha.testcode
            AND ha.rasclientid = 'MEDSIS')
        WHERE 1=1
        ORDER BY
          act.testcode ASC
      ),
    ----- -----
    -----NoProgram-----
      NoProgram AS (
        SELECT DISTINCT
          '-None-' AS program,
          act.testcatcode,        
          act.dept,
          act.test_name,
          act.test_type,
          act.testcode,
          act.eol
        FROM ActiveTests act
          LEFT OUTER JOIN PhlipFlu pf ON (act.testcode = pf.testcode)
          LEFT OUTER JOIN LrnB lb  ON (act.testcode = lb.testcode)
          LEFT OUTER JOIN Medsis md ON (act.testcode = md.testcode)
          LEFT OUTER JOIN MedsisTest mt ON (act.testcode = mt.testcode)          
        WHERE 1=1
          AND ( 1=1
          AND pf.testcode IS NULL 
          AND lb.testcode IS NULL
          AND md.testcode IS NULL
          AND mt.testcode IS NULL
          )
        ORDER BY
          act.testcode ASC
      ),
    ----- -----    

    -----UnionTables-----
      UnionTables AS (
        (SELECT * FROM PhlipFlu)
        UNION  (SELECT * FROM LrnB)
        UNION  (SELECT * FROM Medsis)
        UNION  (SELECT * FROM MedsisTest)
        UNION  (SELECT * FROM NoProgram)
      )
    ----- -----
    -----FinalQuery-----
      SELECT DISTINCT
f.external_id,
        ut.program,
        f.testgroupname,        
        ut.testcatcode,        
        ut.dept,
        ut.test_name,
        ut.test_type,
        ut.testcode,
        ut.eol
       FROM UnionTables ut
         INNER JOIN ordtask ot ON (ot.testcode = ut.testcode)
         INNER JOIN folders f ON (ot.folderno = f.folderno)
       WHERE 1=1
AND f.external_id IN (
'AZ20000121',
'AZ20000120',
'AZ20000119',
'AZ20000094',
'AZ20000096',
'AZ20000095',
'AZ20000109',
'AZ20000108',
'AZ20000110',
'AZ20000111',
'AZ20000112',
'AZ20000114',
'AZ20000113',
'AZ20000115',
'AZ20000116',
'AZ20000118',
'AZ20000117',
'AZ20000116',
'AZ20000118',
'AZ20000117',
'AZ20000091',
'AZ20000105',
'AZ20000106',
'AZ20000104',
'AZ20000107',
'AZ20000103',
'AZ20000102',
'AZ20000101',
'AZ20000100',
'AZ20000099',
'AZ20000098',
'AZ20000097',
'AZ20000093',
'AZ20000092'
)       
AND ut.program <> '-None-'       
       ORDER BY
f.external_id ASC,
        ut.program ASC,
        ut.testcatcode ASC,        
        ut.dept ASC,
        ut.test_name ASC,
        ut.test_type,
        ut.testcode,
        ut.eol
      ----- -----


----------------------------------------------------------------------
