
/*-----WhereIsItAt-----------------------------------------------------------*/
  -----DESCRIPTION-----
    --This set of queries will be used to help determine where in the sample
    --lifecycle the sample is located.  We will uses this as a foundation
    --for the WhreIsItAt application in STARLiMS
      --005. Sample Pre Login
      --010. Receive Prelogged
      --015. Clinical Data Entry
      --020. My Teams Pending Test
      --025. Run Approval
      --030. Micro Run Setup/Batch Results      
      --035. Micro Results Entry
      --040. Samples for Shipment
      --045. Outsource Samples Results Entry        
      --050. Preliminary Release By Panel
      --055. Release By Panel
      --060. Report Delivery Queue
  ----- -----

  ----- HISTORY-----
    --2019.09.27 JTY: Tweak FolderInfo to capture samples that have not had RASCLIENT
    --                assocaited with them yet.
    --2019.01.23 JTY: Addition of "Micro Run Setup/Batch Results"
    --2019.01.15 JTY: Version2 - Modified for sample ID
    --2019.01.14 JTY: Begin development of scripts
  ----- -----

/*---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------*/
  WITH
    -----000. FolderInfo-----  
      FolderInfo AS (
        SELECT DISTINCT
          f.dept,
          f.external_id,
          (coalesce(rc.compname, 'No Client Selected') || ' (' || rc.rasclientid || ')') AS client_name,
          f.folderno,
          f.testgroupname,
          f.apprdate,
          '~' AS eol
        FROM folders f
          INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
          LEFT OUTER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
        WHERE 1=1
          AND f.external_id IN (&SampleList)
      ),
    ----- -----
    -----005. PreLogged-----
      PreLogged AS (
        SELECT DISTINCT
          '005' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Sample Pre Login' AS sample_location,
          ---Properties---
            'Central Receiving Status' AS property01_name,
            cr.status AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN centralreceiving cr ON (fi.external_id = cr.external_id)
        WHERE 1=1
          AND (cr.status IN ('Draft', 'Requested', 'HL7 Pending')
               AND cr.prelogged = 'Y'
               AND cr.status <> 'DBDE')
          OR (cr.status IN ('Prelogged')
              AND EXISTS (
                  SELECT mr.ORIGREC 
                  FROM metadata_repository mr
                  WHERE 1=1
                    AND mr.ORIGINAL_ORIGREC = cr.ORIGREC
                    AND mr.TABLEREFERENCE = 'CENTRALRECEIVING'
                    AND mr.FIELD_VARCHAR_89 = 'Y' 
                    AND mr.FIELD_VARCHAR_90 = 'Receiving'))
      ),
    ----- -----
    -----010. ReceivePrelogged-----
      ReceivePrelogged AS (
        SELECT DISTINCT
          '010' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Received Prelogged' AS sample_location,
          ---Properties---
            'Central Receiving Status' AS property01_name,
            cr.status AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN centralreceiving cr ON (fi.external_id = cr.external_id)
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
        WHERE 1=1
          AND cr.status IN('Prelogged', 'Requested', 'HL7 Pending')  
          AND cr.status <> 'DBDE'  
          AND NOT EXISTS(
              SELECT mr.origrec
              FROM metadata_repository mr
              WHERE 1=1
                AND mr.original_origrec = cr.origrec
                AND mr.tablereference = 'CENTRALRECEIVING'
                AND mr.field_varchar_89 = 'Y')
      ),
    ----- -----
    -----015.ClinicalDataEntry-----
      ClinicalDataEntry AS (
        SELECT DISTINCT
          '015' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Clinical Data Entry' AS sample_location,
          ---Properties---
            '' AS property01_name,
            '' AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN centralreceiving cr ON (fi.external_id = cr.external_id)
        WHERE 1=1
          AND cr.dataentrystatus IN ('ReceiveDone', 'LoginDone', 'Pending')
          AND cr.status  <> 'DBDE' 
          AND cr.status <> 'Temp'
      ),
    ----- -----
    -----020. MyTeamsPendingTest-----
      MyTeamsPendingTest AS (
        SELECT DISTINCT
          '020' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'My Teams Pending Test' AS sample_location,
          ---Properties---
            'Test Name' AS property01_name,
            (t.testno || ' (' || t.testcode || ')') AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          AND ot.ts IN ('Logged','Active')
          AND t.testtype IN ('Multi','Single')
          AND t.testflag <> 'Micro'
          AND ot.qctype = 'N/A'
          AND (ot.outsourceordno IS NULL
         OR EXISTS (
             SELECT oo.origrec
             FROM outsourceorders oo
             WHERE 1=1
               AND oo.outsourceordno = ot.outsourceordno
               AND oo.status = 'Received')
        ) 
      ),
    ----- -----
    -----025. RunApproval-----
      RunApproval AS (
        SELECT DISTINCT
          '025' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Run Approval' AS sample_location,
          ---Properties---
            'Test Name' AS property01_name,
            (t.testno || ' (' || t.testcode || ')') AS property01_value,
            'Run Number' AS property02_name,
            TO_CHAR(ot.runno, '99999') AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          AND fi.external_id IS NOT NULL
          AND t.testtype IN ('Multi','Single')
          AND ot.tsa IN ('RTR','RTROOS')    
          AND ((EXISTS(
              SELECT r.origrec
              FROM runs r
              WHERE 1=1
                AND r.runno = ot.runno
                AND r.runindicator='Manual' 
                AND r.runstatus='Done'
                AND r.approvalstatus IS NULL)
              )
               OR (EXISTS (
                   SELECT r.origrec
                   FROM runs r
                   WHERE 1=1
                     AND r.runno = ot.runno
                     AND r.runindicator <> 'Manual'))
             )
      ),
    ----- -----
    -----030. Micro Run Setup/Batch Results-----
      MicroBatchResults AS (
        SELECT DISTINCT
          '030' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Micro Run Setup/Batch Results Entry' AS sample_location,
          ---Properties---
            'Test Name' AS property01_name,
            (t.testno || ' (' || t.testcode || ')') AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
          INNER JOIN microtasksteps mts ON (ot.ordno = mts.ordno)  
        WHERE 1=1
          AND mts.MICSTATUS = 'Logged'
          AND ( EXISTS(
                       SELECT t2.origrec 
                       FROM tests t2
                         INNER JOIN testwfmethods tw ON (t2.tmname = tw.tmname)
                         INNER JOIN testwfsteps tws ON (tw.tmcode = tws.tmcode)
                       WHERE 1=1
                         AND tws.stepcode = mts.stepcode
                         AND mts.testcode = t2.testcode
                         AND mts.testcode IN (SELECT mtg.testcode FROM microtestgroups mtg)
                         AND tws.entrytype = 'Batch'
                      )
                OR EXISTS(
                          SELECT mqc.origrec
                          FROM microqccontrols mqc
                          WHERE 1=1
                            AND mqc.compid = mts.COMPID 
                            AND mqc.frequency = 'By Run'
                         )
              )              
          AND ( (mts.qctype IS NULL
                 AND EXISTS (
                             SELECT ot2.origrec
                             FROM ordtask ot2
                             WHERE 1=1
                               AND mts.ordno = ot2.ordno
                               AND mts.testcode = ot2.testcode
                               AND ot2.ts NOT IN ('Prelogged','Draft')
                               AND ot2.ts = 'Logged') 
                 ) 
                 OR (mts.qctype IS NOT NULL
                    )                  
              )     
      ),
    ----- -----
    -----035. MicroResultsEntry-----
      MicroResultsEntry AS (
        SELECT DISTINCT
          '035' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Micro Results Entry' AS sample_location,
          ---Properties---
            'Test Name' AS property01_name,
            (t.testno || ' (' || t.testcode || ')') AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
          INNER JOIN orders o ON (ot.ordno = o.ordno)
          INNER JOIN microtasksteps mts ON (1=1
            AND ot.testcode = mts.testcode
            AND ot.ordno = mts.ordno)
        WHERE 1=1
          AND ot.ts NOT IN ('Prelogged','Draft')
          AND mts.micstatus = 'Logged'                                    
      ),
    ----- -----
    -----040. SamplesForShipment-----
      SamplesForShipment AS (
        (SELECT DISTINCT
           '040' AS sorter,
           fi.dept,
           fi.external_id,
           fi.client_name,
           fi.testgroupname,
           'Samples For Shipment' AS sample_location,
           ---Properties---
             'Test Name' AS property01_name,
             (t.testno || ' (' || t.testcode || ')') AS property01_value,
             'Order Number' AS property02_name,
             ot.outsourceordno AS property02_value,
             'Destination Lab' AS property03_name,
             ot.dept AS property03_value,
           --- ---
           '~' AS eol
         FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
           INNER JOIN samplecontainers sc ON (ot.ordno = sc.ordno)
           INNER JOIN samplecontainertests sct ON (sc.containerid = sct.containerid)
           INNER JOIN departments d ON (ot.dept = d.dept)
         WHERE 1=1
          AND ot.outsourceordno = 'OUTSOURCE'
          AND d.sharesdb = 'External'
          AND ot.ts = 'Logged'
          AND sc.status = 'For Shipment' 
          AND sct.testcode = ot.testcode)
         
      UNION
        
        (SELECT DISTINCT
           '035' AS sorter,
           fi.dept,
           fi.external_id,
           fi.client_name,
           fi.testgroupname,
           'Samples For Shipment' AS sample_location,
           ---Properties---
             'Test Name' AS property01_name,
             (t.testno || ' (' || t.testcode || ')') AS property01_value,
             'Order Number' AS property02_name,
             ot.outsourceordno AS property02_value,
             'Destination Lab' AS property03_name,
             ot.dept AS property03_value,
           --- ---
           '~' AS eol
         FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
           INNER JOIN outsourceorders oso ON (ot.outsourceordno = oso.outsourceordno)
           INNER JOIN departments d ON (oso.dept = d.dept)
         WHERE 1=1
           --AND d.sharesdb = 'Shares DB'
           AND (oso.status NOT IN ('Shipped', 'Received', 'Done') 
                OR oso.status IS NULL)
           AND ot.ts = 'Logged' 
           AND ot.outsourceordno <> 'OUTSOURCE')
      ),
    ----- -----
    -----045. OutsourceSamplesResultsEntry-----
      OutsourceSamplesResultsEntry AS (
        SELECT DISTINCT
          '045' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Outsource Samples Results Entry' AS sample_location,
          ---Properties---
            'Test Name' AS property01_name,
            (t.testno || ' (' || t.testcode || ')') AS property01_value,
            'Order Number' AS property02_name,
            ot.outsourceordno AS property02_value,
            'Destination Lab' AS property03_name,
            ot.dept AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
           INNER JOIN departments d ON (ot.dispdept = d.dept)
           INNER JOIN outsourceorders oso ON (ot.outsourceordno = oso.outsourceordno)    
        WHERE 1=1
          AND oso.status IN ('Shipped','Received')
      ),
    ----- -----
    -----050. PrelimReleaseByPanel-----
      PrelimReleaseByPanel AS (
        SELECT DISTINCT
          '050' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Prelim Release By Panel' AS sample_location,
          ---Properties---
            '' AS property01_name,
            '' AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN foldercondition fc ON (f.folderno = fc.folderno)
          INNER JOIN testgroup_users tgu ON (f.testgroupname = tgu.testgroupname)
        WHERE 1=1
          AND fc.status NOT IN ('Done','OOS','Cancel')
          AND fc.approvalstatus IS NULL
          AND f.need_preliminary = 'Y'
          AND NOT EXISTS(
              SELECT cr.origrec
              FROM centralreceiving cr
              WHERE 1=1
                AND cr.external_id LIKE (fi.external_id || '%')
                AND (cr.dataentrystatus <> 'ReleaseDone' OR cr.dbdestatus = 'Conflict'))
         AND NOT EXISTS(
             SELECT 1
             FROM ordtask ot2
               INNER JOIN runs r ON (ot2.runno = r.runno)
             WHERE 1=1
               AND r.approvalstatus IS NULL
               AND ot2.folderno = f.folderno
               AND r.microtestgroup IS NULL)
      ),
    ----- -----
    -----055. ReleaseByPanel-----
      ReleaseByPanel AS (
        SELECT DISTINCT
          '055' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Release By Panel' AS sample_location,
          ---Properties---
            '' AS property01_name,
            '' AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON (fi.folderno = f.folderno)
          INNER JOIN foldercondition fc ON (fi.folderno = fc.folderno)
          INNER JOIN testgroup_users tgu ON (f.testgroupname = tgu.testgroupname)
        WHERE 1=1
          AND fc.status IN ('Done','OOS','Cancel') 
          AND fc.approvalstatus IS NULL 
          AND f.appr_level = tgu.appr_level
          AND tgu.usrnam NOT IN (
              SELECT fel.USRNAM 
              FROM floweventlog fel
              WHERE 1=1
                AND fel.folderno = fi.folderno
                AND UPPER(fel.eventtype) = 'RELEASE BY PANEL' 
                AND fel.sorter IS NULL
                AND fel.appr_level <> -1) 
          AND NOT EXISTS(
              SELECT cr.origrec
              FROM centralreceiving cr
              WHERE 1=1
                AND cr.external_id LIKE (fi.External_Id || '%') 
                AND (cr.dataentrystatus <> 'ReleaseDone' 
                     OR cr.dbdestatus = 'Conflict'))
          AND NOT EXISTS(
               SELECT ot.origrec
               FROM ordtask ot 
               WHERE 1=1
                 AND (ot.tsa <> 'Released' OR ot.tsa IS NULL) 
                 AND fi.folderno = ot.folderno)
      ),
    ----- -----
    -----060. ReportDeliveryQueue-----
      ReportDeliveryQueue AS (
        SELECT DISTINCT
          '060' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Report Delivery Queue' AS sample_location,
          ---Properties---
            'BatchID' AS property01_name,
            TO_CHAR(rdq.batch_id) AS property01_value,
            'ItemNumber' AS property02_name,
            TO_CHAR(rdq.queue_item_no) AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
           INNER JOIN rr_report_delivery_queue rdq ON (fi.folderno = rdq.folderno)
        WHERE 1=1
          AND rdq.status = 'QUEUED'
      ),
    ----- -----
    -----065. ReleasedSamples-----
      ReleasedSamples AS (
        SELECT DISTINCT
          '065' AS sorter,
          fi.dept,
          fi.external_id,
          fi.client_name,
          fi.testgroupname,
          'Released Samples' AS sample_location,
          ---Properties---
            'Folder Approved Date' AS property01_name,
            TO_CHAR(fi.apprdate, 'YYYY-MM-DD') AS property01_value,
            'Approved By' AS property02_name,
            f.approvedby AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
          INNER JOIN folders f ON fi.folderno = f.folderno
        WHERE 1=1
          AND fi.apprdate IS NOT NULL
      ),
    ----- -----
    -----UnionTables-----
      UnionTables AS (
      (SELECT * FROM PreLogged)
      UNION (SELECT * FROM ReceivePrelogged)
      UNION (SELECT * FROM ClinicalDataEntry)
      UNION (SELECT * FROM MyTeamsPendingTest)
      UNION (SELECT * FROM RunApproval)
      UNION (SELECT * FROM MicroBatchResults)      
      UNION (SELECT * FROM MicroResultsEntry)
      UNION (SELECT * FROM SamplesForShipment)
      UNION (SELECT * FROM OutsourceSamplesResultsEntry)
      UNION (SELECT * FROM PrelimReleaseByPanel)
      UNION (SELECT * FROM ReleaseByPanel)
      UNION (SELECT * FROM ReportDeliveryQueue)
      UNION (SELECT * FROM ReleasedSamples)
      )
    ----- -----
    -----FinalQuery-----
      SELECT DISTINCT
        ut.external_id,
        ut.sorter,
        ut.client_name,
        ut.dept,
        ut.testgroupname,
        ut.sample_location,
        ut.property01_name,
        ut.property01_value,
        ut.property02_name,
        ut.property02_value,
        ut.property03_name,
        ut.property03_value,
        ut.eol
       FROM UnionTables ut
       ORDER BY
        ut.external_id ASC,
        ut.sorter ASC,
        ut.dept ASC,
        ut.testgroupname ASC,
        ut.property01_value ASC,
        ut.property02_value ASC,
        ut.property03_value ASC;
    ----- -----




/*---------------------------------------------------------------------------*/



    -----NextItem-----
/*    
      NextItem AS (
        SELECT DISTINCT
          'XXX' AS sorter,
          fi.dept,
          fi.external_id,
          fi.testgroupname,
          'XXXXXXXXXXXXXXXX' AS sample_location,
          ---Properties---
            '' AS property01_name,
            '' AS property01_value,
            '' AS property02_name,
            '' AS property02_value,
            '' AS property03_name,
            '' AS property03_value,
          --- ---
          '~' AS eol
        FROM FolderInfo fi
           INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
           INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          XXXXXXX
        ORDER BY
          fi.dept ASC,
          fi.external_id ASC,
          fi.testgroupname ASC,
          property01_value ASC,
          property02_value ASC,
          property03_value ASC
      ),
*/
    ----- -----
       
