/*
-----Multiple External Contacts--------------------------------------------
  -----DESCRIPTION-----
    V12: It appears that if you change the submitting organization in the 
    accessioning screen, the external contacts information for the original
    submitting organization is not revmoved, so you can end up having multiple
    external contacts assocated with the sample.  The net result of this is that
    you will generate multiple reports for each of the identified external contacts.
    
    Utilize the script below to align the external contact with the current 
    submitting orginization.
  ----- -----
  
  -----HISTORY-----
    2019.12.16 JTY: Created Script
  ----- -----

---------------------------------------------------------------------------
*/

-----01. Identify Records to fix-------------------------------------------
  --Identify records that have multiple external contacts that are not from
  --the same organization (RasClientID).

  SELECT DISTINCT
    cr.external_id,
    cr.rasclientid,
    fc.rasclientid AS wrong_contact,
    fc.submit_method AS wrong_deliverymethod,   
    (fc.rasclientid || ' ---> ' || fc2.rasclientid) AS rasclients,    
    cr.date_received,
    f.apprdate,
    fc.origrec AS wrong_fc_origrec, 
    '~' AS eol
  FROM centralreceiving cr
    INNER JOIN folders f ON (cr.external_id = f.external_id)
    INNER JOIN folderscontactsext fc ON (f.folderno = fc.folderno)
    LEFT OUTER JOIN folderscontactsext fc2 ON (f.folderno = fc2.folderno)
  WHERE 1=1
  --  AND cr.external_id = 'AZ00093080'
    AND fc.contactid <> fc2.contactid
    AND cr.rasclientid <> fc.rasclientid
  ORDER BY
    cr.external_id DESC;

---------------------------------------------------------------------------



-----02. Perform fix-------------------------------------------------------
  --
/*

    MERGE INTO folderscontactsext t1
    USING (
      SELECT DISTINCT
        cr.external_id,
        cr.rasclientid,
        fc.rasclientid AS wrong_contact,
        fc.submit_method AS wrong_deliverymethod,   
        (fc.rasclientid || ' ---> ' || fc2.rasclientid) AS rasclients,    
        cr.date_received,
        f.apprdate,
        fc.origrec AS wrong_fc_origrec, 
        '~' AS eol
      FROM centralreceiving cr
        INNER JOIN folders f ON (cr.external_id = f.external_id)
        INNER JOIN folderscontactsext fc ON (f.folderno = fc.folderno)
        LEFT OUTER JOIN folderscontactsext fc2 ON (f.folderno = fc2.folderno)
      WHERE 1=1
      --  AND cr.external_id = 'AZ00093080'
        AND fc.contactid <> fc2.contactid
        AND cr.rasclientid <> fc.rasclientid
      ORDER BY
        cr.external_id DESC
    ) t2
      ON (t1.origrec = t2.wrong_fc_origrec)
    WHEN MATCHED THEN
      UPDATE SET t1.Rasclientid = t2.wrong_contact
      DELETE WHERE (t1.origrec = t2.wrong_fc_origrec)
*/


---------------------------------------------------------------------------
