/*
-----OrdTask Flag Issues---------------------------------------------------
  -----DESCRIPTION-----
    Identify samples that may have conflicts with the various flags in the
    OrdTask table that may make the sample disapear from the normal starlims
    flow.
  ----- -----
  
  -----HISTORY-----
    2019.12.12 JTY Create SQL
  ----- -----

---------------------------------------------------------------------------
*/
  SELECT DISTINCT
          fi.dept,
          fi.external_id,
--          fi.client_name,
          fi.testgroupname,
          'OrtTask Flags Conflict' AS sample_issue,
            t.testno,
            ot.origrec AS ot_origrec,
            ot.apprdate,
            ot.ts,
            ot.tsa,
            ot.tsadisp,
          '~' AS eol
        FROM folders fi
          INNER JOIN ordtask ot ON (fi.folderno = ot.folderno)
          INNER JOIN tests t ON (ot.testcode = t.testcode)
        WHERE 1=1
          AND fi.external_id IS NOT NULL
AND fi.external_id IN ('AZ00097336')
          AND ot.apprdate IS NOT NULL          
          AND (
               ot.tsa <> ot.tsadisp
               OR ot.tsa NOT IN ('Released', 'Cancel')
               OR ot.ts NOT IN ('OOS', 'Done', 'Cancel')  
          )
ORDER BY
  ot.apprdate DESC,
  fi.external_id DESC;
  
---------------------------------------------------------------------------
---------------------------------------------------------------------------


-----FIX FLAGS-------------------------------------------------------------
/*
  MERGE INTO ordtask t1
  USING (
    SELECT DISTINCT
      f.dept,
      f.external_id,
      f.testgroupname,
      'OrtTask Flags Conflict' AS sample_issue,
      t.testno,
      ot.origrec AS ot_origrec,
      ot.apprdate,
      ot.ts,
      ot.tsa,
      ot.tsadisp,
      '~' AS eol
    FROM folders f
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN tests t ON (ot.testcode = t.testcode)
    WHERE 1=1
      AND f.external_id IS NOT NULL
      AND ot.apprdate IS NOT NULL
      AND ((ot.tsa IS NOT NULL) AND (ot.tsadisp IS NOT NULL))
      AND (
        ot.tsa <> ot.tsadisp
        OR ot.tsa NOT IN ('Released', 'Cancel')
        OR ot.ts NOT IN ('OOS', 'Done', 'Cancel')
      )
    ORDER BY
      ot.apprdate DESC,
      f.external_id DESC
  
  
  ) t2
  ON (t1.origrec = t2.ot_origrec)
  WHEN MATCHED THEN
    UPDATE SET 
      t1.tsa = 'Released',
      t1.tsadisp = 'Released'
*/      
      

--UPDATE ordtask ot SET ot.ts = 'Done', ot.tsadisp = 'Released',  ot.tsa = 'Released' WHERE 1=1 AND ot.origrec = '341270'



---------------------------------------------------------------------------


