
/*-----RightFaxTroubleshooting------------------------------------------------
  -----DESCRIPTION-----
    Use this ste of queries to investigate issues with RightFax.  Queries Include:
      1. GetFaxDetails - Get detail information on faxes for samples.
      2. DaysFaxReview - Review faxes for the day
      3. ClientFailedFaxes - Display list of failed faxes associated with client     
      4. Fix Fax Queue for Sample - Clean up queue for sample that has been resolved.
  ----- -----



  -----HISTORY-----
    2020.04.03 JTY: Updated to include Fix Fax Queue script
    2019.02.15 JTY: Created scripts.
  ----- -----

-----------------------------------------------------------------------------*/







/*-----01. GetFaxDetails-----------------------------------------------------*/
  --Get details on faxes for identified samples
/*
    SELECT DISTINCT
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
      f.dept,
      f.apprdate,
      (rdq.delivery_method || ' (' || rdq.delivery_address || ')') AS delivery_method,
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      fq.statusname,
      fq.receipt AS fax_receipt,      
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,
      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
    AND cr.rasclientid = 'ADJC-2800'
      AND cr.external_id IN (&ExternalIDList)
     AND cr.external_id <> 'AZ00049294'
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      f.apprdate DESC,
      client_name ASC,       
      cr.external_id ASC;
*/
  /*---------------------------------------------------------------------------*/


/*-----02. DaysFaxReview-------------------------------------------------------*/
  --Get Review faxes for the specified day.
/*  
    SELECT DISTINCT
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      rdh.sent_date,
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
rdq.delivery_method,      
      fq.tofax AS to_fax,
      fq.statusname,
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,
      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      fq.postdate,
      fq.origrec,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
      AND rdq.delivery_method = 'Fax'
      AND TO_DATE(rdh.sent_date, 'DD-MON-YY') =  TO_DATE('&CheckDate', 'DD-MON-YY') 
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      fq.postdate ASC;
*/  
  /*---------------------------------------------------------------------------*/
  
  /*-----03. ClientFailedFaxes-------------------------------------------------*/
  
  --Display list of failed faxes associated with client
/*  
    SELECT DISTINCT
      TO_CHAR(fq.postdate, 'DD-MON-YYYY HH:MM:SS  AM') AS post_timestamp,
      rdh.sent_date,
      (rc.compname || ' (' || rc.rasclientid || ')') AS client_name,
      cr.external_id,
      fq.tofax AS to_fax,
      fq.statusname,
      (TO_CHAR(rdq.batch_id) || '-> ' || TO_CHAR(rdq.queue_item_no)) AS batch_queueItem,
      (fq.errorname || '-> ' || fq.crtmessage) AS error_details,
      rc.defaultcontact,
      rc.primaryphone,
      rc.email,
      fq.postdate,
      fq.origrec,
      '~' AS eol
    FROM centralreceiving cr
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN rr_report_delivery_queue rdq ON (f.folderno = rdq.folderno)
      LEFT OUTER JOIN rr_rdq_history rdh ON (rdq.queue_item_no = rdh.queue_item_no)
      LEFT OUTER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
    WHERE 1=1
--      AND TO_DATE(rdh.sent_date, 'DD-MON-YY') =  TO_DATE('&CheckDate', 'DD-MON-YY') 
      AND rc.rasclientid = '&RasClientID'
      AND  fq.statusname <> 'fsDoneOK'
      AND rdh.origrec = (
          SELECT MAX(rdh2.origrec)
          FROM rr_rdq_history rdh2
          WHERE 1=1
            AND rdh2.queue_item_no = rdh.queue_item_no)
    ORDER BY
      fq.postdate ASC;
*/  
  /*---------------------------------------------------------------------------*/  
  
  

  /*---------------------------------------------------------------------------*/    
    --Update Fax Queue so that failed faxes are OK.  This is when you have manually
    --resent faxes via RightFax and verified they were sent.
/*
--  Review Samples of interest and get FaxQueue Origrec number
   SELECT 
     rdq.external_id,
     fq.origrec,
     fq.statusname,
     fq.errorname,
     fq.crtmessage
   FROM rr_report_delivery_queue rdq
     INNER JOIN faxqueue fq ON (rdq.receipt_number = fq.receipt)
   WHERE 1=1
     AND rdq.external_id IN (&SampleIDList)
   ORDER BY
     rdq.external_id ASC,
     fq.origrec ASC;
*/

/*
    UPDATE faxqueue fq
      SET
      fq.statusname = 'fsDoneOK',
      fq.errorname = '',
      fq.crtmessage = 'Fax sent successfully.'
    WHERE 1=1
      AND fq.origrec IN  (&FaxQueOrigrecList)
*/
  /*---------------------------------------------------------------------------*/  
