CREATE OR REPLACE VIEW TMP_ADHS_EPI_COVID AS
SELECT DISTINCT
      --
      ---Sample Information---
        cr.external_id AS sa_externalid,
        f.folderno AS sa_folderno,
        mr.field_varchar_80 AS sa_activitytype,
        cr.date_collected AS sa_datecollected,
        cr.date_received AS sa_datereceived,
        f.apprdate AS sa_dateapproved,
        f.testgroupname AS sa_panel,
        cr.sampdesc AS sa_specimendesc,
        mr.field_varchar_05 AS sa_testreason,
        cr.spec_source AS sa_spectype,
        cr.case_id AS sa_caseid,
        f.event_id AS sa_eventid,
      --- ---
      --Patient Information--
        cr.patient_id AS pi_limspid,
        cr.first_name AS pi_namefirst,
        cr.last_name AS pi_namelast,
        cr.middle_initial AS pi_namemiddle,
        cr.birth_date AS pi_dob,
        mr.field_integer_01 AS pi_age,
        cr.patient_phone AS pi_phone,
        cr.owner_address AS pi_address,
        cr.owner_state AS pi_state,
        cr.owner_county AS pi_county,
        cr.owner_city AS pi_city,
        cr.owner_zip AS pi_zip,
        cr.sex AS pi_sex,
        cr.patientrace AS pi_race,
        cr.ethnicity AS pi_ethnicity,
        mr.field_date_01 AS pi_dateexposure,
        cr.onset_date AS pi_dateonset,
        mr.field_varchar_03 AS pi_symptoms,
        mr.field_varchar_01 AS pi_physician,
        cr.pid AS pi_submitter_pid,
      --- ---
      ---Submitter Information (RasClient)---
        rc.rasclientid AS rc_rasclientid,
        rc.compname AS rc_compname,
        rc.category AS rc_category,
        rc.adress AS rc_address_01,
        rc.adress_a AS rc_address_02,
        rc.state AS rc_state,
        rc.county AS rc_county,
        rc.city AS rc_city,
        rc.zip AS rc_zip,
        rc.defaultcontact AS rc_contact,
        rc.primaryphone AS rc_Phone,
      --- ---
      ---Provider Information---
        mr.field_varchar_20 AS pr_providername,
        mr.field_varchar_21 AS pr_facilityname,
        mr.field_varchar_22 AS pr_address,
        mr.field_varchar_23 AS pr_city,
        mr.field_varchar_24 AS pr_state,
        mr.field_varchar_25 AS pr_zip,
        mr.field_varchar_26 AS pr_county,
        mr.field_varchar_27 AS pr_phone,
      --- ---
      ---Test Information---
        ot.testno AS ti_testname,
        ot.apprdate AS ti_testcompleted,
        r.final AS ti_final,
        r.conclusion AS ti_conclusion,
      --- ---
      ---EPI Questions---
      '~' AS epi,
      mr.field_varchar_201 AS epi_firstest,
      mr.field_varchar_202 AS epi_emphealthcare,
      mr.field_varchar_203 AS epi_sympomatic,
      mr.field_varchar_204 AS epi_admitted,
      mr.field_varchar_205 AS epi_icu,
      mr.field_varchar_206 AS epi_conregetresident,
      mr.field_varchar_207 AS epi_pregnate,
      mr.field_varchar_210 AS epi_empfoolhandler,
      mr.field_varchar_211 AS epi_empchildcare,
      mr.field_varchar_212 AS epi_attchildcare,
      mr.field_varchar_213 AS epi_empcongretcare,
      mr.field_varchar_214 AS epi_recenttravel,
      mr.field_varchar_215 AS epi_traveldetails,
      --- ---
      ---Cares Act Info---
      cr.date_sent AS cv_dateordered,
      tlc.loincnumber AS cv_loinc,
      mlv.text AS cv_deviceid,
      r.snomedcode AS cv_resultcodes,
      rc.organizational_oid AS cv_npi,
      'Arizona State Health Laboratory' AS cv_labname,
      '03D0641866' AS cvlabcliaid,
      '85007' AS cv_labzip,
      ss.snomedct AS cv_specsourcecode,
      --- ---
      '~' AS EOL
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
      LEFT OUTER JOIN testloinccodes tlc ON (ot.testcode = tlc.testcode)
      LEFT OUTER JOIN metadata_lookup_values mlv ON (1=1
        AND mlv.lookup_name = 'TestObservationMethodKits'
        AND ot.testcode = mlv.value
      )
      LEFT OUTER JOIN specimen_sources ss ON (1=1
        AND ss.spectype = 'Clinical'
        AND cr.spec_source = ss.specimen_source
      )
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic')
      AND ot.apprdate IS NOT NULL
      AND ot.testno IN (
          'BGI SARS-2019-nCoV RT-PCR',
          'TaqPath COVID-19 rRT-PCR',
          'Xpert Xpress SARS CoV 2',
          '2019 Novel Coronavirus rRT-PCR',
          'Influenza SARS-CoV-2 Multiplex rRT-PCR',
          'BioFire Respiratory Panel 2.1'
      )
    ORDER BY
      f.apprdate DESC,
      f.folderno ASC
      ;
