/*-----CDC COVID-19 Verify---------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Need to verify all reports have been sent to the CDC.  They have supplied
    --a spreadsheet of the samples they have received and would like us to verify    
  /*----- -----*/

  /*----- -----*/
  /*----- -----*/

  /*-----HISTORY-----*/
    --2020.06.03 JTY: Created Script
  /*----- -----*/
/*---------------------------------------------------------------------------*/



/*-----01. Create Temp Table [ADHS_Temp]-------------------------------------*/

  -----Drop [adhs_temp] Table-----
    --If table exists already we want to drop it, who knows what's in it.
--      DROP TABLE adhs_temp;
  ----- -----

  -----Create [adhs_temp] table-----
/*  
    create table ADHS_TEMP(
      folderno        VARCHAR2(40 CHAR) not null,
      sender          VARCHAR2(40 CHAR) not null,
      collection_date VARCHAR2(15 CHAR),
      test_date       VARCHAR2(15 CHAR),
      report_date     VARCHAR2(15 CHAR),
      final           NVARCHAR2(255)
    )
    tablespace DRAGONFLY
      pctfree 10
      initrans 1
      maxtrans 255
      storage
      (
        initial 64K
        next 1M
        minextents 1
        maxextents unlimited
      );
*/      
  ----- -----

/*---------------------------------------------------------------------------*/



/*---------------------------------------------------------------------------*/
  WITH 
    ---adhs_samples---
    adhs_samples AS (
      SELECT
        f.folderno,
        cr.rasclientid,
        ot.testno,
        r.final,
        cr.date_received,
        cr.date_collected,
        ot.apprdate AS test_date,
        f.apprdate AS report_date,
        '~' AS eol
      FROM folders f
        INNER JOIN ordtask ot ON (f.folderno = ot.folderno)  
        INNER JOIN centralreceiving cr ON (f.external_id = cr.external_id)
        INNER JOIN metadata_repository mr ON (1=1
          AND mr.tablereference = 'CENTRALRECEIVING'
          AND mr.original_origrec = cr.origrec
          AND mr.field_varchar_80 = 'Diagnostic')
        INNER JOIN results r ON (1=1
          AND ot.ordno = r.ordno
          AND ot.testcode = r.testcode)
        WHERE 1=1
          AND f.apprdate IS NOT NULL
          AND f.testgroupname = 'Coronavirus'
          AND ot.testno IN ('2019 Novel Coronavirus rRT-PCR', 'TaqPath COVID-19 rRT-PCR', 'Xpert Xpress SARS CoV 2')
--        AND to_date(ot.apprdate,'DD-MON-YY') BETWEEN to_date('&StartDate','DD-MON-YY') AND to_date('&EndDate0','DD-MON-YY')
      ORDER BY
        f.apprdate ASC,
        f.external_id DESC)
    --- ---   
    ---comparison---
      SELECT
        adhs.rasclientid,
        adhs.folderno,  
        adhs.testno,
        adhs.final,
        adhs.date_collected,
        adhs.test_date,
        adhs.report_date,
        tmp.report_date AS t_report,
        tmp.final AS t_final,
        tmp.collection_date AS t_coll,
        tmp.test_date AS t_test,
        '~' AS eol
      FROM adhs_samples adhs
        LEFT OUTER JOIN adhs_temp tmp ON (tmp.folderno = adhs.folderno)
      WHERE 1=1
        AND tmp.folderno IS NULL
        AND adhs.final NOT IN ('Not Tested', 'Retest')
      ORDER BY
        adhs.folderno ASC;
    --- ---
/*---------------------------------------------------------------------------*/
