CREATE OR REPLACE VIEW ADHS_EPI_COVID AS
/*-----COVID-19 EPI Extract--------------------------------------------------*/
  /*-----DESCRIPTION-----*/
    --Create this query for EPI group who wants access to summary information
    --on COVID-19 testing.  This query is restricted to COVID-19 test in 
    --the system: 
      --BGI SARS-2019-nCoV RT-PCR
      --TaqPath COVID-19 rRT-PCR
      --Xpert Xpress SARS CoV 2
      --2019 Novel Coronavirus rRT-PCR
  /*----- -----*/

  /*----- -----*/
  /*----- -----*/

  /*-----HISTORY-----*/
    --2020.07.09 JTY: Begin query creation
  /*----- -----*/
 
/*---------------------------------------------------------------------------*/




/*-----Core Query------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/
  --Currently this gets all the samples for COVID-19 testing with most of the 
  --requested fields.  Note that some COVID-19 fields are missing (ie 
  --EPI quesionts such as pregnate, etc.)
  --Also we need to determine if they want all results of anlayis, or just the
  --most recent result.
  
  
    SELECT DISTINCT
      --
      ---Sample Information---
        cr.external_id AS sa_externalid,
        f.folderno AS sa_folderno,
        mr.field_varchar_80 AS sa_activitytype,
        cr.date_collected AS sa_datecollected,
        cr.date_received AS sa_datereceived,
        f.apprdate AS sa_dateapproved,
        f.testgroupname AS sa_panel,
        cr.sampdesc AS sa_specimendesc,
        mr.field_varchar_05 AS sa_testreason,
        cr.spec_source AS sa_spectype,
        cr.case_id AS sa_caseid,
        f.event_id AS sa_eventid,
      --- ---
      --Patient Information--
        cr.patient_id AS pi_limspid,
        cr.first_name AS pi_namefirst,
        cr.last_name AS pi_namelast,
        cr.middle_initial AS pi_namemiddle,
        cr.birth_date AS pi_dob,
        mr.field_integer_01 AS pi_age,
        cr.patient_phone AS pi_phone,
        cr.owner_address AS pi_address,
        cr.owner_state AS pi_state,
        cr.owner_county AS pi_county,
        cr.owner_city AS pi_city,
        cr.owner_zip AS pi_zip,
        cr.sex AS pi_sex,
        cr.patientrace AS pi_race,
        cr.ethnicity AS pi_ethnicity,
        mr.field_date_01 AS pi_dateexposure,
        cr.onset_date AS pi_dateonset,
        mr.field_varchar_03 AS pi_symptoms,
        mr.field_varchar_01 AS pi_physician,
        cr.pid AS pi_submitter_pid,
      --- ---
      ---Submitter Information (RasClient)---
        rc.rasclientid AS rc_rasclientid,
        rc.compname AS rc_compname,
        rc.category AS rc_category,
        rc.adress AS rc_address_01,
        rc.adress_a AS rc_address_02,
        rc.state AS rc_state,
        rc.county AS rc_county,
        rc.city AS rc_city,
        rc.zip AS rc_zip,
        rc.defaultcontact AS rc_contact,
        rc.primaryphone AS rc_Phone,
      --- ---
      ---Provider Information---
        mr.field_varchar_20 AS pr_providername,
        mr.field_varchar_21 AS pr_facilityname,
        mr.field_varchar_22 AS pr_address,
        mr.field_varchar_23 AS pr_city,
        mr.field_varchar_24 AS pr_state,
        mr.field_varchar_25 AS pr_zip,
        mr.field_varchar_26 AS pr_county,    
        mr.field_varchar_27 AS pr_phone,
      --- ---    
      ---Test Information---
        ot.testno AS ti_testname,
        ot.apprdate AS ti_testcompleted,   
        r.final AS ti_final,
        r.conclusion AS ti_conclusion,
      --- ---
      '~' AS EOL
    FROM centralreceiving cr
      INNER JOIN metadata_repository mr ON (1=1
        AND mr.tablereference = 'CENTRALRECEIVING'
        AND mr.original_origrec = cr.origrec)
      INNER JOIN rasclients rc ON (cr.rasclientid = rc.rasclientid)  
      INNER JOIN folders f ON (cr.external_id = f.external_id)
      INNER JOIN ordtask ot ON (f.folderno = ot.folderno)
      INNER JOIN results r ON (1=1
        AND ot.ordno = r.ordno
        AND ot.testcode = r.testcode)
    WHERE 1=1
      AND mr.field_varchar_80 IN ('Diagnostic')
      AND ot.apprdate IS NOT NULL
      AND ot.testno IN (
          'BGI SARS-2019-nCoV RT-PCR',
          'TaqPath COVID-19 rRT-PCR', 
          'Xpert Xpress SARS CoV 2', 
          '2019 Novel Coronavirus rRT-PCR'
      )
    ORDER BY
      f.apprdate DESC,
      f.folderno ASC;
/*---------------------------------------------------------------------------*/
